@@ -35,7 +35,7 @@
 #include <QAction>
 #include <QApplication>
 #include <KMenu>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 AdviceSkroogoid::AdviceSkroogoid(QObject* iParent, const QVariantList& args)
     : Plasma::Applet(iParent, args), doc(NULL), widgetLayout(NULL)
@@ -147,7 +147,7 @@ void AdviceSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataE
         listData[adviceId] = adviceValues;
     }
 
-    //Initialisation
+    // Initialisation
     int nb = widgetLayout->count();
     for (int i = 0; widgetLayout && i < nb; ++i) {
         QGraphicsLayoutItem* item = widgetLayout->itemAt(0);
