@@ -26,7 +26,7 @@
 #include <Plasma/Label>
 #include <Plasma/ToolButton>
 #include "skgdocumentbank.h"
-#include <qgraphicslinearlayout.h>
+#include <QGraphicsLinearLayout>
 #include <QFrame>
 #include <Plasma/Frame>
 
