@@ -35,8 +35,8 @@
 #include <KPushButton>
 #include <Plasma/ToolButton>
 #include <Plasma/Frame>
-#include <kmessagebox.h>
-#include <qgraphicsscene.h>
+#include <KMessageBox>
+#include <QGraphicsScene>
 
 BankSkroogoid::BankSkroogoid(QObject* iParent, const QVariantList& args)
     : Plasma::Applet(iParent, args)
@@ -81,7 +81,7 @@ void BankSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEng
     // Get the primary unit
     SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
-    //Initialisation
+    // Initialisation
     int nb = widgetLayout->count();
     for (int i = 0; widgetLayout && i < nb; ++i) {
         QGraphicsLayoutItem* item = widgetLayout->itemAt(0);
