@@ -40,7 +40,7 @@ public:
     /**
       * Default Constructor
       */
-    explicit TipsOfTheDayApplet(QObject* parent, const QVariantList& args);
+    explicit TipsOfTheDayApplet(QObject* iParent, const QVariantList& args);
 
     /**
       * Default Destructor
