@@ -20,6 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgadviceboardwidget.h"
+
+#include <QDomDocument>
+#include <QLayoutItem>
+#include <QToolButton>
+#include <QPushButton>
+#include <KMenu>
+
 #include "skgdocumentbank.h"
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -27,18 +34,12 @@
 #include "skginterfaceplugin.h"
 #include "skgtransactionmng.h"
 
-#include <QDomDocument>
-#include <QLayoutItem>
-#include <QToolButton>
-#include <QPushButton>
-#include <kmenu.h>
-
 SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Advices")), m_maxAdvice(7), m_refreshNeeded(true), m_refresh(NULL)
 {
     SKGTRACEIN(10, "SKGAdviceBoardWidget::SKGAdviceBoardWidget");
 
-    //Create menu
+    // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QWidget* g = new QWidget(this);
@@ -50,7 +51,7 @@ SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
     m_layout->setVerticalSpacing(1);
     setMainWidget(g);
 
-    //menu
+    // menu
     KAction* menuResetAdvice = new KAction(KIcon("edit-undo"), i18nc("Noun, a user action", "Activate all advice"), this);
     connect(menuResetAdvice, SIGNAL(triggered(bool)), this, SLOT(activateAllAdvice()));
     addAction(menuResetAdvice);
@@ -65,7 +66,7 @@ SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
     connect(m_menuAuto, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuAuto);
 
-    //Refresh
+    // Refresh
     connect(getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(dataModified()), Qt::QueuedConnection);
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
     connect(this, SIGNAL(refreshNeeded()), this, SLOT(dataModified()), Qt::QueuedConnection);
@@ -132,7 +133,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     m_refreshNeeded = false;
 
-    //Remove all item of the layout
+    // Remove all item of the layout
     QLayoutItem* child = NULL;
     while ((child = m_layout->takeAt(0)) != 0) {
         QWidget* w = child->widget();
@@ -140,7 +141,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         delete child;
     }
 
-    //Get list of advice
+    // Get list of advice
     double elapse = SKGServices::getMicroTime();
     SKGAdviceList globalAdviceList = SKGMainPanel::getMainPanel()->getAdvice();
     elapse = SKGServices::getMicroTime() - elapse;
@@ -154,18 +155,18 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         globalAdviceList.push_back(ad);
     }
 
-    //Fill layout
+    // Fill layout
     int nbDisplayedAdvice = 0;
     int nb = globalAdviceList.count();
     for (int i = 0; i < m_maxAdvice && i < nb; ++i) {
-        //Get advice
+        // Get advice
         SKGAdvice ad = globalAdviceList.at(i);
 
-        //Create icon
+        // Create icon
         QString iconName = (ad.getPriority() == -1 ? "dialog-information" : ad.getPriority() >= 8 ? "security-low" : ad.getPriority() <= 4 ? "security-high" : "security-medium");
-        QString toolTip = i18n("<p><b>Priority %1:</b>%2</p>", SKGServices::intToString(ad.getPriority()), ad.getLongMessage());
+        QString toolTipString = i18n("<p><b>Priority %1:</b>%2</p>", SKGServices::intToString(ad.getPriority()), ad.getLongMessage());
 
-        //Add ignored action
+        // Add ignored action
         QStringList autoCorrections = ad.getAutoCorrections();
         autoCorrections.push_back(i18nc("Dismiss an advice provided", "Dismiss"));
         autoCorrections.push_back(i18nc("Dismiss an advice provided", "Dismiss during current month"));
@@ -174,7 +175,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 
         int nbSolution = autoCorrections.count();
 
-        //Build button
+        // Build button
         QStringList overlays;
         overlays.push_back(nbSolution > 2 ? "system-run" : "edit-delete");
         QToolButton*  icon = new QToolButton(this);
@@ -191,11 +192,11 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
             QString actionText = autoCorrections.at(k);
             QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(QString(actionText).remove("skg://"), false);
             if (action) {
-                //This is an action
+                // This is an action
                 QAction* act = menu->addAction(action->icon(), action->text(), SKGMainPanel::getMainPanel(), SLOT(openPage()));
                 act->setData(actionText);
             } else {
-                //This is a text
+                // This is a text
                 QAction* act = menu->addAction(KIcon(k < nbSolution - 4 ?  "system-run" : "edit-delete"), autoCorrections.at(k), this, SLOT(adviceClicked()));
                 if (act) {
                     act->setProperty("id", ad.getUUID());
@@ -207,20 +208,20 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         icon->setMenu(menu);
         icon->setPopupMode(QToolButton::InstantPopup);
 
-        icon->setToolTip(toolTip);
+        icon->setToolTip(toolTipString);
 
-        //Create text
+        // Create text
         QLabel* label = new QLabel(this);
         label->setText(ad.getShortMessage());
-        label->setToolTip(toolTip);
+        label->setToolTip(toolTipString);
 
-        //Add them
+        // Add them
         m_layout->addRow(icon, label);
 
         ++nbDisplayedAdvice;
     }
 
-    //Add more
+    // Add more
     if (nb > m_maxAdvice) {
         QPushButton*  more = new QPushButton(this);
         more->setIcon(KIcon("arrow-down-double"));
@@ -231,7 +232,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 
         m_layout->addRow(more, new QLabel(this));
     } else if (nbDisplayedAdvice > 7) {
-        //Add less
+        // Add less
         QPushButton*  less = new QPushButton(this);
         less->setIcon(KIcon("arrow-up-double"));
         less->setIconSize(QSize(22, 22));
@@ -242,7 +243,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         m_layout->addRow(less, new QLabel(this));
     }
 
-    //Add manual refresh button
+    // Add manual refresh button
     m_refresh = new QPushButton(this);
     m_refresh->setIcon(KIcon("view-refresh"));
     m_refresh->setIconSize(QSize(22, 22));
@@ -276,46 +277,50 @@ void SKGAdviceBoardWidget::activateAllAdvice()
         err = getDocument()->executeSqliteOrder("DELETE FROM parameters WHERE t_uuid_parent='advice'");
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Advice activated.")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Advice activation failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Advice activation failed"));
+    }
 
     SKGMainPanel::displayErrorMessage(err);
 }
 
 void SKGAdviceBoardWidget::adviceClicked()
 {
-    //Get advice identifier
+    // Get advice identifier
     QAction* act = qobject_cast< QAction* >(sender());
     if (act) {
         QString uuid = act->property("id").toString();
         if (!uuid.isEmpty()) {
-            //Get solution clicker
+            // Get solution clicker
             int solution = sender()->property("solution").toInt();
 
             if (solution < 0) {
-                //We have to ignore this advice
+                // We have to ignore this advice
                 SKGError err;
                 {
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Dismiss advice"), err);
                     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
 
-                    //Create dismiss
+                    // Create dismiss
                     if (solution == -1 || solution == -2) uuid = SKGServices::splitCSVLine(uuid, '|').at(0);
                     err = getDocument()->setParameter(uuid, solution == -2 || solution == -4 ? "I" : QString("I_" % currentMonth), QVariant(), "advice");
 
-                    //Delete useless dismiss
+                    // Delete useless dismiss
                     IFOKDO(err, getDocument()->executeSqliteOrder("DELETE FROM parameters WHERE t_uuid_parent='advice' AND t_value like 'I_ % ' AND t_value!='I_" % currentMonth % '\''))
                 }
 
-                //status bar
+                // status bar
                 IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Advice dismissed.")))
-                else err.addError(ERR_FAIL, i18nc("Error message",  "Advice dismiss failed"));
+                else {
+                    err.addError(ERR_FAIL, i18nc("Error message",  "Advice dismiss failed"));
+                }
             } else {
-                //Get last transaction id
+                // Get last transaction id
                 int previous = getDocument()->getTransactionToProcess();
 
-                //Execute the advice correction on all plugin
+                // Execute the advice correction on all plugin
                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                 int index = 0;
                 while (index >= 0) {
@@ -323,17 +328,19 @@ void SKGAdviceBoardWidget::adviceClicked()
                     if (plugin) {
                         SKGError err = plugin->executeAdviceCorrection(uuid, solution);
                         if (!err || err.getReturnCode() != ERR_NOTIMPL) {
-                            //The correction has been done or failed. This is the end.
+                            // The correction has been done or failed. This is the end.
                             index = -2;
                         }
-                    } else index = -2;
+                    } else {
+                        index = -2;
+                    }
                     ++index;
                 }
 
-                //Get last transaction id
+                // Get last transaction id
                 int next = getDocument()->getTransactionToProcess();
 
-                //If this is the same transaction, it means that an action has been done outside the document ==> a refresh is needed
+                // If this is the same transaction, it means that an action has been done outside the document ==> a refresh is needed
                 if (next == previous) emit refreshNeeded();
 
                 QApplication::restoreOverrideCursor();
