@@ -40,7 +40,7 @@ void SKGAdviceDataEngine::init()
     if (panel) document = (panel->getDocument());
 
     // Whenever a table is modified, update sources
-    connect(document, SIGNAL(tableModified(QString,int)), this, SLOT(updateAllSources()));
+    connect(document, SIGNAL(tableModified(QString,int,bool)), this, SLOT(updateAllSources()));
 }
 
 
