@@ -20,15 +20,16 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgadviceplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgadviceboardwidget.h"
 #include "skgtipofdayboardwidget.h"
 #include "skgtraces.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -38,9 +39,10 @@ K_PLUGIN_FACTORY(SKGAdvicePluginFactory, registerPlugin<SKGAdvicePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGAdvicePluginFactory("skg_advice", "skg_advice"))
 
-SKGAdvicePlugin::SKGAdvicePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGAdvicePlugin::SKGAdvicePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGAdvicePlugin::SKGAdvicePlugin");
+    Q_UNUSED(iWidget);
 }
 
 SKGAdvicePlugin::~SKGAdvicePlugin()
@@ -59,7 +61,7 @@ bool SKGAdvicePlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_advice/skg_advice.rc");
 
-    //Create yours actions here
+    // Create yours actions here
     return true;
 }
 
@@ -73,13 +75,17 @@ QString SKGAdvicePlugin::getDashboardWidgetTitle(int iIndex)
 {
     SKGTRACEIN(1, "SKGAdvicePlugin::getDashboardWidgetTitle");
     if (iIndex == 0) return i18nc("Noun, a list of items", "Advice");
-    else return i18nc("Noun, a list of items", "Tip of the day");
+    else {
+        return i18nc("Noun, a list of items", "Tip of the day");
+    }
 }
 
 SKGBoardWidget* SKGAdvicePlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGAdviceBoardWidget(currentDocument);
-    else return new SKGTipOfDayBoardWidget(currentDocument);
+    else {
+        return new SKGTipOfDayBoardWidget(currentDocument);
+    }
 }
 
 
