@@ -20,6 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbookmarkplugin.h"
+
+#include <QtGui/QWidget>
+
+#include <KActionCollection>
+#include <KStandardDirs>
+#include <KToolBarPopupAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgbookmark_settings.h"
 #include "skgtraces.h"
 #include "skgerror.h"
@@ -29,14 +38,6 @@
 #include "skgtransactionmng.h"
 #include "skgbookmarkplugindockwidget.h"
 
-#include <QtGui/QWidget>
-
-#include <kactioncollection.h>
-#include <kstandarddirs.h>
-#include <ktoolbarpopupaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -46,10 +47,11 @@ K_PLUGIN_FACTORY(SKGBookmarkPluginFactory, registerPlugin<SKGBookmarkPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGBookmarkPluginFactory("skg_bookmark", "skg_bookmark"))
 
-SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& iArg) :
+SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg) :
     SKGInterfacePlugin(iParent), m_currentDocument(NULL), m_dockWidget(NULL), m_importStdBookmarkAction(NULL), m_bookmarkAction(NULL), m_bookmarkMenu(NULL)
 {
     Q_UNUSED(iArg);
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGBookmarkPlugin::SKGBookmarkPlugin");
 }
 
@@ -90,7 +92,7 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     connect(panelAction, SIGNAL(triggered()), toggle, SLOT(trigger()));
     connect(toggle, SIGNAL(toggled(bool)), panelAction, SLOT(setChecked(bool)));
 
-    //Import bookmarks
+    // Import bookmarks
     QStringList overlaybookmarks;
     overlaybookmarks.push_back(icon());
 
@@ -99,11 +101,11 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("import_standard_bookmarks", m_importStdBookmarkAction);
 
     //
-    KAction* goHome = KStandardAction::home(this, SLOT(goHome()), actionCollection());
-    goHome->setPriority(QAction::LowPriority);
-    registerGlobalAction("go_home", goHome);
+    KAction* goHomeAction = KStandardAction::home(this, SLOT(goHome()), actionCollection());
+    goHomeAction->setPriority(QAction::LowPriority);
+    registerGlobalAction("go_home", goHomeAction);
 
-    //Bookmark
+    // Bookmark
     m_bookmarkAction = new KToolBarPopupAction(KIcon("bookmark-new-list"), i18nc("Verb, action to display bookmarks", "Bookmarks"), this);
     connect(m_bookmarkAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onOpenBookmark()));
     m_bookmarkMenu = static_cast<KMenu*>(m_bookmarkAction->menu());
@@ -117,7 +119,7 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_bookmarkAction->setData(0);
     m_bookmarkAction->setPriority(QAction::LowPriority);
 
-    //bookmarkAction=KStandardAction::redo(this, SLOT(onRedo()), actionCollection());
+    // bookmarkAction=KStandardAction::redo(this, SLOT(onRedo()), actionCollection());
     registerGlobalAction("edit_bookmark", m_bookmarkAction);
 
     return true;
@@ -126,9 +128,9 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 QWidget* SKGBookmarkPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGFilePlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
-    return widget;
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
+    return w;
 }
 
 KConfigSkeleton* SKGBookmarkPlugin::getPreferenceSkeleton()
@@ -148,7 +150,7 @@ void SKGBookmarkPlugin::refresh()
         bool test = (m_currentDocument->getDatabase() != NULL);
         if (m_importStdBookmarkAction) m_importStdBookmarkAction->setEnabled(test);
 
-        //Automatic bookmarks creation
+        // Automatic bookmarks creation
         if (m_currentDocument->getDatabase() != NULL) {
             QString doc_id = m_currentDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id) {
@@ -159,11 +161,11 @@ void SKGBookmarkPlugin::refresh()
                 if (!err && !exist) {
                     importStandardBookmarks();
 
-                    //The file is considered has not modified
+                    // The file is considered has not modified
                     m_currentDocument->setFileNotModified();
                 }
 
-                //Automatic open of autostart bookmark
+                // Automatic open of autostart bookmark
                 if (!err && !(QApplication::keyboardModifiers() &Qt::ShiftModifier)) goHome();
             }
         }
@@ -206,7 +208,7 @@ void SKGBookmarkPlugin::importStandardBookmarks()
     SKGError err;
     SKGBEGINTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Import standard bookmarks"), err);
 
-    //TODO: Must be generic
+    // TODO(Stephane MANKOWSKI): Must be generic
     QStringList bks;
     bks << i18nc("Noun, bookmark name", "Dashboard") % "|N|dashboard-show|\"Dashboard plugin\";\"Dashboard\";\"<!DOCTYPE SKGML><parameters zoomPosition=\"\"0\"\"> <ITEM-1 zoom=\"\"0\"\" index=\"\"0\"\" name=\"\"Skrooge bank plugin\"\" state=\"\"&lt;!DOCTYPE SKGML>&#xa;&lt;parameters menuOther=&quot;Y&quot; menuCurrent=&quot;Y&quot; menuFavorite=&quot;N&quot; menuAssets=&quot;Y&quot; menuInvestment=&quot;Y&quot; menuCreditCard=&quot;Y&quot;/>&#xa;\"\"/> <ITEM-2 zoom=\"\"0\"\" index=\"\"0\"\" name=\"\"Skrooge operation plugin\"\" state=\"\"&lt;!DOCTYPE SKGML>"
         "&#xa;&lt;parameters menuTransfert=&quot;Y&quot;/>&#xa;\"\"/> <ITEM-3 zoom=\"\"0\"\" index=\"\"1\"\" name=\"\"Skrooge operation plugin\"\" state=\"\"\"\"/> <ITEM-4 zoom=\"\"0\"\" index=\"\"0\"\" name=\"\"Skrooge scheduled plugin\"\" state=\"\"\"\"/> <ITEM-5 zoom=\"\"0\"\" index=\"\"0\"\" name=\"\"Skrooge search plugin\"\" state=\"\"&lt;!DOCTYPE SKGML>"
@@ -234,17 +236,19 @@ void SKGBookmarkPlugin::importStandardBookmarks()
         }
     }
 
-    //status
+    // status
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Standard bookmarks imported.")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Import standard bookmarks failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Import standard bookmarks failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
 void SKGBookmarkPlugin::goHome()
 {
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->closeAllPages(false); //Home do not close pinned pages
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->closeAllPages(false);  // Home do not close pinned pages
 
     SKGObjectBase::SKGListSKGObjectBase oNodeList;
     if (m_currentDocument) m_currentDocument->getObjects("v_node", "t_autostart='Y' ORDER BY f_sortorder, t_name", oNodeList);
@@ -254,7 +258,6 @@ void SKGBookmarkPlugin::goHome()
         autostarted_bookmark.load();
         SKGTRACEIN(10, "autostarting bookmark : " % autostarted_bookmark.getName());
         SKGBookmarkPluginDockWidget::openBookmark(autostarted_bookmark, i > 0, true);
-
     }
 }
 
@@ -272,20 +275,20 @@ void SKGBookmarkPlugin::onAddBookmark()
     SKGTRACEIN(1, "SKGBookmarkPlugin::onAddBookmark");
     SKGError err;
 
-    //Get current page
+    // Get current page
     SKGNodeObject node;
     {
-        //Get current selection
+        // Get current selection
         SKGNodeObject parentNode;
         QAction* callerAction = qobject_cast<QAction*>(this->sender());
         if (callerAction) {
             parentNode = SKGNodeObject(m_currentDocument, callerAction->data().toInt());
         }
 
-        //Create bookmark
+        // Create bookmark
         err =  SKGBookmarkPluginDockWidget::createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
     }
-    //status bar
+    // status bar
     IFOK(err) {
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
     }
@@ -296,22 +299,22 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
 {
     KMenu* callerMenu = qobject_cast<KMenu*>(this->sender());
     if (callerMenu && m_currentDocument) {
-        //Remove previous menu
+        // Remove previous menu
         callerMenu->clear();
 
-        //Build query
+        // Build query
         QString wc = "rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id=''";
         int idParent = callerMenu->property("id").toInt();
         if (idParent != 0) wc = "rd_node_id=" % SKGServices::intToString(idParent);
 
-        //Build new menu
+        // Build new menu
         SKGObjectBase::SKGListSKGObjectBase listNode;
         m_currentDocument->getObjects("v_node", wc % " ORDER BY f_sortorder, t_name", listNode);
         int nb = listNode.count();
         for (int i = 0; i < nb; ++i) {
             SKGNodeObject node(listNode.at(i));
             if (node.isFolder()) {
-                //This is a folder
+                // This is a folder
                 KMenu* menu = new KMenu(callerMenu);
                 if (menu) {
                     callerMenu->addMenu(menu);
@@ -321,7 +324,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
                     connect(menu , SIGNAL(aboutToShow()), this, SLOT(onShowBookmarkMenu()));
                 }
             } else {
-                //This is a bookmark
+                // This is a bookmark
                 KAction* act = new KAction(callerMenu);
                 if (act) {
                     callerMenu->addAction(act);
@@ -333,14 +336,14 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
             }
         }
 
-        //Add separator
+        // Add separator
         QAction* sep = new QAction(this);
         sep->setSeparator(true);
         callerMenu->addAction(sep);
 
-        //This common actions
+        // This common actions
         {
-            //Open all
+            // Open all
             KAction* act = new KAction(callerMenu);
             if (act) {
                 callerMenu->addAction(act);
@@ -350,15 +353,15 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
                 connect(act, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onOpenBookmark(Qt::MouseButtons,Qt::KeyboardModifiers)));
             }
             if (SKGMainPanel::getMainPanel()->currentPageIndex() >= 0) {
-                //Bookmark current here
-                KAction* act = new KAction(callerMenu);
-                if (act) {
-                    callerMenu->addAction(act);
-                    act->setText(i18nc("Action", "Bookmark current page here"));
-                    act->setIcon(KIcon("list-add"));
-                    act->setData(idParent);
+                // Bookmark current here
+                KAction* act2 = new KAction(callerMenu);
+                if (act2) {
+                    callerMenu->addAction(act2);
+                    act2->setText(i18nc("Action", "Bookmark current page here"));
+                    act2->setIcon(KIcon("list-add"));
+                    act2->setData(idParent);
 
-                    connect(act, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onAddBookmark()));
+                    connect(act2, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onAddBookmark()));
                 }
             }
         }
