@@ -20,6 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbookmarkplugindockwidget.h"
+
+#include <KMenu>
+#include <KIconDialog>
+
+#include <QHeaderView>
+#include <QResizeEvent>
+
 #include "skgbookmark_settings.h"
 #include "skgtraces.h"
 #include "skgdocument.h"
@@ -30,12 +37,6 @@
 #include "skginterfaceplugin.h"
 #include "skgtransactionmng.h"
 
-#include <kmenu.h>
-#include <kicondialog.h>
-
-#include <QHeaderView>
-#include <QResizeEvent>
-
 bool SKGBookmarkPluginDockWidget::m_middleClick = false;
 
 SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
@@ -47,11 +48,11 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
-    QPalette palette = QApplication::palette();
-    palette.setColor(QPalette::Base, Qt::transparent);
-    ui.kBookmarksList->setPalette(palette);
+    QPalette newPalette = QApplication::palette();
+    newPalette.setColor(QPalette::Base, Qt::transparent);
+    ui.kBookmarksList->setPalette(newPalette);
     ui.kBookmarksList->setRootIsDecorated(false);
-    ui.kBookmarksList->setAnimated(false); //Not compatible with double click
+    ui.kBookmarksList->setAnimated(false);  // Not compatible with double click
     ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
     ui.kTools->setIcon(KIcon("configure"));
@@ -60,7 +61,7 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
     ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showMenu(QPoint)));
 
-    //Add model
+    // Add model
     m_modelview = new SKGObjectModelBase(getDocument(), "v_node", "1=1 ORDER BY f_sortorder, t_name", this, "rd_node_id");
     SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel(this);
     modelproxy->setSourceModel(m_modelview);
@@ -79,7 +80,7 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
 
     ui.kBookmarksList->setTextResizable(false);
 
-    //Refresh action states
+    // Refresh action states
     refresh();
 }
 
@@ -106,7 +107,7 @@ QWidget* SKGBookmarkPluginDockWidget::mainWidget()
 void SKGBookmarkPluginDockWidget::initMenu()
 {
     if (!m_mainMenu) {
-        //Build contextual menu
+        // Build contextual menu
         m_mainMenu = new KMenu(ui.kBookmarksList);
         QAction* actExpandAll = m_mainMenu->addAction(KIcon("format-indent-more"), i18nc("Noun, user action", "Expand all"));
         connect(actExpandAll, SIGNAL(triggered(bool)), ui.kBookmarksList, SLOT(expandAll()));
@@ -152,10 +153,10 @@ void SKGBookmarkPluginDockWidget::initMenu()
     }
 }
 
-void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
+void SKGBookmarkPluginDockWidget::showMenu(const QPoint& iPos)
 {
     initMenu();
-    m_mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
+    m_mainMenu->popup(ui.kBookmarksList->mapToGlobal(iPos));
 }
 
 void SKGBookmarkPluginDockWidget::onSetAutostart()
@@ -177,7 +178,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
 
     SKGError err;
 
-    //foreach selected bookmark, set the t_autostart attribute to 'y' or 'n'
+    // foreach selected bookmark, set the t_autostart attribute to 'y' or 'n'
     {
         int nb = selectedBookmarks.count();
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == "Y" ? i18nc("Noun, name of the user action", "Autostart bookmarks") : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"), err, nb);
@@ -189,10 +190,9 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, value == "Y" ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks")))
     SKGMainPanel::displayErrorMessage(err);
-
 }
 
 
@@ -218,11 +218,11 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
     }
 
     int tabNumberForNextOpen = (m_middleClick || iFirstInNewPage ? -1 : SKGMainPanel::getMainPanel()->currentPageIndex());
-    for (int i = 0; i < nodes.count(); ++i) { //WARNING: This list is modified dynamically
+    for (int i = 0; i < nodes.count(); ++i) {  // WARNING: This list is modified dynamically
         SKGNodeObject selectedNode = nodes.at(i);
         QStringList data = SKGServices::splitCSVLine(selectedNode.getData());
         if (data.count() > 2) {
-            //This bookmark has information ==> we open it
+            // This bookmark has information ==> we open it
             SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()), i == nodes.count() - 1);
             if (page) {
                 if (skgbookmark_settings::pinhomebookmarks()) page->setPin(iPin);
@@ -232,7 +232,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
                 tabNumberForNextOpen = -1;
             }
         } else {
-            //This bookmark is a folder ==> we open children by recursion
+            // This bookmark is a folder ==> we open children by recursion
             SKGObjectBase::SKGListSKGObjectBase children;
             selectedNode.getNodes(children);
             foreach(const SKGObjectBase & item, children) {
@@ -242,7 +242,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
     }
     QApplication::restoreOverrideCursor();
 
-    //Set focus on first page
+    // Set focus on first page
     SKGMainPanel::getMainPanel()->setCurrentPage(setForcusOn);
 }
 
@@ -255,7 +255,7 @@ void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmark");
     QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
-    SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+    SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
     if (model) {
         SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
         if (!node.isFolder()) openBookmark(node);
@@ -266,7 +266,7 @@ void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex& index)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmarkFolder");
     QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
-    SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+    SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
     if (model) {
         SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
         if (node.isFolder()) openBookmark(node);
@@ -279,13 +279,13 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
     SKGError err;
     SKGNodeObject node;
     {
-        //Get current selection name
+        // Get current selection name
         QString name;
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         if (bookmarks.count()) {
             SKGNodeObject parentNode(bookmarks.at(0));
             if (!parentNode.isFolder()) {
-                //This is not a folder, we have to take the parent
+                // This is not a folder, we have to take the parent
                 SKGNodeObject parentNodeTmp;
                 parentNode.getParentNode(parentNodeTmp);
                 parentNode = parentNodeTmp;
@@ -293,16 +293,16 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
             name = parentNode.getFullName();
         }
 
-        //Add current name
+        // Add current name
         if (!name.isEmpty()) name += OBJECTSEPARATOR;
         name += i18nc("Default name for bookmark", "New bookmark");
 
-        //Create bookmark folder
+        // Create bookmark folder
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark folder creation '%1'", name), err);
         err = SKGNodeObject::createPathNode(getDocument(), name, node, true);
     }
 
-    //status bar
+    // status bar
     IFOK(err) {
         ui.kBookmarksList->selectObject(node.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark group created"));
@@ -316,13 +316,13 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
     SKGError err;
     SKGNodeObject rootNode;
     {
-        //Get current selection name
+        // Get current selection name
         QString name;
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         if (bookmarks.count()) {
             SKGNodeObject parentNode(bookmarks.at(0));
             if (!parentNode.isFolder()) {
-                //This is not a folder, we have to take the parent
+                // This is not a folder, we have to take the parent
                 SKGNodeObject parentNodeTmp;
                 parentNode.getParentNode(parentNodeTmp);
                 parentNode = parentNodeTmp;
@@ -330,11 +330,11 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
             name = parentNode.getFullName();
         }
 
-        //Add current name
+        // Add current name
         if (!name.isEmpty()) name += OBJECTSEPARATOR;
         name += i18nc("Default name for bookmark", "New bookmark");
 
-        //Create bookmark folder
+        // Create bookmark folder
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmarks creation"), err);
         err = SKGNodeObject::createPathNode(getDocument(), name, rootNode, true);
         int nb = SKGMainPanel::getMainPanel()->countPages();
@@ -344,7 +344,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
         }
     }
 
-    //status bar
+    // status bar
     IFOK(err) {
         ui.kBookmarksList->selectObject(rootNode.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmarks created"));
@@ -357,18 +357,18 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmark");
     SKGError err;
 
-    //Get current page
+    // Get current page
     SKGNodeObject node;
     {
-        //Get current selection
+        // Get current selection
         SKGNodeObject parentNode(getDocument(), 0);
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         if (bookmarks.count()) parentNode = bookmarks.at(0);
 
-        //Create bookmark
+        // Create bookmark
         err = createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
     }
-    //status bar
+    // status bar
     IFOK(err) {
         ui.kBookmarksList->selectObject(node.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
@@ -381,21 +381,21 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::createNodeFromPage");
     SKGError err;
 
-    //Get current page
+    // Get current page
     oCreatedNode = SKGNodeObject();
     if (iPage) {
-        //Get current selection name
+        // Get current selection name
         QString name;
         SKGNodeObject parentNode = iParentNode;
         if (!parentNode.isFolder()) {
-            //This is not a folder, we have to take the parent
+            // This is not a folder, we have to take the parent
             SKGNodeObject parentNodeTmp;
             parentNode.getParentNode(parentNodeTmp);
             parentNode = parentNodeTmp;
         }
         name = parentNode.getFullName();
 
-        //Add current name
+        // Add current name
         if (!name.isEmpty()) name += OBJECTSEPARATOR;
 
         QString defaultName = iPage->objectName();
@@ -407,7 +407,7 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         }
         name += defaultName;
 
-        //Create bookmark
+        // Create bookmark
         SKGBEGINTRANSACTION(*iParentNode.getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err);
         err = SKGNodeObject::createPathNode(iParentNode.getDocument(), name, oCreatedNode, true);
         IFOK(err) {
@@ -431,7 +431,7 @@ void SKGBookmarkPluginDockWidget::onRenameBookmark()
     QItemSelectionModel* selModel = ui.kBookmarksList->selectionModel();
     QSortFilterProxyModel* proxyModel = qobject_cast< QSortFilterProxyModel* >(ui.kBookmarksList->model());
     if (proxyModel && selModel) {
-        SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
         if (model) {
             QModelIndexList indexes = selModel->selectedRows();
             if (indexes.count() == 1) {
@@ -456,9 +456,8 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
                 SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark icon change"), err);
                 err = node.setIcon(icon);
                 IFOKDO(err, node.save())
-
             }
-            //status bar
+            // status bar
             IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Bookmark icon changed")))
             SKGMainPanel::displayErrorMessage(err);
         }
@@ -472,7 +471,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
     SKGError err;
     {
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark delete"), err);
-        //Get current selection
+        // Get current selection
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         int nb = bookmarks.count();
         for (int i = 0; i < nb && !err; ++i) {
@@ -481,7 +480,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Bookmark deleted")))
     SKGMainPanel::displayErrorMessage(err);
 }
@@ -490,7 +489,7 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
 {
     SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onBookmarkEditorChanged");
 
-    //Enable bookmark buttons
+    // Enable bookmark buttons
     int nbSelectedObjects = getNbSelectedObjects();
     bool testAdd = getDocument()->getDatabase() != NULL && nbSelectedObjects <= 1;
     if (m_actAddBookmarkGroup) m_actAddBookmarkGroup->setEnabled(testAdd);
@@ -504,7 +503,7 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
 void SKGBookmarkPluginDockWidget::refresh()
 {
     SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::refresh");
-    //Bookmarks
+    // Bookmarks
     SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
     int nbSelectedObjects = bookmarks.count();
     if (nbSelectedObjects == 1) {
@@ -514,7 +513,6 @@ void SKGBookmarkPluginDockWidget::refresh()
     } else {
         if (m_actSetAutostart) m_actSetAutostart->setEnabled(nbSelectedObjects > 1);
         if (m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(nbSelectedObjects > 1);
-
     }
 
     onBookmarkEditorChanged();
@@ -522,24 +520,24 @@ void SKGBookmarkPluginDockWidget::refresh()
 
 void SKGBookmarkPluginDockWidget::onPageChanged()
 {
-    //Set current selection of dock
+    // Set current selection of dock
     QString id;
     SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
     if (cPage) id = cPage->getBookmarkID();
     ui.kBookmarksList->selectObject(id % "-node");
 }
 
-void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent* event)
+void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent* iEvent)
 {
-    if (event) {
-        QSize newSize = event->size();
+    if (iEvent) {
+        QSize newSize = iEvent->size();
 
-        //Compute icon size
+        // Compute icon size
         int s = qMax(qMin(newSize.width() / 5, 64), 16);
         ui.kBookmarksList->setIconSize(QSize(s, s));
     }
 
-    QWidget::resizeEvent(event);
+    QWidget::resizeEvent(iEvent);
 }
 
 #include "skgbookmarkplugindockwidget.moc"
