@@ -20,6 +20,17 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgdashboardpluginwidget.h"
+
+#include <KCmdLineArgs>
+#include <KAboutData>
+#include <KMenu>
+#include <KService>
+
+#include <QDomDocument>
+#include <QSpacerItem>
+#include <QMouseEvent>
+#include <QVBoxLayout>
+
 #include "skgmainpanel.h"
 #include "skgtraces.h"
 #include "skgdocument.h"
@@ -29,17 +40,7 @@
 #include "skgflowlayout.h"
 #include "skgboardwidget.h"
 
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <kmenu.h>
-#include <KService>
-
-#include <QDomDocument>
-#include <QSpacerItem>
-#include <QMouseEvent>
-#include <QVBoxLayout>
-
-#define PLASMA (SKGServices::getenv("SKGPLASMA").isEmpty() ? false : true)
+#define PLASMA (SKGServices::getEnvVariable("SKGPLASMA").isEmpty() ? false : true)
 
 SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument), m_flowLayout(NULL), m_menu(NULL), m_addMenu(NULL), m_plasmadashboard(NULL)
@@ -64,11 +65,11 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
             l->addWidget(m_plasmadashboard->widget());
         }
 
-        //Build menu
+        // Build menu
         if (m_addMenu) {
             const KPluginInfo::List skglist = SKGMainPanel::getMainPanel()->getPlasmaApplets();
             foreach(const KPluginInfo & info, skglist) {
-                //Create menu
+                // Create menu
                 QAction* act = m_addMenu->addAction(info.name());
                 if (act) {
                     act->setIcon(KIcon(info.icon()));
@@ -80,7 +81,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
             connect(this, SIGNAL(appletAdded(QString)), m_plasmadashboard, SLOT(addApplet(QString)));
         }
     } else {
-        //Drag and drop
+        // Drag and drop
         m_clickedPoint = QPoint(-1, -1);
 
         const KAboutData* about = KCmdLineArgs::aboutData();
@@ -89,7 +90,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
             ui.kTitle->setComment("<html><body><b>" % i18nc("Message", "Welcome to %1", about->programName()) % "</b></body></html>");
         }
 
-        //Build menu
+        // Build menu
         if (m_addMenu) {
             m_addMenu->clear();
 
@@ -99,7 +100,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
                 if (plugin) {
                     int nbdbw = plugin->getNbDashboardWidgets();
                     for (int j = 0; j < nbdbw; ++j) {
-                        //Create menu
+                        // Create menu
                         QAction* act = m_addMenu->addAction(plugin->getDashboardWidgetTitle(j));
                         if (act) {
                             act->setIcon(KIcon(plugin->icon()));
@@ -108,16 +109,18 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
                             connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddWidget()));
                         }
                     }
-                } else index = -2;
+                } else {
+                    index = -2;
+                }
                 ++index;
             }
         }
 
-        //Build layout
+        // Build layout
         m_flowLayout = new SKGFlowLayout(ui.kContent, 0, 0, 0);
     }
 
-    //Plug buttons with menus
+    // Plug buttons with menus
     if (m_addMenu && ui.kAddWidget) {
         ui.kAddWidget->setIcon(m_addMenu->icon());
         ui.kAddWidget->setMenu(m_addMenu);
@@ -172,7 +175,7 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
     QDomElement root = doc.documentElement();
     if (PLASMA) {
     } else {
-        //Initialisation
+        // Initialisation
         int nb = (m_flowLayout ? m_flowLayout->count() : 0);
         for (int i = 0; i < nb; ++i) {
             SKGBoardWidget* item = m_itemsPointers.at(0);
@@ -196,27 +199,31 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
             QDomElement element = root.firstChildElement("ITEM-" % SKGServices::intToString(index));
             if (!element.isNull()) {
                 SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(element.attribute("name"));
-                QString index = element.attribute("index");
-                if (index.isEmpty()) index = '0';
+                QString indexString = element.attribute("index");
+                if (indexString.isEmpty()) indexString = '0';
                 QString zoom = element.attribute("zoom");
                 if (zoom.isEmpty()) zoom = '0';
-                if (plugin) addItem(plugin, SKGServices::stringToInt(index), SKGServices::stringToInt(zoom), element.attribute("state"));
-            } else index = -1;
+                if (plugin) addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute("state"));
+            } else {
+                index = -1;
+            }
             ++index;
         }
 
-        //In case of reset
+        // In case of reset
         if (m_items.count() == 0 && root.attribute("zoomPosition").isEmpty()) {
-            int index = 0;
-            while (index >= 0) {
-                SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
+            int index2 = 0;
+            while (index2 >= 0) {
+                SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index2);
                 if (plugin) {
-                    int nb = plugin->getNbDashboardWidgets();
-                    for (int j = 0; j < nb; ++j) {
+                    int nb2 = plugin->getNbDashboardWidgets();
+                    for (int j = 0; j < nb2; ++j) {
                         addItem(plugin, j);
                     }
-                } else index = -2;
-                ++index;
+                } else {
+                    index2 = -2;
+                }
+                ++index2;
             }
         }
     }
@@ -238,54 +245,53 @@ QWidget* SKGDashboardPluginWidget::zoomableWidget()
     return SKGTabPage::zoomableWidget();
 }
 
-bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGDashboardPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
     if (PLASMA) {
     } else {
-        if (event && event->type() == QEvent::HoverLeave) {
-            //Leave widget
+        if (iEvent && iEvent->type() == QEvent::HoverLeave) {
+            // Leave widget
             m_timer.stop();
             return true;
         }
 
-        if (event && object &&
-                (event->type() == QEvent::MouseButtonPress ||
-                 event->type() == QEvent::MouseButtonRelease ||
-                 event->type() == QEvent::MouseMove ||
-                 event->type() == QEvent::DragEnter ||
-                 event->type() == QEvent::DragMove ||
-                 event->type() == QEvent::Drop ||
-                 event->type() == QEvent::HoverMove
-                )) {
-            //Search SKGBoardWidget corresponding to this widget
+        if (iEvent && iObject &&
+                (iEvent->type() == QEvent::MouseButtonPress ||
+                 iEvent->type() == QEvent::MouseButtonRelease ||
+                 iEvent->type() == QEvent::MouseMove ||
+                 iEvent->type() == QEvent::DragEnter ||
+                 iEvent->type() == QEvent::DragMove ||
+                 iEvent->type() == QEvent::Drop ||
+                 iEvent->type() == QEvent::HoverMove)) {
+            // Search SKGBoardWidget corresponding to this widget
             SKGBoardWidget* toMove = NULL;
             int toMoveIndex = -1;
             int nb = m_itemsPointers.count();
             for (int i = 0; toMove == NULL && i < nb; ++i) {
                 SKGBoardWidget* w = m_itemsPointers.at(i);
-                if (w && w->getDragWidget() == object) {
+                if (w && w->getDragWidget() == iObject) {
                     toMove = w;
                     toMoveIndex = i;
                 }
             }
 
-            if (event->type() == QEvent::MouseButtonPress) {
-                //Drag
-                QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
+            if (iEvent->type() == QEvent::MouseButtonPress) {
+                // Drag
+                QMouseEvent* mevent = static_cast<QMouseEvent*>(iEvent);
                 if (mevent->button() == Qt::LeftButton) {
                     m_clickedPoint = mevent->pos();
                     m_timer.stop();
                 }
-            } else if (event->type() == QEvent::MouseButtonRelease) {
-                //Drag
-                QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
+            } else if (iEvent->type() == QEvent::MouseButtonRelease) {
+                // Drag
+                QMouseEvent* mevent = static_cast<QMouseEvent*>(iEvent);
                 if (mevent->button() == Qt::LeftButton) {
                     m_clickedPoint = QPoint(-1, -1);
                 }
-            } else if (event->type() == QEvent::MouseMove) {
-                //Drag
+            } else if (iEvent->type() == QEvent::MouseMove) {
+                // Drag
                 if (m_clickedPoint != QPoint(-1, -1) && toMoveIndex != -1) {
-                    QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
+                    QMouseEvent* mevent = static_cast<QMouseEvent*>(iEvent);
                     int distance = (mevent->pos() - m_clickedPoint).manhattanLength();
                     if (distance >= QApplication::startDragDistance()) {
                         QMimeData* mimeData = new QMimeData;
@@ -293,38 +299,40 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
 
                         QDrag* drag = new QDrag(this);
                         drag->setMimeData(mimeData);
-                        drag->exec(); // krazy:exclude=crashy
+                        drag->exec();  // krazy:exclude=crashy
 
                         return true;
                     }
                 }
-            } else if (event->type() == QEvent::DragEnter) {
-                //Drop move
-                QDragEnterEvent* devent = static_cast<QDragEnterEvent*>(event);
+            } else if (iEvent->type() == QEvent::DragEnter) {
+                // Drop move
+                QDragEnterEvent* devent = static_cast<QDragEnterEvent*>(iEvent);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     devent->accept();
 
                     return true;
                 }
-            } else if (event->type() == QEvent::DragMove) {
-                //Drop move
-                QDragMoveEvent* devent = static_cast<QDragMoveEvent*>(event);
+            } else if (iEvent->type() == QEvent::DragMove) {
+                // Drop move
+                QDragMoveEvent* devent = static_cast<QDragMoveEvent*>(iEvent);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     int oldPos = SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
                     if (oldPos != toMoveIndex) devent->accept();
-                    else devent->ignore();
+                    else {
+                        devent->ignore();
+                    }
 
                     return true;
                 }
-            } else if (event->type() == QEvent::Drop) {
-                //Drop
-                QDropEvent* devent = static_cast<QDropEvent*>(event);
+            } else if (iEvent->type() == QEvent::Drop) {
+                // Drop
+                QDropEvent* devent = static_cast<QDropEvent*>(iEvent);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     int oldPos = SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
 
                     if (oldPos + 1 == toMoveIndex) ++toMoveIndex;
 
-                    //Move item
+                    // Move item
                     if (toMoveIndex > oldPos) --toMoveIndex;
                     moveItem(oldPos, toMoveIndex);
 
@@ -336,17 +344,17 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
     return false;
 }
 
-void SKGDashboardPluginWidget::showHeaderMenu(const QPoint& pos)
+void SKGDashboardPluginWidget::showHeaderMenu(const QPoint& iPos)
 {
-    //Display menu
-    if (m_menu) m_menu->popup(mapToGlobal(pos));
+    // Display menu
+    if (m_menu) m_menu->popup(mapToGlobal(iPos));
 }
 
 void SKGDashboardPluginWidget::onAddWidget()
 {
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) {
-        QString id = sender->data().toString();
+    QAction* send = qobject_cast<QAction*>(this->sender());
+    if (send) {
+        QString id = send->data().toString();
         QStringList param = SKGServices::splitCSVLine(id, '-');
 
         SKGInterfacePlugin* db = SKGMainPanel::getMainPanel()->getPluginByName(param.at(0));
@@ -356,27 +364,30 @@ void SKGDashboardPluginWidget::onAddWidget()
 
 void SKGDashboardPluginWidget::onMoveWidget(int iMove)
 {
-    //Get current position
-    QWidget* sender = qobject_cast<QWidget*>(this->sender());
-    if (sender) {
-        int pos = m_itemsPointers.indexOf(parentBoardWidget(sender));
-        int newPos = pos + iMove;
-        if (newPos < 0) newPos = 0;
-        else if (newPos > m_items.count() - 1) newPos = m_items.count() - 1;
+    // Get current position
+    QWidget* send = qobject_cast<QWidget*>(this->sender());
+    if (send) {
+        int currentPos = m_itemsPointers.indexOf(parentBoardWidget(send));
+        int newPos = currentPos + iMove;
+        if (newPos < 0) {
+            newPos = 0;
+        } else if (newPos > m_items.count() - 1) {
+            newPos = m_items.count() - 1;
+        }
 
-        moveItem(pos, newPos);
+        moveItem(currentPos, newPos);
     }
 }
 
 void SKGDashboardPluginWidget::moveItem(int iFrom, int iTo)
 {
-    //Compute new position
+    // Compute new position
     if (iTo != iFrom) {
-        //Move item
+        // Move item
         m_items.move(iFrom, iTo);
         m_itemsPointers.move(iFrom, iTo);
 
-        //Build list of items in the right order
+        // Build list of items in the right order
         QList<SKGBoardWidget*> listWidgets;
         int nb = m_itemsPointers.count();
         for (int i = 0; i < nb; ++i) {
@@ -385,15 +396,13 @@ void SKGDashboardPluginWidget::moveItem(int iFrom, int iTo)
             listWidgets.push_back(wgt2);
         }
 
-        //Add items
+        // Add items
         nb = listWidgets.count();
         for (int i = 0; i < nb; ++i) {
             SKGBoardWidget* dbw = listWidgets.at(i);
             dbw->setParent(ui.kContent);
             m_flowLayout->addWidget(dbw);
         }
-
-
     }
 }
 
@@ -410,21 +419,21 @@ SKGBoardWidget* SKGDashboardPluginWidget::parentBoardWidget(QWidget* iWidget)
 
 void SKGDashboardPluginWidget::onRemoveWidget()
 {
-    int pos = -1;
-    QWidget* sender = qobject_cast<QWidget*>(this->sender());
-    if (sender) pos = m_itemsPointers.indexOf(parentBoardWidget(sender));
-    if (pos >= 0) {
-        //Get item
-        SKGBoardWidget* wgt = m_itemsPointers.at(pos);
+    int p = -1;
+    QWidget* send = qobject_cast<QWidget*>(this->sender());
+    if (send) p = m_itemsPointers.indexOf(parentBoardWidget(send));
+    if (p >= 0) {
+        // Get item
+        SKGBoardWidget* wgt = m_itemsPointers.at(p);
 
-        //Delete widget
+        // Delete widget
         m_flowLayout->removeWidget(wgt);
         wgt->hide();
         wgt->deleteLater();
 
-        //Remove item
-        m_items.removeAt(pos);
-        m_itemsPointers.removeAt(pos);
+        // Remove item
+        m_items.removeAt(p);
+        m_itemsPointers.removeAt(p);
     }
 }
 
@@ -433,12 +442,12 @@ void SKGDashboardPluginWidget::addItem(SKGInterfacePlugin* iDashboard, int iInde
     if (iDashboard && m_flowLayout) {
         SKGBoardWidget* dbw = iDashboard->getDashboardWidget(iIndex);
         if (dbw) {
-            //Add widget
+            // Add widget
             dbw->setParent(ui.kContent);
             dbw->setState(iState);
             m_flowLayout->addWidget(dbw);
 
-            //Install filter
+            // Install filter
             QWidget* drag = dbw->getDragWidget();
             if (drag) {
                 drag->installEventFilter(this);
@@ -446,11 +455,11 @@ void SKGDashboardPluginWidget::addItem(SKGInterfacePlugin* iDashboard, int iInde
                 drag->setAttribute(Qt::WA_Hover);
             }
 
-            //Connect widget
+            // Connect widget
             connect(dbw, SIGNAL(requestRemove()), this, SLOT(onRemoveWidget()), Qt::QueuedConnection);
             connect(dbw, SIGNAL(requestMove(int)), this, SLOT(onMoveWidget(int)), Qt::QueuedConnection);
 
-            //Set size
+            // Set size
             dbw->setZoomRation((iZoom + 15.0) / 5.0);
 
             QString id = iDashboard->objectName() % '-' % SKGServices::intToString(iIndex);
@@ -462,9 +471,9 @@ void SKGDashboardPluginWidget::addItem(SKGInterfacePlugin* iDashboard, int iInde
 
 void SKGDashboardPluginWidget::onAddApplet()
 {
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) {
-        emit appletAdded(sender->data().toString());
+    QAction* send = qobject_cast<QAction*>(this->sender());
+    if (send) {
+        emit appletAdded(send->data().toString());
     }
 }
 #include "skgdashboardpluginwidget.moc"
