@@ -28,7 +28,7 @@
 #include <KSplashScreen>
 #include <KCmdLineArgs>
 #include <KAboutData>
-#include <KNewPasswordDialog>
+#include <knewpassworddialog.h>
 #include <KPasswordDialog>
 #include <kwallet.h>
 #include <KGenericFactory>
@@ -494,9 +494,46 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                 }
             } else {
                 this->onNew();
-                err.addError(ERR_FAIL, i18nc("Error message: Could not open a file",  "Failed to open '%1'.", fileName));
+                if (err.getReturnCode() != ERR_CORRUPTION) {
+                    err.addError(ERR_FAIL, i18nc("Error message: Could not open a file",  "Failed to open '%1'.", fileName));
+                }
             }
 
+            // Display error
+            QAction* recovery = NULL;
+#ifdef Q_OS_UNIX
+            if (err.getReturnCode() == ERR_CORRUPTION) {
+                recovery = new QAction(i18nc("Noun", "Try a recovery"), this);
+                recovery->setIcon(KIcon("games-solve"));
+                recovery->setData(SKGServices::stringsToCsv(QStringList() << fileName << pwd));
+                connect(recovery, SIGNAL(triggered(bool)), this, SLOT(onRecover()));
+            }
+#endif
+            SKGMainPanel::displayErrorMessage(err, recovery);
+        }
+    }
+}
+
+void SKGFilePlugin::onRecover()
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGFilePlugin::onRecover", err);
+    QAction* act = qobject_cast< QAction* >(sender());
+    if (act && m_currentDocument && SKGMainPanel::getMainPanel()) {
+        QStringList params = SKGServices::splitCSVLine(act->data().toString());
+        QString recoveredFileName;
+        err = m_currentDocument->recover(params.at(0), params.at(1), recoveredFileName);
+
+        IFOK(err) {
+            // Display recovery message
+            KMessageWidget* msg = SKGMainPanel::getMainPanel()->displayMessage(i18nc("Positive message", "Your document has been recovered here: %1\nTake care the recovery could be not perfect", recoveredFileName), SKGDocument::Positive);
+            QAction* reopen = new QAction(i18nc("Noun", "Open the recovered file"), msg);
+            reopen->setIcon(KIcon("skg_open"));
+            reopen->setData(recoveredFileName);
+            msg->addAction(reopen);
+            connect(reopen, SIGNAL(triggered(bool)), this, SLOT(onReOpen()));
+            connect(reopen, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
+        } else {
             // Display error
             SKGMainPanel::displayErrorMessage(err);
         }
