@@ -20,13 +20,14 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgdocumentfilter.h"
+
+#include <grantlee/util.h>
+#include <cmath>
+
 #include "skgtraces.h"
 #include "skgdocument.h"
 #include "skgmainpanel.h"
 
-#include "grantlee/util.h"
-
-#include <cmath>
 #ifdef Q_OS_WIN
 #define isnan(a) _isnan(a)
 #define isinf(a) !_finite(a)
@@ -113,8 +114,8 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
             table += "</table>";
             return QVariant(table);
         } else if (input.canConvert<SKGObjectBase>()) {
-            SKGObjectBase obj = input.value<SKGObjectBase>();
-            SKGQStringQStringMap att = obj.getAttributes();
+            SKGObjectBase objectBase = input.value<SKGObjectBase>();
+            SKGQStringQStringMap att = objectBase.getAttributes();
             QStringList keys = att.keys();
             QString table = "<table>";
             int nb = keys.count();
@@ -140,8 +141,8 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
             if (nb) {
                 table = "<table><tr><th>#</th>";
                 for (int i = 0; i < nb; ++i) {
-                    SKGObjectBase obj = l.at(i);
-                    SKGQStringQStringMap att = obj.getAttributes();
+                    SKGObjectBase objectBase = l.at(i);
+                    SKGQStringQStringMap att = objectBase.getAttributes();
                     QStringList keys = att.keys();
                     QString line = QString("<tr><td>") % SKGServices::intToString(i) % "</td>";
                     int nbc = keys.count();
