@@ -20,12 +20,13 @@
  * @author Stephane MANKOWSKI
  */
 #include "skggrantleefilters.h"
+
+#include <QtPlugin>
+
 #include "skgdocumentfilter.h"
 #include "skgobjectfilter.h"
 #include "skgtraces.h"
 
-#include <QtPlugin>
-
 SKGGrantleeFilters::SKGGrantleeFilters(QObject* iParent): QObject(iParent)
 {
     SKGTRACEIN(10, "SKGGrantleeFilters::SKGGrantleeFilters");
@@ -40,15 +41,15 @@ QHash< QString, Grantlee::Filter* > SKGGrantleeFilters::filters(const QString& i
 {
     Q_UNUSED(iName);
 
-    QHash<QString, Grantlee::Filter*> filters;
-    filters.insert(QLatin1String("table"), new SKGDocumentTableFilter());
-    filters.insert(QLatin1String("display"), new SKGDocumentDisplayFilter());
-    filters.insert(QLatin1String("att"), new SKGObjectFilter());
-    filters.insert(QLatin1String("money"), new SKGMoneyFilter());
-    filters.insert(QLatin1String("percent"), new SKGPercentFilter());
-    filters.insert(QLatin1String("dump"), new SKGDumpFilter());
-    filters.insert(QLatin1String("encode"), new SKGUrlEncodeFilter());
-    return filters;
+    QHash<QString, Grantlee::Filter*> filtersList;
+    filtersList.insert(QLatin1String("table"), new SKGDocumentTableFilter());
+    filtersList.insert(QLatin1String("display"), new SKGDocumentDisplayFilter());
+    filtersList.insert(QLatin1String("att"), new SKGObjectFilter());
+    filtersList.insert(QLatin1String("money"), new SKGMoneyFilter());
+    filtersList.insert(QLatin1String("percent"), new SKGPercentFilter());
+    filtersList.insert(QLatin1String("dump"), new SKGDumpFilter());
+    filtersList.insert(QLatin1String("encode"), new SKGUrlEncodeFilter());
+    return filtersList;
 }
 
-Q_EXPORT_PLUGIN2(grantlee_skgfilters, SKGGrantleeFilters)
+Q_EXPORT_PLUGIN2(grantlee_skgfilters, SKGGrantleeFilters)   // NOLINT(readability/fn_size)
