@@ -25,6 +25,7 @@
 #include <KStandardAction>
 #include <KAboutData>
 #include <KGenericFactory>
+#include <KTextBrowser>
 
 #include <QPrinter>
 #include <QPrintDialog>
@@ -35,6 +36,7 @@
 #include "skgprint_settings.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
+#include "skgtreeview.h"
 
 /**
  * This plugin factory.
@@ -195,27 +197,38 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
                         for (int p = 1; p <= pageCopies; ++p) {
                             QWidget* w = pages.at(pageToTreat - 1);
                             if (w) {
-                                // Save palette
-                                QPalette previousPalette = w->palette();
+                                SKGTreeView* tw = qobject_cast< SKGTreeView* >(w);
+                                tw = NULL;
+                                if (tw) {
+                                    KTextBrowser* tb = tw->getTextBrowser();
+                                    if (tb) {
+                                        tb->print(iPrinter);
 
-                                // Draw in a picture with white background
-                                QImage image(w->size(), QImage::Format_ARGB32);
-                                QPainter painter2(&image);
-                                QPalette palette;
-                                palette.setColor(QPalette::Background, Qt::white);
-                                w->setPalette(palette);
-                                w->render(&painter2);
-                                painter2.end();
+                                        delete tb;
+                                    }
+                                } else {
+                                    // Save palette
+                                    QPalette previousPalette = w->palette();
 
-                                // Restore palette
-                                w->setPalette(previousPalette);
+                                    // Draw in a picture with white background
+                                    QImage image(w->size(), QImage::Format_ARGB32);
+                                    QPainter painter2(&image);
+                                    QPalette palette;
+                                    palette.setColor(QPalette::Background, Qt::white);
+                                    w->setPalette(palette);
+                                    w->render(&painter2);
+                                    painter2.end();
 
-                                // Print the picture
-                                QSize size = image.size();
-                                size.scale(rect.size(), Qt::KeepAspectRatio);
-                                painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
-                                painter.setWindow(image.rect());
-                                painter.drawImage(0, 0, image);
+                                    // Restore palette
+                                    w->setPalette(previousPalette);
+
+                                    // Print the picture
+                                    QSize size = image.size();
+                                    size.scale(rect.size(), Qt::KeepAspectRatio);
+                                    painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
+                                    painter.setWindow(image.rect());
+                                    painter.drawImage(0, 0, image);
+                                }
 
                                 if (!(i == nbpages && c == docCopies && p == pageCopies)) {
                                     if (!iPrinter->newPage()) {
