@@ -20,17 +20,17 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgselectallplugin.h"
-#include "skgmainpanel.h"
-#include "skgtreeview.h"
-#include "skgtraces.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
 
 #include <QAbstractItemView>
 
+#include "skgmainpanel.h"
+#include "skgtreeview.h"
+#include "skgtraces.h"
 /**
  * This plugin factory.
  */
@@ -40,10 +40,11 @@ K_PLUGIN_FACTORY(SKGSelectAllPluginFactory, registerPlugin<SKGSelectAllPlugin>()
  */
 K_EXPORT_PLUGIN(SKGSelectAllPluginFactory("skg_selectall", "skg_selectall"))
 
-SKGSelectAllPlugin::SKGSelectAllPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGSelectAllPlugin::SKGSelectAllPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
     m_currentDocument(NULL), m_selectAllAction(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGSelectAllPlugin::SKGSelectAllPlugin");
 }
 
@@ -64,7 +65,7 @@ bool SKGSelectAllPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_selectall/skg_selectall.rc");
 
-    //Menu
+    // Menu
     m_selectAllAction = actionCollection()->addAction(KStandardAction::SelectAll, "edit_select_all", this, SLOT(onSelectAll()));
     registerGlobalAction("edit_select_all", m_selectAllAction);
 
@@ -78,8 +79,7 @@ void SKGSelectAllPlugin::refresh()
     if (SKGMainPanel::getMainPanel()) {
         SKGTabPage* page = SKGMainPanel::getMainPanel()->currentPage();
         if (page) {
-            QWidget* widget = page->mainWidget();
-            QAbstractItemView* view = qobject_cast<QAbstractItemView*>(widget);
+            QAbstractItemView* view = qobject_cast<QAbstractItemView*>(page->mainWidget());
             if (view && m_selectAllAction) m_selectAllAction->setEnabled(true);
         }
     }
@@ -117,8 +117,7 @@ void SKGSelectAllPlugin::onSelectAll()
     if (SKGMainPanel::getMainPanel()) {
         SKGTabPage* page = SKGMainPanel::getMainPanel()->currentPage();
         if (page) {
-            QWidget* widget = page->mainWidget();
-            QAbstractItemView* view = qobject_cast<QAbstractItemView*>(widget);
+            QAbstractItemView* view = qobject_cast<QAbstractItemView*>(page->mainWidget());
             if (view) view->selectAll();
         }
     }
