@@ -20,6 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgundoredoplugin.h"
+
+#include <QtGui/QWidget>
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KToolBarPopupAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgtraces.h"
 #include "skgerror.h"
 #include "skgmainpanel.h"
@@ -27,14 +36,6 @@
 #include "skgservices.h"
 #include "skgundoredo_settings.h"
 
-#include <QtGui/QWidget>
-
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <ktoolbarpopupaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -44,10 +45,11 @@ K_PLUGIN_FACTORY(SKGUndoRedoPluginFactory, registerPlugin<SKGUndoRedoPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGUndoRedoPluginFactory("skg_undoredo", "skg_undoredo"))
 
-SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
     m_undoSaveAction(NULL), m_undoAction(NULL), m_redoAction(NULL), m_undoMenu(NULL), m_redoMenu(NULL), m_currentDocument(NULL), m_dockWidget(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGUndoRedoPlugin::SKGUndoRedoPlugin");
 }
 
@@ -73,7 +75,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_undoredo/skg_undoredo.rc");
 
-    //Menu
+    // Menu
     m_undoSaveAction = new KAction(KIcon("document-revert"), i18nc("Verb, action to cancel previous action", "Revert document"), this);
     connect(m_undoSaveAction, SIGNAL(triggered(bool)), this, SLOT(onUndoSave()));
     m_undoSaveAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_Z);
@@ -99,12 +101,12 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_redoAction->setData(1);
     registerGlobalAction("edit_redo", m_redoAction);
 
-    //Menu
+    // Menu
     KAction* act = new KAction(KIcon("edit-clear-history"), i18nc("Verb, action to cancel previous action", "Clear history"), this);
     connect(act, SIGNAL(triggered(bool)), this, SLOT(onClearHistory()));
     registerGlobalAction("edit_clear_history", act);
 
-    //Dock creation
+    // Dock creation
     m_dockWidget = new QDockWidget(SKGMainPanel::getMainPanel());
     m_dockWidget->setObjectName(QString::fromUtf8("skg_undoredo_docwidget"));
     m_dockWidget->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
@@ -135,7 +137,7 @@ void SKGUndoRedoPlugin::refresh()
         if (m_undoAction) m_undoAction->setEnabled(undoPossible);
         if (m_redoAction) m_redoAction->setEnabled(m_currentDocument->getNbTransaction(SKGDocument::REDO) > 0);
 
-        //Refresh undo redo
+        // Refresh undo redo
         QString name;
         m_currentDocument->getTransactionToProcess(SKGDocument::UNDO, &name);
         QString message = i18nc("Verb",  "Undo operation '%1'.", name);
@@ -153,7 +155,7 @@ void SKGUndoRedoPlugin::refresh()
 QWidget* SKGUndoRedoPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGUndoRedoPlugin::getPreferenceWidget");
-    //Read Setting
+    // Read Setting
     if (m_currentDocument) {
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup pref = config->group("skg_undoredo");
@@ -161,10 +163,10 @@ QWidget* SKGUndoRedoPlugin::getPreferenceWidget()
         pref.writeEntry("cleanHistoryOnSave", (m_currentDocument->getParameter("SKG_UNDO_CLEAN_AFTER_SAVE") == "Y"));
     }
 
-    //Create widget
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
-    return widget;
+    // Create widget
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
+    return w;
 }
 
 KConfigSkeleton* SKGUndoRedoPlugin::getPreferenceSkeleton()
@@ -176,11 +178,11 @@ SKGError SKGUndoRedoPlugin::savePreferences() const
 {
     SKGError err;
     if (m_currentDocument) {
-        //Read Setting
+        // Read Setting
         QString max = SKGServices::intToString(skgundoredo_settings::maxNumberOfUndo());
         QString clean = (skgundoredo_settings::cleanHistoryOnSave() ? "Y" : "N");
 
-        //Save setting in document
+        // Save setting in document
         if (max != m_currentDocument->getParameter("SKG_UNDO_MAX_DEPTH")) err = m_currentDocument->setParameter("SKG_UNDO_MAX_DEPTH", max);
         if (clean != m_currentDocument->getParameter("SKG_UNDO_CLEAN_AFTER_SAVE")) err = m_currentDocument->setParameter("SKG_UNDO_CLEAN_AFTER_SAVE", clean);
     }
@@ -220,7 +222,7 @@ SKGAdviceList SKGUndoRedoPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGUndoRedoPlugin::advice");
     SKGAdviceList output;
     if (!iIgnoredAdvice.contains("skgundoredoplugin_too_big")) {
-        //Get nb transaction
+        // Get nb transaction
         int nbObject = m_currentDocument->getNbTransaction();
         int priority = qMin(10, nbObject / 50);
         if (priority > 0) {
@@ -259,11 +261,13 @@ void SKGUndoRedoPlugin::onClearHistory()
         err = m_currentDocument->removeAllTransactions();
         QApplication::restoreOverrideCursor();
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Clear history successfully done.")))
-        else err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -277,11 +281,13 @@ void SKGUndoRedoPlugin::onUndoSave()
         err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDOLASTSAVE);
         QApplication::restoreOverrideCursor();
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Undo successfully done.")))
-        else err.addError(ERR_FAIL, i18nc("Error message",  "Undo failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Undo failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -297,11 +303,13 @@ void SKGUndoRedoPlugin::onUndo()
             err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDO);
         QApplication::restoreOverrideCursor();
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Undo successfully done.")))
-        else err.addError(ERR_FAIL, i18nc("Error message",  "Undo failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Undo failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -335,11 +343,13 @@ void SKGUndoRedoPlugin::onRedo()
             err = m_currentDocument->undoRedoTransaction(SKGDocument::REDO);
         QApplication::restoreOverrideCursor();
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Redo successfully done.")))
-        else err.addError(ERR_FAIL, i18nc("Error message",  "Redo failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Redo failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
