@@ -20,14 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgundoredoplugindockwidget.h"
+
+#include <QHeaderView>
+#include <QResizeEvent>
+
 #include "skgtraces.h"
 #include "skgobjectmodelbase.h"
 #include "skgdocument.h"
 #include "skgmainpanel.h"
 
-#include <QHeaderView>
-#include <QResizeEvent>
-
 SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument)
 {
@@ -36,9 +37,9 @@ SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
-    QPalette palette = QApplication::palette();
-    palette.setColor(QPalette::Base, Qt::transparent);
-    ui.kTransactionList->setPalette(palette);
+    QPalette newPalette = QApplication::palette();
+    newPalette.setColor(QPalette::Base, Qt::transparent);
+    ui.kTransactionList->setPalette(newPalette);
 
     SKGObjectModelBase* modelview = new SKGObjectModelBase(getDocument(), "doctransaction", "1=1 ORDER BY d_date DESC, id DESC", this);
     ui.kTransactionList->setModel(modelview);
@@ -70,11 +71,13 @@ void SKGUndoRedoPluginDockWidget::onClearHistory()
     SKGError err = getDocument()->removeAllTransactions();
     QApplication::restoreOverrideCursor();
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Clear history successfully done.")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -83,7 +86,7 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
     SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::onUndoRedo");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    //Get Selection
+    // Get Selection
     SKGError err;
     SKGDocument::UndoRedoMode mode;
     SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(ui.kTransactionList->model());
@@ -99,24 +102,27 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
     }
     QApplication::restoreOverrideCursor();
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, mode == SKGDocument::UNDO ? i18nc("Message for successful user action", "Undo successfully done.") : i18nc("Message for successful user action", "Redo successfully done.")))
-    else err.addError(ERR_FAIL, mode == SKGDocument::UNDO ? i18nc("Error message", "Undo failed") : i18nc("Error message", "Redo failed"));
+    else {
+        err.addError(ERR_FAIL, mode == SKGDocument::UNDO ? i18nc("Error message", "Undo failed") : i18nc("Error message", "Redo failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGUndoRedoPluginDockWidget::resizeEvent(QResizeEvent* /*event*/)
+void SKGUndoRedoPluginDockWidget::resizeEvent(QResizeEvent* iEvent)
 {
+    Q_UNUSED(iEvent)
     /*
-    QSize newSize=event->size ();
+     Q Size newSize=iEvent*->size ();
 
-    //Compute icon size
+    // Compute icon size
     int s=qMax(qMin(newSize.width()/10,64),16);
     ui.kTransactionList->setIconSize(QSize(s, s));
 
-    QWidget::resizeEvent(event);
+    QWidget::resizeEvent(iEvent);
     */
 }
 #include "skgundoredoplugindockwidget.moc"
