@@ -21,20 +21,20 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginafb120.h"
+
+#include <KLocale>
+#include <KGenericFactory>
+
+#include <QFile>
+#include <QFileInfo>
+#include <qmath.h>
+#include <QCryptographicHash>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
 
-#include <klocale.h>
-#include <kgenericfactory.h>
-
-#include <QFile>
-#include <qfileinfo.h>
-
-#include <qmath.h>
-#include <QCryptographicHash>
-
 /**
  * This plugin factory.
  */
@@ -72,9 +72,7 @@ double SKGImportPluginAFB120::toAmount(const QString& iAmount, int iNbDecimal)
         bool ok = false;
         amount[amount.count() - 1] = QChar(codeAscii + QChar('1').toAscii() - QString(sign == -1 ? "0x4A" : "0x41").toUInt(&ok, 16));
     }
-
-    double d = double(sign) * SKGServices::stringToDouble(amount) / qPow(10, iNbDecimal);
-    return d;
+    return static_cast<double>(sign) * SKGServices::stringToDouble(amount) / qPow(10, iNbDecimal);
 }
 
 SKGError SKGImportPluginAFB120::importFile()
@@ -83,33 +81,32 @@ SKGError SKGImportPluginAFB120::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportAFB120::importFile", err);
 
-    //Begin transaction
+    // Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "AFB120"), 2);
     IFOK(err) {
-        //Open file
+        // Open file
         IFOK(err) {
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             else {
-
-                //Read lines
+                // Read lines
                 QStringList lines;
                 {
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
                     while (!stream.atEnd()) {
-                        //Read line
+                        // Read line
                         QString line = stream.readLine().trimmed();
                         if (!line.isEmpty())  lines.push_back(line);
                     }
                 }
-                //close file
+                // close file
                 file.close();
 
-                //Step 1 done
+                // Step 1 done
                 IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-                //Read lines
+                // Read lines
                 SKGAccountObject account;
                 SKGUnitObject unit;
                 QString bankName = "AFB120";
@@ -118,11 +115,11 @@ SKGError SKGImportPluginAFB120::importFile()
                 int nb = lines.count();
                 IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
-                    //Read line
+                    // Read line
                     QString line = lines.at(i);
                     if (!line.isEmpty()) {
                         if (line.startsWith(QLatin1String("01"))) {
-                            //Previous balance
+                            // Previous balance
                             QString accountNumber = line.mid(22 - 1, 11);
                             inititalAmount = line.mid(91 - 1, 14);
 
@@ -130,7 +127,7 @@ SKGError SKGImportPluginAFB120::importFile()
                             err = m_importer->getDocument()->getObjects("v_account", "t_number='" % accountNumber % '\'', listAccount);
                             IFOK(err) {
                                 if (listAccount.count() == 1) {
-                                    //Yes ! Only one account found
+                                    // Yes ! Only one account found
                                     account = listAccount.at(0);
                                     err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
                                 } else {
@@ -149,7 +146,7 @@ SKGError SKGImportPluginAFB120::importFile()
                                 }
                             }
                         } else if (line.startsWith(QLatin1String("04"))) {
-                            //Operation
+                            // Operation
                             QString unitCode = line.mid(17 - 1, 3);
                             QString nbDecimal = line.mid(20 - 1, 1);
                             QString codeMode = line.mid(33 - 1, 2);
@@ -157,13 +154,13 @@ SKGError SKGImportPluginAFB120::importFile()
                             QString comment = line.mid(49 - 1, 31).trimmed();
                             QString amount = line.mid(91 - 1, 14);
 
-                            //Initialize balance
+                            // Initialize balance
                             if (unit.getID() == 0) {
                                 err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), unitCode, unit);
                                 if (account.getNbOperation() > 1) {
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning))
                                 } else {
-                                    //Set initial balance
+                                    // Set initial balance
                                     IFOKDO(err, account.setInitialBalance(toAmount(inititalAmount, SKGServices::stringToInt(nbDecimal)), unit))
                                     IFOKDO(err, account.save())
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with AFB120 file content", account.getName())))
@@ -191,7 +188,7 @@ SKGError SKGImportPluginAFB120::importFile()
                 }
                 SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-                //Step 2 done
+                // Step 2 done
                 IFOKDO(err, m_importer->getDocument()->stepForward(2))
             }
         }
