@@ -20,23 +20,24 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginbackend.h"
+
+#include <QFile>
+#include <QFileInfo>
+#include <QDir>
+#include <QProcess>
+#include <QtConcurrentMap>
+#include <QApplication>
+
+#include <KLocale>
+#include <KAboutData>
+#include <KGenericFactory>
+#include <KStandardDirs>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
 
-#include <QFile>
-#include <qfileinfo.h>
-#include <QDir>
-#include <qprocess.h>
-#include <qtconcurrentmap.h>
-#include <QApplication>
-
-#include <klocale.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-#include <kstandarddirs.h>
-
 /**
  * This plugin factory.
  */
@@ -77,15 +78,15 @@ struct download {
         QString file = QDir::tempPath() % "/" % iAccountId % ".csv";
         int retry = 0;
         do {
-            //Build cmd
+            // Build cmd
             QString cmd = m_cmd;
             cmd = cmd.replace("%2", SKGServices::intToString(m_nbToDownload)).replace("%1", iAccountId).replace("%3", m_pwd);
 
-            //Execute
+            // Execute
             QProcess p;
             p.setStandardOutputFile(file);
             p.start(cmd);
-            if (p.waitForFinished() && p.exitCode() == 0) return iAccountId;
+            if (p.waitForFinished(1000 * 60 * 2) && p.exitCode() == 0) return iAccountId;
             ++retry;
         } while (retry < 6);
         return "";
@@ -107,11 +108,11 @@ SKGError SKGImportPluginBackend::importFile()
     QString bankendName = m_importer->getFileNameExtension().toLower();
     err = SKGServices::readPropertyFile(KStandardDirs().findResource("data", "skrooge/backends/" % bankendName % ".backend"), properties);
     IFOK(err) {
-        //Get parameters
+        // Get parameters
         QMap<QString, QString> parameters = this->getImportParameters();
         QString pwd = parameters["password"];
 
-        //Get list of accounts
+        // Get list of accounts
         QStringList backendAccounts;
         QMap<QString, QString> backendAccountsBalance;
         QString csvfile = QDir::tempPath() % "/skrooge_backend.csv";
@@ -119,7 +120,7 @@ SKGError SKGImportPluginBackend::importFile()
         QProcess p;
         p.setStandardOutputFile(csvfile);
         p.start(cmd);
-        if (!p.waitForFinished() || p.exitCode() != 0) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+        if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
         else {
             QFile file(csvfile);
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
@@ -128,49 +129,53 @@ SKGError SKGImportPluginBackend::importFile()
                 QRegExp reggetaccountbalance(properties["getaccountbalance"]);
 
                 QTextStream stream(&file);
-                stream.readLine();//To avoid header
+                stream.readLine();  // To avoid header
                 while (!stream.atEnd()) {
-                    //Read line
+                    // Read line
                     QString line = stream.readLine().trimmed();
 
-                    //Get account id
+                    // Get account id
                     int pos = reggetaccounts.indexIn(line);
                     if (pos > -1) {
                         QString accountid = reggetaccounts.cap(1);
                         if (!backendAccounts.contains(accountid)) {
                             backendAccounts.push_back(accountid);
 
-                            //Get account balance
+                            // Get account balance
                             pos = reggetaccountbalance.indexIn(line);
                             if (pos > -1) backendAccountsBalance[accountid] = reggetaccountbalance.cap(1);
-                            else backendAccountsBalance[accountid] = '0';
+                            else {
+                                backendAccountsBalance[accountid] = '0';
+                            }
                         }
                     } else {
-                        //This is an error
+                        // This is an error
                         err.setReturnCode(ERR_FAIL).setMessage(line).addError(ERR_FAIL, i18nc("Error message",  "Impossible to find the account id with the regular expression '%1' in line '%2'", properties["getaccountid"], line));
                         break;
                     }
                 }
 
-                //close file
+                // close file
                 file.close();
                 file.remove();
             }
         }
 
-        //Download operations
+        // Download operations
         IFOKDO(err, m_importer->getDocument()->stepForward(1, i18nc("Progress message", "Download operations")))
         IFOK(err) {
             if (backendAccounts.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
             else {
-                //Download qif file
+                // Download qif file
                 QDate lastDownload = SKGServices::stringToTime(m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE")).date();
                 QString lastList = m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_LIST");
                 QString currentList = backendAccounts.join(";");
 
                 int nbToDownload = 0;
                 if (currentList != lastList) nbToDownload = 99999;
-                else nbToDownload = qMax(lastDownload.daysTo(QDate::currentDate()) * 10, 20);
+                else {
+                    nbToDownload = qMax(lastDownload.daysTo(QDate::currentDate()) * 10, 20);
+                }
                 QStringList listDownloadedId;
                 {
                     SKGTRACEINRC(10, "SKGImportExportPlugin::importbackend-download", err);
@@ -180,32 +185,32 @@ SKGError SKGImportPluginBackend::importFile()
                 }
                 listDownloadedId.removeAll("");
 
-                //Check
+                // Check
                 int nb = listDownloadedId.count();
                 if (100 * nb / backendAccounts.count() < 80) {
-                    //Some accounts have not been downloaded
+                    // Some accounts have not been downloaded
                     if (nb == 0) {
                         err = SKGError(ERR_FAIL, i18nc("Error message", "No accounts downloaded with the following command:\n%1\nCheck your backend installation.", properties["getoperations"]));
                     } else {
-                        //Warning
+                        // Warning
                         m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded"), SKGDocument::Warning);
                     }
                 }
 
-                //import
+                // import
                 IFOKDO(err, m_importer->getDocument()->stepForward(2, i18nc("Progress message", "Import")))
                 if (!err && nb) {
-                    //import
+                    // import
                     SKGBEGINPROGRESSTRANSACTION(*m_importer->getDocument(), "#INTERNAL#" % i18nc("Noun, name of the user action", "Import one account with %1", "Backend"), err, nb);
 
-                    //Get all messages
+                    // Get all messages
                     QStringList messages;
                     QList<SKGDocument::MessageType> types;
                     IFOKDO(err, m_importer->getDocument()->getMessages(m_importer->getDocument()->getCurrentTransaction(), messages, types, true))
 
-                    //Import all files
+                    // Import all files
                     for (int i = 0; !err && i < nb; ++i) {
-                        //Import
+                        // Import
                         QString file = QDir::tempPath() % "/" % listDownloadedId.at(i) % ".csv";
                         SKGImportExportManager imp1(m_importer->getDocument(), file);
                         imp1.setAutomaticValidation(m_importer->automaticValidation());
@@ -213,22 +218,22 @@ SKGError SKGImportPluginBackend::importFile()
                         imp1.setSinceLastImportDate(m_importer->sinceLastImportDate());
                         imp1.setCodec(m_importer->getCodec());
 
-                        QMap<QString, QString> parameters = imp1.getImportParameters();
-                        parameters["automatic_search_header"] = 'N';
-                        parameters["header_position"] = '1';
-                        parameters["automatic_search_columns"] = 'N';
-                        parameters["columns_positions"] = properties["csvcolumns"];
-                        parameters["mode_csv_unit"] = 'N';
-                        parameters["balance"] = backendAccountsBalance[listDownloadedId.at(i)];
-                        if (i != nb - 1) parameters["donotfinalize"] = 'Y';
-                        imp1.setImportParameters(parameters);
+                        QMap<QString, QString> newParameters = imp1.getImportParameters();
+                        newParameters["automatic_search_header"] = 'N';
+                        newParameters["header_position"] = '1';
+                        newParameters["automatic_search_columns"] = 'N';
+                        newParameters["columns_positions"] = properties["csvcolumns"];
+                        newParameters["mode_csv_unit"] = 'N';
+                        newParameters["balance"] = backendAccountsBalance[listDownloadedId.at(i)];
+                        if (i != nb - 1) newParameters["donotfinalize"] = 'Y';
+                        imp1.setImportParameters(newParameters);
                         IFOKDO(err, imp1.importFile())
 
                         QFile::remove(file);
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    //Reset message
+                    // Reset message
                     IFOKDO(err, m_importer->getDocument()->removeMessages(m_importer->getDocument()->getCurrentTransaction()))
                     int nbm = messages.count();
                     for (int j = 0; j < nbm; ++j)
