@@ -20,19 +20,20 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportplugincsv.h"
+
+#include <KLocale>
+#include <KFilterDev>
+#include <KSaveFile>
+#include <KGenericFactory>
+
+#include <QCryptographicHash>
+#include <QFileInfo>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
 
-#include <klocale.h>
-#include <kfilterdev.h>
-#include <ksavefile.h>
-#include <kgenericfactory.h>
-
-#include <QCryptographicHash>
-#include <qfileinfo.h>
-
 /**
  * This plugin factory.
  */
@@ -107,13 +108,13 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
     QStringList output;
     QString line = iLine.trimmed();
 
-    //Split first line
+    // Split first line
     QStringList csvAttributes = SKGServices::splitCSVLine(line, ';', true, &m_csvSeparator);
     int nb = csvAttributes.count();
     for (int i = 0; i < nb; ++i) {
         QString att = csvAttributes[i].toLower();
 
-        //Search if this csv column is mapping a std attribute
+        // Search if this csv column is mapping a std attribute
         QMapIterator<QString, QString> csvMapperIterator(m_parameters);
         bool found = false;
         while (!found && csvMapperIterator.hasNext()) {
@@ -133,7 +134,7 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
             }
         }
 
-        //Search if this csv column must be added as a property
+        // Search if this csv column must be added as a property
         if (!found &&
                 !m_parameters["mapping_property"].isEmpty() &&
                 QRegExp(m_parameters["mapping_property"], Qt::CaseInsensitive).indexIn(att) != -1 &&
@@ -142,7 +143,7 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
             found = true;
         }
 
-        if (!found) output.push_back("");      //To ignore this column
+        if (!found) output.push_back("");      // To ignore this column
     }
     return output;
 }
@@ -155,33 +156,35 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
     m_csvMapping.clear();
 
     if (iCSVMapping == NULL) {
-        //Automatic build
-        //Open file
+        // Automatic build
+        // Open file
         QFile file(m_importer->getLocalFileName());
         if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
-            //Ignore useless lines
+            // Ignore useless lines
             int headerIndex = getCSVHeaderIndex();
             for (int i = 1; i < headerIndex; ++i)
                 stream.readLine();
 
-            //Get mapping
+            // Get mapping
             if (!stream.atEnd()) m_csvMapping = getCSVMappingFromLine(stream.readLine());
-            else err.setReturnCode(ERR_INVALIDARG);
+            else {
+                err.setReturnCode(ERR_INVALIDARG);
+            }
 
-            //close file
+            // close file
             file.close();
         }
     } else {
-        //Manual build
+        // Manual build
         m_csvMapping = *iCSVMapping;
     }
 
     IFOK(err) {
-        //Check if mandatory attributes have been found
+        // Check if mandatory attributes have been found
         if (!m_csvMapping.contains("date") || !m_csvMapping.contains("amount"))
             err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings."));
     }
@@ -201,8 +204,8 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
     SKGTRACEINRC(10, "SKGImportPluginCsv::setCSVHeaderIndex", err);
 
     if (iIndex == -1) {
-        //Automatic build
-        //Open file
+        // Automatic build
+        // Open file
         QFile file(m_importer->getLocalFileName());
         if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         else {
@@ -212,18 +215,18 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
             int i = 1;
             m_csvHeaderIndex = -1;
             while (!stream.atEnd() && m_csvHeaderIndex == -1) {
-                //Read line
+                // Read line
                 QStringList map = getCSVMappingFromLine(stream.readLine());
                 if (map.contains("date") && map.contains("amount")) m_csvHeaderIndex = i;
 
                 ++i;
             }
 
-            //close file
+            // close file
             file.close();
         }
     } else {
-        //Manual build
+        // Manual build
         m_csvHeaderIndex = iIndex;
     }
 
@@ -250,24 +253,24 @@ SKGError SKGImportPluginCsv::importFile()
 
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginCsv::importFile", err);
-    //Begin transaction
+    // Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "CSV"), 3);
     IFOK(err) {
-        //Initialize some variables
+        // Initialize some variables
         QDateTime now = QDateTime::currentDateTime();
         QString postFix = SKGServices::dateToSqlString(now);
 
-        //Default mapping
+        // Default mapping
         if (getCSVMapping().count() == 0) {
             err = setCSVMapping(NULL);
             IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
         }
         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Mapping used: %1", getCSVMapping().join("|"))))
 
-        //Step 1 done
+        // Step 1 done
         IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-        //Open file
+        // Open file
         IFOK(err) {
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
@@ -275,7 +278,7 @@ SKGError SKGImportPluginCsv::importFile()
                 QTextStream stream(&file);
                 if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
-                //Ignore useless lines
+                // Ignore useless lines
                 int headerIndex = getCSVHeaderIndex();
                 if (headerIndex == -1) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Header not found in CSV file"));
 
@@ -289,7 +292,7 @@ SKGError SKGImportPluginCsv::importFile()
                 }
                 int nbAmount = amountIndexes.count();
 
-                //Get data column
+                // Get data column
                 QStringList dates;
                 QStringList lines;
                 bool modeAutoCreditDebit = (!getCSVMapping().contains("sign") && nbAmount == 2);
@@ -298,22 +301,22 @@ SKGError SKGImportPluginCsv::importFile()
                     if (posdate != -1) {
                         QString currentLine;
                         while (!stream.atEnd()) {
-                            //Read line
+                            // Read line
                             QString line = stream.readLine().trimmed();
                             if (!line.isEmpty()) {
                                 currentLine += line;
 
-                                //Get date
+                                // Get date
                                 QStringList field = SKGServices::splitCSVLine(currentLine, getCSVSeparator());
                                 if (field.count() == 0) {
-                                    //This is a multi line csv filename
+                                    // This is a multi line csv filename
                                 } else {
                                     lines.push_back(currentLine);
                                     currentLine.clear();
 
                                     if (posdate < field.count()) dates.push_back(field.at(posdate).trimmed());
 
-                                    //Check if all amounts are positive
+                                    // Check if all amounts are positive
                                     if (modeAutoCreditDebit) {
                                         for (int i = 0; modeAutoCreditDebit && i < nbAmount; ++i) {
                                             QString s = field.at(amountIndexes.at(i)).trimmed();
@@ -326,24 +329,24 @@ SKGError SKGImportPluginCsv::importFile()
                     }
                 }
 
-                //close file
+                // close file
                 file.close();
 
-                //Select dateformat
+                // Select dateformat
                 QString dateFormat = m_parameters["date_format"];
-                if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
+                if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates);  // Automatic detection
                 if (!err && dateFormat.isEmpty())err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
-                //Step 2 done
+                // Step 2 done
                 IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-                //Treat all lines
+                // Treat all lines
                 IFOK(err) {
                     int nb2 = lines.size();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb2);
 
-                    //Save last mapping used in a settings
+                    // Save last mapping used in a settings
                     QString mappingDesc;
                     int nbMap = getCSVMapping().count();
                     for (int i = 0; i < nbMap; ++i) {
@@ -365,7 +368,7 @@ SKGError SKGImportPluginCsv::importFile()
                         SKGOperationObject currentOperation(m_importer->getDocument());
                         SKGSubOperationObject currentSubOperation(m_importer->getDocument());
 
-                        //Valuate mandatory attribute with default value
+                        // Valuate mandatory attribute with default value
                         if (noUnitColumn && i == 0) err = m_importer->getDefaultUnit(defUnit);
                         IFOKDO(err, currentOperation.setUnit(defUnit))
 
@@ -404,12 +407,19 @@ SKGError SKGImportPluginCsv::importFile()
                                     if (!val.isEmpty()) err = currentOperation.setNumber(SKGServices::stringToInt(val));
                                 } else if (col == "mode") {
                                     if (val == "1") val = i18nc("An operation mode", "Transfer");
-                                    else if (val == "2") val = i18nc("An operation mode", "Direct debit");
-                                    else if (val == "3") val = i18nc("An operation mode", "Check");
-                                    else if (val == "6") val = i18nc("An operation mode", "Withdrawal");
-                                    else if (val == "7") val = i18nc("An operation mode", "Card");
-                                    else if (val == "9") val = i18nc("An operation mode", "Subscription");
-                                    else if (val == "0") val = "";
+                                    else if (val == "2") {
+                                        val = i18nc("An operation mode", "Direct debit");
+                                    } else if (val == "3") {
+                                        val = i18nc("An operation mode", "Check");
+                                    } else if (val == "6") {
+                                        val = i18nc("An operation mode", "Withdrawal");
+                                    } else if (val == "7") {
+                                        val = i18nc("An operation mode", "Card");
+                                    } else if (val == "9") {
+                                        val = i18nc("An operation mode", "Subscription");
+                                    } else if (val == "0") {
+                                        val = "";
+                                    }
                                     err = currentOperation.setMode(val);
                                 } else if (col == "payee") {
                                     SKGPayeeObject payeeObj;
@@ -433,13 +443,13 @@ SKGError SKGImportPluginCsv::importFile()
                                     if (!val.isEmpty() && !amountSet) {
                                         amountSet = true;
                                         if (getCSVMapping().contains("quantity")) {
-                                            //209705 vvvv
+                                            // 209705 vvvv
                                             skg_op_original_amount = val;
-                                            //209705 ^^^^
+                                            // 209705 ^^^^
                                         } else {
                                             err = currentSubOperation.setQuantity(sign * SKGServices::stringToDouble(val));
                                         }
-                                    } else if (modeAutoCreditDebit) sign = 1.0; //Next one will be considered as a credit
+                                    } else if (modeAutoCreditDebit) sign = 1.0;  // Next one will be considered as a credit
                                 } else if (col == "quantity") {
                                     err = currentSubOperation.setQuantity(SKGServices::stringToDouble(val));
                                 } else if (col == "sign") {
@@ -449,14 +459,14 @@ SKGError SKGImportPluginCsv::importFile()
                                         if (cval > 0) err = currentSubOperation.setQuantity(-cval);
                                     }
                                 } else if (col == "unit") {
-                                    //Looking for unit
+                                    // Looking for unit
                                     SKGUnitObject unit(m_importer->getDocument());
-                                    if (val != defUnit.getName()) { //For performance
+                                    if (val != defUnit.getName()) {  // For performance
                                         err = unit.setName(val);
                                         IFOKDO(err, unit.setSymbol(val))
-                                        if (!err && unit.load().isFailed())  err = unit.save(false);    //Save only
+                                        if (!err && unit.load().isFailed())  err = unit.save(false);    // Save only
 
-                                        //This unit is now the default one, it's better for performance
+                                        // This unit is now the default one, it's better for performance
                                         defUnit = unit;
                                     } else {
                                         unit = defUnit;
@@ -477,48 +487,48 @@ SKGError SKGImportPluginCsv::importFile()
                                     IFOKDO(err, unitval.save())
                                     IFOKDO(err, currentOperation.setUnit(unit))
                                 } else if (col == "account") {
-                                    //Looking for account
-                                    if (val != defAccount.getName()) { //For performance
+                                    // Looking for account
+                                    if (val != defAccount.getName()) {  // For performance
                                         SKGAccountObject account(m_importer->getDocument());
                                         account.setName(val);
                                         err = account.load();
                                         IFKO(err) {
-                                            //Not found, we have to create one
+                                            // Not found, we have to create one
                                             SKGBankObject bank(m_importer->getDocument());
                                             QString name = i18nc("Noun",  "Bank for import %1", postFix);
                                             err = bank.setName(name);
                                             if (!err && bank.load().isFailed()) {
-                                                err = bank.save(false);   //Save only
+                                                err = bank.save(false);   // Save only
                                                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default bank '%1' created for import", name)))
                                             }
                                             IFOKDO(err, bank.addAccount(account))
                                             IFOKDO(err, account.setName(val))
-                                            if (!err && account.load().isFailed())  err = account.save(false);     //Save only
+                                            if (!err && account.load().isFailed())  err = account.save(false);     // Save only
                                         }
 
-                                        //This account is now the default one, it's better for performance
+                                        // This account is now the default one, it's better for performance
                                         defAccount = account;
                                     }
                                     IFOKDO(err, currentOperation.setParentAccount(defAccount))
                                 } else if (col == "category") {
-                                    //Set Category
+                                    // Set Category
                                     if (!val.isEmpty()) {
-                                        //Prepare val
+                                        // Prepare val
                                         val.replace('/', OBJECTSEPARATOR);
                                         val.replace(':', OBJECTSEPARATOR);
                                         val.replace(',', OBJECTSEPARATOR);
                                         val.replace(';', OBJECTSEPARATOR);
-                                        //Get previous category
+                                        // Get previous category
                                         if (!currentCategory.isEmpty()) val = currentCategory % OBJECTSEPARATOR % val;
                                         currentCategory = val;
 
-                                        //Create and set category
+                                        // Create and set category
                                         SKGCategoryObject Category;
                                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), val, Category);
                                         IFOKDO(err, currentSubOperation.setCategory(Category))
                                     }
                                 } else {
-                                    //A property
+                                    // A property
                                     propertiesAtt.push_back(col);
                                     propertiesVal.push_back(val);
                                 }
@@ -526,7 +536,7 @@ SKGError SKGImportPluginCsv::importFile()
                         }
 
                         if (!err && initialBalance) {
-                            //Specific values for initial balance
+                            // Specific values for initial balance
                             err = currentOperation.setStatus(SKGOperationObject::CHECKED);
                             IFOKDO(err, currentOperation.setAttribute("d_date", "0000-00-00"))
                         }
@@ -541,7 +551,7 @@ SKGError SKGImportPluginCsv::importFile()
                                     mapOperation[idtransaction] = currentOperation;
                                 }
                             } else {
-                                err = currentOperation.save(false);   //Save only
+                                err = currentOperation.save(false);   // Save only
                             }
                         }
                         if (!err && idgroup != 0) {
@@ -555,13 +565,13 @@ SKGError SKGImportPluginCsv::importFile()
                         IFOKDO(err, currentSubOperation.setParentOperation(currentOperation))
                         IFOKDO(err, currentSubOperation.save(false, false))
 
-                        //209705 vvvv
+                        // 209705 vvvv
                         if (!err && !skg_op_original_amount.isEmpty()) {
                             err = currentOperation.setProperty("SKG_OP_ORIGINAL_AMOUNT", skg_op_original_amount);
                         }
-                        //209705 ^^^^
+                        // 209705 ^^^^
 
-                        //Add properties
+                        // Add properties
                         int nbp = propertiesAtt.count();
                         for (int p = 0; !err && p < nbp; ++p) {
                             err = currentOperation.setProperty(propertiesAtt.at(p) , propertiesVal.at(p));
@@ -576,21 +586,23 @@ SKGError SKGImportPluginCsv::importFile()
                         QString balance = m_parameters["balance"];
                         if (!balance.isEmpty()) {
                             if (emptyAccount) {
-                                //Current amount
+                                // Current amount
                                 double currentAmount = defAccount.getAmount(QDate::currentDate());
 
-                                //Update account
+                                // Update account
                                 IFOKDO(err, defAccount.setInitialBalance(SKGServices::stringToDouble(balance) - currentAmount, defUnit))
                                 IFOKDO(err, defAccount.save())
                                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()), SKGDocument::Warning))
 
-                            } else m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", defAccount.getName()));
+                            } else {
+                                m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", defAccount.getName()));
+                            }
                         }
                     }
 
                     SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-                    //Lines treated
+                    // Lines treated
                     IFOKDO(err, m_importer->getDocument()->stepForward(3))
                 }
             }
@@ -614,7 +626,7 @@ SKGError SKGImportPluginCsv::exportFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportCsv::exportFile", err);
 
-    //Open file
+    // Open file
     KSaveFile file(m_importer->getLocalFileName(false));
     if (!file.open())err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
     else {
@@ -628,7 +640,7 @@ SKGError SKGImportPluginCsv::exportFile()
                   "FROM v_operation_consolidated as v, unit as u WHERE v.rc_unit_id=u.id ORDER BY v.d_date, v.id, v.i_SUBOPID", &out, SKGServices::DUMP_CSV);
     }
 
-    //Close file
+    // Close file
     file.finalize();
     file.close();
 
@@ -646,23 +658,23 @@ SKGError SKGImportPluginCsv::importCSVUnit()
     SKGTRACEINRC(2, "SKGImportPluginCsv::importCSVUnit", err);
 
     if (m_importer->getDocument()) {
-        //Begin transaction
+        // Begin transaction
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), 3);
         IFOK(err) {
-            //File name is the name of the unit
+            // File name is the name of the unit
             QFileInfo fInfo(m_importer->getFileName().path());
             QString unitName = fInfo.baseName();
 
-            //Default mapping
+            // Default mapping
             if (getCSVMapping().count() == 0) {
                 err = setCSVMapping(NULL);
                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
             }
 
-            //Step 1 done
+            // Step 1 done
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-            //Open file
+            // Open file
             IFOK(err) {
                 QFile file(m_importer->getLocalFileName());
                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
@@ -670,46 +682,46 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
-                    //Ignore useless lines
+                    // Ignore useless lines
                     int headerIndex = getCSVHeaderIndex();
                     for (int i = 1; i <= headerIndex; ++i)
                         stream.readLine();
 
-                    //Get data column
+                    // Get data column
                     QStringList dates;
                     QStringList lines;
                     int posdate = m_csvMapping.indexOf("date");
                     if (posdate != -1) {
                         while (!stream.atEnd()) {
-                            //Read line
+                            // Read line
                             QString line = stream.readLine().trimmed();
                             if (!line.isEmpty()) {
                                 lines.push_back(line);
 
-                                //Get date
+                                // Get date
                                 QStringList field = SKGServices::splitCSVLine(line);
                                 if (posdate < field.count()) dates.push_back(field.at(posdate));
                             }
                         }
                     }
 
-                    //close file
+                    // close file
                     file.close();
 
-                    //Select dateformat
+                    // Select dateformat
                     QString dateFormat = SKGServices::getDateFormat(dates);
                     if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
-                    //Step 2 done
+                    // Step 2 done
                     IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-                    //Treat all lines
+                    // Treat all lines
                     IFOK(err) {
                         int nb = lines.size();
                         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
 
-                        //Save last mapping used in a settings
+                        // Save last mapping used in a settings
                         QString mappingDesc;
                         int nbMap = m_csvMapping.count();
                         for (int i = 0; i < nbMap; ++i) {
@@ -733,7 +745,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
 
                         SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-                        //Lines treated
+                        // Lines treated
                         IFOKDO(err, m_importer->getDocument()->stepForward(3))
                     }
                 }
