@@ -21,15 +21,17 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
+#include <QSet>
+
 #include "skgimportplugin.h"
 
-#include <QSet>
 class SKGDocumentBank;
 class SKGUnitObject;
 class SKGAccountObject;
 class SKGCategoryObject;
 class SKGOperationObject;
 class SKGPayeeObject;
+class SKGObjectBase;
 class QDomDocument;
 class QDomElement;
 
@@ -93,6 +95,8 @@ private:
     static QString kmyValue(double iValue);
     static double toKmyValue(const QString& iString);
 
+    static QString getKmyUniqueIdentifier(const SKGObjectBase& iObject);
+
     static QSet<QString>  m_opTreated;
     static QMap<QString, SKGUnitObject> m_mapIdUnit;
     static QMap<QString, SKGAccountObject> m_mapIdAccount;
@@ -100,4 +104,4 @@ private:
     static QMap<QString, SKGPayeeObject> m_mapIdPayee;
 };
 
-#endif // SKGIMPORTPLUGINKMY_H
+#endif  // SKGIMPORTPLUGINKMY_H
