@@ -20,22 +20,23 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginmmb.h"
+
+#include <KIO/NetAccess>
+#include <KGenericFactory>
+
+#include <QFile>
+#include <QSqlDatabase>
+#include <QSqlError>
+#include <QFileInfo>
+
+#include <KLocale>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgobjectbase.h"
 #include "skgimportexportmanager.h"
 
-#include <kio/netaccess.h>
-#include <kgenericfactory.h>
-
-#include <QFile>
-#include <QSqlDatabase>
-#include <QSqlError>
-#include <qfileinfo.h>
-
-#include <klocale.h>
-
 /**
  * This plugin factory.
  */
@@ -72,7 +73,7 @@ SKGError SKGImportPluginMmb::importFile()
         QSqlDatabase originalDocument(QSqlDatabase::addDatabase("QSQLITE", "originalDocument"));
         originalDocument.setDatabaseName(m_importer->getLocalFileName());
         if (!originalDocument.open()) {
-            //Set error message
+            // Set error message
             QSqlError sqlErr = originalDocument.lastError();
             err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
         }
@@ -80,7 +81,7 @@ SKGError SKGImportPluginMmb::importFile()
             QMap<QString, SKGUnitObject> mapUnit;
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MMB"), 9);
 
-            //Step 1 - units
+            // Step 1 - units
             IFOK(err) {
                 SKGStringListList listUnits;
                 err = SKGServices::executeSelectSqliteOrder(&originalDocument, "SELECT CURRENCYID, CURRENCYNAME, PFX_SYMBOL, SFX_SYMBOL, DECIMAL_POINT, GROUP_SEPARATOR, UNIT_NAME, CENT_NAME, SCALE, BASECONVRATE, CURRENCY_SYMBOL, "
@@ -111,7 +112,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-            //Step 2 - bank and accounts
+            // Step 2 - bank and accounts
             QMap<QString, SKGAccountObject> mapAccount;
             IFOK(err) {
                 SKGStringListList listAccounts;
@@ -122,7 +123,7 @@ SKGError SKGImportPluginMmb::importFile()
                     for (int i = 0; !err && i < nb; ++i) {
                         QStringList attributes = listAccounts.at(i + 1);
 
-                        //Create bank
+                        // Create bank
                         SKGBankObject bank(m_importer->getDocument());
                         IFOK(err) {
                             QString bankName = attributes.at(6);
@@ -131,7 +132,7 @@ SKGError SKGImportPluginMmb::importFile()
                         }
                         IFOKDO(err, bank.save())
 
-                        //Create account
+                        // Create account
                         SKGAccountObject account;
                         err = bank.addAccount(account);
                         IFOKDO(err, account.setName(attributes.at(1)))
@@ -155,7 +156,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-            //Step 3 - categories
+            // Step 3 - categories
             QMap<QString, SKGCategoryObject> mapCategory;
             IFOK(err) {
                 SKGStringListList listCategories;
@@ -180,7 +181,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
-            //Step 4 - sub categories
+            // Step 4 - sub categories
             QMap<QString, SKGCategoryObject> mapSubCategory;
             IFOK(err) {
                 SKGStringListList listCategories;
@@ -206,7 +207,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-            //Step 5 - payee
+            // Step 5 - payee
             QMap<QString, SKGPayeeObject> mapPayee;
             IFOK(err) {
                 SKGStringListList listPayee;
@@ -231,7 +232,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-            //Step 6 - operations
+            // Step 6 - operations
             QMap<QString, SKGOperationObject> mapOperation;
             IFOK(err) {
                 SKGStringListList listOperations;
@@ -243,7 +244,7 @@ SKGError SKGImportPluginMmb::importFile()
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         QStringList attributes = listOperations.at(i + 1);
-                        if (attributes.at(6) != "V") { //Void
+                        if (attributes.at(6) != "V") {  // Void
                             bool recurrent = (attributes.at(14) != "N/A");
                             QString idTarget = attributes.at(2);
                             SKGAccountObject acc = mapAccount[attributes.at(1)];
@@ -267,14 +268,14 @@ SKGError SKGImportPluginMmb::importFile()
                             IFOKDO(err, op.setStatus(attributes.at(6) == "R" ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
                             IFOKDO(err, op.save())
 
-                            //Get splits
+                            // Get splits
                             IFOK(err) {
                                 SKGStringListList listSubOperations;
                                 err = SKGServices::executeSelectSqliteOrder(&originalDocument, QString("SELECT SPLITTRANSID, CATEGID, SUBCATEGID, SPLITTRANSAMOUNT FROM ") % (recurrent ? "BUDGET" : "") % "SPLITTRANSACTIONS_V1 WHERE TRANSID=" % attributes.at(0), listSubOperations);
                                 IFOK(err) {
                                     int nb2 = listSubOperations.count() - 1;
                                     if (nb2 <= 0) {
-                                        //No split
+                                        // No split
                                         SKGSubOperationObject subop;
                                         IFOKDO(err, op.addSubOperation(subop))
                                         IFOK(err) {
@@ -282,7 +283,9 @@ SKGError SKGImportPluginMmb::importFile()
                                             if (id == "-1") {
                                                 id = attributes.at(9);
                                                 if (id != "-1") err = subop.setCategory(mapSubCategory[id]);
-                                            } else err = subop.setCategory(mapCategory[id]);
+                                            } else {
+                                                err = subop.setCategory(mapCategory[id]);
+                                            }
                                         }
                                         IFOK(err) {
                                             double q = SKGServices::stringToDouble(attributes.at(5));
@@ -291,7 +294,7 @@ SKGError SKGImportPluginMmb::importFile()
                                         }
                                         IFOKDO(err, subop.save())
                                     } else {
-                                        //Has splits
+                                        // Has splits
                                         for (int j = 0; !err && j < nb2; ++j) {
                                             QStringList attributesSubOp = listSubOperations.at(j + 1);
 
@@ -302,7 +305,9 @@ SKGError SKGImportPluginMmb::importFile()
                                                 if (id == "-1") {
                                                     id = attributesSubOp.at(1);
                                                     if (id != "-1") err = subop.setCategory(mapCategory[id]);
-                                                } else err = subop.setCategory(mapSubCategory[id]);
+                                                } else {
+                                                    err = subop.setCategory(mapSubCategory[id]);
+                                                }
                                             }
                                             IFOK(err) {
                                                 double q = SKGServices::stringToDouble(attributesSubOp.at(3));
@@ -315,7 +320,7 @@ SKGError SKGImportPluginMmb::importFile()
                                 }
                             }
 
-                            //Case transfert
+                            // Case transfert
                             if (!err && idTarget != "-1") {
                                 SKGOperationObject op2;
                                 err = op.duplicate(op2, op.getDate());
@@ -337,7 +342,7 @@ SKGError SKGImportPluginMmb::importFile()
                                 IFOKDO(err, op.save())
                             }
 
-                            //Create reccurent transaction
+                            // Create reccurent transaction
                             if (recurrent) {
                                 SKGRecurrentOperationObject recu;
                                 IFOKDO(err, op.addRecurrentOperation(recu))
@@ -351,52 +356,52 @@ SKGError SKGImportPluginMmb::importFile()
                                 IFOK(err) {
                                     switch (repeats) {
                                     case 1:
-                                        //Weekly
+                                        // Weekly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::WEEK);
                                         IFOKDO(err, recu.setPeriodIncrement(1))
                                         break;
                                     case 2:
-                                        //Bi-Weekly
+                                        // Bi-Weekly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::WEEK);
                                         IFOKDO(err, recu.setPeriodIncrement(2))
                                         break;
                                     case 3:
-                                        //Monthly
+                                        // Monthly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
                                         IFOKDO(err, recu.setPeriodIncrement(1))
                                         break;
                                     case 4:
-                                        //Bi-Monthly
+                                        // Bi-Monthly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
                                         IFOKDO(err, recu.setPeriodIncrement(2))
                                         break;
                                     case 5:
-                                        //Quarterly
+                                        // Quarterly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
                                         IFOKDO(err, recu.setPeriodIncrement(3))
                                         break;
                                     case 6:
-                                        //Half yearly
+                                        // Half yearly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
                                         IFOKDO(err, recu.setPeriodIncrement(6))
                                         break;
                                     case 7:
-                                        //Yearly
+                                        // Yearly
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::YEAR);
                                         IFOKDO(err, recu.setPeriodIncrement(1))
                                         break;
                                     case 8:
-                                        //Four months
+                                        // Four months
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
                                         IFOKDO(err, recu.setPeriodIncrement(4))
                                         break;
                                     case 9:
-                                        //Four weeks
+                                        // Four weeks
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::WEEK);
                                         IFOKDO(err, recu.setPeriodIncrement(4))
                                         break;
                                     case 10:
-                                        //Daily
+                                        // Daily
                                         err = recu.setPeriodUnit(SKGRecurrentOperationObject::DAY);
                                         IFOKDO(err, recu.setPeriodIncrement(1))
                                         break;
@@ -418,7 +423,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
-            //Step 7 - stock
+            // Step 7 - stock
             IFOK(err) {
                 SKGStringListList listStock;
                 err = SKGServices::executeSelectSqliteOrder(&originalDocument, "SELECT STOCKID, HELDAT, PURCHASEDATE, STOCKNAME, SYMBOL, NUMSHARES, PURCHASEPRICE, NOTES, CURRENTPRICE, VALUE, COMMISSION FROM STOCK_V1", listStock);
@@ -428,7 +433,7 @@ SKGError SKGImportPluginMmb::importFile()
                     for (int i = 0; !err && i < nb; ++i) {
                         QStringList attributes = listStock.at(i + 1);
 
-                        //Create unit
+                        // Create unit
                         SKGUnitObject unit(m_importer->getDocument());
                         err = unit.setName(attributes.at(3));
                         IFOKDO(err, unit.setSymbol(attributes.at(4)))
@@ -447,7 +452,7 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, unitValue2.setQuantity(SKGServices::stringToDouble(attributes.at(8))))
                         IFOKDO(err, unitValue2.save(true, false))
 
-                        //Create operation
+                        // Create operation
                         SKGAccountObject acc = mapAccount[attributes.at(1)];
                         SKGUnitObject unitCurrency;
                         IFOKDO(err, acc.getUnit(unitCurrency))
@@ -491,20 +496,20 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(7))
 
-            //Step 8 - asset
+            // Step 8 - asset
             IFOK(err) {
                 SKGStringListList listAssets;
                 err = SKGServices::executeSelectSqliteOrder(&originalDocument, "SELECT ASSETID, STARTDATE, ASSETNAME, VALUE, VALUECHANGE, NOTES, VALUECHANGERATE, ASSETTYPE FROM ASSETS_V1", listAssets);
                 IFOK(err) {
                     int nb = listAssets.count() - 1;
                     if (nb) {
-                        //Create account
-                        //Create bank
+                        // Create account
+                        // Create bank
                         SKGBankObject bank(m_importer->getDocument());
                         IFOKDO(err, bank.setName("MMEX"))
                         IFOKDO(err, bank.save())
 
-                        //Create account
+                        // Create account
                         SKGAccountObject account;
                         err = bank.addAccount(account);
                         IFOKDO(err, account.setName(i18nc("Noun, a type of account", "Assets")))
@@ -515,7 +520,7 @@ SKGError SKGImportPluginMmb::importFile()
                         for (int i = 0; !err && i < nb; ++i) {
                             QStringList attributes = listAssets.at(i + 1);
 
-                            //Create unit
+                            // Create unit
                             SKGUnitObject unit(m_importer->getDocument());
                             err = unit.setName(attributes.at(2));
                             IFOKDO(err, unit.setSymbol(attributes.at(2)))
@@ -529,7 +534,7 @@ SKGError SKGImportPluginMmb::importFile()
                             IFOKDO(err, unitValue.setQuantity(SKGServices::stringToDouble(attributes.at(3))))
                             IFOKDO(err, unitValue.save(true, false))
 
-                            //Create operation
+                            // Create operation
                             SKGOperationObject op;
                             IFOKDO(err, account.addOperation(op, true))
                             IFOKDO(err, op.setComment(attributes.at(5)))
@@ -553,7 +558,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(8))
 
-            //Step 9 - budgets
+            // Step 9 - budgets
             IFOK(err) {
                 SKGStringListList listBudgets;
                 err = SKGServices::executeSelectSqliteOrder(&originalDocument, "SELECT BUDGETENTRYID, (SELECT Y.BUDGETYEARNAME FROM BUDGETYEAR_V1 Y WHERE Y.BUDGETYEARID=BUDGETTABLE_V1.BUDGETYEARID), CATEGID, SUBCATEGID, PERIOD, AMOUNT FROM BUDGETTABLE_V1", listBudgets);
@@ -591,16 +596,18 @@ SKGError SKGImportPluginMmb::importFile()
                         }
 
                         if (step) {
-                            for (int i = 0; !err && i < 12; i = i + step) {
+                            for (int j = 0; !err && j < 12; j = j + step) {
                                 SKGBudgetObject bug(m_importer->getDocument());
                                 err = bug.setYear(SKGServices::stringToInt(attributes.at(1)));
-                                IFOKDO(err, bug.setMonth(step == 12 ? 0 : i + 1))
+                                IFOKDO(err, bug.setMonth(step == 12 ? 0 : j + 1))
                                 IFOK(err) {
                                     QString id = attributes.at(3);
                                     if (id == "-1") {
                                         id = attributes.at(2);
                                         if (id != "-1") err = bug.setCategory(mapCategory[id]);
-                                    } else err = bug.setCategory(mapSubCategory[id]);
+                                    } else {
+                                        err = bug.setCategory(mapSubCategory[id]);
+                                    }
                                 }
                                 IFOKDO(err, bug.setBudgetedAmount(coef * SKGServices::stringToDouble(attributes.at(5))))
                                 IFOKDO(err, bug.save())
@@ -619,7 +626,6 @@ SKGError SKGImportPluginMmb::importFile()
 
             IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("ANALYZE"))
         }
-
     }
     QSqlDatabase::removeDatabase("originalDocument");
     return err;
