@@ -20,6 +20,16 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginmny.h"
+
+#include <KLocale>
+#include <KGenericFactory>
+#include <KStandardDirs>
+
+#include <QDir>
+#include <QProcess>
+#include <QUuid>
+#include <qjson/parser.h>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
@@ -27,15 +37,6 @@
 #include "skgimportexportmanager.h"
 #include "skgpayeeobject.h"
 
-#include <klocale.h>
-#include <kgenericfactory.h>
-#include <kstandarddirs.h>
-
-#include <QDir>
-#include <QProcess>
-#include <QUuid>
-#include <qjson/parser.h>
-
 QMap<QString, SKGUnitObject> SKGImportPluginMny::m_mapIdSecurity;
 QMap<QString, SKGAccountObject> SKGImportPluginMny::m_mapIdAccount;
 QMap<QString, SKGCategoryObject> SKGImportPluginMny::m_mapIdCategory;
@@ -119,7 +120,7 @@ SKGError SKGImportPluginMny::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginMny::importFile", err);
 
-    //Check install
+    // Check install
     if (KStandardDirs::findExe("java").isEmpty()) {
         err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The java application is not installed"));
         err.setProperty("application", "java");
@@ -139,13 +140,13 @@ SKGError SKGImportPluginMny::importFile()
         }
     }
 
-    //Initialisation
+    // Initialisation
     m_mapIdSecurity.clear();
     m_mapIdAccount.clear();
     m_mapIdCategory.clear();
     m_mapIdPayee.clear();
 
-    //Execute sunriise
+    // Execute sunriise
     QString uniqueId = QUuid::createUuid().toString();
     QString temporaryPath = QDir::tempPath() % "/" % uniqueId;
     removeDir(temporaryPath);
@@ -158,10 +159,10 @@ SKGError SKGImportPluginMny::importFile()
         SKGTRACEINRC(10, "SKGImportPluginMny::importFile-SUNRIISE", err);
         p.start(cmd);
     }
-    if (p.waitForFinished() && p.exitCode() == 0) {
-        //Import
+    if (p.waitForFinished(1000 * 60 * 5) && p.exitCode() == 0) {
+        // Import
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MNY"), 6);
-        //Step 1-Import categories
+        // Step 1-Import categories
         IFOK(err) {
             /*[ {
             "id" : 137,
@@ -177,7 +178,7 @@ SKGError SKGImportPluginMny::importFile()
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-CATEGORY", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
-                //Create categories
+                // Create categories
                 int index = 0;
                 for (int t = 0; !err && t < 20 && index < nb; ++t) {
                     for (int i = 0; !err && i < nb && index < nb; ++i) {
@@ -207,7 +208,7 @@ SKGError SKGImportPluginMny::importFile()
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
         }
 
-        //Step 2-Import payees
+        // Step 2-Import payees
         IFOK(err) {
             QVariant var;
             err = readJsonFile(temporaryPath % "/payees.json", var);
@@ -216,14 +217,14 @@ SKGError SKGImportPluginMny::importFile()
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-PAYEE", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
-                //Create categories
+                // Create categories
                 for (int i = 0; !err && i < nb; ++i) {
                     QVariantMap payee = list[i].toMap();
 
                     QString id = payee["id"].toString();
                     QString name = payee["name"].toString();
 
-                    //Is already created?
+                    // Is already created?
                     SKGPayeeObject payeeObject(m_importer->getDocument());
                     err = payeeObject.setName(name);
                     IFOKDO(err, payeeObject.save())
@@ -238,7 +239,7 @@ SKGError SKGImportPluginMny::importFile()
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
         }
 
-        //Step 3-Import securities
+        // Step 3-Import securities
         IFOK(err) {
             QVariant var;
             err = readJsonFile(temporaryPath % "/securities.json", var);
@@ -247,7 +248,7 @@ SKGError SKGImportPluginMny::importFile()
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-UNITS", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
-                //Create categories
+                // Create categories
                 for (int i = 0; !err && i < nb; ++i) {
                     QVariantMap unit = list[i].toMap();
 
@@ -256,12 +257,12 @@ SKGError SKGImportPluginMny::importFile()
                     QString symbol = unit["symbol"].toString();
                     if (symbol.isEmpty()) symbol = name;
 
-                    //Is already created?
+                    // Is already created?
                     SKGUnitObject unitobject(m_importer->getDocument());
                     err = unitobject.setName(name);
                     IFOKDO(err, unitobject.setSymbol(symbol))
                     IFOKDO(err, unitobject.setType(SKGUnitObject::SHARE))
-                    //The unit is not saved because it will be saved when used
+                    // The unit is not saved because it will be saved when used
 
                     m_mapIdSecurity[id] = unitobject;
 
@@ -273,7 +274,7 @@ SKGError SKGImportPluginMny::importFile()
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
         }
 
-        //Step 4-Import accounts
+        // Step 4-Import accounts
         IFOK(err) {
             /*
             {
@@ -295,7 +296,7 @@ SKGError SKGImportPluginMny::importFile()
                 "creditCard" : false,
                 "401k403b" : false
             }*/
-            //List directories
+            // List directories
             QStringList list = temporaryDir.entryList(QStringList() << "*.d", QDir::Dirs);
             SKGTRACEINRC(10, "SKGImportPluginMny::importFile-ACCOUNTS", err);
             int nb = list.count();
@@ -305,7 +306,7 @@ SKGError SKGImportPluginMny::importFile()
             IFOKDO(err, bank.setName("Microsof Money"))
             IFOKDO(err, bank.save())
 
-            //Create accounts
+            // Create accounts
             for (int i = 0; !err && i < nb; ++i) {
                 QString accountDir = list[i];
 
@@ -313,11 +314,11 @@ SKGError SKGImportPluginMny::importFile()
                 err = readJsonFile(temporaryPath % "/" % accountDir % "/account.json", var);
                 QVariantMap account = var.toMap();
                 IFOK(err) {
-                    //Create currency
+                    // Create currency
                     SKGUnitObject unitObj;
                     SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), account["currencyCode"].toString(), unitObj);
 
-                    //Create account
+                    // Create account
                     SKGAccountObject accountObj;
                     err = bank.addAccount(accountObj);
                     IFOKDO(err, accountObj.setName(account["name"].toString()))
@@ -327,10 +328,10 @@ SKGError SKGImportPluginMny::importFile()
                                                    type == 3 ? SKGAccountObject::ASSETS :
                                                    type == 5 ? SKGAccountObject::INVESTMENT :
                                                    type == 6 ? SKGAccountObject::LOAN :
-                                                   SKGAccountObject::OTHER));//TODO
+                                                   SKGAccountObject::OTHER));  // TODO(Stephane MANKOWSKI)
                     IFOKDO(err, accountObj.save())
 
-                    //Update initial balance
+                    // Update initial balance
                     IFOKDO(err, accountObj.setInitialBalance(account["startingBalance"].toDouble(), unitObj))
 
                     IFOKDO(err, accountObj.setClosed(account["closed"].toBool()))
@@ -346,15 +347,15 @@ SKGError SKGImportPluginMny::importFile()
         }
         IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-        //Step 5-Import operation
+        // Step 5-Import operation
         IFOK(err) {
-            //List directories
+            // List directories
             QStringList list = temporaryDir.entryList(QStringList() << "*.d", QDir::Dirs);
             SKGTRACEINRC(10, "SKGImportPluginMny::importFile-OPERATIONS", err);
             int nb = list.count();
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
 
-            //Create accounts
+            // Create accounts
             int index = 0;
             for (int i = 0; !err && i < nb; ++i) {
                 QString accountDir = list[i];
@@ -388,7 +389,7 @@ SKGError SKGImportPluginMny::importFile()
                             IFOKDO(err, operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation["date"].toULongLong()).date()))
                             IFOKDO(err, operationObj.setComment(operation["memo"].toString()))
                             IFOK(err) {
-                                //The number is something like "0     4220725"
+                                // The number is something like "0     4220725"
                                 QString number = operation["number"].toString();
                                 if (!number.isEmpty()) {
                                     QStringList ln = SKGServices::splitCSVLine(number, ' ');
@@ -406,11 +407,11 @@ SKGError SKGImportPluginMny::importFile()
 
                             double amount = operation["amount"].toDouble();
 
-                            //Is it a split?
+                            // Is it a split?
                             QVariantList splits = operation["splits"].toList();
                             int nbs = splits.count();
                             if (nbs) {
-                                //Yes
+                                // Yes
                                 for (int k = 0; !err && k < nbs; ++k) {
                                     QVariantMap split = splits[k].toMap();
                                     QVariantMap transaction = split["transaction"].toMap();
@@ -426,9 +427,9 @@ SKGError SKGImportPluginMny::importFile()
                                     amount -= splitAmount;
                                 }
 
-                                //Is the amount equal to the sum of split?
+                                // Is the amount equal to the sum of split?
                                 if (qAbs(amount) > 0.00001) {
-                                    //Create one more sub operation to align amounts
+                                    // Create one more sub operation to align amounts
                                     SKGSubOperationObject subOperationObj;
                                     IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                     IFOKDO(err, subOperationObj.setQuantity(amount))
@@ -438,7 +439,7 @@ SKGError SKGImportPluginMny::importFile()
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("Warning message", "The operation '%1' has been repaired because its amount was not equal to the sum of the amounts of its splits", operationObj.getDisplayName()), SKGDocument::Warning))
                                 }
                             } else {
-                                //No
+                                // No
                                 SKGSubOperationObject subOperationObj;
                                 IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                 QString catId = operation["categoryId"].toString();
@@ -466,7 +467,7 @@ SKGError SKGImportPluginMny::importFile()
 
         IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-        //Step 6-Group operation
+        // Step 6-Group operation
         if (!err && m_parameters["find_and_group_transfers"] == "Y") {
             int nbg = 0;
             err = m_importer->findAndGroupTransfers(nbg, true);
@@ -477,12 +478,14 @@ SKGError SKGImportPluginMny::importFile()
         SKGENDTRANSACTION(m_importer->getDocument(),  err);
     } else {
         if (p.exitCode() == 1) err.setReturnCode(ERR_ENCRYPTION).setMessage(i18nc("Error message",  "Invalid password"));
-        else err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The execution of '%1' failed", cmd)).addError(ERR_FAIL, i18nc("Error message",  "The extraction from the Microsoft Money document '%1' failed", m_importer->getFileName().prettyUrl()));
+        else {
+            err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The execution of '%1' failed", cmd)).addError(ERR_FAIL, i18nc("Error message",  "The extraction from the Microsoft Money document '%1' failed", m_importer->getFileName().prettyUrl()));
+        }
     }
 
     removeDir(temporaryPath);
 
-    //Clean
+    // Clean
     m_mapIdSecurity.clear();
     m_mapIdAccount.clear();
     m_mapIdCategory.clear();
