@@ -20,18 +20,19 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginmt940.h"
+
+#include <QFile>
+#include <QFileInfo>
+
+#include <KLocale>
+#include <KGenericFactory>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgobjectbase.h"
 #include "skgimportexportmanager.h"
 
-#include <QFile>
-#include <qfileinfo.h>
-
-#include <klocale.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -64,32 +65,32 @@ SKGError SKGImportPluginMT940::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportMt940::importFile", err);
 
-    //Begin transaction
+    // Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MT940"), 2);
     IFOK(err) {
-        //Open file
+        // Open file
         IFOK(err) {
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             else {
-                //Read lines
+                // Read lines
                 QStringList lines;
                 {
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
                     while (!stream.atEnd()) {
-                        //Read line
+                        // Read line
                         QString line = stream.readLine().trimmed();
                         if (!line.isEmpty())  lines.push_back(line);
                     }
                 }
-                //close file
+                // close file
                 file.close();
 
-                //Step 1 done
+                // Step 1 done
                 IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-                //Read lines
+                // Read lines
                 bool importActivated = false;
                 bool in86 = false;
                 SKGAccountObject account;
@@ -100,7 +101,7 @@ SKGError SKGImportPluginMT940::importFile()
                 int nb = lines.count();
                 IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
-                    //Read line
+                    // Read line
                     QString line = lines.at(i);
                     if (!line.isEmpty()) {
                         if (line.startsWith(QLatin1String(":20:"))) {
@@ -109,7 +110,7 @@ SKGError SKGImportPluginMT940::importFile()
                             bankName = line.right(line.count() - 4);
                         } else if (importActivated) {
                             if (line.startsWith(QLatin1String(":25:"))) {
-                                //Account
+                                // Account
                                 QStringList vals = SKGServices::splitCSVLine(line.right(line.count() - 4), '/');
                                 QString name = "MT940";
                                 QString number = name;
@@ -122,12 +123,12 @@ SKGError SKGImportPluginMT940::importFile()
                                     name = number;
                                 }
 
-                                //Search if account is already existing
+                                // Search if account is already existing
                                 SKGObjectBase::SKGListSKGObjectBase listAccount;
                                 err = m_importer->getDocument()->getObjects("v_account", "t_number='" % number % '\'', listAccount);
                                 IFOK(err) {
                                     if (listAccount.count() == 1) {
-                                        //Yes ! Only one account found
+                                        // Yes ! Only one account found
                                         account = listAccount.at(0);
                                         err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
                                     } else {
@@ -152,11 +153,11 @@ SKGError SKGImportPluginMT940::importFile()
                             } else if (line.startsWith(QLatin1String(":60F:")) || line.startsWith(QLatin1String(":60M:"))) {
                                 QString val = line.right(line.count() - 5);
                                 err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), val.mid(7, 3), unit);
-                                //Example C040802EUR16,40
+                                // Example C040802EUR16,40
                                 if (account.getNbOperation() > 1) {
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning))
                                 } else {
-                                    //Set initial balance
+                                    // Set initial balance
                                     IFOKDO(err, account.setInitialBalance((val[0] == 'C' ? 1.0 : -1.0) * SKGServices::stringToDouble(val.right(val.count() - 10)), unit))
                                     IFOKDO(err, account.save())
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with MT940 file content", account.getName())))
@@ -166,7 +167,7 @@ SKGError SKGImportPluginMT940::importFile()
                             } else if (line.startsWith(QLatin1String(":62F:")) || line.startsWith(QLatin1String(":62M:"))) {
                                 in86 = false;
                             } else if (line.startsWith(QLatin1String(":61:"))) {
-                                //Example :61:0712280103D000000000200,00FMSCNONREF
+                                // Example :61:0712280103D000000000200,00FMSCNONREF
                                 QString val = line.right(line.count() - 4);
                                 QDate date = QDate::fromString(val.left(6), "yyMMdd");
                                 if (date.year() < 1970) date = date.addYears(100);
@@ -191,7 +192,7 @@ SKGError SKGImportPluginMT940::importFile()
                                 IFOKDO(err, operation.setDate(date))
                                 IFOKDO(err, operation.setUnit(unit))
                                 IFOKDO(err, operation.setAttribute("t_imported", "T"))
-                                //if(!err) err = operation.setImportID("MT940");
+                                // if(!err) err = operation.setImportID("MT940");
                                 IFOKDO(err, operation.save())
 
                                 SKGSubOperationObject subop;
@@ -227,7 +228,7 @@ SKGError SKGImportPluginMT940::importFile()
                 }
                 SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-                //Step 2 done
+                // Step 2 done
                 IFOKDO(err, m_importer->getDocument()->stepForward(2))
             }
         }
