@@ -20,16 +20,17 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginofx.h"
+
+#include <QFileInfo>
+
+#include <KLocale>
+#include <KGenericFactory>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
 
-#include <qfileinfo.h>
-
-#include <klocale.h>
-#include <kgenericfactory.h>
-
 SKGError SKGImportPluginOfx::m_ofxError;
 QList<OfxStatementData> SKGImportPluginOfx::m_ofxInitialBalance;
 
@@ -79,37 +80,37 @@ SKGError SKGImportPluginOfx::importFile()
             ofx_set_account_cb(ctx, SKGImportPluginOfx::ofxAccountCallback, m_importer);
             ofx_set_statement_cb(ctx, SKGImportPluginOfx::ofxStatementCallback, m_importer);
             ofx_set_transaction_cb(ctx, SKGImportPluginOfx::ofxTransactionCallback, m_importer);
-            //ofx_set_security_cb(ctx, ofxSecurityCallback, this);
+            // ofx_set_security_cb(ctx, ofxSecurityCallback, this);
             int rc = libofx_proc_file(ctx, m_importer->getLocalFileName().toUtf8(), AUTODETECT);
             if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName().prettyUrl()));
             IFOKDO(err, SKGImportPluginOfx::m_ofxError) {
-                //This is an option ==> no error management
+                // This is an option ==> no error management
                 SKGError err2;
                 int nb = SKGImportPluginOfx::m_ofxInitialBalance.count();
                 for (int i = 0; !err2 && i < nb; ++i) {
                     OfxStatementData data = SKGImportPluginOfx::m_ofxInitialBalance.at(i);
 
-                    //Get account
+                    // Get account
                     SKGAccountObject act;
                     if (!err2) err2 = getAccount(data.account_ptr, m_importer->getDocument(), act);
 
-                    //Date of balance
-                    QDate date = (data.ledger_balance_date_valid == true ? QDateTime::fromTime_t (data.ledger_balance_date).date() : QDate::currentDate());
+                    // Date of balance
+                    QDate date = (data.ledger_balance_date_valid == true ? QDateTime::fromTime_t(data.ledger_balance_date).date() : QDate::currentDate());
 
-                    //Get unit
+                    // Get unit
                     SKGUnitObject unit;
                     if (!err2) err2 = m_importer->getDefaultUnit(unit);
 
-                    //Current amount
+                    // Current amount
                     double currentAmount = act.getAmount(date);
 
-                    //Update account
+                    // Update account
                     if (!err2) err2 = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
                     if (!err2) err2 = act.save();
                     if (!err2) err2 = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
                 }
             }
-        } catch (...) {
+        } catch (...) {  // NOLINT(whitespace/parens)
             err = SKGError(ERR_HANDLE, i18nc("Error message", "OFX import failed"));
         }
 
@@ -125,17 +126,17 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
     SKGError err;
     QString accountNumber = iAccountData->account_id;
     QString bankNumber = iAccountData->bank_id;
-    //Correction BUG 234771 vvvvv
+    // Correction BUG 234771 vvvvv
     accountNumber = accountNumber.trimmed();
     bankNumber = bankNumber.trimmed();
-    //Correction BUG 234771 ^^^^^
+    // Correction BUG 234771 ^^^^^
     if (accountNumber.startsWith(bankNumber % ' ')) {
         accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
         QStringList splitNumbers = accountNumber.split(' ');
         if (splitNumbers.count() == 2) accountNumber = splitNumbers.at(1);
     }
 
-    //Check if account is already existing
+    // Check if account is already existing
     err = iDoc->getObject("v_account", "t_number='" % accountNumber % '\'', oAccount);
 
     return err;
@@ -151,10 +152,10 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
     SKGDocumentBank* doc = impotExporter->getDocument();
     if (!doc) return 0;
 
-    ////Get data
+    // // Get data
     OfxAccountData* accountData = data.account_ptr;
     if (accountData && data.ledger_balance_valid == true) {
-        //Get account
+        // Get account
         SKGAccountObject act;
         SKGImportPluginOfx::m_ofxError = getAccount(accountData, doc, act);
         if (!SKGImportPluginOfx::m_ofxError) {
@@ -184,10 +185,10 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         QString agencyNumber = QString::fromUtf8(data.branch_id);
         QString accountNumber = QString::fromUtf8(data.account_id);
         QString bankNumber = QString::fromUtf8(data.bank_id);
-        //Correction BUG 234771 vvvvv
+        // Correction BUG 234771 vvvvv
         accountNumber = accountNumber.trimmed();
         bankNumber = bankNumber.trimmed();
-        //Correction BUG 234771 ^^^^^
+        // Correction BUG 234771 ^^^^^
         if (accountNumber.startsWith(bankNumber % ' ')) {
             accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
             QStringList splitNumbers = accountNumber.split(' ');
@@ -197,35 +198,37 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
             }
         }
 
-        //Check if account is already existing
+        // Check if account is already existing
         SKGAccountObject account;
         SKGImportPluginOfx::m_ofxError = getAccount(&data, doc, account);
         if (!SKGImportPluginOfx::m_ofxError) {
-            //Already existing
+            // Already existing
             account = tmp;
             SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
         } else {
-            //Not existing
+            // Not existing
             QString bankId = (data.bank_id_valid == true ? QString::fromUtf8(data.bank_id) : (data.broker_id_valid == true ? QString::fromUtf8(data.broker_id) : i18nc("Adjective, an unknown item", "Unknown")));
             if (!bankId.isEmpty()) {
-                //Check if bank is already existing
+                // Check if bank is already existing
                 SKGBankObject bank;
                 SKGImportPluginOfx::m_ofxError = doc->getObject("v_bank", "t_bank_number='" % bankId % '\'', tmp);
                 if (!SKGImportPluginOfx::m_ofxError) {
-                    //Already existing
+                    // Already existing
                     bank = tmp;
                 } else {
-                    //Create new bank
+                    // Create new bank
                     bank = SKGBankObject(doc);
                     SKGImportPluginOfx::m_ofxError = bank.setName(bankId);
                     if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = bank.setNumber(QString::fromUtf8(data.bank_id));
                     if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = bank.save();
                 }
 
-                //Create new account
+                // Create new account
                 QString name = QString::fromUtf8(data.account_name);
                 if (name.isEmpty()) name = QString::fromUtf8(data.account_id);
-                else name = name.remove("Bank account ");
+                else {
+                    name = name.remove("Bank account ");
+                }
 
                 if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = bank.addAccount(account);
                 if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.setName(name);
@@ -263,15 +266,15 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         }
     }
     if (data.currency_valid == true) {
-        //Check if unit is already existing
+        // Check if unit is already existing
         SKGUnitObject unit(doc);
         SKGImportPluginOfx::m_ofxError = doc->getObject("v_unit", "t_name='" % QString::fromUtf8(data.currency) % "' OR t_name like '%(" % QString::fromUtf8(data.currency) % ")%'", tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
-            //Already existing
+            // Already existing
             unit = tmp;
             SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultUnit(&unit);
         } else {
-            //Create new account
+            // Create new account
             SKGImportPluginOfx::m_ofxError = unit.setName(QString::fromUtf8(data.currency));
             if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = unit.setSymbol(QString::fromUtf8(data.currency));
             if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = unit.save();
@@ -292,18 +295,18 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
     SKGDocumentBank* doc = impotExporter->getDocument();
     if (!doc) return 0;
 
-    //Get account
+    // Get account
     SKGAccountObject account;
     SKGImportPluginOfx::m_ofxError = getAccount(data.account_ptr, doc, account);
     if (!SKGImportPluginOfx::m_ofxError) {
-        //Get operation date
-        QDate date = QDateTime::fromTime_t (data.date_posted_valid == true ? data.date_posted : data.date_initiated).date();
+        // Get operation date
+        QDate date = QDateTime::fromTime_t(data.date_posted_valid == true ? data.date_posted : data.date_initiated).date();
 
-        //Get unit
+        // Get unit
         SKGUnitObject unit;
         SKGImportPluginOfx::m_ofxError = impotExporter->getDefaultUnit(unit);
 
-        //Create id
+        // Create id
         QString ID;
         if (data.fi_id_valid == true) {
             if (QString::fromUtf8(data.fi_id).count('0') != QString::fromUtf8(data.fi_id).count()) ID = QString("ID-") % QString::fromUtf8(data.fi_id);
@@ -311,7 +314,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             if (QString::fromUtf8(data.reference_number).count('0') != QString::fromUtf8(data.reference_number).count()) ID = QString("REF-") % data.reference_number;
         }
 
-        //Create operation
+        // Create operation
         SKGOperationObject ope;
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.addOperation(ope, true);
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setDate(date);
@@ -321,7 +324,9 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         if (!SKGImportPluginOfx::m_ofxError) {
             QString payeeName;
             if (data.payee_id_valid == true) payeeName = QString::fromUtf8(data.payee_id);
-            else if (data.name_valid == true) payeeName = QString::fromUtf8(data.name);
+            else if (data.name_valid == true) {
+                payeeName = QString::fromUtf8(data.name);
+            }
             if (!payeeName.isEmpty()) {
                 SKGPayeeObject payeeObj;
                 SKGImportPluginOfx::m_ofxError = SKGPayeeObject::createPayee(doc, payeeName, payeeObj);
@@ -334,43 +339,58 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         if (!SKGImportPluginOfx::m_ofxError && data.transactiontype_valid == true) {
             QString mode;
             if (data.transactiontype == OFX_CREDIT) mode = i18nc("Noun, type of OFX transaction", "Credit");
-            else if (data.transactiontype == OFX_DEBIT) mode = i18nc("Noun, type of OFX transaction", "Debit");
-            else if (data.transactiontype == OFX_INT) mode = i18nc("Noun, type of OFX transaction", "Interest");
-            else if (data.transactiontype == OFX_DIV) mode = i18nc("Noun, type of OFX transaction", "Dividend");
-            else if (data.transactiontype == OFX_FEE) mode = i18nc("Noun, type of OFX transaction", "FI fee");
-            else if (data.transactiontype == OFX_SRVCHG) mode = i18nc("Noun, type of OFX transaction", "Service charge");
-            else if (data.transactiontype == OFX_DEP) mode = i18nc("Noun, type of OFX transaction", "Deposit");
-            else if (data.transactiontype == OFX_ATM) mode = i18nc("Noun, type of OFX transaction", "ATM");
-            else if (data.transactiontype == OFX_POS) mode = i18nc("Noun, type of OFX transaction", "Point of sale");
-            else if (data.transactiontype == OFX_XFER) mode = i18nc("An operation mode", "Transfer");
-            else if (data.transactiontype == OFX_CHECK) mode = i18nc("An operation mode", "Check");
-            else if (data.transactiontype == OFX_PAYMENT) mode = i18nc("Noun, type of OFX transaction", "Electronic payment");
-            else if (data.transactiontype == OFX_CASH) mode = i18nc("An operation mode", "Withdrawal");
-            else if (data.transactiontype == OFX_DIRECTDEP) mode = i18nc("Noun, type of OFX transaction", "Deposit");
-            else if (data.transactiontype == OFX_REPEATPMT) mode = i18nc("Noun, type of OFX transaction", "Repeating payment");
-            else if (data.transactiontype == OFX_DIRECTDEBIT) mode = i18nc("An operation mode", "Direct debit");
+            else if (data.transactiontype == OFX_DEBIT) {
+                mode = i18nc("Noun, type of OFX transaction", "Debit");
+            } else if (data.transactiontype == OFX_INT) {
+                mode = i18nc("Noun, type of OFX transaction", "Interest");
+            } else if (data.transactiontype == OFX_DIV) {
+                mode = i18nc("Noun, type of OFX transaction", "Dividend");
+            } else if (data.transactiontype == OFX_FEE) {
+                mode = i18nc("Noun, type of OFX transaction", "FI fee");
+            } else if (data.transactiontype == OFX_SRVCHG) {
+                mode = i18nc("Noun, type of OFX transaction", "Service charge");
+            } else if (data.transactiontype == OFX_DEP) {
+                mode = i18nc("Noun, type of OFX transaction", "Deposit");
+            } else if (data.transactiontype == OFX_ATM) {
+                mode = i18nc("Noun, type of OFX transaction", "ATM");
+            } else if (data.transactiontype == OFX_POS) {
+                mode = i18nc("Noun, type of OFX transaction", "Point of sale");
+            } else if (data.transactiontype == OFX_XFER) {
+                mode = i18nc("An operation mode", "Transfer");
+            } else if (data.transactiontype == OFX_CHECK) {
+                mode = i18nc("An operation mode", "Check");
+            } else if (data.transactiontype == OFX_PAYMENT) {
+                mode = i18nc("Noun, type of OFX transaction", "Electronic payment");
+            } else if (data.transactiontype == OFX_CASH) {
+                mode = i18nc("An operation mode", "Withdrawal");
+            } else if (data.transactiontype == OFX_DIRECTDEP) {
+                mode = i18nc("Noun, type of OFX transaction", "Deposit");
+            } else if (data.transactiontype == OFX_REPEATPMT) {
+                mode = i18nc("Noun, type of OFX transaction", "Repeating payment");
+            } else if (data.transactiontype == OFX_DIRECTDEBIT) {
+                mode = i18nc("An operation mode", "Direct debit");
+            }
 
             SKGImportPluginOfx::m_ofxError = ope.setMode(mode);
         }
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.save();
 
-        //Create sub operation
+        // Create sub operation
         SKGSubOperationObject subop;
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop);
         if (!SKGImportPluginOfx::m_ofxError && data.amount_valid == true) SKGImportPluginOfx::m_ofxError = subop.setQuantity(data.amount + (data.commission_valid == true ? data.commission : 0));
         if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) SKGImportPluginOfx::m_ofxError = subop.setComment(QString::fromUtf8(data.memo));
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop.save();
 
-        //Commission
+        // Commission
         if (!SKGImportPluginOfx::m_ofxError && data.commission_valid == true && data.amount_valid == true && data.commission > 0) {
-            //Create splitter operation
+            // Create splitter operation
             SKGSubOperationObject subop2;
             if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop2);
             if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop2.setComment(i18nc("Noun, a quantity of money taken by a financial institution to perform an operation", "Commission"));
             if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop2.setQuantity(-data.commission);
             if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = subop2.save();
         }
-
     }
     return SKGImportPluginOfx::m_ofxError.getReturnCode();
 }
