@@ -20,20 +20,21 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginskg.h"
+
+#include <QFile>
+#include <QFileInfo>
+#include <QSqlDatabase>
+#include <QSqlError>
+
+#include <KLocale>
+#include <KGenericFactory>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgobjectbase.h"
 #include "skgimportexportmanager.h"
 
-#include <QFile>
-#include <qfileinfo.h>
-#include <QSqlDatabase>
-#include <QSqlError>
-
-#include <klocale.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -76,7 +77,7 @@ SKGError SKGImportPluginSkg::importFile()
             QMap<QString, SKGObjectBase> mapOriginNew;
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "SKG"), 10);
 
-            //Step 1 - units
+            // Step 1 - units
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listUnits;
                 err = docOrigin.getObjects("v_unit", "1=1 order by rd_unit_id, t_type", listUnits);
@@ -87,7 +88,7 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGUnitObject unitOrigin(listUnits.at(i));
                         SKGUnitObject unit(unitOrigin.cloneInto(m_importer->getDocument()));
                         if (unit.load().isFailed()) {
-                            //This unit does not exist yet
+                            // This unit does not exist yet
                             IFOK(err) {
                                 SKGUnitObject::UnitType unitType = unitOrigin.getType();
                                 if (unitType == SKGUnitObject::PRIMARY || unitType == SKGUnitObject::SECONDARY) unitType = SKGUnitObject::CURRENCY;
@@ -104,10 +105,10 @@ SKGError SKGImportPluginSkg::importFile()
                         }
                         mapOriginNew[unitOrigin.getUniqueID()] = unit;
 
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(unitOrigin, unit))
 
-                        //Unit values
+                        // Unit values
                         SKGObjectBase::SKGListSKGObjectBase listUnitsValues;
                         IFOKDO(err, unitOrigin.getUnitValues(listUnitsValues))
                         int nb2 = listUnitsValues.count();
@@ -120,7 +121,7 @@ SKGError SKGImportPluginSkg::importFile()
                             IFOKDO(err, unitval.setQuantity(unitValueOrigin.getQuantity()))
                             IFOKDO(err, unitval.save(true))
 
-                            //Duplicate properties
+                            // Duplicate properties
                             IFOKDO(err, copyParameters(unitValueOrigin, unitval))
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -131,7 +132,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-            //Step 2 - bank and accounts
+            // Step 2 - bank and accounts
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listBanks;
                 err = docOrigin.getObjects("v_bank", "", listBanks);
@@ -142,14 +143,14 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGBankObject bankOrigin(listBanks.at(i));
                         SKGBankObject bank(bankOrigin.cloneInto(m_importer->getDocument()));
                         if (bank.load().isFailed()) {
-                            //This bank does not exist yet
+                            // This bank does not exist yet
                             IFOKDO(err, bank.save(false))
                         }
 
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(bankOrigin, bank))
 
-                        //Accounts
+                        // Accounts
                         SKGObjectBase::SKGListSKGObjectBase listAccounts;
                         IFOKDO(err, bankOrigin.getAccounts(listAccounts))
                         int nb2 = listAccounts.count();
@@ -157,13 +158,13 @@ SKGError SKGImportPluginSkg::importFile()
                             SKGAccountObject accountOrigin(listAccounts.at(j));
                             SKGAccountObject account(accountOrigin.cloneInto(m_importer->getDocument()));
                             if (account.load().isFailed()) {
-                                //This account does not exist yet
+                                // This account does not exist yet
                                 IFOKDO(err, account.setBank(bank))
-                                //Initial balance will be set on operation creation
+                                // Initial balance will be set on operation creation
                                 IFOKDO(err, account.save(false))
                             }
 
-                            //Duplicate properties
+                            // Duplicate properties
                             IFOKDO(err, copyParameters(accountOrigin, account))
 
                             mapOriginNew[accountOrigin.getUniqueID()] = account;
@@ -176,7 +177,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-            //Step 3 - categories
+            // Step 3 - categories
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listCategories;
                 err = docOrigin.getObjects("v_category", "", listCategories);
@@ -188,7 +189,7 @@ SKGError SKGImportPluginSkg::importFile()
 
                         SKGCategoryObject cat;
                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), catOrigin.getFullName(), cat);
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(catOrigin, cat))
                         mapOriginNew[catOrigin.getUniqueID()] = cat;
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -199,7 +200,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
-            //Step 4 - trackers
+            // Step 4 - trackers
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listRefund;
                 err = docOrigin.getObjects("v_refund", "", listRefund);
@@ -210,7 +211,7 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGTrackerObject tracOrigin(listRefund.at(i));
                         SKGTrackerObject trac(tracOrigin.cloneInto(m_importer->getDocument()));
                         err = trac.save();
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(tracOrigin, trac))
                         mapOriginNew[tracOrigin.getUniqueID()] = trac;
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -221,7 +222,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-            //Step 5 - rules
+            // Step 5 - rules
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listRules;
                 err = docOrigin.getObjects("v_rule", "", listRules);
@@ -231,8 +232,8 @@ SKGError SKGImportPluginSkg::importFile()
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGRuleObject rulOrigin(listRules.at(i));
                         SKGRuleObject rul(rulOrigin.cloneInto(m_importer->getDocument()));
-                        err = rul.save(false);  //Save only
-                        //Duplicate properties
+                        err = rul.save(false);  // Save only
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(rulOrigin, rul))
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
@@ -242,7 +243,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-            //Step 6 - payee
+            // Step 6 - payee
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listPayee;
                 err = docOrigin.getObjects("v_payee", "", listPayee);
@@ -256,7 +257,7 @@ SKGError SKGImportPluginSkg::importFile()
                         err = SKGPayeeObject::createPayee(m_importer->getDocument(), paylOrigin.getName(), pay);
                         IFOKDO(err, pay.setAddress(paylOrigin.getAddress()))
                         IFOKDO(err, pay.save())
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(paylOrigin, pay))
                         mapOriginNew[paylOrigin.getUniqueID()] = pay;
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -267,7 +268,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
-            //Step 7 - operations and suboperation
+            // Step 7 - operations and suboperation
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listOperations;
                 err = docOrigin.getObjects("v_operation", "", listOperations);
@@ -289,13 +290,13 @@ SKGError SKGImportPluginSkg::importFile()
                             err = operationOrigin.getParentAccount(actOrig);
                             IFOK(err) {
                                 SKGAccountObject act(mapOriginNew[actOrig.getUniqueID()]);
-                                act.setClosed(false); //To be sure that the modification is possible. NOT SAVED
+                                act.setClosed(false);  // To be sure that the modification is possible. NOT SAVED
                                 IFOKDO(err, operation.setParentAccount(act))
                             }
                         }
                         IFOK(err) {
                             SKGPayeeObject payeeOrig;
-                            operationOrigin.getPayee(payeeOrig);     //Error not managed
+                            operationOrigin.getPayee(payeeOrig);     // Error not managed
                             IFOKDO(err, operation.setPayee(SKGPayeeObject(mapOriginNew[payeeOrig.getUniqueID()])))
                         }
                         IFOK(err) {
@@ -312,10 +313,10 @@ SKGError SKGImportPluginSkg::importFile()
 
                         mapOriginNew[operationOrigin.getUniqueID()] = operation;
 
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(operationOrigin, operation))
 
-                        //Sub operation
+                        // Sub operation
                         SKGObjectBase::SKGListSKGObjectBase listSuboperations;
                         IFOKDO(err, operationOrigin.getSubOperations(listSuboperations))
                         int nb2 = listSuboperations.count();
@@ -326,17 +327,17 @@ SKGError SKGImportPluginSkg::importFile()
                             err = subop.setParentOperation(operation);
                             IFOK(err) {
                                 SKGCategoryObject catOrig;
-                                subopOrigin.getCategory(catOrig);    //Error not managed
+                                subopOrigin.getCategory(catOrig);    // Error not managed
                                 err = subop.setCategory(SKGCategoryObject(mapOriginNew[catOrig.getUniqueID()]));
                             }
                             IFOK(err) {
                                 SKGTrackerObject tracOrig;
-                                subopOrigin.getTracker(tracOrig);    //Error not managed
+                                subopOrigin.getTracker(tracOrig);    // Error not managed
                                 IFOKDO(err, subop.setTracker(SKGTrackerObject(mapOriginNew[tracOrig.getUniqueID()]), true))
                             }
                             IFOKDO(err, subop.save(false))
 
-                            //Duplicate properties
+                            // Duplicate properties
                             IFOKDO(err, copyParameters(subopOrigin, subop))
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -351,7 +352,7 @@ SKGError SKGImportPluginSkg::importFile()
             /*                                      SKGObjectBase opWithThisHash;
                                                 if ( SKGObjectBase::getObject ( m_importer->getDocument(), "operation", "t_imported IN ('Y','P') AND t_import_id='"+QString ( hash.toHex() ) +'\'', opWithThisHash ).isSucceeded() )*/
 
-            //Step 8 - recurrent
+            // Step 8 - recurrent
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase ListRecurrentOperations;
                 err = docOrigin.getObjects("v_recurrentoperation", "", ListRecurrentOperations);
@@ -367,7 +368,7 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, recu.setParentOperation(SKGOperationObject(mapOriginNew[opOrig.getUniqueID()])))
                         IFOKDO(err, recu.save(false))
 
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(recuOrigin, recu))
 
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -378,7 +379,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(8))
 
-            //Step 9 - nodes
+            // Step 9 - nodes
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listNodes;
                 err = docOrigin.getObjects("v_node", "", listNodes);
@@ -402,7 +403,7 @@ SKGError SKGImportPluginSkg::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(9))
 
-            //Step 10 - interest
+            // Step 10 - interest
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listInterests;
                 err = docOrigin.getObjects("v_interest", "", listInterests);
@@ -419,7 +420,7 @@ SKGError SKGImportPluginSkg::importFile()
                         }
                         IFOKDO(err, interest.save())
 
-                        //Duplicate properties
+                        // Duplicate properties
                         IFOKDO(err, copyParameters(interestOrigin, interest))
 
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -454,12 +455,12 @@ SKGError SKGImportPluginSkg::exportFile()
 
     QString tempFile = m_importer->getDocument()->getCurrentTemporaryFile();
     if (m_importer->getDocument()->getCurrentFileName().isEmpty()) {
-        //The database is only in memory
+        // The database is only in memory
         QFile(tempFile).remove();
         QSqlDatabase* fileDb = new QSqlDatabase(QSqlDatabase::addDatabase("QSQLITE", tempFile));
         fileDb->setDatabaseName(tempFile);
         if (!fileDb->open()) {
-            //Set error message
+            // Set error message
             QSqlError sqlErr = fileDb->lastError();
             err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
         } else {
@@ -473,7 +474,7 @@ SKGError SKGImportPluginSkg::exportFile()
         QSqlDatabase::removeDatabase(tempFile);
     }
 
-    //Copy file to file
+    // Copy file to file
     QString file = m_importer->getLocalFileName(false);
     QFile::remove(file);
     if (QFileInfo(file).suffix().toUpper() == "SQLITE") {
