@@ -20,6 +20,14 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginxhb.h"
+
+#include <KLocale>
+#include <KFilterDev>
+#include <KGenericFactory>
+
+#include <QDomDocument>
+#include <QFileInfo>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
@@ -27,13 +35,6 @@
 #include "skgimportexportmanager.h"
 #include "skgpayeeobject.h"
 
-#include <klocale.h>
-#include <kfilterdev.h>
-#include <kgenericfactory.h>
-
-#include <QDomDocument>
-#include <qfileinfo.h>
-
 /**
  * This plugin factory.
  */
@@ -66,21 +67,21 @@ SKGError SKGImportPluginXhb::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginXhb::importFile", err);
 
-    //Initialisation
-    //Open file
+    // Initialisation
+    // Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     else {
         QDomDocument doc;
 
-        //Set the file without uncompression
+        // Set the file without uncompression
         QString errorMsg;
         int errorLine = 0;
         int errorCol = 0;
         bool contentOK = doc.setContent(file->readAll(), &errorMsg, &errorLine, &errorCol);
         file->close();
 
-        //Get root
+        // Get root
         QDomElement docElem = doc.documentElement();
 
         if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
@@ -95,23 +96,23 @@ SKGError SKGImportPluginXhb::importFile()
             SKGUnitObject unit;
             IFOKDO(err, m_importer->getDefaultUnit(unit))
 
-            //Step 1-Create accounts
+            // Step 1-Create accounts
             IFOK(err) {
                 QDomNodeList accountList = docElem.elementsByTagName("account");
                 int nb = accountList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get account object
+                    // Get account object
                     QDomElement account = accountList.at(i).toElement();
 
-                    //Create the bank
+                    // Create the bank
                     SKGBankObject bank(m_importer->getDocument());
                     QString bname = getAttribute(account,  "bankname");
                     if (bname.isEmpty()) bname = "HOMEBANK";
                     IFOKDO(err, bank.setName(bname))
                     IFOKDO(err, bank.save())
 
-                    //Creation of the account
+                    // Creation of the account
                     SKGAccountObject accountObj;
                     IFOKDO(err, bank.addAccount(accountObj))
                     IFOKDO(err, accountObj.setName(getAttribute(account,  "name")))
@@ -136,13 +137,13 @@ SKGError SKGImportPluginXhb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
-            //Step 2-Get payees
+            // Step 2-Get payees
             IFOK(err) {
                 QDomNodeList partyList = docElem.elementsByTagName("pay");
                 int nb = partyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Get payee object
+                    // Get payee object
                     QDomElement party = partyList.at(i).toElement();
                     SKGPayeeObject payeeObject;
                     err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  "name"), payeeObject);
@@ -155,17 +156,17 @@ SKGError SKGImportPluginXhb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-            //Step 3-Create categories
+            // Step 3-Create categories
             IFOK(err) {
                 QDomNodeList categoryList = docElem.elementsByTagName("cat");
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), 2 * nb);
                 for (int j = 0; !err && j < 2; ++j) {
                     for (int i = 0; !err && i < nb; ++i) {
-                        //Get account object
+                        // Get account object
                         QDomElement category = categoryList.at(i).toElement();
 
-                        //Creation of the category
+                        // Creation of the category
                         bool catCreated = false;
                         SKGCategoryObject catObj(m_importer->getDocument());
                         QString parent2 = getAttribute(category,  "parent");
@@ -186,7 +187,7 @@ SKGError SKGImportPluginXhb::importFile()
                             catCreated = true;
                         }
 
-                        //Creation of the attached budget
+                        // Creation of the attached budget
                         if (!err && catCreated) {
                             QString b0 = getAttribute(category,  "b0");
                             QString b1 = getAttribute(category,  "b1");
@@ -212,7 +213,7 @@ SKGError SKGImportPluginXhb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
-            //Step 4-Create transaction
+            // Step 4-Create transaction
             IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), 2);
                 for (int j = 1; !err && j <= 2; ++j) {
@@ -220,10 +221,10 @@ SKGError SKGImportPluginXhb::importFile()
                     int nb = transactionList.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        //Get account object
+                        // Get account object
                         QDomElement transaction = transactionList.at(i).toElement();
 
-                        //Get attributes
+                        // Get attributes
                         QString idAccount = getAttribute(transaction,  "account");
                         QString dst_account = getAttribute(transaction,  "dst_account");
                         if (idAccount != "0") {
@@ -231,10 +232,15 @@ SKGError SKGImportPluginXhb::importFile()
                             QDate date = QDate(1, 1, 1).addDays(1 + SKGServices::stringToInt(getAttribute(transaction,  j == 1 ? "date" : "nextdate")));
                             QString mode = getAttribute(transaction,  "paymode");
                             if (mode == "1") mode = i18nc("Noun: type of payement", "Credit card");
-                            else if (mode == "2") mode = i18nc("Noun: type of payement", "Check");
-                            else if (mode == "3") mode = i18nc("Noun: type of payement", "Cash");
-                            else if (mode == "4" || mode == "5") mode = i18nc("Noun: type of payement", "Transfer");
-                            else mode = i18nc("Noun: type of payement", "Other");
+                            else if (mode == "2") {
+                                mode = i18nc("Noun: type of payement", "Check");
+                            } else if (mode == "3") {
+                                mode = i18nc("Noun: type of payement", "Cash");
+                            } else if (mode == "4" || mode == "5") {
+                                mode = i18nc("Noun: type of payement", "Transfer");
+                            } else {
+                                mode = i18nc("Noun: type of payement", "Other");
+                            }
                             QString comment = QString(getAttribute(transaction,  "wording") % ' ' % getAttribute(transaction,  "info")).trimmed();
                             int flags = SKGServices::stringToInt(getAttribute(transaction,  "flags"));
                             double amount = SKGServices::stringToDouble(getAttribute(transaction,  "amount"));
@@ -242,7 +248,7 @@ SKGError SKGImportPluginXhb::importFile()
                             SKGPayeeObject payee = mapIdPayee[ getAttribute(transaction,  "payee")];
                             SKGCategoryObject category = mapIdCategory[getAttribute(transaction,  "category")];
 
-                            //Creation of the operation
+                            // Creation of the operation
                             SKGOperationObject opObj;
                             IFOKDO(err, account.addOperation(opObj, true))
                             IFOKDO(err, opObj.setDate(date))
@@ -264,7 +270,7 @@ SKGError SKGImportPluginXhb::importFile()
                             IFOKDO(err, subObj.setQuantity(amount))
                             IFOKDO(err, subObj.save())
 
-                            //Transfert
+                            // Transfert
                             /*if(dst_account != idAccount && dst_account != "0") {
                                 SKGAccountObject account = mapIdAccount[dst_account];
                                 SKGOperationObject op2Obj;
@@ -292,9 +298,9 @@ SKGError SKGImportPluginXhb::importFile()
                                 if(!err) err = op2Obj.save();
                             }*/
 
-                            //Scheduled operations
+                            // Scheduled operations
                             if (j == 2) {
-                                //Creation of scheduled operation
+                                // Creation of scheduled operation
                                 SKGRecurrentOperationObject recu;
                                 IFOKDO(err, opObj.addRecurrentOperation(recu))
                                 int limit = SKGServices::stringToInt(getAttribute(transaction,  "limit"));
@@ -304,21 +310,24 @@ SKGError SKGImportPluginXhb::importFile()
                                 int pstep = SKGServices::stringToInt(getAttribute(transaction,  "every"));
                                 SKGRecurrentOperationObject::PeriodUnit p = SKGRecurrentOperationObject::MONTH;
                                 if (punit == 0) p = SKGRecurrentOperationObject::DAY;
-                                else if (punit == 1) p = SKGRecurrentOperationObject::WEEK;
-                                else if (punit == 3) p = SKGRecurrentOperationObject::YEAR;
+                                else if (punit == 1) {
+                                    p = SKGRecurrentOperationObject::WEEK;
+                                } else if (punit == 3) {
+                                    p = SKGRecurrentOperationObject::YEAR;
+                                }
                                 IFOKDO(err, recu.setPeriodIncrement(pstep))
                                 IFOKDO(err, recu.setPeriodUnit(p))
                                 IFOKDO(err, recu.warnEnabled(flags & (1 << 5)))
                                 IFOKDO(err, recu.autoWriteEnabled(flags & (1 << 2)))
                                 IFOKDO(err, recu.save())
-                                //#define OF_VALID        (1<<0)
-                                //#define OF_INCOME       (1<<1)
-                                //#define OF_AUTO         (1<<2)
-                                //#define OF_ADDED        (1<<3)
-                                //#define OF_CHANGED      (1<<4)
-                                //#define OF_REMIND       (1<<5)
-                                //#define OF_CHEQ2        (1<<6)
-                                //#define OF_LIMIT        (1<<7)
+                                // #define OF_VALID        (1<<0)
+                                // #define OF_INCOME       (1<<1)
+                                // #define OF_AUTO         (1<<2)
+                                // #define OF_ADDED        (1<<3)
+                                // #define OF_CHANGED      (1<<4)
+                                // #define OF_REMIND       (1<<5)
+                                // #define OF_CHEQ2        (1<<6)
+                                // #define OF_LIMIT        (1<<7)
                             }
                         }
 
