@@ -20,16 +20,17 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginxml.h"
+
+#include <KLocale>
+#include <KSaveFile>
+#include <KGenericFactory>
+
+#include <QFileInfo>
+
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
 #include "skgservices.h"
 
-#include <klocale.h>
-#include <ksavefile.h>
-#include <kgenericfactory.h>
-
-#include <qfileinfo.h>
-
 /**
  * This plugin factory.
  */
@@ -70,7 +71,7 @@ SKGError SKGImportPluginXml::exportFile()
             stream << doc.toString() << endl;
         }
 
-        //Close file
+        // Close file
         file.finalize();
         file.close();
     }
