@@ -17,12 +17,12 @@
 #include "skgaddoperation.h"
 
 #include <KIcon>
-#include <ksavefile.h>
+#include <KSaveFile>
 
 #include <QStringBuilder>
 #include <QUuid>
 #include <QDir>
-#include <qtextstream.h>
+#include <QTextStream>
 #include <KMessageBox>
 
 SKGAddOperation::SKGAddOperation(QObject* iParent, const QVariantList& args)
@@ -99,7 +99,7 @@ void SKGAddOperation::run(const Plasma::RunnerContext& iContext, const Plasma::Q
         KMessageBox::error(NULL, i18nc("Error message: Could not create a file", "Creation of file %1 failed", fileName));
     }
 
-    //Close file
+    // Close file
     file.finalize();
     file.close();
 }
