@@ -20,6 +20,12 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbankplugin.h"
+
+#include <KActionCollection>
+#include <KAboutData>
+#include <KGenericFactory>
+#include <KStandardDirs>
+
 #include "skgbankpluginwidget.h"
 #include "skgaccountboardwidget.h"
 #include "skgmainpanel.h"
@@ -32,11 +38,6 @@
 #include "skgtransactionmng.h"
 #include "skgbankobject.h"
 
-#include <kactioncollection.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-#include <kstandarddirs.h>
-
 /**
  * This plugin factory.
  */
@@ -46,9 +47,10 @@ K_PLUGIN_FACTORY(SKGBankPluginFactory, registerPlugin<SKGBankPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGBankPluginFactory("skrooge_bank", "skrooge_bank"))
 
-SKGBankPlugin::SKGBankPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/)
+SKGBankPlugin::SKGBankPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_reconciliateAction(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGBankPlugin::SKGBankPlugin");
 }
 
@@ -69,7 +71,7 @@ bool SKGBankPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_bank/skrooge_bank.rc");
 
-    //Menu
+    // Menu
     m_reconciliateAction = new KAction(KIcon("skrooge_duplicate"), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile..."), this);
     connect(m_reconciliateAction, SIGNAL(triggered(bool)), this, SLOT(onReconciliate()));
     m_reconciliateAction->setShortcut(Qt::ALT + Qt::Key_R);
@@ -85,8 +87,11 @@ int SKGBankPlugin::getNbDashboardWidgets()
 QString SKGBankPlugin::getDashboardWidgetTitle(int iIndex)
 {
     if (iIndex == 0) return i18nc("Noun, a list of bank accounts", "Accounts (Light)");
-    else if (iIndex == 1) return i18nc("Noun, a list of bank accounts", "Accounts (Full)");
-    else if (iIndex == 2) return i18nc("Noun, a list of banks", "Banks (Light)");
+    else if (iIndex == 1) {
+        return i18nc("Noun, a list of bank accounts", "Accounts (Full)");
+    } else if (iIndex == 2) {
+        return i18nc("Noun, a list of banks", "Banks (Light)");
+    }
     return i18nc("Noun, a list of banks", "Banks (Full)");
 }
 
@@ -107,9 +112,9 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
         overlayopen.push_back("skg_open");
         KAction* open = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), w);
         connect(open, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
-        QString url = QString("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=Y&lines2=t_BANK&currentPage=-1&mode=0&interval=3&period=0") %
-                      "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.show=graph&columns=" % SKGServices::encodeForUrl("#NOTHING#");
-        open->setData(url);
+        QString u = QString("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=Y&lines2=t_BANK&currentPage=-1&mode=0&interval=3&period=0") %
+                    "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.show=graph&columns=" % SKGServices::encodeForUrl("#NOTHING#");
+        open->setData(u);
 
         w->addAction(open);
         return w;
@@ -151,7 +156,7 @@ QStringList SKGBankPlugin::tips() const
 
 int SKGBankPlugin::getOrder() const
 {
-    //Must be one of the first
+    // Must be one of the first
     return 10;
 }
 
@@ -177,7 +182,7 @@ void SKGBankPlugin::refresh()
 void SKGBankPlugin::onReconciliate()
 {
     if (m_currentBankDocument && SKGMainPanel::getMainPanel()) {
-        //Open in operation plugin
+        // Open in operation plugin
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         for (int i = 0; i < nb; ++i) {
@@ -192,13 +197,13 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGBankPlugin::advice");
     SKGAdviceList output;
 
-    //Get bank without accounts
+    // Get bank without accounts
     if (!iIgnoredAdvice.contains("skgbankplugin_withoutaccount")) {
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT bank.t_name FROM bank WHERE NOT EXISTS (SELECT 1 FROM account WHERE account.rd_bank_id=bank.id)", result);
         int nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
-            //Get parameters
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
             QStringList line = result.at(i);
             QString bank = line.at(0);
 
@@ -214,13 +219,13 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Get accounts closed with money
+    // Get accounts closed with money
     if (!iIgnoredAdvice.contains("skgbankplugin_closedaccount")) {
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_amount WHERE f_CURRENTAMOUNT>0.1 AND t_close='Y'", result);
         int nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
-            //Get parameters
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
             QStringList line = result.at(i);
             QString account = line.at(0);
 
@@ -243,7 +248,7 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGBankPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgbankplugin_withoutaccount|"))) {
-        //Get parameters
+        // Get parameters
         QString bank = iAdviceIdentifier.right(iAdviceIdentifier.length() - 29);
 
         SKGError err;
@@ -256,16 +261,18 @@ SKGError SKGBankPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             IFOKDO(err, bankObj.remove())
         }
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successfully deleted a bank with no account", "Unused bank deleted")))
-        else err.addError(ERR_FAIL, i18nc("Could not delete a bank with no account", "Unused bank deletion failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Could not delete a bank with no account", "Unused bank deletion failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
 
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgbankplugin_closedaccount|"))) {
-        //Get parameters
+        // Get parameters
         QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
 
         SKGAccountObject accountObj(m_currentBankDocument);
@@ -279,9 +286,11 @@ SKGError SKGBankPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 IFOKDO(err, accountObj.save())
             }
 
-            //status bar
+            // status bar
             IFOKDO(err, SKGError(0, i18nc("Successfully reopen account", "Account reopened")))
-            else err.addError(ERR_FAIL, i18nc("Failure", "reopening of the account failed"));
+            else {
+                err.addError(ERR_FAIL, i18nc("Failure", "reopening of the account failed"));
+            }
         } else if (iSolution == 1) {
             {
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create fake operation"), err);
@@ -302,12 +311,14 @@ SKGError SKGBankPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 IFOKDO(err, sop.save())
             }
 
-            //status bar
+            // status bar
             IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Fake operation created.")))
-            else err.addError(ERR_FAIL, i18nc("Error message",  "Creation failed"));
+            else {
+                err.addError(ERR_FAIL, i18nc("Error message",  "Creation failed"));
+            }
         }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
 
         return SKGError();
