@@ -117,13 +117,13 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitEdit->setDocument(iDocument);
 
     // Set show widget
-    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
-    ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "", "t_close='N'");
-    ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'");
-    ui.kView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'");
+    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"), "", "", "", Qt::META + Qt::Key_A);
+    ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "", "t_close='N'", "", Qt::META + Qt::Key_O);
+    ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'", "", Qt::META + Qt::Key_C);
+    ui.kView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'", "", Qt::META + Qt::Key_H);
     if (m_graph) {
         ui.kView->getShowWidget()->addSeparator();
-        ui.kView->getShowWidget()->addItem("graph", i18n("Graph"), "view-investment", "1=0");
+        ui.kView->getShowWidget()->addItem("graph", i18n("Graph"), "view-investment", "1=0", "", "", "", "", Qt::META + Qt::Key_G);
     }
 
     ui.kView->getShowWidget()->setDefaultState("opened");
@@ -210,7 +210,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kWidgetSelector->setSelectedMode(0);
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int,bool)), Qt::QueuedConnection);
     dataModified("", 0);
 }
 
@@ -709,7 +709,7 @@ QString SKGBankPluginWidget::getDefaultStateAttribute()
     return "SKGBANK_DEFAULT_PARAMETERS";
 }
 
-void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
     SKGTRACEIN(10, "SKGBankPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
@@ -720,19 +720,21 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
         m_timer.start(300);
     }
 
-    if (iTableName == "bank" || iTableName.isEmpty()) {
-        // Set completions
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorBank, getDocument(), "bank", "t_name", "", true);
-    }
+    if (!iLightTransaction) {
+        if (iTableName == "bank" || iTableName.isEmpty()) {
+            // Set completions
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorBank, getDocument(), "bank", "t_name", "", true);
+        }
 
-    if (iTableName == "account" || iTableName.isEmpty()) {
-        // Set completions
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAccount, getDocument(), "account", "t_name", "", true);
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorBankNumber, getDocument(), "bank", "t_bank_number", "", true);
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAgencyNumber, getDocument(), "account", "t_agency_number", "", true);
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorNumber, getDocument(), "account", "t_number", "", true);
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAddress, getDocument(), "account", "t_agency_address", "", true);
-        SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorComment, getDocument(), "account", "t_comment", "", true);
+        if (iTableName == "account" || iTableName.isEmpty()) {
+            // Set completions
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAccount, getDocument(), "account", "t_name", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorBankNumber, getDocument(), "bank", "t_bank_number", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAgencyNumber, getDocument(), "account", "t_agency_number", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorNumber, getDocument(), "account", "t_number", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorAddress, getDocument(), "account", "t_agency_address", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kAccountCreatorComment, getDocument(), "account", "t_comment", "", true);
+        }
     }
 }
 
