@@ -20,15 +20,16 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbudgetdelegate.h"
-#include "skgobjectmodelbase.h"
-#include "skgtraces.h"
-#include "skgprogressbar.h"
 
-#include <kcolorscheme.h>
+#include <KColorScheme>
 
 #include <QSortFilterProxyModel>
 #include <QPainter>
 
+#include "skgobjectmodelbase.h"
+#include "skgtraces.h"
+#include "skgprogressbar.h"
+
 SKGBudgetDelegate::SKGBudgetDelegate(QObject* iParent, SKGDocument* iDoc) : QStyledItemDelegate(iParent), m_document(iDoc)
 {}
 
@@ -46,7 +47,7 @@ void SKGBudgetDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opt
     if (m) {
         QString att = m->getAttribute(index.column());
 
-        //Compute pourcent of time
+        // Compute pourcent of time
         QModelIndex idxs = index;
         if (p) idxs = p->mapToSource(index);
         SKGObjectBase obj = m->getObject(idxs);
@@ -112,56 +113,56 @@ void SKGBudgetDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opt
 
             if (budgeted > 0) {
                 if (amount < 0) amount = 0;
-                //Income
+                // Income
                 if (amount < budgeted) {
-                    //Draw red zone
+                    // Draw red zone
                     painter->setBrush(negative);
                     painter->drawRect(rect);
 
-                    //Draw blue zone
+                    // Draw blue zone
                     painter->setBrush(back);
                     QRect r2(rect.left(), rect.top(), rect.width() * (budgeted == 0 ? 1 : amount / budgeted), rect.height());
                     painter->drawRect(r2);
                 } else {
-                    //Draw green zone
+                    // Draw green zone
                     painter->setBrush(positive);
                     painter->drawRect(rect);
 
-                    //Draw blue zone
+                    // Draw blue zone
                     painter->setBrush(back);
                     QRect r2(rect.left(), rect.top(), rect.width() * (amount == 0 ? 0 : budgeted / amount), rect.height());
                     painter->drawRect(r2);
                 }
             } else {
                 if (amount > 0) amount = 0;
-                //Expenditure
+                // Expenditure
                 if (amount < budgeted) {
-                    //Draw red zone
+                    // Draw red zone
                     painter->setBrush(negative);
                     painter->drawRect(rect);
 
-                    //Draw blue zone
+                    // Draw blue zone
                     painter->setBrush(back);
                     QRect r2(rect.left(), rect.top(), rect.width() * (amount == 0 ? 0 : budgeted / amount), rect.height());
                     painter->drawRect(r2);
                 } else {
-                    //Draw green zone
+                    // Draw green zone
                     painter->setBrush(positive);
                     painter->drawRect(rect);
 
-                    //Draw blue zone
+                    // Draw blue zone
                     painter->setBrush(back);
                     QRect r2(rect.left(), rect.top(), rect.width() * (budgeted == 0 ? 1 : amount / budgeted), rect.height());
                     painter->drawRect(r2);
                 }
             }
 
-            //Draw time progress
+            // Draw time progress
             painter->setPen(Qt::black);
             QLine r2(rect.left() + rect.width()*pourcent, rect.top() + 1, rect.left() + rect.width()*pourcent, rect.top() + rect.height() - 1);
             painter->drawLine(r2);
 
-            //Draw text
+            // Draw text
             painter->setPen(m->data(idxs, Qt::TextColorRole).value<QColor>());
 
             QTextOption to;
