@@ -20,6 +20,12 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgbudgetplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgbudgetpluginwidget.h"
 #include "skgbudgetobject.h"
 #include "skgdocumentbank.h"
@@ -28,11 +34,6 @@
 #include "skgtraces.h"
 #include "skgmainpanel.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -42,8 +43,9 @@ K_PLUGIN_FACTORY(SKGBudgetPluginFactory, registerPlugin<SKGBudgetPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGBudgetPluginFactory("skrooge_budget", "skrooge_budget"))
 
-SKGBudgetPlugin::SKGBudgetPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGBudgetPlugin::SKGBudgetPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGBudgetPlugin::SKGBudgetPlugin");
 }
 
@@ -63,8 +65,8 @@ bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_budget/skrooge_budget.rc");
 
-    //Create yours actions here
-    //-----------
+    // Create yours actions here
+    // -----------
     QStringList overlayrun;
     overlayrun.push_back("system-run");
     KAction* act = new KAction(KIcon(icon(), NULL, overlayrun), i18nc("Verb", "Process budget rules"), this);
@@ -117,10 +119,10 @@ SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
     QString month = QDate::currentDate().toString("yyyy-MM");
     QString year = QDate::currentDate().toString("yyyy");
 
-    //Alarms
+    // Alarms
     if (!iIgnoredAdvice.contains("skgbudgetplugin_alarm")) {
         SKGObjectBase::SKGListSKGObjectBase budgets;
-        //Query is done on v_budget_display because v_budget_display is faster than v_budget
+        // Query is done on v_budget_display because v_budget_display is faster than v_budget
         SKGError err = m_currentBankDocument->getObjects("v_budget_display", "(f_CURRENTAMOUNT/f_budgeted_modified>0.8 OR (f_CURRENTAMOUNT<0 AND f_budgeted_modified>0)) AND ABS(f_CURRENTAMOUNT-f_budgeted_modified)>" % SKGServices::doubleToString(EPSILON) % " AND f_budgeted<0 AND (t_PERIOD='" % month % "' OR t_PERIOD='" % year % "');", budgets);
         int nb = budgets.count();
         if (nb) {
@@ -148,8 +150,8 @@ SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     if (!iIgnoredAdvice.contains("skgbudgetplugin_oldprocessing")) {
-        QString d = m_currentBankDocument->getParameter("SKG_LAST_BUDGET_PROCESSING");
-        if (d.isEmpty() ||  SKGServices::stringToTime(d).date() < QDate::currentDate().addMonths(-1)) { //Ignore header
+        QString lastBudgetProcessingDate = m_currentBankDocument->getParameter("SKG_LAST_BUDGET_PROCESSING");
+        if (lastBudgetProcessingDate.isEmpty() ||  SKGServices::stringToTime(lastBudgetProcessingDate).date() < QDate::currentDate().addMonths(-1)) {  // Ignore header
             bool exist = false;
             m_currentBankDocument->existObjects("budgetrule", "", exist);
             if (exist) {
@@ -171,7 +173,7 @@ SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGBudgetPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgbudgetplugin_alarm|"))) {
-        //Get parameters
+        // Get parameters
         QString id = iAdviceIdentifier.right(iAdviceIdentifier.length() - 22);
         SKGBudgetObject budget(m_currentBankDocument, SKGServices::stringToInt(id));
         budget.load();
@@ -196,12 +198,14 @@ void SKGBudgetPlugin::onProcessRules()
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Process budget rules")  , err);
         err = SKGBudgetRuleObject::processAllRules(m_currentBankDocument);
     }
-    //status bar
+    // status bar
     IFOK(err) {
         err = SKGError(0, i18nc("Successful message after an user action", "Budget rules processed"));
-    } else err.addError(ERR_FAIL, i18nc("Error message", "Budget rules failed"));
+    } else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Budget rules failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
