@@ -68,45 +68,54 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     ui.kView->getShowWidget()->addItem("all", i18nc("Noun, budget items to display", "All"), "",
                                        "",
                                        "current;currentYear;currentMonth;previousYear;previousMonth",
-                                       "none");
+                                       "none", "", "",
+                                       Qt::META + Qt::Key_A
+                                      );
     ui.kView->getShowWidget()->addItem("none", i18nc("Noun, budget items to display", "None"), "",
                                        "1=0",
                                        "",  // Check when checked
                                        "all;current;currentYear;currentMonth;previousYear;previousMonth",       // Uncheck when checked
                                        "",       // Check when unchecked
-                                       "all");     // Uncheck when unchecked
+                                       "all",    // Uncheck when unchecked
+                                       Qt::META + Qt::Key_0);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem("current", i18nc("Noun, budget items to display", "Current"), "",
                                        "t_PERIOD>=STRFTIME('%Y-%m', date('now')) OR t_PERIOD=STRFTIME('%Y', date('now'))",
                                        "currentMonth",  // Check when checked
                                        "none",       // Uncheck when checked
                                        "",       // Check when unchecked
-                                       "all");     // Uncheck when unchecked
+                                       "all",    // Uncheck when unchecked
+                                       Qt::META + Qt::Key_1);
+    ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem("currentYear", i18nc("Noun, budget items to display", "Current year"), "view-calendar-month",
                                        "t_PERIOD LIKE STRFTIME('%Y', date('now'))||'%'",
                                        "",
                                        "none",
                                        "",
-                                       "all");
+                                       "all",
+                                       Qt::META + Qt::Key_3);;
     ui.kView->getShowWidget()->addItem("currentMonth", i18nc("Noun, budget items to display", "Current month"), "view-calendar-week",
                                        "t_PERIOD=STRFTIME('%Y-%m', date('now'))",
                                        "",
                                        "none",
                                        "",
-                                       "all;current");
+                                       "all;current",
+                                       Qt::META + Qt::Key_2);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem("previousYear", i18nc("Noun, budget items to display", "Previous year"), "view-calendar-month",
                                        "t_PERIOD LIKE STRFTIME('%Y', date('now','-1 Year'))||'%'",
                                        "",
                                        "none",
                                        "",
-                                       "all");
+                                       "all",
+                                       Qt::META + Qt::Key_5);
     ui.kView->getShowWidget()->addItem("previousMonth", i18nc("Noun, budget items to display", "Previous month"), "view-calendar-week",
                                        "t_PERIOD=STRFTIME('%Y-%m', date('now','-1 Month'))",
                                        "",
                                        "none",
                                        "",
-                                       "all");
+                                       "all",
+                                       Qt::META + Qt::Key_4);
     ui.kView->getShowWidget()->setDefaultState("current");
 
     m_timer.setSingleShot(true);
@@ -172,17 +181,13 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     }
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onBtnModeClicked(int)));
 
-    SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
-    SKGMainPanel::fillWithDistinctValue(ui.kCategoryRule, getDocument(), "category", "t_fullname", "");
-    SKGMainPanel::fillWithDistinctValue(ui.kCategoryTransfer, getDocument(), "category", "t_fullname", "");
-
     ui.kWidgetSelector->setSelectedMode(0);
 
     // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int,bool)), Qt::QueuedConnection);
     dataModified("", 0);
 }
 
@@ -269,7 +274,7 @@ void SKGBudgetPluginWidget::refresh()
     }
 }
 
-void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
     SKGTRACEIN(10, "SKGBudgetPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
@@ -280,13 +285,16 @@ void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTrans
         m_timer.start(300);
     }
 
-    if (iTableName == "category" || iTableName.isEmpty()) {
-        // Set type category
-        SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
-        SKGMainPanel::fillWithDistinctValue(ui.kCategoryRule, getDocument(), "category", "t_fullname", "");
-        SKGMainPanel::fillWithDistinctValue(ui.kCategoryTransfer, getDocument(), "category", "t_fullname", "");
+    if (!iLightTransaction) {
+        if (iTableName == "category" || iTableName.isEmpty()) {
+            // Set type category
+            SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
+            SKGMainPanel::fillWithDistinctValue(ui.kCategoryRule, getDocument(), "category", "t_fullname", "");
+            SKGMainPanel::fillWithDistinctValue(ui.kCategoryTransfer, getDocument(), "category", "t_fullname", "");
+        }
     }
 }
+
 void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
 {
     SKGTRACEIN(10, "SKGBudgetPluginWidget::onBtnModeClicked");
