@@ -20,17 +20,18 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgcalculatorplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgcalculatorpluginwidget.h"
 #include "skginterestboardwidget.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
 #include "skgaccountobject.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -40,8 +41,9 @@ K_PLUGIN_FACTORY(SKGCalculatorPluginFactory, registerPlugin<SKGCalculatorPlugin>
  */
 K_EXPORT_PLUGIN(SKGCalculatorPluginFactory("skrooge_calculator", "skrooge_calculator"))
 
-SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGCalculatorPlugin::SKGCalculatorPlugin");
 }
 
@@ -61,7 +63,7 @@ bool SKGCalculatorPlugin::setupActions(SKGDocument* iDocument, const QStringList
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_calculator/skrooge_calculator.rc");
 
-    //Create yours actions here
+    // Create yours actions here
     return true;
 }
 
@@ -124,7 +126,7 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGCalculatorPlugin::advice");
     SKGAdviceList output;
 
-    //Search investment accounts without interest rate
+    // Search investment accounts without interest rate
     if (!iIgnoredAdvice.contains("skgcalculatorplugin_nointerest")) {
         SKGObjectBase::SKGListSKGObjectBase accounts;
         m_currentBankDocument->getObjects("account", "t_type='I' AND t_close='N' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)", accounts);
@@ -148,7 +150,7 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGCalculatorPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgcalculatorplugin_nointerest|"))) {
-        //Get parameters
+        // Get parameters
         QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 31);
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_calculator_plugin/?currentPage=0&account=" % SKGServices::encodeForUrl(account));
         return SKGError();
