@@ -99,7 +99,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()), Qt::QueuedConnection);
     connect(ui.KYearEdit, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()) , Qt::QueuedConnection);
 
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 
     // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
