@@ -20,6 +20,16 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgcategoriesplugin.h"
+
+#include <KMessageBox>
+#include <KActionCollection>
+#include <KAction>
+#include <KAboutData>
+#include <KStandardDirs>
+#include <KGenericFactory>
+#include <KSelectAction>
+#include <QFileInfo>
+
 #include "skgcategoriespluginwidget.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
@@ -27,14 +37,7 @@
 #include "skgtransactionmng.h"
 #include "skgcategoryobject.h"
 #include "skgdocumentbank.h"
-
-
-#include <kmessagebox.h>
-#include <kactioncollection.h>
-#include <kaction.h>
-#include <kaboutdata.h>
-#include <kstandarddirs.h>
-#include <kgenericfactory.h>
+#include "skgimportexportmanager.h"
 
 /**
  * This plugin factory.
@@ -45,9 +48,10 @@ K_PLUGIN_FACTORY(SKGCategoriesPluginFactory, registerPlugin<SKGCategoriesPlugin>
  */
 K_EXPORT_PLUGIN(SKGCategoriesPluginFactory("skrooge_categories", "skrooge_categories"))
 
-SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/)
+SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_importStdCatAction(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGCategoriesPlugin::SKGCategoriesPlugin");
 }
 
@@ -68,17 +72,31 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_categories/skrooge_categories.rc");
 
-    //Import categories
+    // Import categories
     QStringList overlaycategories;
     overlaycategories.push_back(icon());
 
     QStringList overlaydelete;
     overlaydelete.push_back("edit-delete");
 
-    m_importStdCatAction = new KAction(KIcon("document-import", NULL, overlaycategories), i18nc("Verb", "Import standard categories"), this);
+    KSelectAction* contextMenu = new KSelectAction(KIcon("document-import", NULL, overlaycategories), i18nc("Verb", "Import categories"), this);
+    registerGlobalAction("import_categories" , contextMenu);
+
+    m_importStdCatAction = contextMenu->addAction(KIcon("document-import", NULL, overlaycategories), i18nc("Verb", "Import standard categories"));
+    m_importStdCatAction->setCheckable(false);
     connect(m_importStdCatAction, SIGNAL(triggered(bool)), SLOT(importStandardCategories()));
     registerGlobalAction("import_standard_categories", m_importStdCatAction);
 
+    QStringList listCategories = KStandardDirs().findAllResources("data", "skrooge/categories/" % KGlobal::locale()->country() % "/*.qif");
+    foreach(const QString & cat, listCategories) {
+        QString name = QFileInfo(cat).baseName().replace('_', ' ');
+        KAction* act = contextMenu->addAction(KIcon("document-import", NULL, overlaycategories), i18nc("Verb", "Import categories [%1]", name));
+        act->setCheckable(false);
+        act->setData(cat);
+        connect(act, SIGNAL(triggered(bool)), SLOT(importCategories()));
+        registerGlobalAction("import_categories_" % name, act);
+    }
+
     KAction* deleteUnusedCategoriesAction = new KAction(KIcon(icon(), NULL, overlaydelete), i18nc("Verb", "Delete unused categories"), this);
     connect(deleteUnusedCategoriesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedCategories()));
     registerGlobalAction("clean_delete_unused_categories", deleteUnusedCategoriesAction);
@@ -95,7 +113,9 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
 {
     SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidgetTitle");
     if (iIndex == 0) return i18nc("Report header",  "5 main categories of expenditure");
-    else if (iIndex == 1) return i18nc("Report header",  "5 main variations");
+    else if (iIndex == 1) {
+        return i18nc("Report header",  "5 main variations");
+    }
     return i18nc("Report header",  "Budget");
 }
 
@@ -112,9 +132,9 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
         overlayopen.push_back("skg_open");
         KAction* open = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), w);
         connect(open, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
-        QString url = QString("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=N&lines2=t_REALCATEGORY&currentPage=-1&mode=0&interval=2&period=2&nbLevelLines=1") %
-                      "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.sortColumn=1&tableAndGraphState.show=graph;table&columns=" % SKGServices::encodeForUrl("#NOTHING#");
-        open->setData(url);
+        QString u = QString("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=N&lines2=t_REALCATEGORY&currentPage=-1&mode=0&interval=2&period=2&nbLevelLines=1") %
+                    "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.sortColumn=1&tableAndGraphState.show=graph;table&columns=" % SKGServices::encodeForUrl("#NOTHING#");
+        open->setData(u);
 
         QAction* sep = new QAction(this);
         sep->setSeparator(true);
@@ -139,7 +159,7 @@ void SKGCategoriesPlugin::refresh()
         bool test = (m_currentBankDocument->getDatabase() != NULL);
         if (m_importStdCatAction) m_importStdCatAction->setEnabled(test);
 
-        //Automatic categories creation
+        // Automatic categories creation
         if (m_currentBankDocument->getDatabase() != NULL) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id) {
@@ -150,7 +170,7 @@ void SKGCategoriesPlugin::refresh()
                 if (!err && !exist) {
                     importStandardCategories();
 
-                    //The file is considered has not modified
+                    // The file is considered has not modified
                     m_currentBankDocument->setFileNotModified();
                 }
             }
@@ -158,6 +178,34 @@ void SKGCategoriesPlugin::refresh()
     }
 }
 
+void SKGCategoriesPlugin::importCategories()
+{
+    SKGTRACEIN(10, "SKGCategoriesPlugin::importCategories");
+    SKGError err;
+    KAction* act = qobject_cast< KAction* >(sender());
+    if (act) {
+        QString fileName = act->data().toString();
+        QString name = QFileInfo(fileName).baseName().replace('_', ' ');
+        {
+            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Verb", "Import categories [%1]", name), err);
+
+            SKGImportExportManager imp(m_currentBankDocument, KUrl(fileName));
+            err = imp.importFile();
+            IFOKDO(err, m_currentBankDocument->removeMessages(m_currentBankDocument->getCurrentTransaction()))
+        }
+
+
+        // status
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Categories imported.")))
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Importing categories failed."));
+        }
+
+        // Display error
+        SKGMainPanel::displayErrorMessage(err);
+    }
+}
+
 void SKGCategoriesPlugin::importStandardCategories()
 {
     SKGTRACEIN(10, "SKGCategoriesPlugin::importStandardCategories");
@@ -195,11 +243,13 @@ void SKGCategoriesPlugin::importStandardCategories()
     }
 
 
-    //status
-    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Standard categories imported.")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Importing standard categories failed."));
+    // status
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Categories imported.")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Importing categories failed."));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -246,7 +296,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGCategoriesPlugin::advice");
     SKGAdviceList output;
-    //Check unused categies
+    // Check unused categies
     if (!iIgnoredAdvice.contains("skgcategoriesplugin_unused")) {
         SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgcategoriesplugin_unused");
         bool exist = false;
@@ -264,7 +314,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Check operations not validated
+    // Check operations not validated
     if (!iIgnoredAdvice.contains("skgmonthlyplugin_maincategoriesvariation")) {
         SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgmonthlyplugin_maincategoriesvariation");
         QString month = QDate::currentDate().toString("yyyy-MM");
@@ -293,11 +343,11 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgmonthlyplugin_maincategoriesvariation|"))) {
-        //Get parameters
+        // Get parameters
         QString category = iAdviceIdentifier.right(iAdviceIdentifier.length() - 41);
         QString month = QDate::currentDate().toString("yyyy-MM");
 
-        //Call operation plugin
+        // Call operation plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=skrooge_category&operationTable=v_operation_consolidated&title=" %
                                                SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\''));
         return SKGError();
@@ -319,7 +369,7 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
                 "SELECT DISTINCT(category.t_fullname) FROM category, budgetrule WHERE budgetrule.rc_category_id=category.id UNION ALL "
                 "SELECT DISTINCT(category.t_fullname) FROM category, budgetrule WHERE budgetrule.rc_category_id_target=category.id)", categoriesUsed);
 
-        for (int i = 0; i < categoriesUsed.count(); ++i) { //Warning categoriesUsed is modified in the loop
+        for (int i = 0; i < categoriesUsed.count(); ++i) {  // Warning categoriesUsed is modified in the loop
             QString cat = categoriesUsed.at(i);
             categoriesUsed[i] = SKGServices::stringToSqlString(cat);
             int pos = cat.lastIndexOf(OBJECTSEPARATOR);
@@ -329,16 +379,20 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
         IFOK(err) {
             QString sql;
             if (categoriesUsed.count())  sql = "DELETE FROM category WHERE t_fullname NOT IN ('" % categoriesUsed.join("','") % "')";
-            else sql = "DELETE FROM category";
+            else {
+                sql = "DELETE FROM category";
+            }
             err = m_currentBankDocument->executeSqliteOrder(sql);
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Unused categories deleted")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Unused categories deletion failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Unused categories deletion failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 #include "skgcategoriesplugin.moc"
