@@ -47,10 +47,10 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
     ui.setupUi(this);
 
     // Set show widget
-    ui.kCategoriesView->getShowWidget()->addGroupedItem("all", i18n("All"));
-    ui.kCategoriesView->getShowWidget()->addGroupedItem("income", i18n("Income"), "list-add", "f_REALCURRENTAMOUNT>=0");
-    ui.kCategoriesView->getShowWidget()->addGroupedItem("expenditure", i18n("Expenditure"), "list-remove", "f_REALCURRENTAMOUNT<=0");
-    ui.kCategoriesView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted"), "bookmarks", "t_HASBOOKMARKEDCHILD<>'N'");
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("all", i18n("All"), "", "", "", Qt::META + Qt::Key_A);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("income", i18n("Income"), "list-add", "f_REALCURRENTAMOUNT>=0", "", Qt::META + Qt::Key_Plus);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("expenditure", i18n("Expenditure"), "list-remove", "f_REALCURRENTAMOUNT<=0", "", Qt::META + Qt::Key_Minus);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem("highlighted", i18n("Highlighted"), "bookmarks", "t_HASBOOKMARKEDCHILD<>'N'", "", Qt::META + Qt::Key_H);
     ui.kCategoriesView->getShowWidget()->setDefaultState("all");
 
     ui.kAdd->setMaximumWidth(ui.kAdd->height());
@@ -88,7 +88,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
         ui.kCategoriesView->getView()->insertAction(0, addCategoryAction);
     }
 
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int,bool)), Qt::QueuedConnection);
     connect(ui.kCategoriesView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
     connect(ui.kCategoriesView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kCategoriesView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
@@ -120,16 +120,18 @@ bool SKGCategoriesPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
     return false;
 }
 
-void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
     SKGTRACEIN(10, "SKGCategoriesPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    if (iTableName == "category" || iTableName.isEmpty()) {
-        // Set completions
-        SKGMainPanel::fillWithDistinctValue(ui.kNameInput1, getDocument(), "category", "t_name", "", true);
+    if (!iLightTransaction) {
+        if (iTableName == "category" || iTableName.isEmpty()) {
+            // Set completions
+            SKGMainPanel::fillWithDistinctValue(ui.kNameInput1, getDocument(), "category", "t_name", "", true);
 
-        onSelectionChanged();
+            onSelectionChanged();
+        }
     }
 }
 
