@@ -20,6 +20,22 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportexportplugin.h"
+
+#include <KActionCollection>
+#include <KAction>
+#include <KActionMenu>
+#include <KFileDialog>
+#include <KAboutData>
+#include <KEncodingFileDialog>
+#include <KMessageBox>
+#include <KPasswordDialog>
+#include <KGenericFactory>
+#include <KStandardDirs>
+#include <KMessageWidget>
+
+#include <QTextCodec>
+#include <QDomDocument>
+
 #include "skgtraces.h"
 #include "skgerror.h"
 #include "skgbankincludes.h"
@@ -27,20 +43,6 @@
 #include "skgoperationobject.h"
 #include "skgimportexport_settings.h"
 
-#include <kactioncollection.h>
-#include <kaction.h>
-#include <kactionmenu.h>
-#include <kfiledialog.h>
-#include <kaboutdata.h>
-#include <kencodingfiledialog.h>
-#include <KMessageBox>
-#include <kpassworddialog.h>
-#include <kgenericfactory.h>
-#include <kstandarddirs.h>
-
-#include <QTextCodec>
-#include <QDomDocument>
-#include <kmessagewidget.h>
 /**
  * This plugin factory.
  */
@@ -50,13 +52,14 @@ K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlu
  */
 K_EXPORT_PLUGIN(SKGImportExportPluginFactory("skrooge_importexport", "skrooge_importexport"))
 
-SKGImportExportPlugin::SKGImportExportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGImportExportPlugin::SKGImportExportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
     m_importAction(NULL), m_importBackendAction(NULL), m_importCsvUnitAction(NULL), m_exportFileAction(NULL),
     m_processingFoundTransfert(NULL), m_processingBank(NULL), m_processingAnonymize(NULL), m_validateImportedOperationsAction(NULL),
     m_openNotValidatedAction(NULL), m_mergeImportedOperationAction(NULL), m_currentBankDocument(NULL),
     m_install(false)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGImportExportPlugin::SKGImportExportPlugin");
 }
 
@@ -88,11 +91,11 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_importexport/skrooge_importexport.rc");
 
-    //Imports
+    // Imports
     KActionMenu* imports = new  KActionMenu(KIcon("document-import"), i18nc("Verb, action to import items from another format", "Import"), this);
     registerGlobalAction("import", imports);
 
-    //Import
+    // Import
     QStringList overlay;
     overlay.push_back("skrooge");
 
@@ -102,7 +105,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     imports->addAction(m_importAction);
     registerGlobalAction("import_operation", m_importAction);
 
-    //Import backends
+    // Import backends
     QStringList overlay2;
     overlay.push_back("download");
 
@@ -112,7 +115,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     imports->addAction(m_importBackendAction);
     registerGlobalAction("import_backends", m_importBackendAction);
 
-    //Import CSV Unit
+    // Import CSV Unit
     QStringList overlaycsv;
     overlaycsv.push_back("text-csv");
     m_importCsvUnitAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18nc("Verb, action to import", "Import currency values..."), this);
@@ -120,22 +123,22 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     imports->addAction(m_importCsvUnitAction);
     registerGlobalAction("import_csv_unit", m_importCsvUnitAction);
 
-    //Exports
+    // Exports
     KActionMenu* exports = new  KActionMenu(KIcon("document-export"), i18nc("Verb, action to export items in another format", "Export"), this);
     registerGlobalAction("export", exports);
 
-    //Export
+    // Export
     m_exportFileAction = new KAction(KIcon("document-export"), i18nc("Verb, action to export items to another format", "Export..."), this);
     connect(m_exportFileAction, SIGNAL(triggered(bool)), SLOT(exportFile()));
     exports->addAction(m_exportFileAction);
     m_exportFileAction->setShortcut(Qt::CTRL + Qt::META + Qt::Key_E);
     registerGlobalAction("export_operation", m_exportFileAction);
 
-    //Processing
+    // Processing
     KActionMenu* processing = new  KActionMenu(KIcon("tools-wizard"), i18nc("Noun, apply some kind of transformation on an item", "Processing"), this);
     registerGlobalAction("processing", processing);
 
-    //Processing found and group
+    // Processing found and group
     QStringList overlaytransfers;
     overlaytransfers.push_back("view-financial-transfer");
 
@@ -150,13 +153,13 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     processing->addAction(m_processingAnonymize);
     registerGlobalAction("process_anonymize", m_processingAnonymize);
 
-    //Processing banks
+    // Processing banks
     m_processingBank = new KAction(KIcon("tools-wizard"), i18nc("Verb, action to clean an import", "Clean bank's imports"), this);
     connect(m_processingBank, SIGNAL(triggered(bool)), SLOT(cleanBanks()));
     processing->addAction(m_processingBank);
     registerGlobalAction("process_banks", m_processingBank);
 
-    //Processing banks
+    // Processing banks
     QStringList overlayValidate;
     overlayValidate.push_back("dialog-ok-apply");
     m_validateImportedOperationsAction = new KAction(KIcon("document-import", NULL, overlayValidate), i18nc("Verb, action to validate imported operations", "Validate imported operations"), this);
@@ -184,10 +187,10 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     m_mergeImportedOperationAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_M);
     registerGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
 
-    //Get last argument
+    // Get last argument
     connect(this, SIGNAL(importFileName(QString)), this, SLOT(import(QString)), Qt::QueuedConnection);
 
-    //Open/import input file
+    // Open/import input file
     int nbArg = iArgument.count();
     if (nbArg) {
         QString filename = iArgument.at(nbArg - 1);
@@ -198,7 +201,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         }
     }
 
-    //Krunner operations
+    // Krunner operations
     QString dirName = QDir::homePath() % "/.skrooge/";
     QStringList fileList = QDir(dirName).entryList(QStringList() << "add_operation_*.txt", QDir::Files);
     if (fileList.count()) m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's operations to import"));
@@ -206,34 +209,39 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     return true;
 }
 
-void SKGImportExportPlugin::processArguments(const QStringList& iArgument)
+bool SKGImportExportPlugin::processArguments(const QStringList& iArgument)
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::processArguments");
+    bool output = false;
     int nbArg = iArgument.count();
     if (nbArg) {
         QString filename = iArgument.at(nbArg - 1);
-        if (QFile(filename).exists()) Q_EMIT importFileName(filename);
+        if (QFile(filename).exists()) {
+            Q_EMIT importFileName(filename);
+            output = true;
+        }
     }
+    return output;
 }
 
 QWidget* SKGImportExportPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
 
     ui.kHeaderPositionFrm->hide();
     ui.kColumnsPositionsFrm->hide();
     ui.kCsvMappingFrm->hide();
 
-    //Build list of known backends
+    // Build list of known backends
     QStringList backends;
     foreach(const QString & file, KStandardDirs().findAllResources("data", "skrooge/backends/*.backend")) {
         backends.push_back(QFileInfo(file).baseName().toLower());
     }
     ui.kbackendText->setText(i18nc("Information", "You must enter the list of backends to use separated by a ';'.\nExample: backendA;backendB.\n\nHere is the list of known backends: %1.", backends.join(";")));
 
-    //Add date formats
+    // Add date formats
     QStringList dateFormats;
     dateFormats << i18nc("Format date", "Automatic detection")
                 << "YYYYMMDD"
@@ -247,7 +255,7 @@ QWidget* SKGImportExportPlugin::getPreferenceWidget()
     ui.kcfg_qif_date_format->addItems(dateFormats);
     ui.kcfg_csv_date_format->addItems(dateFormats);
 
-    return widget;
+    return w;
 }
 
 KConfigSkeleton* SKGImportExportPlugin::getPreferenceSkeleton()
@@ -314,7 +322,7 @@ void SKGImportExportPlugin::refresh()
             if (m_mergeImportedOperationAction) m_mergeImportedOperationAction->setEnabled(false);
         }
 
-        //Automatic download
+        // Automatic download
         if (test) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id) {
@@ -323,17 +331,17 @@ void SKGImportExportPlugin::refresh()
                 SKGError err;
 
                 if (skgimportexport_settings::download_on_open()) {
-                    //Check frequency
+                    // Check frequency
                     QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_BACKEND_AUTOMATIC_DOWNLOAD");
                     if (!lastAutomaticDownload.isEmpty()) {
-                        //The automatic import is not done if at least one manual import has not been done
+                        // The automatic import is not done if at least one manual import has not been done
                         QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
                         if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgimportexport_settings::download_frequency() == 0) ||
                                 (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgimportexport_settings::download_frequency() == 1) ||
                                 (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgimportexport_settings::download_frequency() == 2))
 
                         {
-                            //Import
+                            // Import
                             importbackends();
                         }
                     }
@@ -348,21 +356,21 @@ SKGError SKGImportExportPlugin::importbackends()
     SKGError err;
     SKGTRACEINRC(10, "SKGImportExportPlugin::importbackends", err);
     if (m_currentBankDocument) {
-        //Check if already in a transaction
+        // Check if already in a transaction
         if (!m_currentBankDocument->checkExistingTransaction()) {
-            //Repeat later
+            // Repeat later
             QTimer::singleShot(300, this, SLOT(importbackends()));
             return err;
         }
 
-        //Get backends list to used
+        // Get backends list to used
         QStringList backends = SKGServices::splitCSVLine(skgimportexport_settings::backends());
         int nbBackends = backends.count();
 
-        //Import
+        // Import
         SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import with backends"), err, nbBackends);
         for (int i = 0; !err && i < nbBackends; ++i) {
-            //Is password needed?
+            // Is password needed?
             QString pwd;
             QHash< QString, QString > properties;
             err = SKGServices::readPropertyFile(KStandardDirs().findResource("data", "skrooge/backends/" % backends[i] % ".backend"), properties);
@@ -396,14 +404,14 @@ SKGError SKGImportExportPlugin::importbackends()
             IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
         }
 
-        //Memorize the last download date
+        // Memorize the last download date
         IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_BACKEND_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
     }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 
-    //Open last modified operations if setting activated
+    // Open last modified operations if setting activated
     IFOK(err) openLastModifiedIfSetting();
 
     return err;
@@ -425,13 +433,13 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
         QString codec;
 
         if (iFiles.isEmpty()) {
-            //Panel to ask files
+            // Panel to ask files
             KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(lastCodecUsed, "kfiledialog:///IMPEXP",
                                                  sender() == m_importCsvUnitAction ? QString("*.csv|" % i18nc("A file format", "CSV Files")) :
                                                  SKGImportExportManager::getImportMimeTypeFilter(),
                                                  SKGMainPanel::getMainPanel());
-            foreach(const KUrl & url, result.URLs) {
-                fileNames.append(KUrl(url.url()));
+            foreach(const KUrl & u, result.URLs) {
+                fileNames.append(KUrl(u.url()));
             }
             codec = result.encoding;
         } else {
@@ -444,7 +452,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
             {
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import with codec %1", codec), err, nbFiles);
 
-                //Read Setting
+                // Read Setting
                 bool automatic_validation = skgimportexport_settings::automatic_validation();
                 bool automatic_rule = skgimportexport_settings::apply_rules();
                 bool since_last = skgimportexport_settings::since_last_import();
@@ -452,17 +460,17 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                 IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec))
 
                 for (int i = 0; !err && i < nbFiles; ++i) {
-                    //Get Filename
+                    // Get Filename
                     KUrl fileName = fileNames.at(i);
 
-                    //Import
+                    // Import
                     SKGImportExportManager imp1(m_currentBankDocument, fileName);
                     imp1.setAutomaticValidation(automatic_validation);
                     imp1.setAutomaticApplyRules(automatic_rule);
                     imp1.setSinceLastImportDate(since_last);
                     imp1.setCodec(codec);
 
-                    if (QFileInfo(fileName.path()).suffix().toUpper() == "CSV") { //TODO: Better
+                    if (QFileInfo(fileName.path()).suffix().toUpper() == "CSV") {  // TODO(Stephane MANKOWSKI): Better
                         QMap<QString, QString> parameters = imp1.getImportParameters();
 
                         parameters["automatic_search_header"] = (skgimportexport_settings::automatic_search_header() ? "Y" : "N");
@@ -493,7 +501,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         if (!parameters["date_format"].contains("YY")) parameters["date_format"] = "";
 
                         imp1.setImportParameters(parameters);
-                    } else if (QFileInfo(fileName.path()).suffix().toUpper() == "QIF") { //TODO: Better
+                    } else if (QFileInfo(fileName.path()).suffix().toUpper() == "QIF") {  // TODO(Stephane MANKOWSKI): Better
                         QMap<QString, QString> parameters = imp1.getImportParameters();
 
                         parameters["date_format"] = skgimportexport_settings::qif_date_format();
@@ -502,7 +510,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         imp1.setImportParameters(parameters);
                     }
 
-                    //Optimization
+                    // Optimization
                     if (i != nbFiles - 1) {
                         QMap< QString, QString > parameters = imp1.getImportParameters();
                         parameters["donotfinalize"] = 'Y';
@@ -520,11 +528,11 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         QString pwd;
                         QString additionalMessage;
                         do {
-                            //Reset error
+                            // Reset error
                             err = SKGError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName.prettyUrl()));
                             pwd = "";
 
-                            //Use password dialog
+                            // Use password dialog
                             QApplication::restoreOverrideCursor();
                             QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
                             dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
@@ -532,7 +540,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                             delete dlg;
                             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-                            //Load file
+                            // Load file
                             if (!pwd.isEmpty()) {
                                 QMap<QString, QString> parameters = imp1.getImportParameters();;
                                 parameters["password"] = pwd;
@@ -542,7 +550,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                                     if (err.getReturnCode() == ERR_ENCRYPTION) {
                                         additionalMessage = i18nc("The user did not provide the correct password", "<b>Wrong password.</b>\n");
                                     } else {
-                                        //Import error
+                                        // Import error
                                         break;
                                     }
                                 }
@@ -562,12 +570,12 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
             }
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             err = SKGError(0, i18np("%1 file successfully imported.", "%1 files successfully imported.", nbFiles));
         }
 
-        //Display error
+        // Display error
         m_install = false;
         KMessageWidget* msg = SKGMainPanel::displayErrorMessage(err);
         if (err.getReturnCode() == ERR_INSTALL && msg) {
@@ -579,7 +587,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
             connect(install, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
         }
 
-        //Open last modified operations if setting activated
+        // Open last modified operations if setting activated
         IFOK(err) openLastModifiedIfSetting();
     }
 }
@@ -611,11 +619,13 @@ void SKGImportExportPlugin::exportFile()
             }
         }
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "File '%1' successfully exported.", fileName)))
-        else err.addError(ERR_FAIL, i18nc("Error message", "Export of '%1' failed", fileName));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Export of '%1' failed", fileName));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -630,10 +640,10 @@ void SKGImportExportPlugin::anonymize()
         err = imp1.anonymize();
         QApplication::restoreOverrideCursor();
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("An anonymized document is a document where all private data has been removed", "Document anonymized.")))
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -652,17 +662,21 @@ void SKGImportExportPlugin::findTransfers()
             }
         }
 
-        //status bar
+        // status bar
         IFOK(err) {
             if (NbOperationsMerged) err = SKGError(0, i18np("Document successfully processed. %1 transfer created.",
                                                        "Document successfully processed. %1 transfers created.", NbOperationsMerged));
-            else err = m_currentBankDocument->sendMessage(i18nc("Information message", "No transfers found"));
-        } else err.addError(ERR_FAIL, i18nc("Error message", "Processing failed."));
+            else {
+                err = m_currentBankDocument->sendMessage(i18nc("Information message", "No transfers found"));
+            }
+        } else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Processing failed."));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
 
-        //Open last modified operations if setting activated
+        // Open last modified operations if setting activated
         if (!err && NbOperationsMerged) openLastModifiedIfSetting();
     }
 }
@@ -679,14 +693,16 @@ void SKGImportExportPlugin::cleanBanks()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Document successfully cleaned.")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Clean failed."));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Clean failed."));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 
-    //Open last modified operations if setting activated
+    // Open last modified operations if setting activated
     IFOK(err) openLastModifiedIfSetting();
 }
 
@@ -711,11 +727,13 @@ void SKGImportExportPlugin::validateImportedOperations()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported operations validated.")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -731,13 +749,22 @@ void SKGImportExportPlugin::mergeImportedOperation()
         if (nb == 2) {
             SKGOperationObject opImported(selection.at(0));
             SKGOperationObject opManual(selection.at(1));
-            if (opImported.isImported() != opManual.isImported()) {
-                if (!opImported.isImported())  qSwap(opImported, opManual);
+            if (opImported.isImported() || opManual.isImported()) {
+                if (opImported.isImported() && opManual.isImported()) {
+                    // Both are imports, so the "imported" on is the last one
+                    if (opImported.getID() < opManual.getID()) {
+                        qSwap(opImported, opManual);
+                    }
+                } else if (!opImported.isImported()) {
+                    qSwap(opImported, opManual);
+                }
 
-                //Mode force?
+                // Mode force?
                 bool modeForce = false;
                 QAction* act = qobject_cast< QAction* >(sender());
-                if (act) modeForce = (act->data().toInt() == 1);
+                if (act) {
+                    modeForce = (act->data().toInt() == 1);
+                }
 
                 if (!modeForce && opImported.getCurrentAmount() != opManual.getCurrentAmount()) {
                     KMessageWidget* msgWidget = SKGMainPanel::getMainPanel()->displayErrorMessage(i18nc("Question",  "Amounts are not equals. Do you want to force the merge ?"));
@@ -758,22 +785,22 @@ void SKGImportExportPlugin::mergeImportedOperation()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported operations merged.")))
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
 void SKGImportExportPlugin::openLastModifiedIfSetting()
 {
-    //Read Setting
+    // Read Setting
     bool open_after_import_or_processing = skgimportexport_settings::open_after_import_or_processing();
     if (open_after_import_or_processing) {
-        //Open last operations
-        QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction("view_open_last_modified");
-        if (action) {
-            action->trigger();
+        // Open last operations
+        QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("view_open_last_modified");
+        if (act) {
+            act->trigger();
         }
     }
 }
@@ -787,11 +814,13 @@ void SKGImportExportPlugin::validateAllOperations()
         err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET t_imported='Y' WHERE t_imported='P'");
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Operations validated.")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -800,7 +829,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGImportExportPlugin::advice");
     SKGAdviceList output;
 
-    //Check operations not validated
+    // Check operations not validated
     if (!iIgnoredAdvice.contains("skgimportexportplugin_notvalidated")) {
         bool exist = false;
         m_currentBankDocument->existObjects("operation", "t_imported='P'", exist);
@@ -818,7 +847,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Krunner operations
+    // Krunner operations
     QString dirName = QDir::homePath() % "/.skrooge/";
     QStringList fileList = QDir(dirName).entryList(QStringList() << "add_operation_*.txt", QDir::Files);
     int nb = fileList.count();
@@ -831,9 +860,9 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
             QFile file(fileName);
             if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 QTextStream stream(&file);
-                QString action = stream.readLine().trimmed();
+                stream.readLine().trimmed();  // action not used yet
                 QString date = KGlobal::locale()->formatDate(SKGServices::stringToTime(stream.readLine().trimmed()).date(), KLocale::ShortDate);
-                QString amount = m_currentBankDocument->formatMoney(SKGServices::stringToDouble(stream.readLine().trimmed()), m_currentBankDocument->getPrimaryUnit())  ;
+                QString amount = m_currentBankDocument->formatMoney(SKGServices::stringToDouble(stream.readLine().trimmed()), m_currentBankDocument->getPrimaryUnit());
                 QString payee = stream.readLine().trimmed();
                 SKGAdvice ad;
                 ad.setUUID("skgimportexportplugin_krunner_" % fileName);
@@ -848,7 +877,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
                 ad.setAutoCorrections(autoCorrections);
                 output.push_back(ad);
 
-                //Close file
+                // Close file
                 file.close();
             }
         }
@@ -860,45 +889,45 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
 {
     if (iAdviceIdentifier.startsWith(QLatin1String("skgimportexportplugin_krunner_")) && m_currentBankDocument) {
         SKGError err;
-        //Get file name
+        // Get file name
         QString fileName = iAdviceIdentifier.right(iAdviceIdentifier.length() - 30);
         QFile file(fileName);
 
-        //Get accounts
+        // Get accounts
         QStringList listAccounts;
         m_currentBankDocument->getDistinctValues("account", "t_name", "t_type IN ('C', 'D', 'W') and t_close='N'", listAccounts);
         if (iSolution < listAccounts.count()) {
-            //Addition in an account
+            // Addition in an account
 
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 err = SKGError(ERR_FAIL, i18nc("An erro message", "Open file '%1' failed", fileName));
             } else {
                 QTextStream stream(&file);
-                QString action = stream.readLine().trimmed();
+                stream.readLine().trimmed();  // action is not used yet
                 QDate date = SKGServices::stringToTime(stream.readLine().trimmed()).date();
                 double amount = SKGServices::stringToDouble(stream.readLine().trimmed());
                 QString payee = stream.readLine().trimmed();
 
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import krunner's operation"), err);
 
-                //Get account
+                // Get account
                 SKGAccountObject act(m_currentBankDocument);
                 err = act.setName(listAccounts.at(iSolution));
                 IFOKDO(err, act.load())
 
-                //Get unit
+                // Get unit
                 SKGUnitObject unit(m_currentBankDocument);
                 IFOKDO(err, unit.setName(m_currentBankDocument->getPrimaryUnit().Name))
                 IFOKDO(err, unit.load())
 
-                //Add operation
+                // Add operation
                 SKGOperationObject op;
                 IFOKDO(err, act.addOperation(op))
                 IFOKDO(err, op.setDate(date))
                 IFOKDO(err, op.setUnit(unit))
 
                 if (!payee.isEmpty()) {
-                    //Get payee
+                    // Get payee
                     SKGPayeeObject pa;
                     IFOKDO(err, SKGPayeeObject::createPayee(m_currentBankDocument, payee, pa, true))
                     IFOKDO(err, op.setPayee(pa))
@@ -910,13 +939,13 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 }
                 IFOKDO(err, op.save())
 
-                //Add suboperation
+                // Add suboperation
                 SKGSubOperationObject sop;
                 IFOKDO(err, op.addSubOperation(sop))
                 IFOKDO(err, sop.setQuantity(-amount))
                 IFOKDO(err, sop.save())
 
-                //Finalize the importation
+                // Finalize the importation
                 IFOK(err) {
                     bool automatic_validation = skgimportexport_settings::automatic_validation();
                     bool automatic_rule = skgimportexport_settings::apply_rules();
@@ -929,21 +958,23 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                     err = imp1.finalizeImportation();
                 }
 
-                //Close file
+                // Close file
                 file.close();
             }
 
-            //status bar
+            // status bar
             IFOK(err) {
                 err = SKGError(0, i18nc("Message for successful user action", "Operations imported."));
                 QFile::remove(fileName);
-            } else err.addError(ERR_FAIL, i18nc("Error message", "Import failed"));
+            } else {
+                err.addError(ERR_FAIL, i18nc("Error message", "Import failed"));
+            }
         } else {
             err = SKGError(0, i18nc("Message for successful user action", "Operations removed."));
             QFile::remove(fileName);
         }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
         return SKGError();
     }
