@@ -86,7 +86,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     addAction(m_menuSuboperation);
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGOperationBoardWidget::~SKGOperationBoardWidget()
