@@ -135,7 +135,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_openHighLights->setData(QString("skg://skrooge_operation_plugin/?title_icon=bookmarks&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Highlighted operations")) %
                                       "&operationWhereClause=" % SKGServices::encodeForUrl("t_bookmarked='Y'")));
     connect(m_openHighLights, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
-    m_openHighLights->setShortcut(Qt::META + Qt::Key_H);
+    m_openHighLights->setShortcut(Qt::CTRL + Qt::META + Qt::Key_H);
     registerGlobalAction("view_open_highlight", m_openHighLights);
 
     // ------------
