@@ -20,17 +20,18 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgpayeeplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgpayeepluginwidget.h"
 #include "skgpayee_settings.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
 #include "skgtransactionmng.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -40,8 +41,9 @@ K_PLUGIN_FACTORY(SKGPayeePluginFactory, registerPlugin<SKGPayeePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGPayeePluginFactory("skrooge_payee", "skrooge_payee"))
 
-SKGPayeePlugin::SKGPayeePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGPayeePlugin::SKGPayeePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGPayeePlugin::SKGPayeePlugin");
 }
 
@@ -62,7 +64,7 @@ bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_payee/skrooge_payee.rc");
 
-    //Actions
+    // Actions
     QStringList overlaydelete;
     overlaydelete.push_back("edit-delete");
 
@@ -120,7 +122,7 @@ SKGAdviceList SKGPayeePlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGPayeePlugin::advice");
     SKGAdviceList output;
-    //Check unused payee
+    // Check unused payee
     if (!iIgnoredAdvice.contains("skgpayeeplugin_unused")) {
         bool exist = false;
         m_currentBankDocument->existObjects("payee", "NOT EXISTS (SELECT 1 FROM operation WHERE operation.r_payee_id=payee.id)", exist);
@@ -146,16 +148,18 @@ void SKGPayeePlugin::deleteUnusedPayees() const
     if (m_currentBankDocument) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused payees")  , err);
 
-        //Modification of payee object
+        // Modification of payee object
         QString sql = "DELETE FROM payee WHERE NOT EXISTS (SELECT 1 FROM operation WHERE operation.r_payee_id=payee.id)";
         err = m_currentBankDocument->executeSqliteOrder(sql);
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Unused payees deleted")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Unused payees deletion failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Unused payees deletion failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
