@@ -91,7 +91,7 @@ protected:
     virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
 
 private Q_SLOTS:
-    void dataModified(const QString& iTableName, int iIdTransaction);
+    void dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction = false);
     void onSelectionChanged();
     void onEditorModified();
     void onAddPayee();
