@@ -53,7 +53,7 @@ SKGReportBoardWidget::SKGReportBoardWidget(SKGDocumentBank* iDocument)
     setMainWidget(m_graph);
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGReportBoardWidget::~SKGReportBoardWidget()
