@@ -20,6 +20,14 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgreportplugin.h"
+
+#include <KAction>
+#include <KActionCollection>
+#include <KAboutData>
+#include <KGenericFactory>
+
+#include <QDomDocument>
+
 #include "skgreportpluginwidget.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
@@ -35,13 +43,6 @@
 #include "skgdocumentbank.h"
 #include "skgreport_settings.h"
 
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
-#include <QDomDocument>
-
 /**
  * This plugin factory.
  */
@@ -51,10 +52,11 @@ K_PLUGIN_FACTORY(SKGReportPluginFactory, registerPlugin<SKGReportPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGReportPluginFactory("skrooge_report", "skrooge_report"))
 
-SKGReportPlugin::SKGReportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGReportPlugin::SKGReportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
     m_openReportAction(NULL), m_currentBankDocument(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGReportPlugin::SKGReportPlugin");
 }
 
@@ -75,7 +77,7 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_report/skrooge_report.rc");
 
-    //Menu
+    // Menu
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
     m_openReportAction = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), this);
@@ -83,7 +85,7 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     m_openReportAction->setShortcut(Qt::META + Qt::Key_R);
     registerGlobalAction("open_report", m_openReportAction);
 
-    //---------------
+    // ---------------
     KAction* act = new KAction(KIcon("security-low", NULL, overlayopen), i18nc("Verb", "Open very old operations..."), this);
     act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title=" %
                          SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very old operations")) %
@@ -135,9 +137,9 @@ SKGTabPage* SKGReportPlugin::getWidget()
 QWidget* SKGReportPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGReportPlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
-    return widget;
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
+    return w;
 }
 
 KConfigSkeleton* SKGReportPlugin::getPreferenceSkeleton()
@@ -189,84 +191,84 @@ void SKGReportPlugin::onOpenReport()
         int nb = selection.count();
         if (nb > 0) {
             QString wc;
-            QString title;
+            QString titleTable;
             QString table = selection.at(0).getRealTable();
             if (table == "account") {
                 wc = "rd_account_id in (";
-                title = i18nc("Noun, a list of items", "Operations of account ");
+                titleTable = i18nc("Noun, a list of items", "Operations of account ");
 
                 for (int i = 0; i < nb; ++i) {
                     SKGAccountObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
-                        title += ',';
+                        titleTable += ',';
                     }
                     wc += SKGServices::intToString(tmp.getID());
-                    title += i18n("'%1'", tmp.getName());
+                    titleTable += i18n("'%1'", tmp.getName());
                 }
                 wc += ')';
             } else if (table == "unit") {
                 wc = "rc_unit_id in (";
-                title = i18nc("Noun, a list of items", "Operations with Unit equal to ");
+                titleTable = i18nc("Noun, a list of items", "Operations with Unit equal to ");
 
                 for (int i = 0; i < nb; ++i) {
                     SKGUnitObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
-                        title += ',';
+                        titleTable += ',';
                     }
                     wc += SKGServices::intToString(tmp.getID());
-                    title += i18n("'%1'", tmp.getName());
+                    titleTable += i18n("'%1'", tmp.getName());
                 }
                 wc += ')';
             } else if (table == "category") {
                 wc = "t_REALCATEGORY in (";
                 QString wc2;
-                title = i18nc("Noun, a list of items", "Operations with Category equal to ");
+                titleTable = i18nc("Noun, a list of items", "Operations with Category equal to ");
 
                 for (int i = 0; i < nb; ++i) {
                     SKGCategoryObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
                         wc2 += " OR ";
-                        title += ',';
+                        titleTable += ',';
                     }
                     wc += '\'' % SKGServices::stringToSqlString(tmp.getFullName()) % '\'';
                     wc2 += "t_REALCATEGORY like '" % SKGServices::stringToSqlString(tmp.getFullName()) % "%'";
-                    title += i18n("'%1'", tmp.getFullName());
+                    titleTable += i18n("'%1'", tmp.getFullName());
                 }
                 wc += ") OR " % wc2;
             } else if (table == "refund") {
                 wc = "r_refund_id in (";
-                title = i18nc("Noun, a list of items", "Operations followed by ");
+                titleTable = i18nc("Noun, a list of items", "Operations followed by ");
 
                 for (int i = 0; i < nb; ++i) {
                     SKGTrackerObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
-                        title += ',';
+                        titleTable += ',';
                     }
                     wc += SKGServices::intToString(tmp.getID());
-                    title += i18n("'%1'", tmp.getName());
+                    titleTable += i18n("'%1'", tmp.getName());
                 }
                 wc += ')';
             } else if (table == "payee") {
                 wc = "r_payee_id in (";
-                title = i18nc("Noun, a list of items", "Operations assigned to ");
+                titleTable = i18nc("Noun, a list of items", "Operations assigned to ");
 
                 for (int i = 0; i < nb; ++i) {
                     SKGPayeeObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
-                        title += ',';
+                        titleTable += ',';
                     }
                     wc += SKGServices::intToString(tmp.getID());
-                    title += i18n("'%1'", tmp.getName());
+                    titleTable += i18n("'%1'", tmp.getName());
                 }
                 wc += ')';
             } else if (table == "operation") {
                 wc = "id in (";
-                title = i18nc("Noun, a list of items", "Selected operations");
+                titleTable = i18nc("Noun, a list of items", "Selected operations");
 
                 for (int i = 0; i < nb; ++i) {
                     if (i) {
@@ -276,7 +278,7 @@ void SKGReportPlugin::onOpenReport()
                 }
                 wc += ')';
             } else if (table == "rule") {
-                title = i18nc("Noun, a list of items", "Operations corresponding to rule ");
+                titleTable = i18nc("Noun, a list of items", "Operations corresponding to rule ");
 
                 for (int i = 0; i < nb; ++i) {
                     SKGRuleObject tmp(selection.at(i));
@@ -284,16 +286,16 @@ void SKGReportPlugin::onOpenReport()
                     if (!ruleWc.isEmpty()) {
                         if (!wc.isEmpty()) {
                             wc += " OR ";
-                            title += ',';
+                            titleTable += ',';
                         }
                         wc += '(' % ruleWc % ')';
-                        title += i18n("'%1'", tmp.getSearchDescription());
+                        titleTable += i18n("'%1'", tmp.getSearchDescription());
                     }
                 }
             }
 
-            //Call report plugin
-            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_report_plugin/?period=0&title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(title) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
+            // Call report plugin
+            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_report_plugin/?period=0&title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(titleTable) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
         }
     }
 }
@@ -303,7 +305,7 @@ SKGAdviceList SKGReportPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGReportPlugin::advice");
     SKGAdviceList output;
 
-    //Very old operation
+    // Very old operation
     if (!iIgnoredAdvice.contains("skgreportplugin_veryold")) {
         bool exist = false;
         m_currentBankDocument->existObjects("operation", "d_date<=(SELECT date('now', '-50 year')) AND d_date<>'0000-00-00'", exist);
