@@ -171,7 +171,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     connect(ui.kCorrectedBy, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kCorrectedByMode, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
 
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)));
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
 
     if (iMinimmumMode) {
@@ -949,7 +949,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         if (nbBudgets) {
                             // Get most active account
                             SKGStringListList list;
-                            err = doc->executeSelectSqliteOrder("SELECT account.id FROM account, operation WHERE +operation.rd_account_id=account.id AND d_date>date('now', '-3 month') GROUP BY (t_name) ORDER BY COUNT(1) DESC LIMIT 1", list);
+                            err = doc->executeSelectSqliteOrder("SELECT IFNULL((SELECT account.id FROM account, operation WHERE +operation.rd_account_id=account.id AND d_date>date('now', '-3 month') GROUP BY (t_name) ORDER BY COUNT(1) DESC LIMIT 1), (SELECT id FROM account)) ", list);
                             if (!err && list.count() == 2) {
                                 SKGAccountObject account(doc, SKGServices::stringToInt(list.at(1).at(0)));
                                 err = account.load();
