@@ -20,6 +20,13 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgscheduledplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+#include <KStandardDirs>
+
 #include "skgscheduledpluginwidget.h"
 #include "skgscheduled_settings.h"
 #include "skgrecurrentoperationobject.h"
@@ -30,12 +37,6 @@
 #include "skgsuboperationobject.h"
 #include "skghtmlboardwidget.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-#include <kstandarddirs.h>
-
 /**
  * This plugin factory.
  */
@@ -45,9 +46,10 @@ K_PLUGIN_FACTORY(SKGScheduledPluginFactory, registerPlugin<SKGScheduledPlugin>()
  */
 K_EXPORT_PLUGIN(SKGScheduledPluginFactory("skrooge_scheduled", "skrooge_scheduled"))
 
-SKGScheduledPlugin::SKGScheduledPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+SKGScheduledPlugin::SKGScheduledPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_scheduleOperationAction(NULL), m_counterAdvice(0)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGScheduledPlugin::SKGScheduledPlugin");
 }
 
@@ -68,7 +70,7 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_scheduled/skrooge_scheduled.rc");
 
-    //Create yours actions here
+    // Create yours actions here
     m_scheduleOperationAction = new KAction(KIcon("skrooge_schedule"), i18nc("Verb, create a scheduled operation", "Schedule"), this);
     connect(m_scheduleOperationAction, SIGNAL(triggered(bool)), this, SLOT(onScheduleOperation()));
     m_scheduleOperationAction->setShortcut(Qt::CTRL + Qt::Key_I);
@@ -89,7 +91,7 @@ void SKGScheduledPlugin::refresh()
             if (m_scheduleOperationAction) m_scheduleOperationAction->setEnabled(false);
         }
 
-        //Automatic insert
+        // Automatic insert
         if (m_currentBankDocument && m_currentBankDocument->getDatabase() != NULL) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id && m_currentBankDocument->getParameter("SKG_DB_BANK_VERSION") >= "0.5") {
@@ -97,7 +99,7 @@ void SKGScheduledPlugin::refresh()
                 m_cacheAdvice.clear();
 
                 SKGError err;
-                //Read Setting
+                // Read Setting
                 bool check_on_open = skgscheduled_settings::check_on_open();
 
                 if (check_on_open) {
@@ -105,7 +107,7 @@ void SKGScheduledPlugin::refresh()
                     int nbi = 0;
                     err = SKGRecurrentOperationObject::process(m_currentBankDocument, nbi);
                 }
-                //Display error
+                // Display error
                 SKGMainPanel::displayErrorMessage(err);
             }
         }
@@ -140,9 +142,9 @@ SKGTabPage* SKGScheduledPlugin::getWidget()
 QWidget* SKGScheduledPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGScheduledPlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
-    return widget;
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
+    return w;
 }
 
 KConfigSkeleton* SKGScheduledPlugin::getPreferenceSkeleton()
@@ -191,7 +193,7 @@ SKGError SKGScheduledPlugin::savePreferences() const
 {
     SKGError err;
     if (m_currentBankDocument) {
-        //Read Setting
+        // Read Setting
         if (skgscheduled_settings::create_template()) {
             SKGObjectBase::SKGListSKGObjectBase recurrents;
             err = m_currentBankDocument->getObjects("v_recurrentoperation", "(select count(1) from operation where operation.id=rd_operation_id and t_template='N')=1", recurrents);
@@ -199,7 +201,7 @@ SKGError SKGScheduledPlugin::savePreferences() const
             if (nb) {
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Conversion schedule"), err, nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    //Migration of existing schedule in template mode
+                    // Migration of existing schedule in template mode
                     SKGRecurrentOperationObject recOp(recurrents.at(i));
                     SKGOperationObject operationObj;
 
@@ -232,7 +234,7 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
 
     SKGOperationObject operationObjOrig;
     if (!isTemplate && skgscheduled_settings::create_template()) {
-        //The selected operation is not a template and settings is set to create one
+        // The selected operation is not a template and settings is set to create one
         operationObjOrig = operationObjDuplicate;
         IFOKDO(err, operationObjOrig.duplicate(operationObjDuplicate, operationObjOrig.getDate(), true))
         IFOK(err) m_currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), SKGDocument::Positive);
@@ -266,7 +268,7 @@ void SKGScheduledPlugin::onScheduleOperation()
     SKGError err;
     SKGTRACEINRC(10, "SKGScheduledPlugin::onScheduleOperation", err);
 
-    //Get Selection
+    // Get Selection
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
@@ -282,16 +284,18 @@ void SKGScheduledPlugin::onScheduleOperation()
             }
 
             IFOK(err) {
-                //Open the scheduled operation
+                // Open the scheduled operation
                 SKGMainPanel::getMainPanel()->openPage("skg://skrooge_scheduled_plugin/?selection=" % SKGServices::encodeForUrl(SKGServices::stringsToCsv(list)));
             }
         }
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation scheduled.")))
-        else err.addError(ERR_FAIL, i18nc("Error message",  "Operation schedule failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Operation schedule failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -301,14 +305,14 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGScheduledPlugin::advice");
     SKGAdviceList output;
 
-    //Recurrent operation with the last inserted operation having a different amount
+    // Recurrent operation with the last inserted operation having a different amount
     if (!iIgnoredAdvice.contains("skgscheduledplugin_notuptodate")) {
         SKGTRACEIN(10, "SKGScheduledPlugin::advice-skgscheduledplugin_notuptodate");
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND ABS(r.f_CURRENTAMOUNT-r2.f_CURRENTAMOUNT)>" % SKGServices::doubleToString(EPSILON), result);
         int nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
-            //Get parameters
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
             QStringList line = result.at(i);
             int idRecu = SKGServices::stringToInt(line.at(0));
             QString idOper = line.at(1);
@@ -330,7 +334,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Possible recurrent operations
+    // Possible recurrent operations
     if (!iIgnoredAdvice.contains("skgscheduledplugin_possibleschedule")) {
         SKGTRACEIN(10, "SKGScheduledPlugin::advice-skgscheduledplugin_possibleschedule");
         if (m_counterAdvice % 10 != 0) {
@@ -343,8 +347,8 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
                     "AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.d_date=date(op2.d_date, '+1 month') "
                     "AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 op2  WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.rc_unit_id=op2.rc_unit_id)", result);
             int nb = result.count();
-            for (int i = 1; i < nb; ++i) { //Ignore header
-                //Get parameters
+            for (int i = 1; i < nb; ++i) {  // Ignore header
+                // Get parameters
                 QStringList line = result.at(i);
                 QString id = line.at(0);
                 QString name = line.at(1);
@@ -370,13 +374,13 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 {
     SKGError err;
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_notuptodate|"))) {
-        //Get parameters
+        // Get parameters
         QString parameters = iAdviceIdentifier.right(iAdviceIdentifier.length() - 31);
         int pos = parameters.indexOf(';');
         int idOper = SKGServices::stringToInt(parameters.left(pos));
         double amount = SKGServices::stringToDouble(parameters.right(parameters.length() - 1 - pos));
 
-        //Update the operation
+        // Update the operation
         {
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled operation"), err);
             SKGOperationObject op(m_currentBankDocument, idOper);
@@ -384,12 +388,12 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             IFOKDO(err, op.getSubOperations(subOps))
 
             if (subOps.count() == 1) {
-                //Change the quantity of the sub operation
+                // Change the quantity of the sub operation
                 SKGSubOperationObject so1(subOps.at(0));
                 IFOKDO(err, so1.setQuantity(amount))
                 IFOKDO(err, so1.save())
             } else if (subOps.count() >= 1) {
-                //Add a split
+                // Add a split
                 SKGSubOperationObject so1;
                 IFOKDO(err, op.addSubOperation(so1))
                 IFOKDO(err, so1.setQuantity(amount - op.getCurrentAmount()))
@@ -397,19 +401,21 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             }
         }
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operation updated.")))
-        else err.addError(ERR_FAIL, i18nc("Error message", "Update failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Update failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
 
         return err;
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_possibleschedule|"))) {
-        //Get parameters
+        // Get parameters
         int idOper = SKGServices::stringToInt(iAdviceIdentifier.right(iAdviceIdentifier.length() - 36));
 
-        //Update the operation
+        // Update the operation
         {
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Scheduled operation"), err);
             SKGOperationObject op(m_currentBankDocument, idOper);
@@ -421,14 +427,16 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             IFOKDO(err, rop.setDate(rop.getNextDate()))
             IFOKDO(err, rop.save(true, false))
 
-            m_counterAdvice = 0; //To force the update
+            m_counterAdvice = 0;  // To force the update
         }
 
-        //status bar
+        // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation scheduled.")))
-        else err.addError(ERR_FAIL, i18nc("Error message", "Schedule failed"));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Schedule failed"));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
 
         return err;
