@@ -61,7 +61,7 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     addAction(m_menuFavorite);
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGAlarmBoardWidget::~SKGAlarmBoardWidget()
