@@ -20,6 +20,12 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgsearchplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgsearchpluginwidget.h"
 #include "skgsearch_settings.h"
 #include "skgtraces.h"
@@ -31,11 +37,6 @@
 #include "skgdocumentbank.h"
 #include "skgcategoryobject.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -45,8 +46,9 @@ K_PLUGIN_FACTORY(SKGSearchPluginFactory, registerPlugin<SKGSearchPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGSearchPluginFactory("skrooge_search", "skrooge_search"))
 
-SKGSearchPlugin::SKGSearchPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGSearchPlugin::SKGSearchPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGSearchPlugin::SKGSearchPlugin");
     m_timer.setSingleShot(true);
     connect(&m_timer, SIGNAL(timeout()), this, SLOT(raiseAlarms()), Qt::QueuedConnection);
@@ -89,13 +91,13 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_search/skrooge_search.rc");
 
-    //Create yours actions here
-    //Execute on all operation
+    // Create yours actions here
+    // Execute on all operation
     m_executeAll = new KAction(KIcon("system-run"), i18nc("Verb, action to execute", "Execute on all operations"), this);
     connect(m_executeAll, SIGNAL(triggered(bool)), SLOT(execute()));
     registerGlobalAction("execute_all", m_executeAll);
 
-    //Execute on imported operation
+    // Execute on imported operation
     {
         QStringList overlaycsv;
         overlaycsv.push_back("document-import");
@@ -104,7 +106,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
         registerGlobalAction("execute_imported", m_executeImported);
     }
 
-    //Execute on not validated
+    // Execute on not validated
     {
         QStringList overlaycsv;
         overlaycsv.push_back("dialog-ok-apply");
@@ -113,7 +115,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
         registerGlobalAction("execute_not_validated", m_executeNotValidated);
     }
 
-    //Search
+    // Search
     m_searchAction = actionCollection()->addAction(KStandardAction::Find, "edit_find", this, SLOT(find()));
     registerGlobalAction("edit_find", m_searchAction);
 
@@ -131,7 +133,7 @@ void SKGSearchPlugin::refresh()
             if (m_executeNotValidated) m_executeNotValidated->setEnabled(test);
         }
 
-        //Start alarm
+        // Start alarm
         if (m_currentBankDocument && m_currentBankDocument->getDatabase() != NULL) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id) {
@@ -156,7 +158,7 @@ void SKGSearchPlugin::raiseAlarms()
             }
         }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
 
         m_timer.start(skgsearch_settings::alarm_frequency() * 60 * 1000);
@@ -168,15 +170,18 @@ void SKGSearchPlugin::execute()
     SKGError err;
     SKGTRACEINRC(1, "SKGSearchPlugin::execute", err);
 
-    //Get rules
+    // Get rules
     SKGObjectBase::SKGListSKGObjectBase rules = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
     int nb = rules.count();
     if (m_currentBankDocument) {
         SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Process execution"), err, nb);
         SKGRuleObject::ProcessMode mode = SKGRuleObject::ALL;
-        if (sender() == m_executeImported) mode = SKGRuleObject::IMPORTED;
-        else if (sender() == m_executeNotValidated) mode = SKGRuleObject::IMPORTEDNOTVALIDATE;
+        if (sender() == m_executeImported) {
+            mode = SKGRuleObject::IMPORTED;
+        } else if (sender() == m_executeNotValidated) {
+            mode = SKGRuleObject::IMPORTEDNOTVALIDATE;
+        }
         for (int i = 0; !err && i < nb; ++i) {
             SKGRuleObject rule(rules.at(i));
             err = rule.execute(mode);
@@ -184,11 +189,13 @@ void SKGSearchPlugin::execute()
         }
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Process executed")))
-    else err.addError(ERR_FAIL, i18nc("Error message",  "Process execution failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Process execution failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -301,7 +308,7 @@ void SKGSearchPlugin::find()
             }
         }
 
-        //Call search plugin
+        // Call search plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_search_plugin/?currentPage=0&xmlsearchcondition=" % SKGServices::encodeForUrl(xmlsearchcondition));
     }
 }
@@ -315,9 +322,9 @@ SKGTabPage* SKGSearchPlugin::getWidget()
 QWidget* SKGSearchPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGSearchPlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
-    return widget;
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
+    return w;
 }
 
 KConfigSkeleton* SKGSearchPlugin::getPreferenceSkeleton()
@@ -363,7 +370,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGSearchPlugin::advice");
     SKGAdviceList output;
 
-    //Alarms
+    // Alarms
     if (!iIgnoredAdvice.contains("skgsearchplugin_alarm")) {
         SKGObjectBase::SKGListSKGObjectBase rules;
         SKGError err = m_currentBankDocument->getObjects("v_rule", "t_action_type='A' ORDER BY i_ORDER", rules);
@@ -397,7 +404,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgsearchplugin_alarm|"))) {
-        //Get parameters
+        // Get parameters
         QString id = iAdviceIdentifier.right(iAdviceIdentifier.length() - 22);
         SKGSearchPluginWidget::open(SKGRuleObject(m_currentBankDocument, SKGServices::stringToInt(id)));
         return SKGError();
