@@ -44,11 +44,11 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
-    ui.kView->getShowWidget()->addItem("search", i18nc("Noun, a search", "Search"), "edit-find", "t_action_type='S'", "", "", "");
-    ui.kView->getShowWidget()->addItem("update", i18nc("Noun, a modification", "Update"), "view-refresh", "t_action_type='U'", "", "", "");
-    ui.kView->getShowWidget()->addItem("alarm", i18nc("Noun, an alarm", "Alarm"), "dialog-warning", "t_action_type='A'", "", "", "");
+    ui.kView->getShowWidget()->addItem("search", i18nc("Noun, a search", "Search"), "edit-find", "t_action_type='S'", "", "", "", "", Qt::META + Qt::Key_S);
+    ui.kView->getShowWidget()->addItem("update", i18nc("Noun, a modification", "Update"), "view-refresh", "t_action_type='U'", "", "", "", "", Qt::META + Qt::Key_U);
+    ui.kView->getShowWidget()->addItem("alarm", i18nc("Noun, an alarm", "Alarm"), "dialog-warning", "t_action_type='A'", "", "", "", "", Qt::META + Qt::Key_A);
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem("highlighted", i18nc("Adjective, an highlighted item", "Highlighted"), "bookmarks", "t_bookmarked='Y'", "", "", "");
+    ui.kView->getShowWidget()->addItem("highlighted", i18nc("Adjective, an highlighted item", "Highlighted"), "bookmarks", "t_bookmarked='Y'", "", "", "", "", Qt::META + Qt::Key_H);
     ui.kView->getShowWidget()->setDefaultState("search;update;alarm;highlighted");
 
     // Add Standard KDE Icons to buttons
@@ -139,7 +139,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 
     onSelectionChanged();
