@@ -20,16 +20,17 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgtrackerplugin.h"
+
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KAboutData>
+#include <KGenericFactory>
+
 #include "skgtrackerpluginwidget.h"
 #include "skgtracker_settings.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-
 /**
  * This plugin factory.
  */
@@ -39,8 +40,9 @@ K_PLUGIN_FACTORY(SKGTrackerPluginFactory, registerPlugin<SKGTrackerPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGTrackerPluginFactory("skrooge_tracker", "skrooge_tracker"))
 
-SKGTrackerPlugin::SKGTrackerPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGTrackerPlugin::SKGTrackerPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGTrackerPlugin::SKGTrackerPlugin");
 }
 
@@ -61,7 +63,7 @@ bool SKGTrackerPlugin::setupActions(SKGDocument* iDocument, const QStringList& i
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_tracker/skrooge_tracker.rc");
 
-    //Create yours actions here
+    // Create yours actions here
     return true;
 }
 
@@ -112,12 +114,12 @@ SKGAdviceList SKGTrackerPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGTrackerPlugin::advice");
     SKGAdviceList output;
-    //Search old trackers
+    // Search old trackers
     if (!iIgnoredAdvice.contains("skgtrackerplugin_old")) {
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name  FROM v_refund_display WHERE t_close='N' AND julianday('now')-julianday(d_LASTDATE)>300 ORDER BY julianday('now')-julianday(d_LASTDATE) DESC;", result);
         int nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
+        for (int i = 1; i < nb; ++i) {  // Ignore header
             SKGAdvice ad;
             ad.setUUID("skgtrackerplugin_old|" % result.at(i).at(0));
             ad.setPriority(2);
