@@ -40,9 +40,9 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
     ui.setupUi(this);
 
     // Set show widget
-    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"));
-    ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "task-ongoing", "t_close='N'");
-    ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'");
+    ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"), "", "", "", Qt::META + Qt::Key_A);
+    ui.kView->getShowWidget()->addGroupedItem("opened", i18n("Opened"), "task-ongoing", "t_close='N'", "", Qt::META + Qt::Key_O);
+    ui.kView->getShowWidget()->addGroupedItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'", "", Qt::META + Qt::Key_C);
     ui.kView->getShowWidget()->setDefaultState("opened");
 
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
@@ -65,7 +65,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
         ui.kView->getView()->resizeColumnToContents(0);
     }
 
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int,bool)), Qt::QueuedConnection);
     connect(ui.kView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
@@ -153,15 +153,17 @@ void SKGTrackerPluginWidget::onEditorModified()
     ui.kAddButton->setEnabled(!ui.kNameInput->text().isEmpty());
 }
 
-void SKGTrackerPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGTrackerPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
     SKGTRACEIN(10, "SKGTrackerPluginWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    if (iTableName == "refund" || iTableName.isEmpty()) {
-        // Set completions
-        SKGMainPanel::fillWithDistinctValue(ui.kNameInput, getDocument(), "refund", "t_name", "", true);
-        SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "refund", "t_comment", "", true);
+    if (!iLightTransaction) {
+        if (iTableName == "refund" || iTableName.isEmpty()) {
+            // Set completions
+            SKGMainPanel::fillWithDistinctValue(ui.kNameInput, getDocument(), "refund", "t_name", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "refund", "t_comment", "", true);
+        }
     }
 }
 
