@@ -20,6 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgunitplugin.h"
+
+#include <KInputDialog>
+#include <KActionCollection>
+#include <KAction>
+#include <KAboutData>
+#include <KGenericFactory>
+#include <KStandardDirs>
+#include <KComponentData>
+
 #include "skgunitpluginwidget.h"
 #include "skgunitboardwidget.h"
 #include "skgunit_settings.h"
@@ -30,14 +39,6 @@
 #include "skgdocumentbank.h"
 #include "skgunitvalueobject.h"
 
-#include <kinputdialog.h>
-#include <kactioncollection.h>
-#include <kaction.h>
-#include <kaboutdata.h>
-#include <kgenericfactory.h>
-#include <kstandarddirs.h>
-#include <kcomponentdata.h>
-
 /**
  * This plugin factory.
  */
@@ -47,10 +48,11 @@ K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGUnitPluginFactory("skrooge_unit", "skrooge_unit"))
 
-SKGUnitPlugin::SKGUnitPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/)
+SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL),
       m_splitShareAction(NULL)
 {
+    Q_UNUSED(iWidget);
     SKGTRACEIN(10, "SKGUnitPlugin::SKGUnitPlugin");
 }
 
@@ -71,13 +73,13 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_unit/skrooge_unit.rc");
 
-    //Menu
+    // Menu
     m_splitShareAction = new KAction(KIcon("skrooge_split_stock"), i18nc("Verb", "Split share..."), this);
     connect(m_splitShareAction, SIGNAL(triggered(bool)), this, SLOT(onSplitShare()));
     m_splitShareAction->setShortcut(Qt::ALT + Qt::Key_Slash);
     registerGlobalAction("edit_split_stock", m_splitShareAction);
 
-    //-----------
+    // -----------
     KAction* act = new KAction(KIcon(icon()), i18nc("Verb", "Delete unused units"), this);
     connect(act, SIGNAL(triggered(bool)), this, SLOT(deleteUnusedUnits()));
     registerGlobalAction("clean_delete_unused_units", act);
@@ -91,17 +93,23 @@ int SKGUnitPlugin::getNbDashboardWidgets()
 
 QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, the title of a section", "Quotes");
-    else return i18nc("Noun, the title of a section", "Stock portfolio");
+    if (iIndex == 0) {
+        return i18nc("Noun, the title of a section", "Quotes");
+    } else {
+        return i18nc("Noun, the title of a section", "Stock portfolio");
+    }
 }
 
 SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGUnitBoardWidget(m_currentBankDocument);
-    else return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                           getDashboardWidgetTitle(iIndex),
-                                           KStandardDirs().findResource("data", "skrooge/html/default/portfolio.html"),
-                                           QStringList() << "v_operation_display");
+    if (iIndex == 0) {
+        return new SKGUnitBoardWidget(m_currentBankDocument);
+    } else {
+        return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                      getDashboardWidgetTitle(iIndex),
+                                      KStandardDirs().findResource("data", "skrooge/html/default/portfolio.html"),
+                                      QStringList() << "v_operation_display");
+    }
 }
 
 void SKGUnitPlugin::refresh()
@@ -119,12 +127,12 @@ void SKGUnitPlugin::refresh()
             }
         }
 
-        //Automatic download
+        // Automatic download
         if (test) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id) {
                 m_docUniqueIdentifier = doc_id;
-                //Check if current unit is existing
+                // Check if current unit is existing
                 KLocale* loc = KGlobal::locale();
                 bool exist = false;
                 SKGError err = m_currentBankDocument->existObjects("unit", "", exist);
@@ -132,15 +140,15 @@ void SKGUnitPlugin::refresh()
                     if (!exist) {
                         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err);
                         IFOK(err) {
-                            //Create default unit
+                            // Create default unit
                             SKGUnitObject unit;
                             err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, loc->currencyCode(), unit);
 
-                            //The file is considered has not modified
+                            // The file is considered has not modified
                             m_currentBankDocument->setFileNotModified();
                         }
                     } else if (skgunit_settings::download_on_open()) {
-                        //Check frequency
+                        // Check frequency
                         QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD");
                         if (lastAutomaticDownload.isEmpty()) lastAutomaticDownload = "1970-01-01";
                         QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
@@ -149,7 +157,7 @@ void SKGUnitPlugin::refresh()
                                 (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
 
                         {
-                            //Download all units
+                            // Download all units
                             SKGObjectBase::SKGListSKGObjectBase selection;
                             err = m_currentBankDocument->getObjects("unit", "", selection);
                             int nb = selection.count();
@@ -160,13 +168,13 @@ void SKGUnitPlugin::refresh()
                                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                             }
 
-                            //Memorize the last download date
+                            // Memorize the last download date
                             IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
                         }
                     }
                 }
 
-                //Display error
+                // Display error
                 SKGMainPanel::displayErrorMessage(err);
             }
         }
@@ -182,10 +190,10 @@ SKGTabPage* SKGUnitPlugin::getWidget()
 QWidget* SKGUnitPlugin::getPreferenceWidget()
 {
     SKGTRACEIN(10, "SKGUnitPlugin::getPreferenceWidget");
-    QWidget* widget = new QWidget();
-    ui.setupUi(widget);
+    QWidget* w = new QWidget();
+    ui.setupUi(w);
 
-    return widget;
+    return w;
 }
 
 KConfigSkeleton* SKGUnitPlugin::getPreferenceSkeleton()
@@ -237,7 +245,7 @@ void SKGUnitPlugin::onSplitShare()
     SKGError err;
     SKGTRACEINRC(10, "SKGUnitPlugin::onSplitShare", err);
 
-    //Get Selection
+    // Get Selection
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
@@ -253,11 +261,13 @@ void SKGUnitPlugin::onSplitShare()
             }
         }
 
-        //status
+        // status
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Stock split.")))
-        else err.addError(ERR_FAIL, i18nc("Error message", "Splitting stock failed."));
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Splitting stock failed."));
+        }
 
-        //Display error
+        // Display error
         SKGMainPanel::displayErrorMessage(err);
     }
 }
@@ -267,15 +277,15 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEIN(10, "SKGUnitPlugin::advice");
     SKGAdviceList output;
 
-    //Get all currencies
+    // Get all currencies
     SKGStringListList result;
     m_currentBankDocument->executeSelectSqliteOrder("SELECT (SELECT count(1) FROM operation WHERE operation.rc_unit_id=unit.id), unit.t_name FROM unit WHERE t_type='C' GROUP BY t_name ORDER BY count(1) DESC", result);
     int nb = result.count();
 
-    //Check primary unit
+    // Check primary unit
     if (!iIgnoredAdvice.contains("skgunitplugin_primaryunit")) {
         if (m_currentBankDocument->getPrimaryUnit().Name.isEmpty() && nb > 1) {
-            //Get unit
+            // Get unit
             QString unit = result.at(1).at(1);
 
             SKGAdvice ad;
@@ -285,7 +295,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setLongMessage(i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted"));
             QStringList autoCorrections;
             autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit));
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
 
@@ -293,10 +303,10 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Check secondary unit
+    // Check secondary unit
     if (!iIgnoredAdvice.contains("skgunitplugin_secondaryunit")) {
         if (m_currentBankDocument->getSecondaryUnit().Name.isEmpty() && nb > 1) {
-            //Get unit
+            // Get unit
             QString unit = result.at(1).at(1);
 
             SKGAdvice ad;
@@ -306,18 +316,18 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setLongMessage(i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information."));
             QStringList autoCorrections;
             autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit));
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
-    //Shares not downloaded
+    // Shares not downloaded
     if (!iIgnoredAdvice.contains("skgunitplugin_notdownloaded")) {
         m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)", result);
         nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
-            //Get parameters
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
             QStringList line = result.at(i);
             QString unit = line.at(0);
             QString internet_code = line.at(1);
@@ -328,14 +338,14 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
             QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
             if (!internet_code.isEmpty()) autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
-    //Check unused units
+    // Check unused units
     if (!iIgnoredAdvice.contains("skgunitplugin_unused")) {
         bool exist = false;
         m_currentBankDocument->existObjects("unit", "t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)", exist);
@@ -352,12 +362,12 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Check unit too complex
+    // Check unit too complex
     if (!iIgnoredAdvice.contains("skgunitplugin_toocomplex")) {
         m_currentBankDocument->executeSelectSqliteOrder("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id", result);
         nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
-            //Get parameters
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
             QStringList line = result.at(i);
             QString unit = line.at(0);
 
@@ -367,18 +377,18 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setShortMessage(i18nc("Advice on making the best (short)", "The definition of the unit '%1' is too complex", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' is defined relatively to another unit defined relatively to a third one. This is too complex and not supported by Skrooge.", unit));
             QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
-    //Unit with very old values
+    // Unit with very old values
     if (!iIgnoredAdvice.contains("skgunitplugin_veryold")) {
         m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', '-50 year')))", result);
         nb = result.count();
-        for (int i = 1; i < nb; ++i) { //Ignore header
-            //Get parameters
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
             QStringList line = result.at(i);
             QString unit = line.at(0);
 
@@ -388,7 +398,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has very old values", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Unit '%1' has very old values. Check if this is normal.", unit));
             QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -403,7 +413,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         if (iSolution == 1) {
             SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         } else {
-            //Get parameters
+            // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 26);
 
             SKGError err;
@@ -416,11 +426,13 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 IFOKDO(err, unitObj.save(true, false))
             }
 
-            //status bar
+            // status bar
             IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Primary currency defined.")))
-            else err.addError(ERR_FAIL, i18nc("Error message", "Primary currency definition failed"));
+            else {
+                err.addError(ERR_FAIL, i18nc("Error message", "Primary currency definition failed"));
+            }
 
-            //Display error
+            // Display error
             SKGMainPanel::displayErrorMessage(err);
         }
 
@@ -429,7 +441,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         if (iSolution == 1) {
             SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         } else {
-            //Get parameters
+            // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
 
             SKGError err;
@@ -442,11 +454,13 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 IFOKDO(err, unitObj.save(true, false))
             }
 
-            //status bar
+            // status bar
             IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Secondary currency defined.")))
-            else err.addError(ERR_FAIL, i18nc("Error message", "Secondary currency definition failed"));
+            else {
+                err.addError(ERR_FAIL, i18nc("Error message", "Secondary currency definition failed"));
+            }
 
-            //Display error
+            // Display error
             SKGMainPanel::displayErrorMessage(err);
         }
 
@@ -455,7 +469,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         if (iSolution == 0) {
             SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         } else {
-            //Get parameters
+            // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
 
             SKGError err;
@@ -464,7 +478,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             IFOKDO(err, unitObj.load())
             IFOKDO(err, SKGUnitPluginWidget::downloadUnitValue(unitObj, SKGUnitPluginWidget::getDownloadModeFromSettings()))
 
-            //Display error
+            // Display error
             SKGMainPanel::displayErrorMessage(err);
         }
 
@@ -486,16 +500,18 @@ void SKGUnitPlugin::deleteUnusedUnits() const
     if (m_currentBankDocument) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused units")  , err);
 
-        //Modification of payee object
+        // Modification of payee object
         QString sql = "DELETE FROM unit WHERE t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)";
         err = m_currentBankDocument->executeSqliteOrder(sql);
     }
 
-    //status bar
+    // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Unused units deleted")))
-    else err.addError(ERR_FAIL, i18nc("Error message", "Unused units deletion failed"));
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Unused units deletion failed"));
+    }
 
-    //Display error
+    // Display error
     SKGMainPanel::displayErrorMessage(err);
 }
 
