@@ -67,33 +67,35 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitTableViewEdition->getShowWidget()->addItem("all", i18nc("Noun, items to display", "All"), "",
             "",
             "currency;share;index;object",  // Check when checked
-            "highlighted");  // Uncheck when checked
-    ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all");
+            "highlighted", // Uncheck when checked
+            "", "",
+            Qt::META + Qt::Key_A);
+    ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "bookmarks", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all", "", Qt::META + Qt::Key_H);
     ui.kUnitTableViewEdition->getShowWidget()->addSeparator();
     ui.kUnitTableViewEdition->getShowWidget()->addItem("currency", i18nc("Noun, a country's currency", "Currency"), "",
             "t_type IN ('1','2','C')",
             "",  // Check when checked
             "highlighted",       // Uncheck when checked
             "",       // Check when unchecked
-            "all");     // Uncheck when unchecked
+            "all", Qt::META + Qt::Key_C);     // Uncheck when unchecked
     ui.kUnitTableViewEdition->getShowWidget()->addItem("share", i18nc("Noun, a financial share, as in a stock market", "Share"), "",
             "t_type='S'",
             "",
             "highlighted",
             "",
-            "all");
+            "all", Qt::META + Qt::Key_S);
     ui.kUnitTableViewEdition->getShowWidget()->addItem("index", i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), "",
             "t_type='I'",
             "",
             "highlighted",
             "",
-            "all;current");
+            "all;current", Qt::META + Qt::Key_I);
     ui.kUnitTableViewEdition->getShowWidget()->addItem("object", i18nc("Noun, a physical object like a house or a car", "Object"), "",
             "t_type='O'",
             "",
             "highlighted",
             "",
-            "all");
+            "all", Qt::META + Qt::Key_O);
 
     ui.kUnitTableViewEdition->getShowWidget()->setDefaultState("all;currency;share;index;object");
 
@@ -239,7 +241,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     }
 
     // Refresh
-    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     ui.kWidgetSelector->setSelectedMode(0);
 
     // Fill combo box for reference currency
