@@ -23,7 +23,7 @@
  */
 #include <QDesignerCustomWidgetCollectionInterface>
 
-#include <kglobal.h>
+#include <KGlobal>
 #include "skgbankgui_export.h"
 /**
  * QDesigner plugin collection
@@ -50,4 +50,4 @@ private:
     QList<QDesignerCustomWidgetInterface*> m_widgets;
 };
 
-#endif // SKGBKWIDGETCOLLECTIONDESIGNERPLUGIN_H
+#endif  // SKGBKWIDGETCOLLECTIONDESIGNERPLUGIN_H
