@@ -20,6 +20,19 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgobjectmodel.h"
+
+#include <KIcon>
+#include <KStandardDirs>
+#include <KLocalizedString>
+#include <KLocale>
+#include <KConfigGroup>
+
+#include <QApplication>
+#include <QDir>
+#include <QMimeData>
+#include <QFont>
+#include <QColor>
+
 #include "skgdocumentbank.h"
 #include "skgaccountobject.h"
 #include "skgcategoryobject.h"
@@ -35,18 +48,6 @@
 #include "skgtraces.h"
 #include "skgmainpanel.h"
 
-#include <kicon.h>
-#include <kstandarddirs.h>
-#include <klocalizedstring.h>
-#include <klocale.h>
-#include <kconfiggroup.h>
-
-#include <QApplication>
-#include <QDir>
-#include <QMimeData>
-#include <QFont>
-#include <qcolor.h>
-
 SKGObjectModel::SKGObjectModel(SKGDocumentBank* iDocument,
                                const QString& iTable,
                                const QString& iWhereClause,
@@ -99,16 +100,16 @@ void SKGObjectModel::buidCache()
         }
         if (m_cacheUnit.Symbol.isEmpty()) m_cacheUnit.Symbol = ' ';
 
-        //Bug 209672 vvvv
+        // Bug 209672 vvvv
         if (unitObject.getType() == SKGUnitObject::INDEX) {
             m_cacheUnit.Symbol = ' ';
             m_cacheUnit.Name = ' ';
         }
-        //Bug 209672 ^^^^
+        // Bug 209672 ^^^^
     }
 
     if (m_operationTable) {
-        //Read Setting
+        // Read Setting
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup pref = config->group("skrooge_operation");
         m_fontFutureOperationsColor = qVariantFromValue(pref.readEntry("fontFutureColor", QColor(Qt::gray)));
@@ -117,7 +118,7 @@ void SKGObjectModel::buidCache()
     }
 
     if (m_recurrentoperationTable) {
-        //Read Setting
+        // Read Setting
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup pref = config->group("skrooge_scheduled");
         m_fontDisabledScheduleColor = qVariantFromValue(pref.readEntry("fontFutureColor", QColor(Qt::gray)));
@@ -153,7 +154,6 @@ void SKGObjectModel::buidCache()
     }
 
     if (m_unitTable) {
-
         m_iconMuchMore = KIcon("skrooge_much_more");
         m_iconMuchLess = KIcon("skrooge_much_less");
         m_iconMore = KIcon("skrooge_more");
@@ -194,10 +194,15 @@ QVariant SKGObjectModel::headerData(int section, Qt::Orientation orientation, in
     if (orientation == Qt::Horizontal) {
         if (role == Qt::DisplayRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) att = m_listAttibutes[section];
-            else att = SKGServices::intToString(section);
+            if (section >= 0 && section < m_listAttibutes.count()) {
+                att = m_listAttibutes[section];
+            } else {
+                att = SKGServices::intToString(section);
+            }
 
-            if (att == "t_bookmarked" || att == "i_NBRECURRENT" || att == "t_status" || att == "t_close" || att == "t_imported") return "";
+            if (att == "t_bookmarked" || att == "i_NBRECURRENT" || att == "t_status" || att == "t_close" || att == "t_imported") {
+                return "";
+            }
         }
     }
     return SKGObjectModelBase::headerData(section, orientation, role);
@@ -210,8 +215,11 @@ QString SKGObjectModel::getAttributeForGrouping(const SKGObjectBase& iObject, co
     } else if (m_ruleTable && iAttribute == "t_action_type") {
         QString val = iObject.getAttribute(iAttribute);
         if (val == "S") val = i18nc("Noun, a search", "Search");
-        else if (val == "U") val = i18nc("Noun, a modification", "Update");
-        else val = i18nc("Noun, an alarm", "Alarm");
+        else if (val == "U") {
+            val = i18nc("Noun, a modification", "Update");
+        } else {
+            val = i18nc("Noun, an alarm", "Alarm");
+        }
         return val;
     } else if (iAttribute == "t_bookmarked" || iAttribute == "t_close") {
         QString val = iObject.getAttribute(iAttribute);
@@ -223,59 +231,75 @@ QString SKGObjectModel::getAttributeForGrouping(const SKGObjectBase& iObject, co
     return SKGObjectModelBase::getAttributeForGrouping(iObject, iAttribute);
 }
 
-QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
+QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 {
-    if (!index.isValid()) return QVariant();
+    if (!iIndex.isValid()) return QVariant();
     _SKGTRACEIN(10, "SKGObjectModel::data");
-    SKGObjectBase* obj = getObjectPointer(index);
-    if (obj->getTable().isEmpty()) return SKGObjectModelBase::data(index, role);
+    SKGObjectBase* obj = getObjectPointer(iIndex);
+    if (obj->getTable().isEmpty()) return SKGObjectModelBase::data(iIndex, iRole);
 
-    switch (role) {
+    switch (iRole) {
     case Qt::DisplayRole:
     case Qt::EditRole:
     case Qt::UserRole: {
-        QString att = m_listAttibutes[index.column()];
+        QString att = m_listAttibutes[iIndex.column()];
         QString val = obj->getAttribute(att);
         if (((att == "t_bookmarked" || att == "t_status" || att == "i_NBRECURRENT" || att == "t_imported"))
                 || (att == "t_close")
                 || (att == "t_action_type")
            ) {
-            if (role == Qt::UserRole) {
+            if (iRole == Qt::UserRole) {
                 if (m_ruleTable && att == "t_action_type") {
-                    SKGObjectBase* obj = getObjectPointer(index);
-                    if (obj) {
-                        QString val = obj->getAttribute(att);
-                        if (val == "S") return i18nc("Noun, a search", "Search");
-                        else if (val == "U") return i18nc("Noun, a modification", "Update");
-                        else return i18nc("Noun, an alarm", "Alarm");
+                    if (val == "S") return i18nc("Noun, a search", "Search");
+                    else if (val == "U") {
+                        return i18nc("Noun, a modification", "Update");
+                    } else {
+                        return i18nc("Noun, an alarm", "Alarm");
                     }
                 }
                 return val;
-            } else return "";
+            } else {
+                return "";
+            }
         } else if (m_interestTable && att == "t_expenditure_value_date_mode") {
             if (val == "0") return i18nc("Noun", "Day -0");
-            else if (val == "1") return i18nc("Noun", "Day -1");
-            else if (val == "2") return i18nc("Noun", "Day -2");
-            else if (val == "3") return i18nc("Noun", "Day -3");
-            else if (val == "4") return i18nc("Noun", "Day -4");
-            else if (val == "5") return i18nc("Noun", "Day -5");
-            else return i18nc("Noun", "Fifteen");
+            else if (val == "1") {
+                return i18nc("Noun", "Day -1");
+            } else if (val == "2") {
+                return i18nc("Noun", "Day -2");
+            } else if (val == "3") {
+                return i18nc("Noun", "Day -3");
+            } else if (val == "4") {
+                return i18nc("Noun", "Day -4");
+            } else if (val == "5") {
+                return i18nc("Noun", "Day -5");
+            } else {
+                return i18nc("Noun", "Fifteen");
+            }
+        } else if (m_accountTable && att == "d_reconciliationdate") {
+            if (val.isEmpty()) return i18nc("Noun", "Never");
         } else if (m_interestTable && att == "t_income_value_date_mode") {
             if (val == "0") return i18nc("Noun", "Day +0");
-            else if (val == "1") return i18nc("Noun", "Day +1");
-            else if (val == "2") return i18nc("Noun", "Day +2");
-            else if (val == "3") return i18nc("Noun", "Day +3");
-            else if (val == "4") return i18nc("Noun", "Day +4");
-            else if (val == "5") return i18nc("Noun", "Day +5");
-            else return i18nc("Noun", "Fifteen");
-        } else if (getAttributeType(index.column()) == SKGServices::FLOAT) {
+            else if (val == "1") {
+                return i18nc("Noun", "Day +1");
+            } else if (val == "2") {
+                return i18nc("Noun", "Day +2");
+            } else if (val == "3") {
+                return i18nc("Noun", "Day +3");
+            } else if (val == "4") {
+                return i18nc("Noun", "Day +4");
+            } else if (val == "5") {
+                return i18nc("Noun", "Day +5");
+            } else {
+                return i18nc("Noun", "Fifteen");
+            }
+        } else if (getAttributeType(iIndex.column()) == SKGServices::FLOAT) {
             double dval = SKGServices::stringToDouble(val);
-            if (role == Qt::DisplayRole) {
+            if (iRole == Qt::DisplayRole) {
                 if (att.endsWith(QLatin1String("_INCOME")) ||
                         att.endsWith(QLatin1String("_EXPENSE")) ||
                         (m_categoryTable && (att == "f_REALCURRENTAMOUNT" ||
                                              att == "f_SUMCURRENTAMOUNT"))) {
-                    double dval = SKGServices::stringToDouble(val);
                     if (dval == 0) return "";
                 }
 
@@ -295,11 +319,11 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                     }
                 }
 
-                //Bug 209672 vvvv
+                // Bug 209672 vvvv
                 if (m_unitTable) {
                     if (obj->getAttribute("t_type") == "I") unit.Symbol = ' ';
                 }
-                //Bug 209672 ^^^
+                // Bug 209672 ^^^
 
                 if (QString::compare(att, "f_rate", Qt::CaseInsensitive) == 0) {
                     unit.Symbol = '%';
@@ -315,19 +339,21 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
             } else {
                 return dval;
             }
-        } else if (getAttributeType(index.column()) == SKGServices::INTEGER) {
+        } else if (getAttributeType(iIndex.column()) == SKGServices::INTEGER) {
             if (m_recurrentoperationTable && att == "i_nb_times") {
                 QString t_times = obj->getAttribute("t_times");
                 if (t_times != "Y") return QChar(8734);
-            } else if ((att == "i_number" || att == "i_NBOPERATIONS" || att == "i_SUMNBOPERATIONS") && val == "0") return "";
+            } else if ((att == "i_number" || att == "i_NBOPERATIONS" || att == "i_SUMNBOPERATIONS") && val == "0") {
+                return "";
+            }
 
             return SKGServices::stringToInt(val);
         }
         break;
     }
     case Qt::DecorationRole: {
-        //decoration
-        QString att = m_listAttibutes[index.column()];
+        // decoration
+        QString att = m_listAttibutes[iIndex.column()];
         if (att == "t_bookmarked") {
             if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
         } else if (m_operationTable || m_recurrentoperationTable) {
@@ -337,18 +363,22 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
             } else if (att == "t_CATEGORY") {
                 if (SKGServices::stringToInt(obj->getAttribute("i_NBSUBOPERATIONS")) > 1) return m_iconSplit;
             } else if (att == "i_NBRECURRENT" && m_operationTable) {
-                if (obj->getAttribute("i_NBRECURRENT") != "0") return m_iconRecurrentMaster;
-                else if (obj->getAttribute("r_recurrentoperation_id") != "0") return m_iconRecurrent;
+                if (obj->getAttribute("i_NBRECURRENT") != "0") {
+                    return m_iconRecurrentMaster;
+                } else if (obj->getAttribute("r_recurrentoperation_id") != "0") {
+                    return m_iconRecurrent;
+                }
             } else if (att == "t_imported") {
                 QString impStatus = obj->getAttribute("t_imported");
                 if (impStatus == "Y") return m_iconImported;
-                else if (impStatus == "P")  return m_iconImportedChecked;
+                else if (impStatus == "P") {
+                    return m_iconImportedChecked;
+                }
             } else if (att == "t_REFUND" || att == "t_REALREFUND") {
-                SKGObjectBase* obj = getObjectPointer(index);
                 QString trackerName;
-                if (obj) trackerName = obj->getAttribute(att);
+                trackerName = obj->getAttribute(att);
                 if (!trackerName.isEmpty()) {
-                    SKGTrackerObject tracker(SKGObjectBase(getDocument(), "refund")); //Better performance if v_refund is not used
+                    SKGTrackerObject tracker(SKGObjectBase(getDocument(), "refund"));  // Better performance if v_refund is not used
                     tracker.setName(trackerName);
                     tracker.load();
 
@@ -359,17 +389,24 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
             if (att == "t_action_type") {
                 QString val = obj->getAttribute(att);
                 if (val == "S") return m_iconSearch;
-                else if (val == "U") return m_iconUpdate;
-                else return m_iconAlarm;
+                else if (val == "U") {
+                    return m_iconUpdate;
+                } else {
+                    return m_iconAlarm;
+                }
             }
         } else if (m_unitTable) {
             if (att == "f_CURRENTAMOUNT") {
                 SKGUnitObject unit(*obj);
                 double annualchange = 365 * unit.getDailyChange();
                 if (annualchange >= 15) return m_iconMuchMore;
-                else if (annualchange <= -15) return m_iconMuchLess;
-                else if (annualchange >= 5) return m_iconMore;
-                else if (annualchange <= -5) return m_iconLess;
+                else if (annualchange <= -15) {
+                    return m_iconMuchLess;
+                } else if (annualchange >= 5) {
+                    return m_iconMore;
+                } else if (annualchange <= -5) {
+                    return m_iconLess;
+                }
             }
         } else if (m_accountTable) {
             if (att == "t_BANK") {
@@ -379,20 +416,31 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                     QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                     return qVariantFromValue(QIcon(dirLogo.absoluteFilePath(t_icon)));
                 }
-            } /*else if(att == "t_TYPENLS") {
-QString type = obj->getAttribute("t_type");
-if(type == "C") return KIcon("view-bank-account-savings");
-else if(type == "D")  return KIcon("view-credit-card-account");
-else if(type == "I")  return KIcon("view-stock-account");
-else if(type == "A")  return KIcon("view-loan-asset");
-else if(type == "W")  return KIcon("kwalletmanager");
-else return KIcon();
-} */
+            }
+#if 0
+            else if (att == "t_TYPENLS") {
+                QString type = obj->getAttribute("t_type");
+                if (type == "C") return KIcon("view-bank-account-savings");
+                else if (type == "D")  {
+                    return KIcon("view-credit-card-account");
+                } else if (type == "I")  {
+                    return KIcon("view-stock-account");
+                } else if (type == "A")  {
+                    return KIcon("view-loan-asset");
+                } else if (type == "W")  {
+                    return KIcon("kwalletmanager");
+                } else {
+                    return KIcon();
+                }
+            }
+#endif
         } else if (m_categoryTable) {
-            if (index.column() == 0) {
+            if (iIndex.column() == 0) {
                 QString t_TYPEEXPENSE = obj->getAttribute("t_TYPEEXPENSE");
                 if (t_TYPEEXPENSE == "-") return m_iconCategoryMoins;
-                else if (t_TYPEEXPENSE == "+") return m_iconCategoryPlus;
+                else if (t_TYPEEXPENSE == "+") {
+                    return m_iconCategoryPlus;
+                }
                 return m_iconCategory;
             }
         } else if (m_budgetTable) {
@@ -405,31 +453,37 @@ else return KIcon();
                 } else {
                     double transferred = SKGServices::stringToDouble(obj->getAttribute("f_transferred"));
                     if (transferred < -EPSILON) return m_iconAnber;
-                    else return m_iconGreen;
+                    else {
+                        return m_iconGreen;
+                    }
                 }
             }
         }
         break;
     }
     case Qt::TextColorRole: {
-        //Text color
-        QString att = m_listAttibutes[index.column()];
+        // Text color
+        QString att = m_listAttibutes[iIndex.column()];
         if (m_recurrentoperationTable) {
             if (obj->getAttribute("i_nb_times") == "0") return  m_fontDisabledScheduleColor;
-            else if (att == "d_date" && SKGServices::stringToTime(obj->getAttribute("d_date")).date() <= QDate::currentDate()) return m_fontNegativeColor;
+            else if (att == "d_date" && SKGServices::stringToTime(obj->getAttribute("d_date")).date() <= QDate::currentDate()) {
+                return m_fontNegativeColor;
+            }
         } else if (m_operationTable) {
             if (SKGServices::stringToTime(obj->getAttribute("d_date")).date() > QDate::currentDate()) return m_fontFutureOperationsColor;
-            else if (getAttributeType(index.column()) != SKGServices::FLOAT) {
+            else if (getAttributeType(iIndex.column()) != SKGServices::FLOAT) {
                 if (obj->getAttribute("t_imported") == "P") return  m_fontNotValidatedOperationsColor;
-                else if (m_suboperationTable) return m_fontSubOperationsColor;
+                else if (m_suboperationTable) {
+                    return m_fontSubOperationsColor;
+                }
             }
         }
         break;
     }
     case Qt::TextAlignmentRole: {
-        //Text alignment
+        // Text alignment
         if (m_recurrentoperationTable) {
-            QString att = m_listAttibutes[index.column()];
+            QString att = m_listAttibutes[iIndex.column()];
 
             if (att == "i_auto_write_days" || att == "i_warn_days" || att == "i_nb_times") {
                 return static_cast<int>(Qt::AlignVCenter | Qt::AlignLeft);
@@ -438,71 +492,90 @@ else return KIcon();
         break;
     }
     case Qt::CheckStateRole: {
-        //CheckState
-        QString att = m_listAttibutes[index.column()];
+        // CheckState
+        QString att = m_listAttibutes[iIndex.column()];
         if (m_operationTable && att == "t_status") {
             QString cond = obj->getAttribute("t_status");
             if (cond == "P") return Qt::PartiallyChecked;
-            else if (cond == "Y") return Qt::Checked;
-            else if (cond == "N") return Qt::Unchecked;
+            else if (cond == "Y") {
+                return Qt::Checked;
+            } else if (cond == "N") {
+                return Qt::Unchecked;
+            }
         } else if (att == "t_close") {
             QString cond = obj->getAttribute("t_close");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_recurrentoperationTable && att == "i_auto_write_days") {
             QString cond = obj->getAttribute("t_auto_write");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_recurrentoperationTable && att == "i_warn_days") {
             QString cond = obj->getAttribute("t_warn");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_recurrentoperationTable && att == "i_nb_times") {
             QString cond = obj->getAttribute("t_times");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_budgetRuleTable && att == "t_CATEGORYCONDITION") {
             QString cond = obj->getAttribute("t_category_condition");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_budgetRuleTable && att == "i_year") {
             QString cond = obj->getAttribute("t_year_condition");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_budgetRuleTable && att == "i_month") {
             QString cond = obj->getAttribute("t_month_condition");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_budgetRuleTable && att == "t_CATEGORY") {
             QString cond = obj->getAttribute("t_category_target");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         } else  if (m_budgetTable && att == "t_CATEGORY") {
             QString cond = obj->getAttribute("t_including_subcategories");
             if (cond == "Y") return Qt::Checked;
-            else return Qt::Unchecked;
+            else {
+                return Qt::Unchecked;
+            }
         }
         break;
     }
     case Qt::ToolTipRole: {
-        //Tooltip
+        // Tooltip
         QString toolTipString;
-        QString att = m_listAttibutes[index.column()];
-        if (getAttributeType(index.column()) == SKGServices::FLOAT) {
-            //Add secondary unit
+        QString att = m_listAttibutes[iIndex.column()];
+        if (getAttributeType(iIndex.column()) == SKGServices::FLOAT) {
+            // Add secondary unit
             if (!att.contains("QUANTITY") && att != "f_coef" && att != "f_rate") {
                 SKGServices::SKGUnitInfo secondaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
                 if (!secondaryUnit.Symbol.isEmpty()) {
                     double val = SKGServices::stringToDouble(obj->getAttribute(att));
                     if ((!att.endsWith(QLatin1String("_INCOME")) && !att.endsWith(QLatin1String("_EXPENSE"))) || val != 0) {
                         if (secondaryUnit.Value)  toolTipString = KGlobal::locale()->formatMoney(val / secondaryUnit.Value, secondaryUnit.Symbol, secondaryUnit.NbDecimal);
-
                     }
-
                 }
             }
 
-            //Add original amount
+            // Add original amount
             QString originalAmount = obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
             if (!originalAmount.isEmpty()) {
                 if (!toolTipString.isEmpty()) toolTipString += "\n\n";
@@ -515,7 +588,7 @@ else return KIcon();
                                        gain);
             }
 
-            //Add balance
+            // Add balance
             if (m_operationTable) {
                 SKGOperationObject op(*obj);
                 if (!op.isTemplate()) {
@@ -610,16 +683,16 @@ else return KIcon();
                 }
             }
         } else if (m_ruleTable && att == "t_action_type") {
-            SKGObjectBase* obj = getObjectPointer(index);
-            if (obj) {
-                QString val = obj->getAttribute(att);
-                if (val == "S") toolTipString = i18nc("Noun, a search", "Search");
-                else if (val == "U") toolTipString = i18nc("Noun, a modification", "Update");
-                else toolTipString = i18nc("Noun, an alarm", "Alarm");
+            QString val = obj->getAttribute(att);
+            if (val == "S") toolTipString = i18nc("Noun, a search", "Search");
+            else if (val == "U") {
+                toolTipString = i18nc("Noun, a modification", "Update");
+            } else {
+                toolTipString = i18nc("Noun, an alarm", "Alarm");
             }
         }
 
-        QString toolTipStringBase = SKGObjectModelBase::data(index, role).toString();
+        QString toolTipStringBase = SKGObjectModelBase::data(iIndex, iRole).toString();
         if (!toolTipStringBase.isEmpty()) {
             if (!toolTipString.isEmpty()) toolTipString += "\n\n";
             toolTipString += toolTipStringBase;
@@ -629,45 +702,45 @@ else return KIcon();
     default: {
     }
     }
-    return SKGObjectModelBase::data(index, role);
+    return SKGObjectModelBase::data(iIndex, iRole);
 }
 
-bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, int role)
+bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue, int iRole)
 {
-    if (!index.isValid()) return false;
+    if (!iIndex.isValid()) return false;
 
-    if (role == Qt::CheckStateRole) {
+    if (iRole == Qt::CheckStateRole) {
         SKGError err;
         {
             if (m_accountTable) {
-                SKGAccountObject obj(getObject(index));
+                SKGAccountObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
-                                         (static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
+                                         (static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
                 if (abs(obj.getCurrentAmount()) > 0.01) err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
-                IFOKDO(err, obj.setClosed(static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked))
+                IFOKDO(err, obj.setClosed(static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked))
                 IFOKDO(err, obj.save())
             } else if (m_trackerTable) {
-                SKGTrackerObject obj(getObject(index));
+                SKGTrackerObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
-                                         (static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
-                err = obj.setClosed(static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked);
+                                         (static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
+                err = obj.setClosed(static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked);
                 IFOKDO(err, obj.save())
             } else if (m_operationTable) {
-                //Get the real object, not the object from the view
-                SKGObjectBase* objtmp = getObjectPointer(index);
+                // Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(iIndex);
                 if (objtmp) {
                     SKGOperationObject obj = SKGOperationObject(objtmp->getDocument(), objtmp->getID());
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
                     SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
                     SKGOperationObject::OperationStatus t_status = statusinitial;
                     if (QApplication::keyboardModifiers() &Qt::ControlModifier) {
-                        //2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
-                        t_status = SKGOperationObject::CHECKED ;
-                        //t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
+                        // 2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
+                        t_status = SKGOperationObject::CHECKED;
+                        // t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
                     } else {
-                        //2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
+                        // 2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
                         t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::POINTED : (t_status == SKGOperationObject::POINTED ? SKGOperationObject::NONE : SKGOperationObject::POINTED));
-                        //t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
+                        // t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
                     }
                     if (t_status != statusinitial) {
                         err = obj.setStatus(t_status);
@@ -675,10 +748,10 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     }
                 }
             } else if (m_recurrentoperationTable) {
-                QString att = m_listAttibutes[index.column()];
+                QString att = m_listAttibutes[iIndex.column()];
 
-                //Get the real object, not the object from the view
-                SKGObjectBase* objtmp = getObjectPointer(index);
+                // Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(iIndex);
                 if (objtmp) {
                     SKGRecurrentOperationObject obj = SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
 
@@ -695,10 +768,10 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     }
                 }
             } else if (m_budgetRuleTable) {
-                QString att = m_listAttibutes[index.column()];
+                QString att = m_listAttibutes[iIndex.column()];
 
-                //Get the real object, not the object from the view
-                SKGObjectBase* objtmp = getObjectPointer(index);
+                // Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(iIndex);
                 if (objtmp) {
                     SKGBudgetRuleObject obj = SKGBudgetRuleObject(objtmp->getDocument(), objtmp->getID());
 
@@ -718,10 +791,10 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     }
                 }
             } else if (m_budgetTable) {
-                QString att = m_listAttibutes[index.column()];
+                QString att = m_listAttibutes[iIndex.column()];
 
-                //Get the real object, not the object from the view
-                SKGObjectBase* objtmp = getObjectPointer(index);
+                // Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(iIndex);
                 if (objtmp) {
                     SKGBudgetObject obj = SKGBudgetObject(objtmp->getDocument(), objtmp->getID());
 
@@ -737,26 +810,28 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
         SKGMainPanel::displayErrorMessage(err);
         return !err;
     }
-    return SKGObjectModelBase::setData(index, value, role);
+    return SKGObjectModelBase::setData(iIndex, iValue, iRole);
 }
 
-Qt::ItemFlags SKGObjectModel::flags(const QModelIndex& index) const
+Qt::ItemFlags SKGObjectModel::flags(const QModelIndex& iIndex) const
 {
     _SKGTRACEIN(10, "SKGObjectModel::flags");
 
-    Qt::ItemFlags flags = SKGObjectModelBase::flags(index);
+    Qt::ItemFlags f = SKGObjectModelBase::flags(iIndex);
 
-    if (index.isValid()) {
-        QString att = m_listAttibutes[index.column()];
-        if (att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable || m_interestTable || m_interestResultTable) flags = flags & ~Qt::ItemIsEditable;
+    if (iIndex.isValid()) {
+        QString att = m_listAttibutes[iIndex.column()];
+        if (att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable || m_interestTable || m_interestResultTable) f = f & ~Qt::ItemIsEditable;
     }
 
     if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
-        if (index.isValid()) flags |= Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
-        else flags |= Qt::ItemIsDropEnabled;
+        if (iIndex.isValid()) f |= Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
+        else {
+            f |= Qt::ItemIsDropEnabled;
+        }
     }
 
-    return flags;
+    return f;
 }
 
 Qt::DropActions SKGObjectModel::supportedDragActions() const
@@ -771,24 +846,24 @@ Qt::DropActions SKGObjectModel::supportedDropActions() const
     return SKGObjectModelBase::supportedDropActions();
 }
 
-bool SKGObjectModel::dropMimeData(const QMimeData* data,
-                                  Qt::DropAction action,
-                                  int row, int column,
+bool SKGObjectModel::dropMimeData(const QMimeData* iData,
+                                  Qt::DropAction iAction,
+                                  int iRow, int iColumn,
                                   const QModelIndex& iParent)
 {
-    if (SKGObjectModelBase::dropMimeData(data, action, row, column, iParent)) return true;
-    if (action == Qt::IgnoreAction) return true;
-    if (!data || !(data->hasFormat("application/skg.category.ids") ||
-                   data->hasFormat("application/skg.payee.ids") ||
-                   data->hasFormat("application/skg.account.ids") ||
-                   data->hasFormat("application/skg.refund.ids") ||
-                   data->hasFormat("application/skg.unit.ids")
-                  )) return false;
-    if (column > 0) return false;
+    if (SKGObjectModelBase::dropMimeData(iData, iAction, iRow, iColumn, iParent)) return true;
+    if (iAction == Qt::IgnoreAction) return true;
+    if (!iData || !(iData->hasFormat("application/skg.category.ids") ||
+                    iData->hasFormat("application/skg.payee.ids") ||
+                    iData->hasFormat("application/skg.account.ids") ||
+                    iData->hasFormat("application/skg.refund.ids") ||
+                    iData->hasFormat("application/skg.unit.ids")
+                   )) return false;
+    if (iColumn > 0) return false;
 
     SKGError err;
-    if (data->hasFormat("application/skg.category.ids")) {
-        QByteArray encodedData = data->data("application/skg.category.ids");
+    if (iData->hasFormat("application/skg.category.ids")) {
+        QByteArray encodedData = iData->data("application/skg.category.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -807,13 +882,15 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
                 err = child.load();
                 IFOK(err) {
                     if (iParent.isValid()) err = child.setParentCategory(parentCategory);
-                    else err = child.removeParentCategory();
+                    else {
+                        err = child.removeParentCategory();
+                    }
                 }
                 IFOKDO(err, child.save())
             }
         }
-    } else if (data->hasFormat("application/skg.payee.ids")) {
-        QByteArray encodedData = data->data("application/skg.payee.ids");
+    } else if (iData->hasFormat("application/skg.payee.ids")) {
+        QByteArray encodedData = iData->data("application/skg.payee.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -831,8 +908,8 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
                 IFOKDO(err, parentPayee.merge(child))
             }
         }
-    } else if (data->hasFormat("application/skg.account.ids")) {
-        QByteArray encodedData = data->data("application/skg.account.ids");
+    } else if (iData->hasFormat("application/skg.account.ids")) {
+        QByteArray encodedData = iData->data("application/skg.account.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -850,8 +927,8 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
                 IFOKDO(err, parentAccount.merge(child))
             }
         }
-    } else if (data->hasFormat("application/skg.unit.ids")) {
-        QByteArray encodedData = data->data("application/skg.unit.ids");
+    } else if (iData->hasFormat("application/skg.unit.ids")) {
+        QByteArray encodedData = iData->data("application/skg.unit.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -869,8 +946,8 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
                 IFOKDO(err, parentUnit.merge(child))
             }
         }
-    } else if (data->hasFormat("application/skg.refund.ids")) {
-        QByteArray encodedData = data->data("application/skg.refund.ids");
+    } else if (iData->hasFormat("application/skg.refund.ids")) {
+        QByteArray encodedData = iData->data("application/skg.refund.ids");
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -898,13 +975,15 @@ void SKGObjectModel::dataModified(const QString& iTableName, int iIdTransaction)
     if (getRealTable() == iTableName || iTableName.isEmpty() || getRealTable() == "doctransaction") {
         SKGTRACEIN(1, "SKGObjectModel::dataModified");
         if (iTableName == "category") {
-            //Full refresh
+            // Full refresh
             m_isResetRealyNeeded = true;
             refresh();
         } else {
             SKGObjectModelBase::dataModified(iTableName, iIdTransaction);
         }
-    } else SKGObjectModelBase::dataModified(iTableName, iIdTransaction);
+    } else {
+        SKGObjectModelBase::dataModified(iTableName, iIdTransaction);
+    }
 }
 
 
