@@ -20,6 +20,12 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgpredicatcreator.h"
+
+#include <QDomDocument>
+#include <QTableWidget>
+#include <QCheckBox>
+#include <QApplication>
+
 #include "skgdocument.h"
 #include "skgmainpanel.h"
 #include "skgservices.h"
@@ -28,18 +34,13 @@
 #include "skgdateedit.h"
 #include "skgruleobject.h"
 
-#include <QDomDocument>
-#include <QTableWidget>
-#include <QCheckBox>
-#include <QApplication>
-
 SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
     : QWidget(iParent), m_updateMode(iModeUpdate), m_kValue1(NULL), m_kValue2(NULL), m_kAttributes(NULL)
 {
     SKGServices::AttributeType attType = SKGServices::TEXT;
     if (document) attType = document->getAttributeType(attribute);
 
-    //Build
+    // Build
     this->setAutoFillBackground(true);
     this->resize(491, 25);
     QHBoxLayout* horizontalLayout = new QHBoxLayout(this);
@@ -49,11 +50,11 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     m_kOperator = new SKGComboBox(this);
     m_kOperator->setObjectName(QString::fromUtf8("kOperator"));
     m_kOperator->setSizeAdjustPolicy(KComboBox::AdjustToContentsOnFirstShow);
-    QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    sizePolicy.setHorizontalStretch(0);
-    sizePolicy.setVerticalStretch(0);
-    sizePolicy.setHeightForWidth(m_kOperator->sizePolicy().hasHeightForWidth());
-    m_kOperator->setSizePolicy(sizePolicy);
+    QSizePolicy newSizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
+    newSizePolicy2.setHorizontalStretch(0);
+    newSizePolicy2.setVerticalStretch(0);
+    newSizePolicy2.setHeightForWidth(m_kOperator->sizePolicy().hasHeightForWidth());
+    m_kOperator->setSizePolicy(newSizePolicy2);
 
     horizontalLayout->addWidget(m_kOperator);
     int nbAtt = iListAtt.count();
@@ -63,11 +64,11 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             m_kAttributes->setObjectName(QString::fromUtf8("kAttributes"));
             m_kAttributes->setMinimumSize(QSize(100, 0));
             m_kAttributes->setEditable(false);
-            QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-            sizePolicy.setHorizontalStretch(0);
-            sizePolicy.setVerticalStretch(0);
-            sizePolicy.setHeightForWidth(m_kAttributes->sizePolicy().hasHeightForWidth());
-            m_kAttributes->setSizePolicy(sizePolicy);
+            QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+            newSizePolicy.setHorizontalStretch(0);
+            newSizePolicy.setVerticalStretch(0);
+            newSizePolicy.setHeightForWidth(m_kAttributes->sizePolicy().hasHeightForWidth());
+            m_kAttributes->setSizePolicy(newSizePolicy);
 
             horizontalLayout->addWidget(m_kAttributes);
 
@@ -82,11 +83,11 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setEditable(true);
-            QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-            sizePolicy.setHorizontalStretch(0);
-            sizePolicy.setVerticalStretch(0);
-            sizePolicy.setHeightForWidth(cmbVal1->sizePolicy().hasHeightForWidth());
-            cmbVal1->setSizePolicy(sizePolicy);
+            QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+            newSizePolicy.setHorizontalStretch(0);
+            newSizePolicy.setVerticalStretch(0);
+            newSizePolicy.setHeightForWidth(cmbVal1->sizePolicy().hasHeightForWidth());
+            cmbVal1->setSizePolicy(newSizePolicy);
 
             horizontalLayout->addWidget(cmbVal1);
             m_kValue1 = cmbVal1;
@@ -96,11 +97,11 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
             cmbVal2->setMinimumSize(QSize(100, 0));
             cmbVal2->setEditable(true);
-            QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-            sizePolicy.setHorizontalStretch(0);
-            sizePolicy.setVerticalStretch(0);
-            sizePolicy.setHeightForWidth(cmbVal2->sizePolicy().hasHeightForWidth());
-            cmbVal2->setSizePolicy(sizePolicy);
+            QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+            newSizePolicy.setHorizontalStretch(0);
+            newSizePolicy.setVerticalStretch(0);
+            newSizePolicy.setHeightForWidth(cmbVal2->sizePolicy().hasHeightForWidth());
+            cmbVal2->setSizePolicy(newSizePolicy);
 
             horizontalLayout->addWidget(cmbVal2);
             m_kValue2 = cmbVal2;
@@ -162,11 +163,11 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
                 cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
                 cmbVal1->setMinimumSize(QSize(100, 0));
                 cmbVal1->setEditable(true);
-                QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-                sizePolicy.setHorizontalStretch(0);
-                sizePolicy.setVerticalStretch(0);
-                sizePolicy.setHeightForWidth(cmbVal1->sizePolicy().hasHeightForWidth());
-                cmbVal1->setSizePolicy(sizePolicy);
+                QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+                newSizePolicy.setHorizontalStretch(0);
+                newSizePolicy.setVerticalStretch(0);
+                newSizePolicy.setHeightForWidth(cmbVal1->sizePolicy().hasHeightForWidth());
+                cmbVal1->setSizePolicy(newSizePolicy);
 
                 horizontalLayout->addWidget(cmbVal1);
                 m_kValue1 = cmbVal1;
@@ -177,11 +178,11 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
                 cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
                 cmbVal2->setMinimumSize(QSize(100, 0));
                 cmbVal2->setEditable(false);
-                QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-                sizePolicy.setHorizontalStretch(0);
-                sizePolicy.setVerticalStretch(0);
-                sizePolicy.setHeightForWidth(cmbVal2->sizePolicy().hasHeightForWidth());
-                cmbVal2->setSizePolicy(sizePolicy);
+                QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+                newSizePolicy.setHorizontalStretch(0);
+                newSizePolicy.setVerticalStretch(0);
+                newSizePolicy.setHeightForWidth(cmbVal2->sizePolicy().hasHeightForWidth());
+                cmbVal2->setSizePolicy(newSizePolicy);
                 cmbVal2->addItems(QStringList() << "YYYYMMDD" << "MMDDYYYY" << "DDMMYYYY"
                                   << "MM-DD-YY" << "DD-MM-YY" << "MM-DD-YYYY" << "DD-MM-YYYY" << "YYYY-MM-DD");
 
@@ -219,7 +220,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         }
     }
 
-    //Fill combo boxes
+    // Fill combo boxes
     m_kOperator->clear();
     m_kOperator->addItem("" , "");
 
@@ -230,7 +231,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
 
     QStringList listOps = SKGRuleObject::getListOfOperators(attType, m_updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH);
     int nb = listOps.count();
-    if (iModeUpdate && attribute == "t_REALCATEGORY" && nb > 1) nb = 1; //TODO: unblock t_REALCATEGORY
+    if (iModeUpdate && attribute == "t_REALCATEGORY" && nb > 1) nb = 1;  // TODO(Stephane MANKOWSKI): unblock t_REALCATEGORY
     for (int i = 0; i < nb; ++i) {
         QString op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
@@ -253,10 +254,10 @@ SKGPredicatCreator::~SKGPredicatCreator()
     m_kAttributes = NULL;
 }
 
-bool SKGPredicatCreator::eventFilter(QObject* object, QEvent* event)
+bool SKGPredicatCreator::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    Q_UNUSED(object);
-    if (event && (event->type() == QEvent::FocusIn || event->type() == QEvent::FocusOut)) {
+    Q_UNUSED(iObject);
+    if (iEvent && (iEvent->type() == QEvent::FocusIn || iEvent->type() == QEvent::FocusOut)) {
         QObject* appliFocus = QApplication::focusWidget();
 
         while (appliFocus) {
@@ -304,36 +305,33 @@ QString SKGPredicatCreator::xmlDescription()
             QDomElement root = doc.createElement("element");
             doc.appendChild(root);
 
-            //Condition
+            // Condition
             root.setAttribute("operator", op);
             if (m_kValue1 && m_kValue1->isVisible()) {
                 SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
                 if (cmbVal1)  root.setAttribute("value", SKGServices::dateToSqlString(QDateTime(cmbVal1->date())));
                 else {
-                    SKGCalculatorEdit* cmbVal1 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
-                    if (cmbVal1)  root.setAttribute("value", cmbVal1->text());
+                    SKGCalculatorEdit* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
+                    if (cmbVal12)  root.setAttribute("value", cmbVal12->text());
                     else {
-                        QCheckBox* cmbVal1 = qobject_cast<QCheckBox*> (m_kValue1);
-                        if (cmbVal1)  root.setAttribute("value", cmbVal1->checkState() == Qt::Checked ? "Y" : cmbVal1->checkState() == Qt::Unchecked ? "N" : "P");
+                        QCheckBox* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
+                        if (cmbVal13)  root.setAttribute("value", cmbVal13->checkState() == Qt::Checked ? "Y" : cmbVal13->checkState() == Qt::Unchecked ? "N" : "P");
                         else {
-                            SKGComboBox* cmbVal1 = qobject_cast<SKGComboBox*> (m_kValue1);
-                            if (cmbVal1) root.setAttribute("value", cmbVal1->text());
+                            SKGComboBox* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
+                            if (cmbVal14) root.setAttribute("value", cmbVal14->text());
                         }
                     }
-
-
                 }
-
             }
             if (m_kValue2 && m_kValue2->isVisible()) {
                 SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
                 if (cmbVal2)  root.setAttribute("value2", SKGServices::dateToSqlString(QDateTime(cmbVal2->date())));
                 else {
-                    SKGCalculatorEdit* cmbVal2 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
-                    if (cmbVal2)  root.setAttribute("value2", cmbVal2->text());
+                    SKGCalculatorEdit* cmbVal21 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
+                    if (cmbVal21)  root.setAttribute("value2", cmbVal21->text());
                     else {
-                        SKGComboBox* cmbVal2 = qobject_cast<SKGComboBox*> (m_kValue2);
-                        if (cmbVal2)  root.setAttribute("value2", cmbVal2->text());
+                        SKGComboBox* cmbVal22 = qobject_cast<SKGComboBox*> (m_kValue2);
+                        if (cmbVal22)  root.setAttribute("value2", cmbVal22->text());
                     }
                 }
             }
@@ -355,31 +353,32 @@ void SKGPredicatCreator::setXmlDescription(const QString& iXML)
     doc.setContent(iXML);
     QDomElement root = doc.documentElement();
 
-    //Condition
+    // Condition
     if (m_kOperator) {
         m_kOperator->setCurrentIndex(m_kOperator->findData(root.attribute("operator")));
         SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
         if (cmbVal1)  cmbVal1->setDate(SKGServices::stringToTime(root.attribute("value")).date());
         else {
-            SKGCalculatorEdit* cmbVal1 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
-            if (cmbVal1)  cmbVal1->setText(root.attribute("value"));
+            SKGCalculatorEdit* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
+            if (cmbVal12)  cmbVal12->setText(root.attribute("value"));
             else {
-                QCheckBox* cmbVal1 = qobject_cast<QCheckBox*> (m_kValue1);
-                if (cmbVal1)  cmbVal1->setCheckState(root.attribute("value") == "Y" ? Qt::Checked : root.attribute("value") == "P" ? Qt::PartiallyChecked : Qt::Unchecked);
+                QCheckBox* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
+                if (cmbVal13)  cmbVal13->setCheckState(root.attribute("value") == "Y" ? Qt::Checked : root.attribute("value") == "P" ? Qt::PartiallyChecked : Qt::Unchecked);
                 else {
-                    SKGComboBox* cmbVal1 = qobject_cast<SKGComboBox*> (m_kValue1);
-                    if (cmbVal1)  cmbVal1->setText(root.attribute("value"));
+                    SKGComboBox* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
+                    if (cmbVal14)  cmbVal14->setText(root.attribute("value"));
                 }
             }
         }
+
         SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
         if (cmbVal2)  cmbVal2->setDate(SKGServices::stringToTime(root.attribute("value2")).date());
         else {
-            SKGCalculatorEdit* cmbVal2 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
-            if (cmbVal2)  cmbVal2->setText(root.attribute("value2"));
+            SKGCalculatorEdit* cmbVal22 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
+            if (cmbVal22)  cmbVal22->setText(root.attribute("value2"));
             else {
-                SKGComboBox* cmbVal2 = qobject_cast<SKGComboBox*> (m_kValue2);
-                if (cmbVal2) cmbVal2->setText(root.attribute("value2"));
+                SKGComboBox* cmbVal23 = qobject_cast<SKGComboBox*> (m_kValue2);
+                if (cmbVal23) cmbVal23->setText(root.attribute("value2"));
             }
         }
 
