@@ -47,26 +47,27 @@ public:
     struct SKGInterestItem {
         SKGObjectBase object;   /**< The object (an operation, an interest or nothing for initial balance) */
         QDate date;             /**< The date */
-        QDate valueDate;    /**< The valueDate */
-        int base;           /**< Base */
+        QDate valueDate;        /**< The valueDate */
+        int base;               /**< Base */
         double amount;          /**< Amount */
         double coef;            /**< Coef */
         double rate;            /**< Rate */
         double annualInterest;  /**< Annual Interest */
         double accruedInterest; /**< Accrued Interest */
-    } ;
+    };
 
     /**
      * This enumerate defines type of account
      */
-    enum AccountType {CURRENT,   /**< to define a bank account*/
-                      CREDITCARD,/**< to define a credit card account*/
-                      INVESTMENT,/**< to define an account for investment */
-                      ASSETS,    /**< to define a assets account */
-                      OTHER,     /**< other kind of account */
-                      WALLET,    /**< to define a wallet account */
-                      LOAN,       /**< to define a loan account */
-                      SAVING       /**< to define a saving account */
+    enum AccountType {CURRENT,     /**< to define a bank account*/
+                      CREDITCARD,  /**< to define a credit card account*/
+                      INVESTMENT,  /**< to define an account for investment */
+                      ASSETS,      /**< to define a assets account */
+                      OTHER,       /**< other kind of account */
+                      WALLET,      /**< to define a wallet account */
+                      LOAN,        /**< to define a loan account */
+                      SAVING,      /**< to define a saving account */
+                      PENSION      /**< to define a pension account */
                      };
 
     /**
@@ -227,9 +228,10 @@ public:
     /**
      * Get amount of the account at a date
      * @param iDate date
+     * @param iOnlyCurrencies only the operations based on currencies are taken into account, not shares
      * @return amount of the account
      */
-    virtual double getAmount(const QDate& iDate) const;
+    virtual double getAmount(const QDate& iDate, bool iOnlyCurrencies = false) const;
 
     /**
      * Set the type of this account
@@ -335,6 +337,20 @@ public:
      */
     virtual double getMinLimitAmount() const;
 
+    /**
+     * Set reconciliation date of this account
+     * @param iDate the date
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setReconciliationDate(const QDate& iDate);
+
+    /**
+     * Get reconciliation date of this account
+     * @return the date
+     */
+    virtual QDate getReconciliationDate() const;
+
     /**
      * Get the unit
      * @param oUnit the unit
