@@ -20,11 +20,12 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgbankobject.h"
+
+#include <KLocale>
+
 #include "skgaccountobject.h"
 #include "skgdocumentbank.h"
 
-#include <klocale.h>
-
 SKGBankObject::SKGBankObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_bank", iID)
 {
 }
