@@ -20,14 +20,15 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 #include "skgbudgetobject.h"
+
+#include <KLocale>
+
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgcategoryobject.h"
 #include "skgbudgetruleobject.h"
 #include "skgtransactionmng.h"
 
-#include <klocale.h>
-
 SKGBudgetObject::SKGBudgetObject(SKGDocument* iDocument, int iID)
     : SKGObjectBase(iDocument, "v_budget", iID)
 {
@@ -59,7 +60,7 @@ const SKGBudgetObject& SKGBudgetObject::operator= (const SKGObjectBase& iObject)
 
 QString SKGBudgetObject::getWhereclauseId() const
 {
-    //Could we use the id
+    // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
         QString y = getAttribute("i_year");
@@ -128,7 +129,6 @@ SKGError SKGBudgetObject::setCategory(const SKGCategoryObject& iCategory)
 SKGError SKGBudgetObject::getCategory(SKGCategoryObject& oCategory) const
 {
     return getDocument()->getObject("v_category", "id=" % getAttribute("rc_category_id"), oCategory);
-
 }
 
 SKGError SKGBudgetObject::enableSubCategoriesInclusion(bool iEnable)
@@ -150,12 +150,12 @@ SKGError SKGBudgetObject::process()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGBudgetObject::process", err);
-    //Main values
+    // Main values
     int m = getMonth();
     int y = getYear();
     double transferred = SKGServices::stringToDouble(getAttribute("f_transferred"));
 
-    //Get budgets rules ordered
+    // Get budgets rules ordered
     SKGObjectBase::SKGListSKGObjectBase budgetsRules;
     QString sql = "(t_year_condition='N' OR i_year=" % SKGServices::intToString(y) % ") AND "
                   "(t_month_condition='N' OR i_month=" % SKGServices::intToString(m) % ") AND "
@@ -169,29 +169,29 @@ SKGError SKGBudgetObject::process()
         for (int i = 0; !err && i < nb; ++i) {
             SKGBudgetRuleObject rule(budgetsRules.at(i));
 
-            //Do we have something to do
+            // Do we have something to do
             SKGBudgetRuleObject::Condition cond = rule.getCondition();
             double delta = getDelta();
             double quantity = rule.getQuantity();
             if (delta) {
                 if (cond == SKGBudgetRuleObject::ALL || (delta < 0 && cond == SKGBudgetRuleObject::NEGATIVE) || (delta > 0 && cond == SKGBudgetRuleObject::POSITIVE)) {
-                    //Compute value to transfer
+                    // Compute value to transfer
                     double value = (rule.isAbolute() ? (cond == SKGBudgetRuleObject::NEGATIVE ? qMax(delta, quantity) : qMin(delta, quantity)) : quantity * (delta - transferred) / 100.0);
 
-                    //Get impacted budget
+                    // Get impacted budget
                     SKGBudgetObject impactedBudget = *this;
                     impactedBudget.resetID();
 
                     SKGBudgetRuleObject::Mode mode = rule.getTransferMode();
                     if (mode == SKGBudgetRuleObject::NEXT) {
-                        //Next
+                        // Next
                         int mi = m;
                         int yi = y;
                         if (mi == 0) {
-                            //Yearly budget
+                            // Yearly budget
                             ++yi;
                         } else {
-                            //Monthly budget
+                            // Monthly budget
                             ++mi;
                             if (mi == 13) {
                                 mi = 1;
@@ -201,12 +201,12 @@ SKGError SKGBudgetObject::process()
                         IFOKDO(err, impactedBudget.setYear(yi))
                         IFOKDO(err, impactedBudget.setMonth(mi))
                     } else if (mode == SKGBudgetRuleObject::YEAR) {
-                        //Year
+                        // Year
                         IFOKDO(err, impactedBudget.setYear(y))
                         IFOKDO(err, impactedBudget.setMonth(0))
                     }
 
-                    //Change category
+                    // Change category
                     if (!err && rule.isCategoryChangeEnabled()) {
                         SKGCategoryObject transferCategory;
                         rule.getTransferCategory(transferCategory);
@@ -267,7 +267,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
         err = iDocument->executeSelectSqliteOrder(sql, listTmp);
 
 
-        //SELECT r.d_date,r.i_period_increment,r.t_period_unit, r.i_nb_times, r. t_times, r.t_CATEGORY, r.f_CURRENTAMOUNT  FROM v_recurrentoperation_display r WHERE r.t_TRANSFER='N'
+        // SELECT r.d_date,r.i_period_increment,r.t_period_unit, r.i_nb_times, r. t_times, r.t_CATEGORY, r.f_CURRENTAMOUNT  FROM v_recurrentoperation_display r WHERE r.t_TRANSFER='N'
 
         /*double sumBudgeted = 0;
         double sumOps = 0;*/
@@ -277,22 +277,22 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
             int step = 0;
             err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create automatic budget"), nbval - 1 + 1 + (iRemovePreviousBudget ? 1 : 0));
 
-            //Remove previous budgets
+            // Remove previous budgets
             if (iRemovePreviousBudget) {
                 IFOKDO(err, iDocument->executeSqliteOrder("DELETE FROM budget WHERE i_year=" % SKGServices::intToString(iYear)))
                 ++step;
                 IFOKDO(err, iDocument->stepForward(step))
             }
 
-            //Create budgets
-            for (int i = 1; !err && i < nbval; ++i) { //Ignore header
-                //Get values
+            // Create budgets
+            for (int i = 1; !err && i < nbval; ++i) {  // Ignore header
+                // Get values
                 QString catName = listTmp.at(i).at(0);
                 int count = SKGServices::stringToInt(listTmp.at(i).at(1));
                 int countPercent = SKGServices::stringToInt(listTmp.at(i).at(2));
                 double amount = SKGServices::stringToDouble(listTmp.at(i).at(3));
                 int month = SKGServices::stringToInt(listTmp.at(i).at(4));
-                //sumOps += SKGServices::stringToDouble(listTmp.at(i).at(5));
+                // sumOps += SKGServices::stringToDouble(listTmp.at(i).at(5));
 
                 if (!catName.isEmpty() && (countPercent > 85 || count == 1)) {
                     SKGCategoryObject cat;;
@@ -305,14 +305,14 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
                         IFOKDO(err, budget.setCategory(cat))
                         IFOKDO(err, budget.save())
 
-                        //sumBudgeted += amount;
+                        // sumBudgeted += amount;
                     }
                 }
                 ++step;
                 IFOKDO(err, iDocument->stepForward(step))
             }
 
-            //Analyze
+            // Analyze
             IFOKDO(err, iDocument->executeSqliteOrder("ANALYZE");)
             ++step;
             IFOKDO(err, iDocument->stepForward(step))
@@ -330,11 +330,11 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
     if (iDocument) {
         err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Balance budgets"), 2);
 
-        //Monthly balancing
+        // Monthly balancing
         if (!err && iMonth != -1) {
             for (int m = (iMonth == 0 ? 1 : iMonth); !err && m <= (iMonth == 0 ? 12 : iMonth); ++m) {
                 SKGStringListList listTmp;
-                err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND i_month=" % SKGServices::intToString(m) % " AND rc_category_id<>0", listTmp) ;
+                err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND i_month=" % SKGServices::intToString(m) % " AND rc_category_id<>0", listTmp);
                 if (!err && listTmp.count() == 2) {
                     SKGBudgetObject budget(iDocument);
                     double amount = -SKGServices::stringToDouble(listTmp.at(1).at(0));
@@ -347,10 +347,10 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
         }
         IFOKDO(err, iDocument->stepForward(1))
 
-        //Annual balancing
+        // Annual balancing
         if (!err && iBalanceYear) {
             SKGStringListList listTmp;
-            err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND (i_month<>0 OR rc_category_id<>0)", listTmp) ;
+            err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND (i_month<>0 OR rc_category_id<>0)", listTmp);
             if (!err && listTmp.count() == 2) {
                 SKGBudgetObject budget(iDocument);
                 double amount = -SKGServices::stringToDouble(listTmp.at(1).at(0));
