@@ -34,7 +34,7 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGBudgetObject : public SKGObjectBase
 {
-    Q_OBJECT;
+    Q_OBJECT
 public:
     /**
     * Constructor
@@ -58,7 +58,7 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGBudgetObject(const SKGObjectBase& iObject);
+    explicit SKGBudgetObject(const SKGObjectBase& iObject);
 
     /**
      * Operator affectation
@@ -169,11 +169,12 @@ public:
      * @param iDocument the document where to create*
      * @param iYear year of budget
      * @param iBaseYear year of the base for computation
+     * @param iUseScheduledOperation use the scheduled operations for a more accurate creation
      * @param iRemovePreviousBudget remove existing budget for @param iYear
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError createAutomaticBudget(SKGDocumentBank* iDocument, int iYear, int iBaseYear, bool iRemovePreviousBudget = false);
+    static SKGError createAutomaticBudget(SKGDocumentBank* iDocument, int iYear, int iBaseYear, bool iUseScheduledOperation, bool iRemovePreviousBudget);
 
     /**
      * Create automatically budget items based on existing operations
