@@ -20,12 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgcategoryobject.h"
+
+#include <KLocale>
+
 #include "skgsuboperationobject.h"
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
-#include <klocale.h>
-
 SKGCategoryObject::SKGCategoryObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, "v_category", iID)
 {
 }
@@ -59,13 +60,15 @@ SKGError SKGCategoryObject::setName(const QString& iName)
 {
     SKGError err;
     if (iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL,  i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'" , iName, QString(OBJECTSEPARATOR)));
-    else err = SKGNamedObject::setName(iName);
+    else {
+        err = SKGNamedObject::setName(iName);
+    }
     return err;
 }
 
 QString SKGCategoryObject::getWhereclauseId() const
 {
-    //Could we use the id
+    // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
         if (!(getAttribute("t_name").isEmpty())) {
@@ -74,7 +77,9 @@ QString SKGCategoryObject::getWhereclauseId() const
         QString rd_category_id = getAttribute("rd_category_id");
         if (!output.isEmpty()) output += " AND ";
         if (rd_category_id.isEmpty()) output += "(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')";
-        else output += "rd_category_id=" % rd_category_id;
+        else {
+            output += "rd_category_id=" % rd_category_id;
+        }
     }
     return output;
 }
@@ -93,21 +98,23 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
     SKGError err;
     SKGTRACEINRC(10, "SKGCategoryObject::createPathCategory", err);
 
-    //Check if category is already existing
+    // Check if category is already existing
     if (iFullPath.isEmpty()) {
         oCategory = SKGCategoryObject(NULL, 0);
     } else if (iDocument) {
         if (!iRenameIfAlreadyExist) iDocument->getObject("v_category", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
-        else oCategory.resetID();
+        else {
+            oCategory.resetID();
+        }
         if (oCategory.getID() == 0) {
-            //No, we have to create it
-            //Search category separator
+            // No, we have to create it
+            // Search category separator
             int posSeparator = iFullPath.lastIndexOf(OBJECTSEPARATOR);
             if (posSeparator == -1) {
                 oCategory = SKGCategoryObject(iDocument);
                 err = oCategory.setName(iFullPath);
 
-                //Check if already existing
+                // Check if already existing
                 if (!err && iRenameIfAlreadyExist) {
                     int index = 1;
                     while (!err && oCategory.exist()) {
@@ -118,22 +125,22 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
 
                 IFOKDO(err, oCategory.save())
             } else {
-                //Get first and second parts of the branch
+                // Get first and second parts of the branch
                 QString first = iFullPath.mid(0, posSeparator);
                 QString second = iFullPath.mid(posSeparator + QString(OBJECTSEPARATOR).length(), iFullPath.length() - posSeparator - QString(OBJECTSEPARATOR).length());
 
-                //Get first category
+                // Get first category
                 SKGCategoryObject FirstCategory;
                 err = SKGCategoryObject::createPathCategory(iDocument, first, FirstCategory);
 
                 IFOK(err) {
-                    //Get second category
+                    // Get second category
                     err = FirstCategory.addCategory(oCategory);
 
-                    //Add second under first
+                    // Add second under first
                     IFOKDO(err, oCategory.setName(second))
 
-                    //Check if already existing
+                    // Check if already existing
                     if (!err && iRenameIfAlreadyExist) {
                         int index = 2;
                         while (!err && oCategory.exist()) {
@@ -142,7 +149,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                         }
                     }
 
-                    //save
+                    // save
                     IFOKDO(err, oCategory.save())
                 }
             }
@@ -174,15 +181,15 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
     SKGTRACEINRC(10, "SKGCategoryObject::setParentCategory", err);
     if (iCategory.getID() == 0) err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::setParentCategory")));
     else {
-        //Check if it's a loop
+        // Check if it's a loop
         SKGCategoryObject current = iCategory;
         do {
             if (current == *this) {
                 err = SKGError(ERR_FAIL,  i18nc("Error message", "You cannot create a loop."));
             } else {
-                SKGCategoryObject parent;
-                current.getParentCategory(parent);
-                current = parent;
+                SKGCategoryObject parent2;
+                current.getParentCategory(parent2);
+                current = parent2;
             }
         } while (!err && current.getID() != 0);
 
@@ -207,15 +214,15 @@ SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) cons
 SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
 {
     SKGError err;
-    SKGCategoryObject parent;
-    err = getParentCategory(parent);
+    SKGCategoryObject parent2;
+    err = getParentCategory(parent2);
     IFOK(err) {
-        if (!parent.exist()) {
-            //No parent
+        if (!parent2.exist()) {
+            // No parent
             oCategory = *this;
         } else {
-            //Parent exist
-            err = parent.getRootCategory(oCategory);
+            // Parent exist
+            err = parent2.getRootCategory(oCategory);
         }
     }
     return err;
@@ -231,8 +238,12 @@ SKGError SKGCategoryObject::getCategories(SKGListSKGObjectBase& oCategoryList) c
 
 double SKGCategoryObject::getCurrentAmount() const
 {
-    SKGNamedObject cat(getDocument(), "v_category_display", getID());
-    return SKGServices::stringToDouble(cat.getAttribute("f_SUMCURRENTAMOUNT"));
+    QString v = getAttribute("f_SUMCURRENTAMOUNT");
+    if (v.isEmpty()) {
+        SKGNamedObject cat(getDocument(), "v_category_display", getID());
+        v = cat.getAttribute("f_SUMCURRENTAMOUNT");
+    }
+    return SKGServices::stringToDouble(v);
 }
 
 SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
@@ -246,7 +257,6 @@ SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperation
 SKGError SKGCategoryObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
-
 }
 
 bool SKGCategoryObject::isBookmarked() const
