@@ -30,7 +30,7 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGCategoryObject : public SKGNamedObject
 {
-    Q_OBJECT;
+    Q_OBJECT
 public:
     /**
      * Constructor
@@ -49,7 +49,7 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGCategoryObject(const SKGObjectBase& iObject);
+    explicit SKGCategoryObject(const SKGObjectBase& iObject);
 
     /**
      * Operator affectation
