@@ -20,6 +20,17 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportexportmanager.h"
+
+#include <KLocale>
+#include <KSaveFile>
+#include <KServiceTypeTrader>
+
+#include <QRegExp>
+#include <QFileInfo>
+#include <QTextCodec>
+#include <QCryptographicHash>
+#include <QTemporaryFile>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgbankincludes.h"
@@ -29,16 +40,6 @@
 #include "skgrecurrentoperationobject.h"
 #include "skgimportplugin.h"
 
-#include <klocale.h>
-#include <ksavefile.h>
-#include <kservicetypetrader.h>
-
-#include <QRegExp>
-#include <QFileInfo>
-#include <QTextCodec>
-#include <QCryptographicHash>
-#include <QTemporaryFile>
-
 SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
         const KUrl& iFileName)
     : QObject(), m_document(iDocument), m_fileName(iFileName),
@@ -110,7 +111,9 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         QString number;
         QString name = items.at(0);
         if (items.count() == 2) bankname = items.at(1);
-        else bankname = name;
+        else {
+            bankname = name;
+        }
         name.replace('_', ' ');
         name.replace('-', ' ');
         QRegExp rx("(\\d{6,})");
@@ -119,7 +122,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             if (name != number) name = name.remove(number).trimmed();
         }
 
-        //Searching if an account exist
+        // Searching if an account exist
         QString whereClause = "t_name='" % name % '\'';
         if (!number.isEmpty()) whereClause += " OR t_number='" % number % "'";
         foreach(const QString & val, name.split(' ')) {
@@ -130,7 +133,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             err = m_document->getObjects("v_account", whereClause, listAccount);
             IFOK(err) {
                 if (listAccount.count() == 1) {
-                    //Yes ! Only one account found
+                    // Yes ! Only one account found
                     SKGAccountObject account(listAccount.at(0));
                     m_defaultAccount = new SKGAccountObject(account);
                     err = m_document->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
@@ -140,16 +143,16 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             }
         }
 
-        //If better account not found, then we must create one
+        // If better account not found, then we must create one
         if (m_defaultAccount == NULL) {
             SKGAccountObject account;
             SKGBankObject bank(m_document);
             IFOKDO(err, bank.setName(bankname))
-            if (!err && bank.load().isFailed()) err = bank.save(false);    //Save only
+            if (!err && bank.load().isFailed()) err = bank.save(false);    // Save only
             IFOKDO(err, bank.addAccount(account))
             IFOKDO(err, account.setName(name))
             IFOKDO(err, account.setNumber(number))
-            if (!err && account.load().isFailed()) err = account.save(false);    //Save only
+            if (!err && account.load().isFailed()) err = account.save(false);    // Save only
             IFOK(err) m_defaultAccount = new SKGAccountObject(account);
             IFOKDO(err, m_document->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name)))
         }
@@ -180,19 +183,19 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
             m_defaultUnit = NULL;
         }
 
-        //Do we have to found the best unit for a date ?
+        // Do we have to found the best unit for a date ?
         QString wc = "t_type IN ('1', '2', 'C')";
         if (iDate) {
-            //Yes
+            // Yes
             wc += " AND d_MINDATE<'" % SKGServices::dateToSqlString(QDateTime(*iDate)) % '\'';
         }
 
-        //Check if a unit exist
+        // Check if a unit exist
         SKGObjectBase::SKGListSKGObjectBase listUnits;
         err = m_document->getObjects("v_unit", wc % " ORDER BY ABS(f_CURRENTAMOUNT-1) ASC" , listUnits);
         IFOK(err) {
             if (listUnits.count() == 0) {
-                //Not found, we have to create one
+                // Not found, we have to create one
                 QDateTime now = QDateTime::currentDateTime();
 
                 SKGUnitObject unit(m_document);
@@ -213,7 +216,7 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
 
                 IFOK(err) m_defaultUnit = new SKGUnitObject(unit);
             } else {
-                //Found, we can use it
+                // Found, we can use it
                 m_defaultUnit = new SKGUnitObject(listUnits.at(0));
             }
         }
@@ -261,49 +264,59 @@ SKGError SKGImportExportManager::finalizeImportation()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation", err);
     if (m_document && !getImportParameters().contains("donotfinalize")) {
-        //Count the number of operations imported but already existing
+        // Count the number of operations imported but already existing
         QString wc = "v_operation.t_imported='T' AND v_operation.t_import_id<>'' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
-        int nb;
-        err = m_document->getNbObjects("v_operation", wc, nb);
-        if (!err && nb) {
-            err = m_document->sendMessage(i18np("one operation not imported because it already exists", "%1 operations not imported because they already exists", nb), SKGDocument::Warning);
+        int nbOperations;
+        err = m_document->getNbObjects("v_operation", wc, nbOperations);
+        if (!err && nbOperations) {
+            err = m_document->sendMessage(i18np("One operation not imported because it already exists", "%1 operations not imported because they already exists", nbOperations), SKGDocument::Warning);
 
-            //Remove operations imported for nothing
+            // Remove operations imported for nothing
             IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')'))
         }
 
-        //Delete operations before the last import
+        // Delete operations before the last import
         if (m_since_last_import && !err) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-deletebeforelastimport", err);
-            err = m_document->executeSqliteOrder("DELETE FROM operation WHERE operation.t_imported='T' AND "
-                                                 "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>operation.d_date)");
+
+            // Count the number of operations before the last import
+            QString wc2 = "operation.t_imported='T' AND "
+                          "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>operation.d_date)";
+            int nbOperations2;
+            err = m_document->getNbObjects("operation", wc2, nbOperations2);
+            if (!err && nbOperations2) {
+                err = m_document->sendMessage(i18np("One operation not imported because before the last imported one, you can uncheck the option to avoid this", "%1 operations not imported because before the last imported one, you can uncheck the option to avoid this", nbOperations2), SKGDocument::Warning);
+
+                // Remove operations imported for nothing
+                IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE " % wc2))
+            }
         }
 
-        //For performances
+        // For performances
         IFOKDO(err, m_document->executeSqliteOrder("ANALYZE"))
 
-        //Apply rules
+        // Apply rules
         if (!err && m_automaticApplyRulesOfImportedOperation) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-applyrules", err);
-            //Get rules
+            // Get rules
             SKGObjectBase::SKGListSKGObjectBase rules;
             IFOKDO(err, m_document->getObjects("v_rule", "1=1 ORDER BY f_sortorder", rules))
 
-            int nb = rules.count();
-            IFOKDO(err, m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Finalize import"), nb))
-            for (int i = 0; !err && i < nb; ++i) {
+            int nbRules = rules.count();
+            IFOKDO(err, m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Finalize import"), nbRules))
+            for (int i = 0; !err && i < nbRules; ++i) {
                 SKGRuleObject rule(rules.at(i));
                 err = rule.execute(SKGRuleObject::IMPORTING);
                 IFOKDO(err, m_document->stepForward(i + 1))
             }
             SKGENDTRANSACTION(m_document,  err);
 
-            //A failure in rule will not block the transaction.
-            //A warning message is sent
+            // A failure in rule will not block the transaction.
+            // A warning message is sent
             IFKO(err) err = m_document->sendMessage(i18nc("Warning message", "Error during execution of rules:\n%1", err.getFullMessageWithHistorical()), SKGDocument::Error);
         }
 
-        //Change imported status
+        // Change imported status
         IFOK(err) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-setfinalstatus", err);
             err = m_document->executeSqliteOrder(QString("UPDATE operation SET t_imported='") %
@@ -420,7 +433,7 @@ SKGImportPlugin* SKGImportExportManager::getImportPlugin()
             if (factory) {
                 SKGImportPlugin* pluginInterface = factory->create<SKGImportPlugin> (this);
                 if (pluginInterface && pluginInterface->isImportPossible()) {
-                    //Import
+                    // Import
                     m_importPlugin = pluginInterface;
                 }
             } else {
@@ -444,7 +457,7 @@ SKGImportPlugin* SKGImportExportManager::getExportPlugin()
             if (factory) {
                 SKGImportPlugin* pluginInterface = factory->create<SKGImportPlugin> (this);
                 if (pluginInterface && pluginInterface->isExportPossible()) {
-                    //Import
+                    // Import
                     m_exportPlugin = pluginInterface;
                 }
             } else {
@@ -467,11 +480,11 @@ SKGError SKGImportExportManager::importFile()
         IFOKDO(err, m_document->stepForward(1))
 
         IFOK(err) {
-            //Search plugins
+            // Search plugins
             bool fileTreated = false;
             SKGImportPlugin* pluginInterface = getImportPlugin();
             if (pluginInterface) {
-                //Import
+                // Import
                 fileTreated = true;
                 SKGTRACEL(2) << "Input filename=" << m_fileName.prettyUrl() << endl;
                 SKGTRACEL(2) << "Input local filename=" << getLocalFileName() << endl;
@@ -496,11 +509,11 @@ SKGError SKGImportExportManager::exportFile()
     if (m_document) {
         err = m_document->executeSqliteOrder("ANALYZE");
         IFOK(err) {
-            //Search plugins
+            // Search plugins
             bool fileTreated = false;
             SKGImportPlugin* pluginInterface = getExportPlugin();
             if (pluginInterface) {
-                //Import
+                // Import
                 fileTreated = true;
                 SKGTRACEL(2) << "Input filename=" << m_fileName.prettyUrl() << endl;
                 SKGTRACEL(2) << "Input local filename=" << getLocalFileName(false) << endl;
@@ -520,11 +533,11 @@ SKGError SKGImportExportManager::cleanBankImport()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportExportManager::cleanBankImport", err);
 
-    //Begin transaction
+    // Begin transaction
     if (m_document) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Clean import"), 3);
         IFOK(err) {
-            //Step 1 Clean operations without mode and with comment with double space
+            // Step 1 Clean operations without mode and with comment with double space
             SKGObjectBase::SKGListSKGObjectBase operations;
             IFOKDO(err, m_document->getObjects("operation", "t_imported!='N' and t_mode='' and t_comment like '%  %'", operations))
 
@@ -532,73 +545,73 @@ SKGError SKGImportExportManager::cleanBankImport()
             for (int i = 0; !err && i < nb ; ++i) {
                 SKGOperationObject op(operations[i]);
 
-                //Comment is like this: <TYPE>  <INFO>
-                //Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
+                // Comment is like this: <TYPE>  <INFO>
+                // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
                 QRegExp rx("(.+) {2,}(.+)");
                 QString comment = op.getComment();
                 if (rx.indexIn(comment) != -1) {
-                    //Get parameters
+                    // Get parameters
                     QString mode = rx.cap(1);
                     QString info = rx.cap(2);
 
-                    //Modify
+                    // Modify
                     err = op.setComment(info.trimmed());
                     IFOKDO(err, op.setMode(mode.trimmed()))
-                    IFOKDO(err, op.save(true, false))   //No reload
+                    IFOKDO(err, op.save(true, false))   // No reload
                 }
             }
 
-            //Step 1 done
+            // Step 1 done
             IFOKDO(err, m_document->stepForward(1))
 
-            //Step 2 Clean operations without mode and with comment
+            // Step 2 Clean operations without mode and with comment
             IFOKDO(err, m_document->getObjects("operation", "t_imported!='N' and t_mode='' and t_comment!=''", operations))
 
             nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
                 SKGOperationObject op(operations[i]);
 
-                //Comment is like this: <TYPE> <INFO>
-                //Example: RETRAIT DAB 14-05-16607-482390
+                // Comment is like this: <TYPE> <INFO>
+                // Example: RETRAIT DAB 14-05-16607-482390
                 QRegExp rx("(\\S+) +(.+)");
                 QString comment = op.getComment();
                 if (rx.indexIn(comment) != -1) {
-                    //Get parameters
+                    // Get parameters
                     QString mode = rx.cap(1);
                     QString info = rx.cap(2);
 
-                    //Modify
+                    // Modify
                     err = op.setComment(info.trimmed());
                     IFOKDO(err, op.setMode(mode.trimmed()))
-                    IFOKDO(err, op.save(true, false))   //No reload
+                    IFOKDO(err, op.save(true, false))   // No reload
                 }
             }
 
-            //Step 2 done
+            // Step 2 done
             IFOKDO(err, m_document->stepForward(2))
 
-            //Step 3 Clean cheque without number
+            // Step 3 Clean cheque without number
             IFOKDO(err, m_document->getObjects("operation", "t_imported!='N' and i_number=0 and lower(t_mode)='cheque'", operations))
 
             nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
                 SKGOperationObject op(operations[i]);
 
-                //Comment is like this: <TYPE>  <INFO>
-                //Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
+                // Comment is like this: <TYPE>  <INFO>
+                // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
                 QRegExp rx("(\\d+)");
                 QString comment = op.getComment();
                 if (rx.indexIn(comment) != -1) {
-                    //Get parameters
+                    // Get parameters
                     int number = SKGServices::stringToInt(rx.cap(1));
 
-                    //Modify
+                    // Modify
                     err = op.setNumber(number);
-                    IFOKDO(err, op.save(true, false))   //No reload
+                    IFOKDO(err, op.save(true, false))   // No reload
                 }
             }
 
-            //Step 3 done
+            // Step 3 done
             IFOKDO(err, m_document->stepForward(3))
         }
 
@@ -626,7 +639,7 @@ SKGError SKGImportExportManager::anonymize()
                           << "UPDATE operation SET t_comment=''"
                           << "UPDATE suboperation SET t_comment='', f_value=f_value%1234.56"
                           << "DELETE FROM parameters WHERE t_name NOT LIKE 'SKG_%' OR t_name='SKG_PASSWORD'"
-                          << "DELETE FROM doctransactionitem"; //For better performances
+                          << "DELETE FROM doctransactionitem";  // For better performances
 
                 int nb = sqlOrders.count();
                 SKGBEGINPROGRESSTRANSACTION(*m_document, "##INTERNAL##" % i18nc("Progression step", "Anonymize"), err, nb);
@@ -649,12 +662,12 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
 
     oNbOperationsMerged = 0;
 
-    //Begin transaction
+    // Begin transaction
     if (m_document) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 3);
         IFOK(err) {
             IFOKDO(err, m_document->executeSqliteOrder("ANALYZE"))
-            //Look for operations with
+            // Look for operations with
             //  Same units
             //  Same dates
             //  Null i_group_id
@@ -665,26 +678,26 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
                        "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0" %
                        (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
                        listTmp));
-            //Step 1 done
+            // Step 1 done
             IFOKDO(err, m_document->stepForward(1))
 
             SKGStringListList listTmp2;
-            //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
+            // +A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             IFOKDO(err, m_document->executeSelectSqliteOrder(
                        "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0" %
                        (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
                        listTmp2));
 
-            //Step 2 done
+            // Step 2 done
             IFOKDO(err, m_document->stepForward(2))
-            listTmp2.removeAt(0);    //Remove header
+            listTmp2.removeAt(0);    // Remove header
             listTmp += listTmp2;
 
-            //Group
+            // Group
             {
                 oNbOperationsMerged = listTmp.count();
                 IFOKDO(err, m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), oNbOperationsMerged - 1))
-                for (int i = 1; !err && i < oNbOperationsMerged ; ++i) { //First line ignored because of it's header
+                for (int i = 1; !err && i < oNbOperationsMerged ; ++i) {  // First line ignored because of it's header
                     SKGOperationObject op1(m_document, SKGServices::stringToInt(listTmp.at(i).at(0)));
                     SKGOperationObject op2(m_document, SKGServices::stringToInt(listTmp.at(i).at(1)));
 
@@ -698,9 +711,8 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
             }
             oNbOperationsMerged = (oNbOperationsMerged - 1) * 2;
 
-            //Step 3 done
+            // Step 3 done
             IFOKDO(err, m_document->stepForward(3))
-
         }
         SKGENDTRANSACTION(m_document,  err);
     }
