@@ -21,7 +21,7 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <kparts/plugin.h>
+#include <KParts/Plugin>
 
 #include "skgerror.h"
 #include "skgbankgui_export.h"
@@ -36,7 +36,6 @@ class SKGBANKMODELER_EXPORT SKGImportPlugin : public KParts::Plugin
 {
     Q_OBJECT
 public:
-
     /**
      * Default constructor
      * @param iImporter the parent importer
@@ -110,11 +109,11 @@ private:
 protected:
     SKGImportExportManager* m_importer;
     QMap<QString, QString> m_parameters;
-
 };
+
 /**
  * This plugin interface definition.
  */
 Q_DECLARE_INTERFACE(SKGImportPlugin, "skrooge.com.SKGImportPlugin/1.0")
 
-#endif // SKGIMPORTPLUGIN_H
+#endif  // SKGIMPORTPLUGIN_H
