@@ -20,6 +20,9 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgoperationobject.h"
+
+#include <KLocale>
+
 #include "skgrecurrentoperationobject.h"
 #include "skgsuboperationobject.h"
 #include "skgaccountobject.h"
@@ -29,8 +32,6 @@
 #include "skgdocument.h"
 #include "skgtraces.h"
 
-#include <klocale.h>
-
 SKGOperationObject::SKGOperationObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, "v_operation", iID)
 {}
 
@@ -60,8 +61,8 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
 {
     SKGError err;
     SKGTRACEINRC(20, "SKGOperationObject::duplicate", err);
-    //Create the duplicated operation
-    oOperation = SKGOperationObject(getDocument(), this->getID());  //To be sure the object is on v_operation
+    // Create the duplicated operation
+    oOperation = SKGOperationObject(getDocument(), this->getID());  // To be sure the object is on v_operation
     IFOKDO(err, oOperation.load())
     IFOKDO(err, oOperation.resetID())
     IFOKDO(err, oOperation.setDate(iDate))
@@ -74,7 +75,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
     IFOKDO(err, oOperation.setGroupOperation(oOperation))
     IFOKDO(err, oOperation.save(false, false))
 
-    //Duplicate subop
+    // Duplicate subop
     IFOK(err) {
         SKGListSKGObjectBase subops;
         err = getSubOperations(subops);
@@ -87,7 +88,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
         }
     }
 
-    //Duplicate grouped operation to support recurrent transfers
+    // Duplicate grouped operation to support recurrent transfers
     IFOK(err) {
         SKGListSKGObjectBase goupops;
         err = getGroupedOperations(goupops);
@@ -95,7 +96,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
         for (int i = 0; !err && i < nbgoupops; ++i) {
             SKGOperationObject groupop(goupops.at(i));
             if (groupop != *this) {
-                //Create the duplicated operation
+                // Create the duplicated operation
                 SKGOperationObject newgroupop = groupop;
                 err = newgroupop.resetID();
                 IFOKDO(err, newgroupop.setDate(iDate))
@@ -109,7 +110,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
                 IFOKDO(err, newgroupop.setGroupOperation(oOperation))
                 IFOKDO(err, newgroupop.save(false))
 
-                //Duplicate subop
+                // Duplicate subop
                 IFOK(err) {
                     SKGListSKGObjectBase subops;
                     err = groupop.getSubOperations(subops);
@@ -147,7 +148,9 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount,
     else {
         if (newAccount != currentAccount) {
             if (iAccount.isClosed() && !iForce) err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
-            else err = setAttribute("rd_account_id", newAccount);
+            else {
+                err = setAttribute("rd_account_id", newAccount);
+            }
         }
     }
     return err;
@@ -198,7 +201,9 @@ SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
 {
     QString t_status = getAttribute("t_status");
     if (t_status == "Y") return SKGOperationObject::CHECKED;
-    else if (t_status == "P") return SKGOperationObject::POINTED;
+    else if (t_status == "P") {
+        return SKGOperationObject::POINTED;
+    }
     return SKGOperationObject::NONE;
 }
 
@@ -220,7 +225,7 @@ QDate SKGOperationObject::getDate() const
 SKGError SKGOperationObject::getUnit(SKGUnitObject& oUnit) const
 {
     SKGError err = (getDocument() == NULL ? SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing")) : getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit));
-    //SKGError err = getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit);
+    // SKGError err = getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit);
     return err;
 }
 
@@ -248,7 +253,9 @@ SKGError SKGOperationObject::getGroupedOperations(SKGListSKGObjectBase& oGrouped
     SKGError err;
     QString gpId1 = getAttribute("i_group_id");
     if (gpId1 == "0") oGroupedOperations.clear();
-    else  err = getDocument()->getObjects("v_operation", "i_group_id=" % gpId1, oGroupedOperations);
+    else {
+        err = getDocument()->getObjects("v_operation", "i_group_id=" % gpId1, oGroupedOperations);
+    }
     return err;
 }
 
@@ -263,36 +270,36 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
     SKGError err;
     SKGTRACEINRC(20, "SKGOperationObject::setGroupOperation", err);
 
-    //Is it a remove group ?
+    // Is it a remove group ?
     if (iOperation == *this) {
-        //Yes
+        // Yes
         err = setAttribute("i_group_id", "0");
     } else {
-        //Get previous groups
+        // Get previous groups
         QString group1 = getAttribute("i_group_id");
         QString group2 = iOperation.getAttribute("i_group_id");
 
-        //Create a new group
+        // Create a new group
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT max(i_group_id) from operation", result);
         IFOK(err) {
-            //Compute new group id
+            // Compute new group id
             QString newIdGroup('1');
             if (result.count() == 2) {
                 newIdGroup = SKGServices::intToString(SKGServices::stringToInt(result.at(1).at(0)) + 1);
             }
 
-            //Set group id
+            // Set group id
             SKGOperationObject op1 = SKGOperationObject(iOperation.getDocument(), iOperation.getID());
             err = op1.setAttribute("i_group_id", newIdGroup);
             IFOKDO(err, op1.save(true, false))
 
             IFOKDO(err, setAttribute("i_group_id", newIdGroup))
 
-            //Update all objects of group2
+            // Update all objects of group2
             if (!err && !group1.isEmpty() && group1 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group1);
 
-            //Update all objects of group2
+            // Update all objects of group2
             if (!err && !group1.isEmpty() && group2 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group2);
         }
     }
@@ -303,7 +310,6 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
 SKGError SKGOperationObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
-
 }
 
 bool SKGOperationObject::isBookmarked() const
@@ -314,7 +320,6 @@ bool SKGOperationObject::isBookmarked() const
 SKGError SKGOperationObject::setImported(bool iImported)
 {
     return setAttribute("t_imported", iImported ? "Y" : "N");
-
 }
 
 bool SKGOperationObject::isImported() const
@@ -337,7 +342,6 @@ QString SKGOperationObject::getImportID() const
 SKGError SKGOperationObject::setTemplate(bool iTemplate)
 {
     return setAttribute("t_template", iTemplate ? "Y" : "N");
-
 }
 
 bool SKGOperationObject::isTemplate() const
@@ -366,7 +370,6 @@ SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase& oSubOperatio
     SKGError err;
     if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getSubOperations")));
     else {
-
         err = getDocument()->getObjects("v_suboperation",
                                         "rd_operation_id=" % SKGServices::intToString(getID()), oSubOperations);
     }
@@ -394,17 +397,17 @@ double SKGOperationObject::getBalance() const
 
 double SKGOperationObject::getAmount(const QDate& iDate) const
 {
-    //Get quantity
+    // Get quantity
     double quantity = SKGServices::stringToDouble(getAttribute("f_QUANTITY"));
 
-    //Is the unit value already in cache ?
+    // Is the unit value already in cache ?
     double coef = 1;
     QString val = getDocument()->getCachedValue("unitvalue-" % getAttribute("rc_unit_id"));
     if (!val.isEmpty()) {
-        //Yes
+        // Yes
         coef = SKGServices::stringToDouble(val);
     } else {
-        //No
+        // No
         SKGUnitObject unit;
         if (getUnit(unit).isSucceeded()) coef = unit.getAmount(iDate);
     }
@@ -437,7 +440,7 @@ SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecur
 
 SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne)
 {
-    //Merge operation
+    // Merge operation
     SKGError err = setDate(iDeletedOne.getDate());
     IFOKDO(err, setImportID(iDeletedOne.getImportID()))
     IFOKDO(err, setAttribute("t_imported", iDeletedOne.getAttribute("t_imported")))
@@ -450,7 +453,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     if (!err && !getNumber()) err = setNumber(iDeletedOne.getNumber());
     IFOKDO(err, save())
 
-    //Merge suboperations
+    // Merge suboperations
     if (qAbs(getCurrentAmount() - iDeletedOne.getCurrentAmount()) > 0.0001) {
         SKGObjectBase::SKGListSKGObjectBase subOps1;
         IFOKDO(err, getSubOperations(subOps1))
@@ -459,13 +462,13 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
         IFOKDO(err, iDeletedOne.getSubOperations(subOps2))
 
         if (subOps2.count() == 1 && subOps1.count() == 1) {
-            //Change the quantity of the sub operation
+            // Change the quantity of the sub operation
             SKGSubOperationObject so1(subOps1.at(0));
             SKGSubOperationObject so2(subOps2.at(0));
             IFOKDO(err, so1.setQuantity(so2.getQuantity()))
             IFOKDO(err, so1.save())
         } else if (subOps2.count() >= 1 && subOps1.count() >= 1) {
-            //Add a split
+            // Add a split
             SKGSubOperationObject so1;
             IFOKDO(err, addSubOperation(so1))
             IFOKDO(err, so1.setQuantity(iDeletedOne.getCurrentAmount() - getCurrentAmount()))
@@ -474,7 +477,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
         IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
     }
 
-    //Delete useless operation
+    // Delete useless operation
     IFOKDO(err, iDeletedOne.remove(false))
     return err;
 }
