@@ -20,12 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgpayeeobject.h"
+
+#include <KLocale>
+
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgoperationobject.h"
 
-#include <klocale.h>
-
 SKGPayeeObject::SKGPayeeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_payee", iID)
 {
 }
@@ -63,13 +64,13 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
     SKGError err;
     SKGTRACEINRC(10, "SKGPayeeObject::createPayee", err);
 
-    //Check if refund is already existing
+    // Check if refund is already existing
     if (iName.isEmpty()) {
         oPayee = SKGPayeeObject(NULL, 0);
     } else if (iDocument) {
         iDocument->getObject("v_payee", "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oPayee);
         if (oPayee.getID() == 0) {
-            //No, we have to create it
+            // No, we have to create it
             oPayee = SKGPayeeObject(iDocument);
             err = oPayee.setName(iName);
             IFOKDO(err, oPayee.save())
@@ -104,7 +105,6 @@ QString SKGPayeeObject::getAddress() const
 SKGError SKGPayeeObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
-
 }
 
 bool SKGPayeeObject::isBookmarked() const
