@@ -20,14 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgrecurrentoperationobject.h"
+
+#include <KLocale>
+
 #include "skgoperationobject.h"
 #include "skgsuboperationobject.h"
 #include "skgservices.h"
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
-#include <klocale.h>
-
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, "v_recurrentoperation", iID)
 {
 }
@@ -83,8 +84,11 @@ SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUn
 {
     QString t_period_unit = getAttribute("t_period_unit");
     if (t_period_unit == "D") return SKGRecurrentOperationObject::DAY;
-    else if (t_period_unit == "W") return SKGRecurrentOperationObject::WEEK;
-    else if (t_period_unit == "M") return SKGRecurrentOperationObject::MONTH;
+    else if (t_period_unit == "W") {
+        return SKGRecurrentOperationObject::WEEK;
+    } else if (t_period_unit == "M") {
+        return SKGRecurrentOperationObject::MONTH;
+    }
     return SKGRecurrentOperationObject::YEAR;
 }
 
@@ -125,18 +129,21 @@ SKGError SKGRecurrentOperationObject::timeLimit(bool iTimeLimit)
 
 SKGError SKGRecurrentOperationObject::setTimeLimit(const QDate& iLastDate)
 {
-    //Get parameters
+    // Get parameters
     QDate firstDate = this->getDate();
     SKGRecurrentOperationObject::PeriodUnit period = this->getPeriodUnit();
     int occu = this->getPeriodIncrement();
 
-    //Compute nb time
+    // Compute nb time
     int nbd = firstDate.daysTo(iLastDate);
     if (period == SKGRecurrentOperationObject::DAY) nbd = nbd / occu;
-    else if (period == SKGRecurrentOperationObject::WEEK) nbd = nbd / (7 * occu);
-    else if (period == SKGRecurrentOperationObject::MONTH) {
+    else if (period == SKGRecurrentOperationObject::WEEK) {
+        nbd = nbd / (7 * occu);
+    } else if (period == SKGRecurrentOperationObject::MONTH) {
         nbd = (iLastDate.day() >= firstDate.day() ? 0 : -1) + (iLastDate.year() - firstDate.year()) * 12 + (iLastDate.month() - firstDate.month());
-    } else if (period == SKGRecurrentOperationObject::YEAR) nbd = nbd / (365 * occu);
+    } else if (period == SKGRecurrentOperationObject::YEAR) {
+        nbd = nbd / (365 * occu);
+    }
 
     if (nbd < -1) nbd = -1;
     return setTimeLimit(nbd + 1);
@@ -162,9 +169,13 @@ QDate SKGRecurrentOperationObject::getNextDate() const
     SKGRecurrentOperationObject::PeriodUnit punit = getPeriodUnit();
     int p = getPeriodIncrement();
     if (punit == SKGRecurrentOperationObject::DAY) nextDate = nextDate.addDays(p);
-    else if (punit == SKGRecurrentOperationObject::WEEK) nextDate = nextDate.addDays(7 * p);
-    else if (punit == SKGRecurrentOperationObject::MONTH) nextDate = nextDate.addMonths(p);
-    else if (punit == SKGRecurrentOperationObject::YEAR) nextDate = nextDate.addYears(p);
+    else if (punit == SKGRecurrentOperationObject::WEEK) {
+        nextDate = nextDate.addDays(7 * p);
+    } else if (punit == SKGRecurrentOperationObject::MONTH) {
+        nextDate = nextDate.addMonths(p);
+    } else if (punit == SKGRecurrentOperationObject::YEAR) {
+        nextDate = nextDate.addYears(p);
+    }
     return nextDate;
 }
 
@@ -186,7 +197,6 @@ bool SKGRecurrentOperationObject::isWarnEnabled() const
 SKGError SKGRecurrentOperationObject::autoWriteEnabled(bool iAutoWrite)
 {
     return setAttribute("t_auto_write", iAutoWrite ? "Y" : "N");
-
 }
 
 bool SKGRecurrentOperationObject::isAutoWriteEnabled() const
@@ -212,19 +222,19 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
                 SKGOperationObject op;
                 err = getParentOperation(op);
                 IFOK(err) {
-                    //Create the duplicated operation
+                    // Create the duplicated operation
                     SKGOperationObject newOp;
                     err = op.duplicate(newOp, nextDate);
 
                     if (!op.isTemplate()) {
-                        //Set old op as recurrent
+                        // Set old op as recurrent
                         IFOKDO(err, op.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID())))
                         IFOKDO(err, op.save())
 
-                        //Set new operation as reference
+                        // Set new operation as reference
                         IFOKDO(err, setParentOperation(newOp))
                     } else {
-                        //Set new op as recurrent
+                        // Set new op as recurrent
                         IFOKDO(err, newOp.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID())))
                         IFOKDO(err, newOp.save())
                     }
@@ -234,12 +244,12 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
                     IFOKDO(err, save())
                     IFOKDO(err, load())
 
-                    //Process again in case of multi insert needed
+                    // Process again in case of multi insert needed
                     int nbi = 0;
                     IFOKDO(err, process(nbi, iForce, iDate))
                     oNbInserted = oNbInserted + 1 + nbi;
 
-                    //Send message
+                    // Send message
                     IFOKDO(err, newOp.load())
                     IFOK(err) {
                         err = getDocument()->sendMessage(i18nc("An information message", "Operation '%1' has been inserted", newOp.getDisplayName()), SKGDocument::Positive);
@@ -271,7 +281,7 @@ SKGError SKGRecurrentOperationObject::process(SKGDocumentBank* iDocument, int& o
     SKGError err;
     oNbInserted = 0;
 
-    //Get all operation with auto_write
+    // Get all operation with auto_write
     SKGListSKGObjectBase recuOps;
     if (iDocument) err = iDocument->getObjects("v_recurrentoperation", "", recuOps);
 
