@@ -20,26 +20,26 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgreportbank.h"
-#include "skgtraces.h"
-#include "skgdocumentbank.h"
-#include "skgaccountobject.h"
-#include "skgunitobject.h"
-#include "skgoperationobject.h"
-#include "skgrecurrentoperationobject.h"
 
-#include <kstandarddirs.h>
+#include <KStandardDirs>
 #include <grantlee/engine.h>
 #include <grantlee/templateloader.h>
 #include <grantlee/metatype.h>
-#include <kaboutdata.h>
-#include <kcomponentdata.h>
-#include <kcolorscheme.h>
+#include <KAboutData>
+#include <KComponentData>
+#include <KColorScheme>
 #include <KUrl>
 
 #include <QTextStream>
 #include <QFile>
 #include <QDir>
 
+#include "skgtraces.h"
+#include "skgdocumentbank.h"
+#include "skgaccountobject.h"
+#include "skgunitobject.h"
+#include "skgoperationobject.h"
+#include "skgrecurrentoperationobject.h"
 
 GRANTLEE_BEGIN_LOOKUP(SKGObjectBase)
 Q_UNUSED(object);
@@ -51,7 +51,7 @@ SKGReportBank::SKGReportBank(SKGDocument* iDocument)
 {
     SKGTRACEIN(1, "SKGReportBank::SKGReportBank");
 
-    //Grantlee initialization
+    // Grantlee initialization
     Grantlee::MetaType::init();
     Grantlee::registerMetaType<SKGObjectBase>();
 }
@@ -88,7 +88,7 @@ QVariantList SKGReportBank::getPortfolio()
             if (doc && loc) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
-                //Get list of operations
+                // Get list of operations
                 SKGObjectBase::SKGListSKGObjectBase objs;
                 SKGError err = doc->getObjects("v_operation_display", "d_date<'" % SKGServices::dateToSqlString(QDateTime(date2)) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
                 int nb = objs.count();
@@ -101,8 +101,7 @@ QVariantList SKGReportBank::getPortfolio()
                          << i18nc("Column table title", "Initial amount")
                          << loc->formatDate(date2, KLocale::ShortDate)
                          << i18nc("Column table title", "Variation")
-                         << i18nc("Column table title", "Variation %")
-                         ;
+                         << i18nc("Column table title", "Variation %");
                     table << QVariant(line);
 
                     QList<unitValues> listUnitValues;
@@ -139,20 +138,20 @@ QVariantList SKGReportBank::getPortfolio()
 
                     nb = listUnitValues.count();
                     for (int j = 0; j < nb; ++j) {
-                        unitValues current = listUnitValues.at(j);
+                        unitValues current2 = listUnitValues.at(j);
 
-                        SKGServices::SKGUnitInfo ui = current.unit.getUnitInfo();
+                        SKGServices::SKGUnitInfo ui = current2.unit.getUnitInfo();
                         ui.Value = 1;
 
                         QVariantList line2;
-                        line2 << current.unit.getSymbol()
-                              << current.unit.getName()
-                              << doc->formatMoney(current.quantity, ui, false)
-                              << current.purchaseAmount
-                              << current.initalAmount
-                              << current.currentAmount
-                              << current.currentAmount - current.initalAmount
-                              << (current.initalAmount == 0.0 ? 0.0 : (current.currentAmount - current.initalAmount) / current.initalAmount);
+                        line2 << current2.unit.getSymbol()
+                              << current2.unit.getName()
+                              << doc->formatMoney(current2.quantity, ui, false)
+                              << current2.purchaseAmount
+                              << current2.initalAmount
+                              << current2.currentAmount
+                              << current2.currentAmount - current2.initalAmount
+                              << (current2.initalAmount == 0.0 ? 0.0 : (current2.currentAmount - current2.initalAmount) / current2.initalAmount);
                         table << QVariant(line2);
                     }
                 }
@@ -228,10 +227,8 @@ QVariantList SKGReportBank::getAccountTable()
                 SKGObjectBase::SKGListSKGObjectBase accounts;
                 SKGError err = doc->getObjects("v_account_display", "1=1 ORDER BY t_TYPENLS, t_BANK, t_name", accounts);
                 IFOK(err) {
-                    QVariantList line;
-                    line << "sum" << doc->getDisplay("t_ACCOUNT") << loc->formatDate(date1, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) <<
-                         "%" << loc->formatDate(date3, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) << "%";
-                    table.push_back(line);
+                    table.push_back(QVariantList() << "sum" << doc->getDisplay("t_ACCOUNT") << loc->formatDate(date1, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) <<
+                                    "%" << loc->formatDate(date3, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) << "%");
                     double sumTypeV1 = 0;
                     double sumTypeV2 = 0;
                     double sumTypeV3 = 0;
@@ -249,12 +246,10 @@ QVariantList SKGReportBank::getAccountTable()
                         bool closed = account.isClosed();
                         if (type != currentType) {
                             if (!currentType.isEmpty()) {
-                                QVariantList line2;
-                                line2 << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2 <<
-                                      (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
-                                      << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
-                                      << "" << "";
-                                table.push_back(line2);
+                                table.push_back(QVariantList() << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2 <<
+                                                (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
+                                                << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
+                                                << "" << "");
                                 sumTypeV1 = 0;
                                 sumTypeV2 = 0;
                                 sumTypeV3 = 0;
@@ -262,16 +257,13 @@ QVariantList SKGReportBank::getAccountTable()
                             currentType = type;
                         }
                         if (!closed || qAbs(v1) > 0.01 || qAbs(v2) > 0.01 || qAbs(v3) > 0.01) {
-                            QVariantList line2;
                             QString icon = account.getAttribute("t_ICON");
                             if (!icon.isEmpty()) {
                                 QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                                 icon = dirLogo.absoluteFilePath(icon);
                             }
-                            line2 << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
-                                  << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute("t_BANK") << icon ;
-                            table.push_back(line2);
-                            ;
+                            table.push_back(QVariantList() << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
+                                            << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute("t_BANK") << icon);
                         }
                         sumTypeV1 += v1;
                         sumTypeV2 += v2;
@@ -281,21 +273,13 @@ QVariantList SKGReportBank::getAccountTable()
                         sumV3 += v3;
                     }
 
-                    {
-                        QVariantList line;
-                        line << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2
-                             << (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
-                             << "" << "";
-                        table.push_back(line);
-                    }
+                    table.push_back(QVariantList() << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2
+                                    << (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
+                                    << "" << "");
 
-                    {
-                        QVariantList line;
-                        line << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2
-                             << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3))
-                             << "" << "";
-                        table.push_back(line);
-                    }
+                    table.push_back(QVariantList() << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2
+                                    << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3))
+                                    << "" << "");
                 }
             }
         }
@@ -324,17 +308,15 @@ QVariantList SKGReportBank::getBankTable()
                 SKGObjectBase::SKGListSKGObjectBase accounts;
                 SKGError err = doc->getObjects("v_account", "1=1 ORDER BY t_BANK", accounts);
                 IFOK(err) {
-                    QVariantList line;
-                    line << "sum" << doc->getDisplay("t_BANK") << loc->formatDate(date1, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) <<
-                         "%" << loc->formatDate(date3, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) << "%";
-                    table.push_back(line);
+                    table.push_back(QVariantList() << "sum" << doc->getDisplay("t_BANK") << loc->formatDate(date1, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) <<
+                                    "%" << loc->formatDate(date3, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) << "%");
                     double sumTypeV1 = 0;
                     double sumTypeV2 = 0;
                     double sumTypeV3 = 0;
                     double sumV1 = 0;
                     double sumV2 = 0;
                     double sumV3 = 0;
-                    QString currentType;
+                    QString currentName;
                     QString currentIcon;
                     bool currentOpen = false;
                     int nb = accounts.count();
@@ -343,29 +325,27 @@ QVariantList SKGReportBank::getBankTable()
                         double v1 = account.getAmount(date1);
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
-                        QString type = account.getAttribute("t_BANK");
-                        //320114 vvvv
-                        if (type.isEmpty()) type = i18nc("Noun", "Unknown");
-                        //320114 ^^^^
+                        QString name = account.getAttribute("t_BANK");
+                        // 320114 vvvv
+                        if (name.isEmpty()) name = i18nc("Noun", "Unknown");
+                        // 320114 ^^^^
                         QString icon = account.getAttribute("t_ICON");
                         if (!icon.isEmpty()) {
                             QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                             icon = dirLogo.absoluteFilePath(icon);
                         }
                         bool open = !account.isClosed();
-                        if (type != currentType) {
-                            if (!currentType.isEmpty() && currentOpen) {
-                                QVariantList line;
-                                line << false << currentType << sumTypeV1 << sumTypeV2 <<
-                                     (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3)) <<
-                                     currentIcon;
-                                table.push_back(line);
+                        if (name != currentName) {
+                            if (!currentName.isEmpty() && currentOpen) {
+                                table.push_back(QVariantList() << false << currentName << sumTypeV1 << sumTypeV2 <<
+                                                (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3)) <<
+                                                currentIcon);
                                 sumTypeV1 = 0;
                                 sumTypeV2 = 0;
                                 sumTypeV3 = 0;
                                 currentOpen = open;
                             }
-                            currentType = type;
+                            currentName = name;
                             currentIcon = icon;
                         }
                         currentOpen = currentOpen || open;
@@ -379,19 +359,13 @@ QVariantList SKGReportBank::getBankTable()
                     }
 
                     if (currentOpen) {
-                        QVariantList line;
-                        line << false << currentType << sumTypeV1 << sumTypeV2
-                             << (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3
-                             << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
-                             << currentIcon;
-                        table.push_back(line);
+                        table.push_back(QVariantList() << false << currentName << sumTypeV1 << sumTypeV2
+                                        << (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3
+                                        << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
+                                        << currentIcon);
                     }
 
-                    {
-                        QVariantList line;
-                        line << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2 << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3));
-                        table.push_back(line);
-                    }
+                    table.push_back(QVariantList() << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2 << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3)));
                 }
             }
         }
@@ -464,7 +438,7 @@ QVariant SKGReportBank::getAdvice()
     SKGTRACEIN(10, "SKGReportBank::getAdvice");
     QVariant output = m_cache["getAdvice"];
     if (!output.isValid()) {
-        //TODO output = qVariantFromValue(SKGMainPanel::getMainPanel()->getAdvice());
+        // TODO(Stephane MANKOWSKI) output = qVariantFromValue(SKGMainPanel::getMainPanel()->getAdvice());
         m_cache["getAdvice"] = output;
     }
     return output;
@@ -483,9 +457,7 @@ QVariantList SKGReportBank::getIncomeVsExpenditure()
             SKGError err = doc->getObjects("v_operation_display", "d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N'", ops);
             int nbval = ops.count();
             if (!err && nbval > 0) {
-                QVariantList line;
-                line << "sum" << "" << previousmonth << month << "max";
-                table.push_back(line);
+                table.push_back(QVariantList() << "sum" << "" << previousmonth << month << "max");
 
                 double income_previous_month = 0;
                 double expense_previous_month = 0;
@@ -498,33 +470,21 @@ QVariantList SKGReportBank::getIncomeVsExpenditure()
                     QDate d = QDate::fromString(m, "yyyy-MM").addMonths(1).addDays(-1);
                     double v = op.getAmount(d);
                     if (v > 0 && m == month) income_month += v;
-                    else if (v < 0 && m == month) expense_month += v;
-                    else if (v > 0 && m == previousmonth) income_previous_month += v;
-                    else if (v < 0 && m == previousmonth) expense_previous_month += v;
+                    else if (v < 0 && m == month) {
+                        expense_month += v;
+                    } else if (v > 0 && m == previousmonth) {
+                        income_previous_month += v;
+                    } else if (v < 0 && m == previousmonth) {
+                        expense_previous_month += v;
+                    }
                 }
                 double saving_previous_month = income_previous_month + expense_previous_month;
                 double saving_month = income_month + expense_month;
 
-                {
-                    QVariantList line;
-                    line << false << doc->getDisplay("f_CURRENTAMOUNT_INCOME") << qAbs(income_previous_month) << qAbs(income_month);
-                    table.push_back(line);
-                }
-                {
-                    QVariantList line;
-                    line << false << doc->getDisplay("f_CURRENTAMOUNT_EXPENSE") << qAbs(expense_previous_month) << qAbs(expense_month);
-                    table.push_back(line);
-                }
-                {
-                    QVariantList line;
-                    line << true << i18nc("Noun",  "Savings possible") << saving_previous_month << saving_month;
-                    table.push_back(line);
-                }
-                {
-                    QVariantList line;
-                    line << true << i18nc("Noun",  "Max") << qMax(qAbs(income_previous_month), qAbs(expense_previous_month)) << qMax(qAbs(income_month), qAbs(expense_month));
-                    table.push_back(line);
-                }
+                table.push_back(QVariantList() << false << doc->getDisplay("f_CURRENTAMOUNT_INCOME") << qAbs(income_previous_month) << qAbs(income_month));
+                table.push_back(QVariantList() << false << doc->getDisplay("f_CURRENTAMOUNT_EXPENSE") << qAbs(expense_previous_month) << qAbs(expense_month));
+                table.push_back(QVariantList() << true << i18nc("Noun",  "Savings possible") << saving_previous_month << saving_month);
+                table.push_back(QVariantList() << true << i18nc("Noun",  "Max") << qMax(qAbs(income_previous_month), qAbs(expense_previous_month)) << qMax(qAbs(income_month), qAbs(expense_month)));
             }
             m_cache["getIncomeVsExpenditure"] = table;
         }
