@@ -20,14 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgruleobject.h"
+
+#include <KLocale>
+
+#include <QDomDocument>
+
 #include "skgunitvalueobject.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 
-#include <klocale.h>
-
-#include <QDomDocument>
-
 SKGRuleObject::SKGRuleObject(SKGDocument* iDocument, int iID)
     : SKGObjectBase(iDocument, "v_rule", iID)
 {
@@ -73,10 +74,10 @@ bool SKGRuleObject::isBookmarked() const
 
 SKGError SKGRuleObject::save(bool iInsertOrUpdate, bool iReloadAfterSave)
 {
-    //Do the save
+    // Do the save
     SKGError err = SKGObjectBase::save(iInsertOrUpdate, iReloadAfterSave);
 
-    //Raise alarm
+    // Raise alarm
     if (!err && getActionType() == ALARM) err = execute();
 
     return err;
@@ -156,7 +157,9 @@ QString SKGRuleObject::getSelectSqlOrder(const QString& iAdditionalCondition) co
     QString wc2 = SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), getXMLSearchDefinition(), true, SEARCH);
     if (!wc2.isEmpty()) {
         if (wc.isEmpty()) wc = wc2;
-        else wc = '(' % wc % ") AND (" % wc2 % ')';
+        else {
+            wc = '(' % wc % ") AND (" % wc2 % ')';
+        }
     }
     if (wc.isEmpty()) wc = "1=1";
     wc = "d_date!='0000-00-00' AND (" % wc % ')';
@@ -168,7 +171,7 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
     SKGTRACEIN(10, "SKGRuleObject::getAlarmInfo");
     SKGRuleObject::SKGAlarmInfo alarm;
     if (getActionType() == SKGRuleObject::ALARM) {
-        //Alarm mode
+        // Alarm mode
         QString wc = getSelectSqlOrder();
         if (wc.isEmpty()) wc = "1=1";
 
@@ -197,22 +200,25 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
     SKGError err;
     SKGTRACEINRC(10, "SKGRuleObject::execute", err);
     if (getActionType() == SKGRuleObject::UPDATE) {
-        //Update mode
+        // Update mode
         QString addSql;
         if (iMode == IMPORTED) addSql = "t_imported!='N'";
-        else if (iMode == IMPORTEDNOTVALIDATE) addSql = "t_imported='P'";
-        else if (iMode == IMPORTING) addSql = "t_imported='T'";
+        else if (iMode == IMPORTEDNOTVALIDATE) {
+            addSql = "t_imported='P'";
+        } else if (iMode == IMPORTING) {
+            addSql = "t_imported='T'";
+        }
 
         QString wc = getSelectSqlOrder(addSql);
         if (wc.isEmpty()) wc = "1=1";
 
         SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
         if (doc) {
-            QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true);  //SQL + SET clause
+            QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true);  // SQL + SET clause
             int nb = list.count();
             err = doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Apply rule"), nb);
             IFOK(err) {
-                //All sql orders must be executed to be sure than i_tmp is reset
+                // All sql orders must be executed to be sure than i_tmp is reset
                 SKGError err2;
                 for (int i = 0; i < nb; ++i) {
                     QString sql = list.at(i);
@@ -227,15 +233,15 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 SKGStringListList result;
                 err = doc->executeSelectSqliteOrder("SELECT changes()", result);
                 if (!err && result.count() == 2) {
-                    int nb = SKGServices::stringToInt(result.at(1).at(0));
-                    if (nb) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nb, getAttribute("i_ORDER")));
+                    int nbChanges = SKGServices::stringToInt(result.at(1).at(0));
+                    if (nbChanges) doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nbChanges, getAttribute("i_ORDER")));
                 }
             }
 
             SKGENDTRANSACTION(doc,  err);
         }
     } else if (getActionType() == SKGRuleObject::ALARM) {
-        //Alarm mode
+        // Alarm mode
         QString wc = getSelectSqlOrder();
         if (wc.isEmpty()) wc = "1=1";
 
@@ -249,7 +255,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 SKGStringListList result;
                 err = doc->executeSelectSqliteOrder(sql, result);
                 if (!err && result.count() == 2) {
-                    //Is alarm raised ?
+                    // Is alarm raised ?
                     if (result.at(1).at(0) == "1") doc->sendMessage(result.at(1).at(3));
                 }
             }
@@ -377,7 +383,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
 {
     QStringList output;
     if (iType == UPDATE) {
-        //Mode update
+        // Mode update
         if (iAttributeType == SKGServices::TEXT) {
             output.push_back("#ATT#='#V1S#'");
             output.push_back("#ATT#=lower(#ATT#)");
@@ -398,7 +404,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#=WORD(#ATT2#,#V1S#)");
         }
     } else if (iType == SEARCH) {
-        //Mode query
+        // Mode query
         if (iAttributeType == SKGServices::TEXT) {
             output.push_back("#ATT# LIKE '%#V1S#%'");
             output.push_back("#ATT# LIKE '#V1S#%'");
@@ -464,7 +470,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
 {
     QStringList output;
     if (iFullUpdate) {
-        //Add markers
+        // Add markers
         output.push_back("UPDATE v_operation_prop set i_tmp=1 WHERE #WC#");
     }
 
@@ -483,14 +489,14 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
             while (!n.isNull()) {
                 QDomElement element = n.toElement();
                 if (!element.isNull()) {
-                    //Build element description
+                    // Build element description
                     QString elementDescription;
                     QString attribute = element.attribute("attribute");
                     QString propName;
                     if (iSQL) {
                         attribute = SKGServices::stringToSqlString(attribute);
                         if (attribute.startsWith(QLatin1String("p_"))) {
-                            //Case property
+                            // Case property
                             propName = attribute.right(attribute.length() - 2);
                             if (iType == SEARCH) {
                                 attribute = "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND i_PROPVALUE";
@@ -529,7 +535,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
 
                     elementDescription = elementDescription.replace("#ATT#", attribute);
 
-                    //Att2
+                    // Att2
                     QString attribute2 = element.attribute("att2");
                     if (iSQL) {
                         attribute2 = SKGServices::stringToSqlString(attribute2);
@@ -544,7 +550,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                     }
                     elementDescription = elementDescription.replace("#ATT2#", attribute2);
 
-                    //Add it to line description
+                    // Add it to line description
                     if (iSQL) {
                         if (iType == UPDATE) {
                             if (!iFullUpdate) {
@@ -562,18 +568,24 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                         if (posSeparator == -1) {
                                             if (parentcat.isEmpty())
                                                 output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "', 0)");
-                                            else output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                            else {
+                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                            }
                                             stop = true;
                                         } else {
-                                            //Get first and second parts of the branch
+                                            // Get first and second parts of the branch
                                             QString first = cat.mid(0, posSeparator);
                                             QString second = cat.mid(posSeparator + QString(OBJECTSEPARATOR).length(), cat.length() - posSeparator - QString(OBJECTSEPARATOR).length());
                                             if (parentcat.isEmpty())
                                                 output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "', 0)");
-                                            else output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                            else {
+                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                            }
 
                                             if (parentcat.isEmpty()) parentcat = first;
-                                            else parentcat = parentcat % OBJECTSEPARATOR % first;
+                                            else {
+                                                parentcat = parentcat % OBJECTSEPARATOR % first;
+                                            }
                                             cat = second;
                                         }
                                     }
@@ -609,7 +621,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
     }
 
     if (iFullUpdate) {
-        //Remove markers
+        // Remove markers
         output.push_back("UPDATE v_operation_prop set i_tmp=0 WHERE i_tmp=1");
     }
     return output;
