@@ -31,7 +31,7 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGTrackerObject : public SKGNamedObject
 {
-    Q_OBJECT;
+    Q_OBJECT
 
 public:
     /**
@@ -51,7 +51,7 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGTrackerObject(const SKGObjectBase& iObject);
+    explicit SKGTrackerObject(const SKGObjectBase& iObject);
 
     /**
      * Operator affectation
