@@ -22,7 +22,7 @@
   Boston, MA 02110-1301, USA.
 */
 
-//krazy:excludeall=qclasses as we want to subclass from QComboBox, not KComboBox
+// krazy:excludeall=qclasses as we want to subclass from QComboBox, not KComboBox
 
 #include "kdateedit.h"
 
@@ -74,9 +74,9 @@ KDateEdit::KDateEdit(QWidget* iParent)
     setupKeywords();
     lineEdit()->installEventFilter(this);
 
-    KDateValidator* validator = new KDateValidator(this);
-    validator->setKeywords(mKeywordMap.keys());
-    setValidator(validator);
+    KDateValidator* newValidator = new KDateValidator(this);
+    newValidator->setKeywords(mKeywordMap.keys());
+    setValidator(newValidator);
 
     mTextChanged = false;
 }
@@ -85,9 +85,9 @@ KDateEdit::~KDateEdit()
 {
 }
 
-void KDateEdit::setDate(const QDate& date)
+void KDateEdit::setDate(const QDate& iDate)
 {
-    assignDate(date);
+    assignDate(iDate);
     updateView();
 }
 
@@ -148,8 +148,8 @@ void KDateEdit::showPopup()
     // The combo box is now shown pressed. Make it show not pressed again
     // by causing its (invisible) list box to emit a 'selected' signal.
     // First, ensure that the list box contains the date currently displayed.
-    QDate date = parseDate();
-    assignDate(date);
+    QDate date2 = parseDate();
+    assignDate(date2);
     updateView();
 
     // Now, simulate an Enter to unpress it
@@ -162,14 +162,14 @@ void KDateEdit::showPopup()
     }
 }
 
-void KDateEdit::dateSelected(const QDate& date)
+void KDateEdit::dateSelected(const QDate& iDate)
 {
-    if (assignDate(date)) {
+    if (assignDate(iDate)) {
         updateView();
-        emit dateChanged(date);
-        emit dateEntered(date);
+        emit dateChanged(iDate);
+        emit dateEntered(iDate);
 
-        if (date.isValid()) {
+        if (iDate.isValid()) {
             mPopup->hide();
         }
     }
@@ -179,15 +179,15 @@ void KDateEdit::lineEnterPressed()
 {
     bool replaced = false;
 
-    QDate date = parseDate(&replaced);
+    QDate date2 = parseDate(&replaced);
 
-    if (assignDate(date)) {
+    if (assignDate(date2)) {
         if (replaced) {
             updateView();
         }
 
-        emit dateChanged(date);
-        emit dateEntered(date);
+        emit dateChanged(date2);
+        emit dateEntered(date2);
     }
 }
 
@@ -247,49 +247,49 @@ void KDateEdit::focusOutEvent(QFocusEvent* e)
 
 void KDateEdit::keyPressEvent(QKeyEvent* e)
 {
-    QDate date;
+    QDate date2;
 
     if (!mReadOnly) {
         switch (e->key()) {
         case Qt::Key_Up:
-            date = parseDate();
-            if (!date.isValid()) break;
-            if (e->modifiers() & Qt::ControlModifier) { //Warning OSX: The KeypadModifier value will also be set when an arrow key is pressed as the arrow keys are considered part of the keypad.
-                date = date.addMonths(1);
+            date2 = parseDate();
+            if (!date2.isValid()) break;
+            if (e->modifiers() & Qt::ControlModifier) {  // Warning OSX: The KeypadModifier value will also be set when an arrow key is pressed as the arrow keys are considered part of the keypad.
+                date2 = date2.addMonths(1);
             } else {
-                date = date.addDays(1);
+                date2 = date2.addDays(1);
             }
             break;
         case Qt::Key_Down:
-            date = parseDate();
-            if (!date.isValid()) break;
-            if (e->modifiers() & Qt::ControlModifier) { //Warning OSX: The KeypadModifier value will also be set when an arrow key is pressed as the arrow keys are considered part of the keypad.
-                date = date.addMonths(-1);
+            date2 = parseDate();
+            if (!date2.isValid()) break;
+            if (e->modifiers() & Qt::ControlModifier) {  // Warning OSX: The KeypadModifier value will also be set when an arrow key is pressed as the arrow keys are considered part of the keypad.
+                date2 = date2.addMonths(-1);
             } else {
-                date = date.addDays(-1);
+                date2 = date2.addDays(-1);
             }
             break;
         case Qt::Key_PageUp:
-            date = parseDate();
-            if (!date.isValid()) break;
-            date = date.addMonths(1);
+            date2 = parseDate();
+            if (!date2.isValid()) break;
+            date2 = date2.addMonths(1);
             break;
         case Qt::Key_PageDown:
-            date = parseDate();
-            if (!date.isValid()) break;
-            date = date.addMonths(-1);
+            date2 = parseDate();
+            if (!date2.isValid()) break;
+            date2 = date2.addMonths(-1);
             break;
         case Qt::Key_Equal:
-            date = QDate::currentDate();
+            date2 = QDate::currentDate();
             break;
         default: {}
         }
 
-        if (date.isValid() && assignDate(date)) {
+        if (date2.isValid() && assignDate(date2)) {
             e->accept();
             updateView();
-            emit dateChanged(date);
-            emit dateEntered(date);
+            emit dateChanged(date2);
+            emit dateEntered(date2);
             return;
         }
     }
@@ -297,17 +297,17 @@ void KDateEdit::keyPressEvent(QKeyEvent* e)
     QComboBox::keyPressEvent(e);
 }
 
-bool KDateEdit::eventFilter(QObject* object, QEvent* event)
+bool KDateEdit::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (object == lineEdit()) {
+    if (iObject == lineEdit()) {
         // We only process the focus out event if the text has changed
         // since we got focus
-        if ((event->type() == QEvent::FocusOut) && mTextChanged) {
+        if ((iEvent->type() == QEvent::FocusOut) && mTextChanged) {
             lineEnterPressed();
             mTextChanged = false;
-        } else if (event->type() == QEvent::KeyPress) {
+        } else if (iEvent->type() == QEvent::KeyPress) {
             // Up and down arrow keys step the date
-            QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+            QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
 
             if (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) {
                 lineEnterPressed();
@@ -321,10 +321,10 @@ bool KDateEdit::eventFilter(QObject* object, QEvent* event)
 
 void KDateEdit::slotTextChanged(const QString&)
 {
-    QDate date = parseDate();
+    QDate date2 = parseDate();
 
-    if (assignDate(date)) {
-        emit dateChanged(date);
+    if (assignDate(date2)) {
+        emit dateChanged(date2);
     }
 
     mTextChanged = true;
@@ -352,9 +352,9 @@ void KDateEdit::setupKeywords()
     setCompleter(comp);
 }
 
-bool KDateEdit::assignDate(const QDate& date)
+bool KDateEdit::assignDate(const QDate& iDate)
 {
-    mDate = date;
+    mDate = iDate;
     mTextChanged = false;
     return true;
 }
