@@ -20,20 +20,21 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgboardwidget.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
-#include "skgzoomselector.h"
 
 #include <QToolButton>
 #include <QPushButton>
-#include <kmenu.h>
+#include <KMenu>
+
+#include "skgtraces.h"
+#include "skgmainpanel.h"
+#include "skgzoomselector.h"
 
 SKGBoardWidget::SKGBoardWidget(SKGDocument* iDocument, const QString& iTitle, bool iZoomable)
     : SKGWidget(iDocument), m_title(iTitle), m_menu(NULL), m_zoomMenu(NULL), m_zoomRatio(1.0)
 {
     SKGTRACEIN(10, "SKGBoardWidget::SKGBoardWidget");
 
-    //Created widgets
+    // Created widgets
     QHBoxLayout* horizontalLayout = new QHBoxLayout(this);
     horizontalLayout->setSpacing(0);
     horizontalLayout->setContentsMargins(0, 0, 0, 0);
@@ -55,9 +56,9 @@ SKGBoardWidget::SKGBoardWidget(SKGDocument* iDocument, const QString& iTitle, bo
     m_gridLayout->addWidget(m_toolButton, 0, 0, 1, 1);
 
     m_Title = new QLabel(m_frame);
-    QFont font = m_Title->font();
-    font.setBold(true);
-    m_Title->setFont(font);
+    QFont boldFont = m_Title->font();
+    boldFont.setBold(true);
+    m_Title->setFont(boldFont);
     m_Title->setAlignment(Qt::AlignCenter);
     m_Title->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed));
 
@@ -73,7 +74,7 @@ SKGBoardWidget::SKGBoardWidget(SKGDocument* iDocument, const QString& iTitle, bo
 
     horizontalLayout->addWidget(m_frame);
 
-    //Add default actions
+    // Add default actions
     QWidget* w = new QWidget(this);
     QHBoxLayout* hlayoutMove = new QHBoxLayout(w);
     hlayoutMove->setSpacing(2);
@@ -138,10 +139,10 @@ SKGBoardWidget::SKGBoardWidget(SKGDocument* iDocument, const QString& iTitle, bo
     sep->setSeparator(true);
     addAction(sep);
 
-    //Set main title
+    // Set main title
     setMainTitle(iTitle);
 
-    //Set default icon
+    // Set default icon
     m_toolButton->setIcon(KIcon("configure"));
 }
 
@@ -189,17 +190,19 @@ void SKGBoardWidget::setZoomRation(double iRation)
 {
     if (m_zoomMenu) {
         if (m_zoomRatio == 1.0) {
-            //Memorize initial size
+            // Memorize initial size
             m_initialSize = minimumSize();
         }
 
-        //Move zoom widget
+        // Move zoom widget
         m_zoomRatio = iRation;
         if (m_zoomRatio < 1.0) m_zoomRatio = 1.0;
-        else if (m_zoomRatio > 5.0) m_zoomRatio = 5.0;
+        else if (m_zoomRatio > 5.0) {
+            m_zoomRatio = 5.0;
+        }
         m_zoomMenu->setValue(5.0 * iRation - 15.0, false);
 
-        //Resize widget
+        // Resize widget
         QSize newSize(m_initialSize.width()*iRation, m_initialSize.height()*iRation);
         setMinimumSize(newSize);
     }
@@ -225,7 +228,7 @@ void SKGBoardWidget::insertAction(int iPos, QAction* iAction)
 {
     m_menu->insertAction(m_menu->actions()[iPos], iAction);
 
-    //Change icon
+    // Change icon
     if (!iAction->isCheckable() && !iAction->isSeparator()) m_toolButton->setIcon(KIcon("run-build-configure"));
 }
 
@@ -238,7 +241,7 @@ void SKGBoardWidget::addAction(QAction* iAction)
     }
     m_menu->addAction(iAction);
 
-    //Change icon
+    // Change icon
     if (!iAction->isCheckable() && !iAction->isSeparator()) m_toolButton->setIcon(KIcon("run-build-configure"));
 }
 
