@@ -20,17 +20,18 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgcalculatoredit.h"
-#include "skgservices.h"
-#include "skgtraces.h"
 
-#include <kglobal.h>
-#include <klocale.h>
-#include <kcolorscheme.h>
+#include <KGlobal>
+#include <KLocale>
+#include <KColorScheme>
 
 #include <QDoubleValidator>
 #include <QKeyEvent>
 #include <QScriptEngine>
 
+#include "skgservices.h"
+#include "skgtraces.h"
+
 SKGCalculatorEdit::SKGCalculatorEdit(QWidget* iParent)
     : KLineEdit(iParent), m_lastValue(0), m_lastOperator(0), m_valid(true)
 {
@@ -51,8 +52,11 @@ double SKGCalculatorEdit::value()
 int SKGCalculatorEdit::sign() const
 {
     QString t = text();
-    if (t.count() && t[0] == '+') return 1;
-    else if (t.count() && t[0] == '-') return -1;
+    if (t.count() && t[0] == '+') {
+        return 1;
+    } else if (t.count() && t[0] == '-') {
+        return -1;
+    }
     return 0;
 }
 
@@ -65,8 +69,8 @@ void SKGCalculatorEdit::setMode(Mode iMode)
 {
     m_currentMode = iMode;
     if (iMode == CALCULATOR) {
-        QDoubleValidator* validator = new QDoubleValidator(this);
-        setValidator(validator);
+        QDoubleValidator* newValidator = new QDoubleValidator(this);
+        setValidator(newValidator);
         setAlignment(Qt::AlignRight);
     } else {
         setValidator(NULL);
@@ -80,23 +84,23 @@ void SKGCalculatorEdit::setValue(double iValue)
 
 void SKGCalculatorEdit::setText(const QString& iText)
 {
-    //Set default color
+    // Set default color
     QPalette field_palette = palette();
     field_palette.setColor(QPalette::Text, m_fontColor);
     setPalette(field_palette);
     m_valid = true;
 
-    //Set text (to be sure than keyPressEvent is able to get it)
+    // Set text (to be sure than keyPressEvent is able to get it)
     KLineEdit::setText(iText);
 
-    //Simulate a validation
+    // Simulate a validation
     if (mode() == EXPRESSION) {
         bool previous = this->blockSignals(true);
         keyPressEvent(Qt::Key_Return);
         this->blockSignals(previous);
     }
 
-    //Set text (to display the input value)
+    // Set text (to display the input value)
     if (m_valid) KLineEdit::setText(iText);
 }
 
@@ -114,38 +118,40 @@ void SKGCalculatorEdit::addParameterValue(const QString& iParameter, double iVal
 {
     m_parameters.insert(iParameter, iValue);
 
-    //Refresh completion
+    // Refresh completion
     KCompletion* comp = this->completionObject();
     if (comp) comp->addItem('=' % iParameter);
 }
 
-void SKGCalculatorEdit::keyPressEvent(QKeyEvent* event)
+void SKGCalculatorEdit::keyPressEvent(QKeyEvent* iEvent)
 {
-    if (event) {
-        int key = event->key();
+    if (iEvent) {
+        int key = iEvent->key();
         if (mode() == CALCULATOR) {
             bool hasText = !text().isEmpty() && selectedText() != text();
 
-            if (event->count() == 1 && ((key == Qt::Key_Plus && hasText) || (key == Qt::Key_Minus && hasText) || key == Qt::Key_Asterisk || key == Qt::Key_Slash || key == Qt::Key_Return || key == Qt::Key_Enter)) {
+            if (iEvent->count() == 1 && ((key == Qt::Key_Plus && hasText) || (key == Qt::Key_Minus && hasText) || key == Qt::Key_Asterisk || key == Qt::Key_Slash || key == Qt::Key_Return || key == Qt::Key_Enter)) {
                 keyPressEvent(key);
-                event->accept();
-            } else KLineEdit::keyPressEvent(event);
+                iEvent->accept();
+            } else {
+                KLineEdit::keyPressEvent(iEvent);
+            }
         } else {
-            //Set default color
+            // Set default color
             QPalette field_palette = palette();
             field_palette.setColor(QPalette::Text, m_fontColor);
             setPalette(field_palette);
 
             keyPressEvent(key);
-            KLineEdit::keyPressEvent(event);
+            KLineEdit::keyPressEvent(iEvent);
         }
     }
 }
 
-void SKGCalculatorEdit::focusOutEvent(QFocusEvent* event)
+void SKGCalculatorEdit::focusOutEvent(QFocusEvent* iEvent)
 {
     keyPressEvent(Qt::Key_Return);
-    KLineEdit::focusOutEvent(event);
+    KLineEdit::focusOutEvent(iEvent);
 }
 
 void SKGCalculatorEdit::keyPressEvent(int key)
@@ -204,14 +210,14 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
     QString t = text().trimmed();
     if (!t.isEmpty()) {
         m_formula = t;
-        t = t.replace(',', '.'); // Replace comma by a point in case of typo
+        t = t.replace(',', '.');  // Replace comma by a point in case of typo
         KLocale* loc = KGlobal::locale();
         if (loc) {
             if (!loc->thousandsSeparator().isEmpty()) t = t.replace(loc->thousandsSeparator(), ".");
             if (!loc->monetaryThousandsSeparator().isEmpty()) t = t.replace(loc->monetaryThousandsSeparator(), ".");
         }
 
-        //Remove double . in numbers
+        // Remove double . in numbers
         int toRemoveIndex = -1;
         int nbc = t.count();
         for (int i = 0; i < nbc; ++i) {
@@ -221,8 +227,12 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
                     --nbc;
                     --i;
                     toRemoveIndex = i;
-                } else toRemoveIndex = i;
-            } else if (t[i] < '0' || t[i] > '9') toRemoveIndex = -1;
+                } else {
+                    toRemoveIndex = i;
+                }
+            } else if (t[i] < '0' || t[i] > '9') {
+                toRemoveIndex = -1;
+            }
         }
         if (t.startsWith(QLatin1String("="))) {
             t = t.right(t.length() - 1);
@@ -232,7 +242,9 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
                 t.replace(i.key(), SKGServices::doubleToString(i.value()));
             }
 
-        } else m_formula = "";
+        } else {
+            m_formula = "";
+        }
 
         QScriptEngine myEngine;
         QScriptValue result = myEngine.evaluate(t);
