@@ -20,9 +20,10 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgcolorbutton.h"
-#include "skglineedit.h"
 
-#include <qtextstream.h>
+#include <QTextStream>
+
+#include "skglineedit.h"
 
 SKGColorButton::SKGColorButton(QWidget* iParent)
     : QWidget(iParent)
