@@ -147,7 +147,7 @@ void SKGFilteredTableView::setModel(SKGObjectModelBase* iModel)
 
         connect(m_objectModel, SIGNAL(beforeReset()), ui.kView, SLOT(saveSelection()));
         connect(m_objectModel, SIGNAL(afterReset()), ui.kView, SLOT(resetSelection()));
-        connect(m_objectModel->getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+        connect(m_objectModel->getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     }
     dataModified("", 0);
 }
