@@ -20,20 +20,22 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgfilteredtableviewdesignerplugin.h"
-#include "skgfilteredtableview.h"
 
-#include <kicon.h>
+#include <KIcon>
 
 #include <QtPlugin>
 
+#include "skgfilteredtableview.h"
+
 SKGFilteredTableViewDesignerPlugin::SKGFilteredTableViewDesignerPlugin(QObject* iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGFilteredTableViewDesignerPlugin::initialize(QDesignerFormEditorInterface* /* core */)
+void SKGFilteredTableViewDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
 {
+    Q_UNUSED(iCore);
     if (m_initialized) return;
 
     m_initialized = true;
