@@ -21,19 +21,19 @@
  */
 #include "skgflowlayout.h"
 
-#include <qlayout.h>
-#include <qwidget.h>
+#include <QLayout>
+#include <QWidget>
 
-SKGFlowLayout::SKGFlowLayout(QWidget* iParent, int margin, int hSpacing, int vSpacing)
+SKGFlowLayout::SKGFlowLayout(QWidget* iParent, int iMargin, int hSpacing, int vSpacing)
     : QLayout(iParent), m_hSpace(hSpacing), m_vSpace(vSpacing)
 {
-    setContentsMargins(margin, margin, margin, margin);
+    setContentsMargins(iMargin, iMargin, iMargin, iMargin);
 }
 
-SKGFlowLayout::SKGFlowLayout(int margin, int hSpacing, int vSpacing)
+SKGFlowLayout::SKGFlowLayout(int iMargin, int hSpacing, int vSpacing)
     : QLayout(), m_hSpace(hSpacing), m_vSpace(vSpacing)
 {
-    setContentsMargins(margin, margin, margin, margin);
+    setContentsMargins(iMargin, iMargin, iMargin, iMargin);
 }
 
 SKGFlowLayout::~SKGFlowLayout()
@@ -142,21 +142,21 @@ int SKGFlowLayout::doLayout(const QRect& rect, bool testOnly) const
     foreach(QLayoutItem * item, m_itemList) {
         QWidget* wid = item->widget();
         if (wid) {
-            //Get spaces
+            // Get spaces
             int spaceX = horizontalSpacing();
             if (spaceX == -1) spaceX = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
 
             int spaceY = verticalSpacing();
             if (spaceY == -1) spaceY = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
 
-            //Try option
+            // Try option
             bool optionUsed = false;
             if (lineHeight && x1) {
                 int nextX = x1 + item->sizeHint().width() + spaceX;
                 if (nextX <= x && y1 - y + item->sizeHint().height() <= lineHeight) {
                     optionUsed = true;
 
-                    //Position item
+                    // Position item
                     if (!testOnly) item->setGeometry(QRect(QPoint(x1, y1), item->sizeHint()));
 
                     x1 = nextX;
@@ -172,7 +172,7 @@ int SKGFlowLayout::doLayout(const QRect& rect, bool testOnly) const
                     lineHeight = 0;
                 }
 
-                //Position item
+                // Position item
                 if (!testOnly) item->setGeometry(QRect(QPoint(x, y), item->sizeHint()));
 
                 x1 = x;
