@@ -22,7 +22,7 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include <QStringList>
-#include <kparts/part.h>
+#include <KParts/Part>
 
 #include "skgdocument.h"
 #include "skgtabpage.h"
@@ -71,8 +71,9 @@ public:
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
+     * @return true if the arguments have been processed
      */
-    virtual void processArguments(const QStringList& iArgument);
+    virtual bool processArguments(const QStringList& iArgument);
 
     /**
      * Must be modified to close properly the plugin.
@@ -201,11 +202,11 @@ public:
 
 private:
     Q_DISABLE_COPY(SKGInterfacePlugin)
-
 };
+
 /**
  * This plugin interface definition.
  */
 Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0")
 
-#endif // SKGINTERFACEPLUGIN_H
+#endif  // SKGINTERFACEPLUGIN_H
