@@ -21,7 +21,7 @@
  */
 #include "skglineedit.h"
 
-#include <klineedit.h>
+#include <KLineEdit>
 
 SKGLineEdit::SKGLineEdit(QWidget* iParent)
     : KLineEdit(iParent), m_substringCompletionMode(true)
@@ -42,11 +42,13 @@ void SKGLineEdit::setSubstringCompletionMode(bool iMode)
     m_substringCompletionMode = iMode;
 }
 
-void SKGLineEdit::makeCompletion(const QString& text)
+void SKGLineEdit::makeCompletion(const QString& iText)
 {
     if (m_substringCompletionMode && completionMode() == KGlobalSettings::CompletionPopup)
-        setCompletedItems(completionObject()->substringCompletion(text));
-    else KLineEdit::makeCompletion(text);
+        setCompletedItems(completionObject()->substringCompletion(iText));
+    else {
+        KLineEdit::makeCompletion(iText);
+    }
 }
 
 #include "skglineedit.moc"
