@@ -2061,14 +2061,17 @@ KMessageWidget* SKGMainPanel::displayErrorMessage(const QString& iMessage)
     return displayMessage(msg, SKGDocument::Error);
 }
 
-KMessageWidget* SKGMainPanel::displayErrorMessage(const SKGError& iError)
+KMessageWidget* SKGMainPanel::displayErrorMessage(const SKGError& iError, QAction* iAction)
 {
     SKGTRACEIN(1, "SKGMainPanel::displayErrorMessage");
     KMessageWidget* msg = NULL;
     SKGMainPanel* parent = SKGMainPanel::getMainPanel();
     if (parent) {
         if (iError) {
+            // Get the message
             msg = parent->displayErrorMessage(iError.getFullMessage());
+
+            // Add history action in case of
             if (iError.getHistoricalSize()) {
                 QAction* history = new QAction(i18nc("Noun", "History"), msg);
                 history->setIcon(KIcon("dialog-information"));
@@ -2077,6 +2080,13 @@ KMessageWidget* SKGMainPanel::displayErrorMessage(const SKGError& iError)
                 connect(history, SIGNAL(triggered(bool)), parent, SLOT(displayErrorMessage()));
                 connect(history, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
             }
+
+            // Add the additionnal action
+            if (iAction) {
+                iAction->setParent(msg);
+                msg->addAction(iAction);
+                connect(iAction, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
+            }
         } else {
             // Status bar
             QLabel* label = parent->statusNormalMessage();
