@@ -92,9 +92,10 @@ public:
     /**
      * Display an error message
      * @param iError the error
-     * @return the message widget*
+     * @param iAction the additionnal action to add
+     * @return the message widget
      */
-    static KMessageWidget* displayErrorMessage(const SKGError& iError);
+    static KMessageWidget* displayErrorMessage(const SKGError& iError, QAction* iAction = NULL);
 
     /**
      * Fill a widget with distinct values
