@@ -52,7 +52,7 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
 
     setTable(iTable);
 
-    connect(m_document, SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
+    connect(m_document, SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)));
     if (SKGMainPanel::getMainPanel()) connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
 }
 
