@@ -156,7 +156,8 @@ int SKGShow::count()
     return m_check_to_check.count();
 }
 
-int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, const QString& iIcon, const QString& iWhereClose, const QString& iGroup)
+int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
+                            const QString& iWhereClose, const QString& iGroup, const QKeySequence& iShortcut)
 {
     if (m_menu) {
         QActionGroup* groupAction = m_groups[iGroup];
@@ -173,6 +174,7 @@ int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, co
             act->setIcon(KIcon(iIcon));
             act->setData(iIdentifier);
             act->setCheckable(true);
+            if (!iShortcut.isEmpty()) act->setShortcut(iShortcut);
 
             m_check_to_check[act] = "";
             m_check_to_uncheck[act] = "";
@@ -200,7 +202,8 @@ int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QSt
                      const QString& iListIdToCheckWhenChecked ,
                      const QString& iListIdToUncheckWhenChecked ,
                      const QString& iListIdToCheckWhenUnchecked ,
-                     const QString& iListIdToUncheckWhenUnchecked
+                     const QString& iListIdToUncheckWhenUnchecked,
+                     const QKeySequence& iShortcut
                     )
 {
     if (m_menu) {
@@ -212,6 +215,7 @@ int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QSt
             act->setIcon(KIcon(iIcon));
             act->setData(iIdentifier);
             act->setCheckable(true);
+            if (!iShortcut.isEmpty()) act->setShortcut(iShortcut);
 
             m_check_to_check[act] = iListIdToCheckWhenChecked;
             m_check_to_uncheck[act] = iListIdToUncheckWhenChecked;
