@@ -156,6 +156,7 @@ public:
      * @param iListIdToUncheckWhenChecked list of item identifiers (separated by ;) to uncheck when unchecked Defaults to "".
      * @param iListIdToCheckWhenUnchecked list of item identifiers (separated by ;) to check when checked Defaults to "".
      * @param iListIdToUncheckWhenUnchecked list of item identifiers (separated by ;) to uncheck when unchecked Defaults to "".
+     * @param iShortcut the associated shortcut.
      * @return the index of the new item
      **/
     virtual int addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon = "",
@@ -163,7 +164,8 @@ public:
                         const QString& iListIdToCheckWhenChecked = "",
                         const QString& iListIdToUncheckWhenChecked = "",
                         const QString& iListIdToCheckWhenUnchecked = "",
-                        const QString& iListIdToUncheckWhenUnchecked = "");
+                        const QString& iListIdToUncheckWhenUnchecked = "",
+                        const QKeySequence& iShortcut = QKeySequence());
 
     /**
      * @brief Add an item to the menu
@@ -173,13 +175,15 @@ public:
      * @param iIcon icon Defaults to "".
      * @param iWhereClose icon Defaults to "".
      * @param iGroup the group of actions.
+     * @param iShortcut the associated shortcut.
      * @return the index of the new item
      **/
     virtual int addGroupedItem(const QString& iIdentifier,
                                const QString& iText,
                                const QString& iIcon = "",
                                const QString& iWhereClose = "",
-                               const QString& iGroup = "");
+                               const QString& iGroup = "",
+                               const QKeySequence& iShortcut = QKeySequence());
 
     /**
      * @brief Set the list of items to check when iIndex is checked
