@@ -20,20 +20,22 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgshowdesignerplugin.h"
-#include "skgshow.h"
 
-#include <kicon.h>
+#include <KIcon>
 
 #include <QtPlugin>
 
+#include "skgshow.h"
+
 SKGShowDesignerPlugin::SKGShowDesignerPlugin(QObject* iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGShowDesignerPlugin::initialize(QDesignerFormEditorInterface* /* core */)
+void SKGShowDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
 {
+    Q_UNUSED(iCore);
     if (m_initialized) return;
 
     m_initialized = true;
