@@ -20,12 +20,13 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgsortfilterproxymodel.h"
+
+#include <QRegExp>
+
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgobjectmodelbase.h"
 
-#include <QRegExp>
-
 SKGSortFilterProxyModel::SKGSortFilterProxyModel(QObject* iParent)
     : QSortFilterProxyModel(iParent)
 {
@@ -44,7 +45,7 @@ SKGSortFilterProxyModel::~SKGSortFilterProxyModel()
 bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
                                        const QModelIndex& right) const
 {
-    //Get source
+    // Get source
     SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(this->sourceModel());
     if (model) {
         QVariant leftData = model->data(left, Qt::UserRole);
@@ -52,14 +53,14 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
         SKGObjectBase* leftObj = model->getObjectPointer(left);
         if (leftData == rightData && leftObj) {
             if (leftObj->getTable().isEmpty() && left.column() != 0) {
-                //Groups
+                // Groups
                 return SKGSortFilterProxyModel::lessThan(model->index(left.row(), 0), model->index(right.row(), 0));
             }
             SKGObjectBase* rightObj = model->getObjectPointer(right);
             return (rightObj && leftObj->getID() < rightObj->getID());
         } else {
-            //For better performances, and avoid too many calls to QAbstractItemModel::data
-            //return QSortFilterProxyModel::lessThan(left, right);
+            // For better performances, and avoid too many calls to QAbstractItemModel::data
+            // return QSortFilterProxyModel::lessThan(left, right);
             switch (leftData.userType()) {
             case QVariant::Invalid:
                 return (rightData.type() != QVariant::Invalid);
@@ -99,13 +100,13 @@ bool SKGSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex
 {
     _SKGTRACEIN(10, "SKGSortFilterProxyModel::filterAcceptsRow");
 
-    //Initialisation
+    // Initialisation
     bool output = (filterRegExp().isEmpty());
     if (!output) {
-        //Build list of criterias
+        // Build list of criterias
         QList< SKGServices::SKGSearchCriteria > criterias = SKGServices::stringToSearchCriterias(filterRegExp().pattern());
 
-        //Check if at least one group validate the line
+        // Check if at least one group validate the line
         int nbList = criterias.count();
         output = false;
         for (int i = 0; i < nbList; ++i) {
@@ -113,7 +114,9 @@ bool SKGSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex
 
             bool validateAllWords =  filterAcceptsRowWords(source_row, source_parent, criterias[i].words);
             if (mode == '+') output |= validateAllWords;
-            else if (mode == '-' && validateAllWords) output = false;
+            else if (mode == '-' && validateAllWords) {
+                output = false;
+            }
         }
 
         if (!output) {
@@ -135,17 +138,17 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
 {
     _SKGTRACEIN(10, "SKGSortFilterProxyModel::filterAcceptsRowWords");
 
-    //Initialisation
+    // Initialisation
     bool output = true;
 
-    //Get source
+    // Get source
     QAbstractItemModel* model = this->sourceModel();
     if (model) {
         int nbwords = iWords.count();
         for (int w = 0; output && w < nbwords; ++w) {
             QString word = iWords.at(w);
 
-            //Is this word validated by at least one column ?
+            // Is this word validated by at least one column ?
             output = false;
             int nbcol = model->columnCount();
             for (int i = 0; !output && i < nbcol; ++i) {
