@@ -20,13 +20,14 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtablewidget.h"
-#include "skgtraces.h"
 
 #include <QKeyEvent>
 #include <QApplication>
 #include <QClipboard>
 #include <QScrollBar>
 
+#include "skgtraces.h"
+
 SKGTableWidget::SKGTableWidget(QWidget* iParent)
     : QTableWidget(iParent), stickH(false), stickV(false)
 {
@@ -43,18 +44,18 @@ SKGTableWidget::~SKGTableWidget()
 
 void SKGTableWidget::onRangeChanged()
 {
-    QScrollBar* scroll = qobject_cast<QScrollBar*>(sender());
-    if ((stickH && scroll == horizontalScrollBar()) || (stickV && scroll == verticalScrollBar())) {
-        scroll->setValue(scroll->maximum());
+    QScrollBar* scrollb = qobject_cast<QScrollBar*>(sender());
+    if ((stickH && scrollb == horizontalScrollBar()) || (stickV && scrollb == verticalScrollBar())) {
+        scrollb->setValue(scrollb->maximum());
     }
 }
 
 void SKGTableWidget::onActionTriggered()
 {
-    QScrollBar* scroll = qobject_cast<QScrollBar*>(sender());
-    if (scroll) {
-        if (scroll == horizontalScrollBar()) stickH = (scroll->value() == scroll->maximum());
-        if (scroll == verticalScrollBar()) stickV = (scroll->value() == scroll->maximum());
+    QScrollBar* scrollb = qobject_cast<QScrollBar*>(sender());
+    if (scrollb) {
+        if (scrollb == horizontalScrollBar()) stickH = (scrollb->value() == scrollb->maximum());
+        if (scrollb == verticalScrollBar()) stickV = (scrollb->value() == scrollb->maximum());
     }
 }
 
@@ -77,38 +78,38 @@ bool SKGTableWidget::stickVertical() const
     return stickV;
 }
 
-bool SKGTableWidget::eventFilter(QObject* object, QEvent* event)
+bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (object == this) {
-        QKeyEvent* kevent = dynamic_cast<QKeyEvent*>(event);
+    if (iObject == this && iEvent != NULL && iEvent->type() == QEvent::KeyPress) {
+        QKeyEvent* kevent = static_cast<QKeyEvent*>(iEvent);
         if (kevent) {
             if (kevent->key() == Qt::Key_Delete && state() != QAbstractItemView::EditingState) {
-                QList<QTableWidgetItem*> selectedItems = this->selectedItems();
-                int nb = selectedItems.count();
+                QList<QTableWidgetItem*> listOfSelectedItems = this->selectedItems();
+                int nb = listOfSelectedItems.count();
                 if (nb > 0) {
-                    //Build list of indexes
+                    // Build list of indexes
                     QList<int> listIndex;
                     for (int i = 0; i < nb; ++i) {
-                        QModelIndex mIndex = this->indexFromItem(selectedItems[i]);
+                        QModelIndex mIndex = this->indexFromItem(listOfSelectedItems[i]);
                         if (!listIndex.contains(mIndex.row())) listIndex.append(mIndex.row());
                     }
 
-                    //Sort reverse
+                    // Sort reverse
                     qSort(listIndex.begin(), listIndex.end(), qGreater<int>());
 
-                    //Emit events
+                    // Emit events
                     nb = listIndex.count();
                     for (int i = 0; i < nb; ++i) {
                         Q_EMIT removeLine(listIndex[i]);
                     }
 
-                    if (event) event->accept();
-                    return true; //stop the process
+                    if (iEvent) iEvent->accept();
+                    return true;  // stop the process
                 }
             } else if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
-                if (event) event->accept();
-                return true; //stop the process
+                if (iEvent) iEvent->accept();
+                return true;  // stop the process
             }
         }
     }
