@@ -76,11 +76,11 @@ Q_SIGNALS:
 protected:
     /**
      * Event filtering
-     * @param object object
-     * @param event event
+     * @param iObject object
+     * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* object, QEvent* event);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
 
 private Q_SLOTS:
     void copy();
@@ -92,4 +92,4 @@ private:
     bool stickV;
 };
 
-#endif // SKGTABLEWIDGET_H
+#endif  // SKGTABLEWIDGET_H
