@@ -21,16 +21,15 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <QWidget>
+
+#include <KGlobal>
 
 #include "skgbasegui_export.h"
 #include "ui_skgtablewithgraph.h"
 #include "skgcombobox.h"
 #include "skgservices.h"
 
-#include <qwidget.h>
-
-#include <kglobal.h>
-
 class SKGGraphicsScene;
 class KMenu;
 class QTimer;
@@ -147,7 +146,7 @@ public Q_SLOTS:
      * Returns the text report.
      * @return text report
      */
-    virtual SKGWebView* textReport() const ;
+    virtual SKGWebView* textReport() const;
 
     /**
      * Set Data
@@ -393,7 +392,7 @@ private Q_SLOTS:
     void refresh();
     void redrawText();
     void redrawGraph();
-    void showMenu(const QPoint& pos);
+    void showMenu(const QPoint& iPos);
 
 private:
     Q_DISABLE_COPY(SKGTableWithGraph)
@@ -464,4 +463,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(SKGTableWithGraph::DisplayAdditionalFlag)
 
-#endif // SKGTABLEWITHGRAPH_H
+#endif  // SKGTABLEWITHGRAPH_H
