@@ -20,6 +20,15 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtabpage.h"
+
+#include <KMessageBox>
+
+#include <QtGui/QWidget>
+#include <QWebView>
+
+#include <qmath.h>
+#include <math.h>
+
 #include "skgnodeobject.h"
 #include "skgservices.h"
 #include "skgdocument.h"
@@ -28,21 +37,13 @@
 #include "skgmainpanel.h"
 #include "skgtreeview.h"
 
-#include <kmessagebox.h>
-
-#include <QtGui/QWidget>
-#include <QWebView>
-
-#include <qmath.h>
-#include <math.h>
-
 SKGTabPage::SKGTabPage(SKGDocument* iDocument)
     : SKGWidget(iDocument), m_pin(false)
 {
     SKGTRACEIN(5, "SKGTabPage::SKGTabPage");
 
-    //Save original size
-    m_fontOriginalPointSize = this->font().pointSize(); //Use this instead of zoomableWidget()
+    // Save original size
+    m_fontOriginalPointSize = this->font().pointSize();  // Use this instead of zoomableWidget()
 }
 
 SKGTabPage::~SKGTabPage()
@@ -61,8 +62,7 @@ bool SKGTabPage::close(bool iForce)
                                           i18nc("Question", "Pinned page"),
                                           KStandardGuiItem::yes(),
                                           KStandardGuiItem::no(),
-                                          "closepinnedpage"
-                                         );
+                                          "closepinnedpage");
         QApplication::restoreOverrideCursor();
     }
     overwrite();
@@ -101,16 +101,16 @@ void SKGTabPage::setNextPages(const QList<SKGTabPage::SKGPageHistoryItem>& iPage
 
 bool SKGTabPage::isOverwriteNeeded()
 {
-    //Is this widget linked to a bookmark ?
+    // Is this widget linked to a bookmark ?
     if (!m_bookmarkID.isEmpty()) {
-        //Yes. Is state modified ?
+        // Yes. Is state modified ?
         SKGNodeObject node(getDocument(), SKGServices::stringToInt(m_bookmarkID));
         if (node.exist()) {
-            QStringList data = SKGServices::splitCSVLine(node.getData());
+            QStringList d = SKGServices::splitCSVLine(node.getData());
             QString fullname = node.getFullName();
-            if (data.count() > 2) {
+            if (d.count() > 2) {
                 QString currentState = getState().trimmed();
-                QString oldState = data[2].trimmed();
+                QString oldState = d[2].trimmed();
                 currentState.remove('\n');
                 oldState.remove('\n');
                 SKGTRACEL(20) << "oldState      =[" << oldState << ']' << endl;
@@ -120,7 +120,7 @@ bool SKGTabPage::isOverwriteNeeded()
             }
         }
     } else {
-        //No. It is a page opened from context or from another page
+        // No. It is a page opened from context or from another page
         QString name = getDefaultStateAttribute();
         if (!name.isEmpty()) {
             QString currentState = getState().trimmed();
@@ -138,16 +138,16 @@ bool SKGTabPage::isOverwriteNeeded()
 
 void SKGTabPage::overwrite(bool iUserConfirmation)
 {
-    //Is this widget linked to a bookmark ?
+    // Is this widget linked to a bookmark ?
     if (!m_bookmarkID.isEmpty()) {
-        //Yes. Is state modified ?
+        // Yes. Is state modified ?
         SKGNodeObject node(getDocument(), SKGServices::stringToInt(m_bookmarkID));
         if (node.exist()) {
-            QStringList data = SKGServices::splitCSVLine(node.getData());
+            QStringList d = SKGServices::splitCSVLine(node.getData());
             QString fullname = node.getFullName();
-            if (data.count() > 2) {
+            if (d.count() > 2) {
                 QString currentState = getState().trimmed();
-                QString oldState = data[2].trimmed();
+                QString oldState = d[2].trimmed();
                 currentState.remove('\n');
                 oldState.remove('\n');
                 SKGTRACEL(20) << "oldState      =[" << oldState << ']' << endl;
@@ -166,8 +166,8 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
                         SKGError err;
                         {
                             SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", fullname), err);
-                            data[2] = currentState;
-                            IFOKDO(err, node.setData(SKGServices::stringsToCsv(data)))
+                            d[2] = currentState;
+                            IFOKDO(err, node.setData(SKGServices::stringsToCsv(d)))
                             IFOKDO(err, node.save())
                         }
                         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Bookmark updated")))
@@ -177,7 +177,7 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
             }
         }
     } else {
-        //No. It is a page opened from context or from another page
+        // No. It is a page opened from context or from another page
         QString name = getDefaultStateAttribute();
         if (!name.isEmpty()) {
             QString currentState = getState().trimmed();
@@ -245,9 +245,9 @@ void SKGTabPage::setZoomPosition(int iValue)
         if (webView) {
             webView->setZoomFactor(qPow(10, static_cast<qreal>(iValue) / 30.0));
         } else if (widget) {
-            QFont font = widget->font();
-            font.setPointSize(qMax(1, m_fontOriginalPointSize + iValue));
-            widget->setFont(font);
+            QFont f = widget->font();
+            f.setPointSize(qMax(1, m_fontOriginalPointSize + iValue));
+            widget->setFont(f);
         }
     }
 }
@@ -261,7 +261,9 @@ int SKGTabPage::zoomPosition()
     else {
         QWebView* webView = qobject_cast<QWebView*>(widget);
         if (webView) output = qRound(30.0 * log10(webView->zoomFactor()));
-        else if (widget) output = widget->font().pointSize() - m_fontOriginalPointSize;
+        else if (widget) {
+            output = widget->font().pointSize() - m_fontOriginalPointSize;
+        }
     }
     return output;
 }
