@@ -21,13 +21,14 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include "skgbasegui_export.h"
-#include "skgwidget.h"
 
 #include <QWidget>
 #include <QList>
 
-#include <kglobal.h>
+#include <KGlobal>
+
+#include "skgbasegui_export.h"
+#include "skgwidget.h"
 
 class SKGMainPanel;
 class SKGTreeView;
@@ -49,7 +50,7 @@ public:
         QString state;      /**< The state */
         QString icon;       /**< The icon */
         QString bookmarkID;     /**< The bookmarkID */
-    } ;
+    };
 
     /**
      * Default Constructor
@@ -199,4 +200,4 @@ private:
  */
 Q_DECLARE_TYPEINFO(SKGTabPage::SKGPageHistoryItem, Q_PRIMITIVE_TYPE);
 
-#endif // SKGTABPAGE_H
+#endif  // SKGTABPAGE_H
