@@ -21,13 +21,13 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include "skgbasegui_export.h"
-
-#include <ktabwidget.h>
+#include <KTabWidget>
 
 #include <QMap>
 #include <QTimer>
 
+#include "skgbasegui_export.h"
+
 class QPushButton;
 
 /**
@@ -68,4 +68,4 @@ private:
     QMap<QWidget*, QPushButton*> m_tabIndexSaveButton;
 };
 
-#endif // SKGTABWIDGET_H
+#endif  // SKGTABWIDGET_H
