@@ -27,6 +27,7 @@
 #include <KLocale>
 #include <KFileDialog>
 #include <KStandardAction>
+#include <KTextBrowser>
 
 #include <QDomDocument>
 #include <QHeaderView>
@@ -44,6 +45,9 @@
 #include <QClipboard>
 #include <QTextCodec>
 #include <QPushButton>
+#include <qtextobject.h>
+#include <qtexttable.h>
+#include <QTextDocumentWriter>
 
 #include "skgtraces.h"
 #include "skgobjectmodelbase.h"
@@ -936,62 +940,107 @@ void SKGTreeView::setTextResizable(bool resizable)
     m_textResizable = resizable;
 }
 
-SKGStringListList SKGTreeView::getTable() const
+KTextBrowser* SKGTreeView::getTextBrowser() const
+{
+    KTextBrowser* output = new KTextBrowser();
+    QTextCursor cursor = output->textCursor();
+    cursor.beginEditBlock();
+
+    // Create table format
+    QTextTableFormat tableFormat;
+    tableFormat.setAlignment(Qt::AlignHCenter);
+    tableFormat.setAlignment(Qt::AlignLeft);
+    tableFormat.setBackground(QColor("#ffffff"));
+    tableFormat.setCellPadding(5);
+    tableFormat.setCellSpacing(5);
+
+    // Create table
+    SKGStringListList table = getTable();
+    int nbRows = table.count();
+    int nbCol = table.at(0).count();
+
+    QTextTable* tableau = cursor.insertTable(nbRows, nbCol, tableFormat);
+
+    //Create frame
+    QTextFrame* frame = cursor.currentFrame();
+    QTextFrameFormat frameFormat = frame->frameFormat();
+    frameFormat.setBorder(0);
+    frame->setFrameFormat(frameFormat);
+
+    // Create header table format
+    QTextCharFormat headerFormat;
+    headerFormat.setFontPointSize(15);
+    headerFormat.setFontWeight(QFont::Bold);
+
+    // Create text format
+    QTextCharFormat textFormat;
+    textFormat.setFontPointSize(12);
+
+    // Create header
+    for (int r = 0; r < nbRows; ++r) {
+        QStringList line = table.at(r);
+        for (int c = 0 ; c < nbCol ; ++c) {
+            QTextCursor cellCursor = tableau->cellAt(r, c).firstCursorPosition();
+            cellCursor.insertText(line.at(c) , (r == 0 ? headerFormat : textFormat));
+        }
+    }
+
+    // End
+    cursor.endEditBlock();
+
+    return output;
+}
+
+
+SKGStringListList SKGTreeView::getTable(const QModelIndex& iIndex) const
 {
     // Build table
     SKGStringListList table;
 
     // Get header names
     if (m_model) {
+        // Header
         int nb = m_model->columnCount();
-        QStringList cols;
-        for (int i = 0; i < nb; ++i) {
-            cols.append(m_model->headerData(i, Qt::Horizontal, Qt::UserRole).toString().split('|').at(0));
+        if (!iIndex.isValid()) {
+            QStringList cols;
+            for (int i = 0; i < nb; ++i) {
+                cols.append(m_model->headerData(i, Qt::Horizontal, Qt::UserRole).toString().split('|').at(0));
+            }
+            table.append(cols);
         }
-        table.append(cols);
 
         // Get content
-        table.append(getTableContent());
+        int nb2 = m_model->rowCount(iIndex);
+        for (int i = 0; i < nb2; ++i) {
+            QStringList row;
+            for (int j = 0; j < nb; j++) {
+                // We have to check the type for 214849
+                QModelIndex idx = m_model->index(i, j, iIndex);
+
+                SKGServices::AttributeType type = m_model->getAttributeType(j);
+                QString display = m_model->data(idx, type == SKGServices::FLOAT || m_model->getObject(idx).getTable().isEmpty() ?  Qt::DisplayRole : Qt::UserRole).toString();
+                if (display.isEmpty()) {
+                    display = m_model->data(idx, Qt::DisplayRole).toString();
+                }
+                row.append(display);
+            }
+
+            table.append(row);
+
+            QModelIndex idx0 = m_model->index(i, 0, iIndex);
+            if (m_model->hasChildren(idx0)) {
+                table.append(getTable(idx0));
+            }
+        }
     }
     return table;
 }
 
-SKGStringListList SKGTreeView::getTableContent(const QModelIndex& iIndex) const
-{
-    // Build table
-    SKGStringListList table;
-
-    int nb = m_model->columnCount();
-    int nb2 = m_model->rowCount(iIndex);
-    for (int i = 0; i < nb2; ++i) {
-        QStringList row;
-        for (int j = 0; j < nb; j++) {
-            // We have to check the type for 214849
-            QModelIndex idx = m_model->index(i, j, iIndex);
-
-            SKGServices::AttributeType type = m_model->getAttributeType(j);
-            QString display = m_model->data(idx, type == SKGServices::FLOAT || m_model->getObject(idx).getTable().isEmpty() ?  Qt::DisplayRole : Qt::UserRole).toString();
-            if (display.isEmpty()) display = m_model->data(idx, Qt::DisplayRole).toString();
-            row.append(display);
-        }
-
-        table.append(row);
-
-        QModelIndex idx0 = m_model->index(i, 0, iIndex);
-        if (m_model->hasChildren(idx0)) {
-            table.append(getTableContent(idx0));
-        }
-    }
-
-    return table;
-}
-
-
 SKGError SKGTreeView::exportInFile(const QString& iFileName)
 {
     SKGError err;
     _SKGTRACEIN(10, "SKGTreeView::exportInFile");
-    QString lastCodecUsed = QTextCodec::codecForLocale()->name();
+    QString codec = QTextCodec::codecForLocale()->name();
     QString extension = QFileInfo(iFileName).suffix().toUpper();
     if (extension == "CSV") {
         // Write file
@@ -999,7 +1048,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
         if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
         else {
             QTextStream out(&file);
-            out.setCodec(lastCodecUsed.toAscii().constData());
+            out.setCodec(codec.toAscii().constData());
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_CSV);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
@@ -1042,13 +1091,42 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
         generator.setViewBox(QRect(0, 0, w->widthMM(), w->heightMM()));
 
         painter.end();
+    } else if (extension == "HTML") {
+        // Write file
+        KSaveFile file(iFileName);
+        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
+        else {
+            QTextStream out(&file);
+            out.setCodec(codec.toAscii().constData());
+            KTextBrowser* tb = getTextBrowser();
+            if (tb) {
+                out << tb->toHtml().replace("<meta name=\"qrichtext\" content=\"1\" />", "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />") << endl;
+
+                delete tb;
+            }
+        }
+
+        // Close file
+        file.finalize();
+        file.close();
+    } else if (extension == "ODT") {
+        KTextBrowser* tb = getTextBrowser();
+        if (tb) {
+            QTextDocument doc;
+            doc.setHtml(tb->toHtml());
+
+            QTextDocumentWriter docWriter(iFileName);
+            docWriter.write(&doc);
+
+            delete tb;
+        }
     } else {
         // Write file
         KSaveFile file(iFileName);
         if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
         else {
             QTextStream out(&file);
-            out.setCodec(lastCodecUsed.toAscii().constData());
+            out.setCodec(codec.toAscii().constData());
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_TEXT);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
@@ -1068,8 +1146,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
 void SKGTreeView::onExport()
 {
     _SKGTRACEIN(10, "SKGTreeView::onExport");
-    QString lastCodecUsed = QTextCodec::codecForLocale()->name();
-    QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "text/csv text/plain image/svg+xml application/pdf" , this, QString(), &lastCodecUsed);
+    QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "text/csv text/plain text/html application/vnd.oasis.opendocument.text  image/svg+xml application/pdf" , this);
     if (!fileName.isEmpty()) {
         SKGError err = exportInFile(fileName);
         SKGMainPanel::displayErrorMessage(err);
