@@ -33,8 +33,9 @@
 #include "skgmainpanel.h"
 
 class SKGObjectModelBase;
-class QSortFilterProxyModel;
 class SKGDocument;
+class KTextBrowser;
+class QSortFilterProxyModel;
 class QTimer;
 
 /**
@@ -94,11 +95,18 @@ public:
     */
     virtual void setDefaultSaveParameters(SKGDocument* iDocument, const QString& iParameterName);
 
+    /**
+     * Get the table content as KTextBrowser
+     * @return the table content (MUST BE DELETED)
+     */
+    virtual KTextBrowser* getTextBrowser() const;
+
     /**
      * Get the table content
+     * @param iIndex the line index
      * @return the table content
      */
-    virtual SKGStringListList getTable() const;
+    virtual SKGStringListList getTable(const QModelIndex& iIndex = QModelIndex()) const;
 
     /**
      * Get the current selection
@@ -305,8 +313,6 @@ private Q_SLOTS:
     void onActionTriggered(int action);
     void onRangeChanged();
 
-    SKGStringListList getTableContent(const QModelIndex& iIndex = QModelIndex()) const;
-
 private:
     Q_DISABLE_COPY(SKGTreeView)
 
