@@ -17,15 +17,13 @@
 #ifndef SKGUNIQUEAPPLICATION_H
 #define SKGUNIQUEAPPLICATION_H
 /** @file
-* This file defines the main of an application.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
+ * This file defines the main of an application.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include "skgbasegui_export.h"
-
-#include <kuniqueapplication.h>
-
+#include <KUniqueApplication>
 #include <QTimer>
+#include "skgbasegui_export.h"
 
 class SKGDocument;
 class KSplashScreen;
@@ -75,4 +73,4 @@ private Q_SLOTS:
 private:
     QTimer m_timer;
 };
-#endif // SKGUNIQUEAPPLICATION_H
+#endif  // SKGUNIQUEAPPLICATION_H
