@@ -155,6 +155,12 @@ static const int ERR_ENCRYPTION = 12;
  */
 static const int ERR_INSTALL = 13;
 
+/**
+ * @var ERR_CORRUPTION
+ * Error number
+ */
+static const int ERR_CORRUPTION = 14;
+
 /**
  * @brief For a not modified field
  **/
