@@ -350,7 +350,19 @@ public Q_SLOTS:
     virtual SKGError initialize();
 
     /**
-     * load an existing document.
+     * Recover a corrupted file.
+     * WARNING: This method must NOT be used in a transaction.
+     * @see endTransaction
+     * @param iName the file name to load.
+     * @param iPassword the password of the SKGDocument.
+     * @param oRecoveredFile the recovered file.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError recover(const QString& iName, const QString& iPassword, QString& oRecoveredFile);
+
+    /**
+     * Load an existing document.
      * WARNING: This method must NOT be used in a transaction.
      * @see endTransaction
      * @param iName the file name to load.
@@ -513,10 +525,11 @@ public Q_SLOTS:
 
     /**
      * Refresh all views and indexes in the database
+     * @param iForce force the refresh
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError refreshViewsIndexesAndTriggers();
+    virtual SKGError refreshViewsIndexesAndTriggers(bool iForce = false);
 
     /**
      * Get the display string for any modeler object (table, attribute)
@@ -812,9 +825,10 @@ Q_SIGNALS:
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
      * @param iTableName the name of the modified table. iTableName="" if all tables must be refreshed
      * @param iIdTransaction the id of the transaction for direct modifications of the table (update of modify objects is enough)
+     * @param iLightTransaction to if the transaction is light
      *or 0 in case of modifications by impact (full table must be refreshed)
      */
-    void tableModified(const QString& iTableName, int iIdTransaction);
+    void tableModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction);
 
     /**
      * This signal is launched by endTransaction when a transaction is successfully ended
