@@ -35,7 +35,9 @@ SKGError::SKGError(const SKGError& iError)
     m_rc = iError.m_rc;
     m_message = iError.m_message;
     if (Q_UNLIKELY(iError.m_previousError != NULL)) m_previousError = new SKGError(*iError.m_previousError);
-    else m_previousError = NULL;
+    else {
+        m_previousError = NULL;
+    }
 }
 
 SKGError::~SKGError()
