@@ -20,13 +20,14 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgnodeobject.h"
+
+#include <KLocale>
+#include <KIcon>
+
 #include "skgtraces.h"
 #include "skgdefine.h"
 #include "skgdocument.h"
 
-#include <klocale.h>
-#include <kicon.h>
-
 SKGNodeObject::SKGNodeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_node", iID)
 {
 }
@@ -54,13 +55,15 @@ SKGError SKGNodeObject::setName(const QString& iName)
 {
     SKGError err;
     if (iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL, i18nc("Error message: an invalid character was found", "The name '%1' is invalid : the '%2' character is forbidden ", iName, QString(OBJECTSEPARATOR)));
-    else err = SKGNamedObject::setName(iName);
+    else {
+        err = SKGNamedObject::setName(iName);
+    }
     return err;
 }
 
 QString SKGNodeObject::getWhereclauseId() const
 {
-    //Could we use the id
+    // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
         if (!(getAttribute("t_name").isEmpty())) {
@@ -69,7 +72,9 @@ QString SKGNodeObject::getWhereclauseId() const
         QString rd_node_id = getAttribute("rd_node_id");
         if (!output.isEmpty()) output += " AND ";
         if (rd_node_id.isEmpty()) output += "(rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id='')";
-        else output += "rd_node_id=" % rd_node_id;
+        else {
+            output += "rd_node_id=" % rd_node_id;
+        }
     }
     return output;
 }
@@ -144,17 +149,17 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
     SKGError err;
     SKGTRACEINRC(10, "SKGNodeObject::createPathNode", err);
     SKGTRACEL(10) << "Input parameter [iFullPath]=" << iFullPath << endl;
-    //Check if node is already existing
+    // Check if node is already existing
     if (!iRenameIfAlreadyExist && iDocument) iDocument->getObject("v_node", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oNode);
     if (oNode.getID() == 0) {
-        //No, we have to create it
-        //Search node separator
+        // No, we have to create it
+        // Search node separator
         int posSeparator = iFullPath.lastIndexOf(OBJECTSEPARATOR);
         if (posSeparator == -1) {
             oNode = SKGNodeObject(iDocument);
             err = oNode.setName(iFullPath);
 
-            //Check if already existing
+            // Check if already existing
             if (!err && iRenameIfAlreadyExist) {
                 int index = 1;
                 while (!err && oNode.exist()) {
@@ -167,22 +172,22 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
             IFOKDO(err, oNode.setOrder(-1))
             IFOKDO(err, oNode.save())
         } else {
-            //Get first and second parts of the branch
+            // Get first and second parts of the branch
             QString first = iFullPath.mid(0, posSeparator);
             QString second = iFullPath.mid(posSeparator + QString(OBJECTSEPARATOR).length(), iFullPath.length() - posSeparator - QString(OBJECTSEPARATOR).length());
 
-            //Get first node
+            // Get first node
             SKGNodeObject FirstNode;
             err = SKGNodeObject::createPathNode(iDocument, first, FirstNode);
 
             IFOK(err) {
-                //Get second node
+                // Get second node
                 err = FirstNode.addNode(oNode);
 
-                //Add second under first
+                // Add second under first
                 IFOKDO(err, oNode.setName(second))
 
-                //Check if already existing
+                // Check if already existing
                 if (!err && iRenameIfAlreadyExist) {
                     int index = 2;
                     while (!err && oNode.exist()) {
@@ -191,7 +196,7 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
                     }
                 }
 
-                //save
+                // save
                 IFOKDO(err, oNode.setIcon("folder-bookmark"))
                 IFOKDO(err, oNode.setOrder(-1))
                 IFOKDO(err, oNode.save())
@@ -225,7 +230,7 @@ SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
     SKGTRACEINRC(10, "SKGNodeObject::setParentNode", err);
     if (iNode.getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::setParentNode")));
     else {
-        //Check if it's a loop
+        // Check if it's a loop
         SKGNodeObject current = iNode;
         do {
             if (current == *this) {
@@ -247,7 +252,9 @@ SKGError SKGNodeObject::getParentNode(SKGNodeObject& oNode) const
     SKGError err;
     QString parent_id = getAttribute("rd_node_id");
     if (!parent_id.isEmpty()) err = getDocument()->getObject("v_node", "id=" % parent_id , oNode);
-    else oNode = SKGNodeObject();
+    else {
+        oNode = SKGNodeObject();
+    }
     return err;
 }
 
