@@ -20,14 +20,16 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgobjectbase.h"
+
+#include <KLocale>
+
+#include <QSqlDatabase>
+#include <KStringHandler>
+
 #include "skgtraces.h"
 #include "skgdocument.h"
 #include "skgnamedobject.h"
 
-#include <klocale.h>
-
-#include <QSqlDatabase>
-#include <kstringhandler.h>
 /**
  * This private class of SKGObjectBase
  */
@@ -66,7 +68,7 @@ SKGObjectBase::SKGObjectBase(SKGDocument* iDocument, const QString& iTable, int
     d->id = iID;
     d->table = iTable;
     d->document = iDocument;
-    if (d->id != 0) load();
+    if (Q_LIKELY(d->id != 0)) load();
 }
 
 SKGObjectBase::~SKGObjectBase()
@@ -199,8 +201,10 @@ SKGError SKGObjectBase::setAttributes(const QStringList& iNames, const QStringLi
         QString att = iNames.at(i);
         QString val = iValues.at(i);
 
-        if (att != "id") err = setAttribute(att, val);
-        else  d->id = SKGServices::stringToInt(val);
+        if (Q_LIKELY(att != "id")) err = setAttribute(att, val);
+        else {
+            d->id = SKGServices::stringToInt(val);
+        }
     }
     return err;
 }
@@ -208,10 +212,10 @@ SKGError SKGObjectBase::setAttributes(const QStringList& iNames, const QStringLi
 SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue)
 {
     SKGError err;
-    if (iValue != NOUPDATE) {
+    if (Q_LIKELY(iValue != NOUPDATE)) {
         QString val = iValue;
 
-        //Case modification on pointed document
+        // Case modification on pointed document
         if (this->getRealTable() == this->getTable() && iName != iName.toLower()) {
             QString realAttribute = d->document->getRealAttribute(iName);
             if (!realAttribute.isEmpty()) {
@@ -228,17 +232,23 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
                     }
                 }
             }
-        }
-        //Case modificator
-        else if (iValue.startsWith(QLatin1String("="))) {
+        } else if (iValue.startsWith(QLatin1String("="))) {
+            // Case modificator
             QString op = iValue.right(iValue.length() - 1).toLower();
             val = d->attributes[iName];
-            if (op == i18nc("Key word to modify a string into a field", "lower")) val = val.toLower();
-            else if (op == i18nc("Key word to modify a string into a field", "upper")) val = val.toUpper();
-            else if (op == i18nc("Key word to modify a string into a field", "capwords")) val = KStringHandler::capwords(val);
-            else if (op == i18nc("Key word to modify a string into a field", "capitalize")) val = val.left(1).toUpper() % val.right(val.length() - 1).toLower();
-            else if (op == i18nc("Key word to modify a string into a field", "trim")) val = val.trimmed();
-            else val = iValue;
+            if (op == i18nc("Key word to modify a string into a field", "lower")) {
+                val = val.toLower();
+            } else if (op == i18nc("Key word to modify a string into a field", "upper")) {
+                val = val.toUpper();
+            } else if (op == i18nc("Key word to modify a string into a field", "capwords")) {
+                val = KStringHandler::capwords(val);
+            } else if (op == i18nc("Key word to modify a string into a field", "capitalize")) {
+                val = val.left(1).toUpper() % val.right(val.length() - 1).toLower();
+            } else if (op == i18nc("Key word to modify a string into a field", "trim")) {
+                val = val.trimmed();
+            } else {
+                val = iValue;
+            }
         }
         d->attributes[iName] = val;
     }
@@ -248,18 +258,18 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
 QString SKGObjectBase::getAttribute(const QString& iName) const
 {
     QString output;
-    if (d->attributes.contains(iName)) {
+    if (Q_LIKELY(d->attributes.contains(iName))) {
         output = d->attributes[iName];
     } else if (iName == "id") {
         output = SKGServices::intToString(getID());
     } else {
-        //Is the iName a number ?
+        // Is the iName a number ?
         bool ok;
         int pos = iName.toInt(&ok);
         if (ok) {
-            //What is the key corresponding to this name ?
+            // What is the key corresponding to this name ?
             QStringList keys = d->attributes.keys();
-            if (pos >= 0 && pos < keys.count()) output = d->attributes[keys[pos]];
+            if (pos >= 0 && pos < keys.count()) output = d->attributes[keys.at(pos)];
         }
     }
 
@@ -285,20 +295,20 @@ SKGError SKGObjectBase::load()
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::load", err);
 
-    if (getDocument() && !getTable().isEmpty()) {
-        //Prepare where clause
+    if (Q_LIKELY(getDocument() && !getTable().isEmpty())) {
+        // Prepare where clause
         QString wc = getWhereclauseId();
         if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
 
-        //Execute sql order
+        // Execute sql order
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT * FROM " % d->table % " WHERE " % wc, result);
         IFOK(err) {
             int size = result.size();
-            if (size == 1)  err = SKGError(ERR_INVALIDARG, i18nc("Error message: Could not load something because it is not in the database", "Load of '%1' with '%2' failed because it was not found in the database", d->table, wc));
-            else if (size != 2)  err = SKGError(ERR_INVALIDARG, i18np("Load of '%2' with '%3' failed because of bad size of result (found one object)",
-                                                    "Load of '%2' with '%3' failed because of bad size of result (found %1 objects)",
-                                                    size - 1, d->table, wc));
+            if (Q_UNLIKELY(size == 1))  err = SKGError(ERR_INVALIDARG, i18nc("Error message: Could not load something because it is not in the database", "Load of '%1' with '%2' failed because it was not found in the database", d->table, wc));
+            else if (Q_UNLIKELY(size != 2))  err = SKGError(ERR_INVALIDARG, i18np("Load of '%2' with '%3' failed because of bad size of result (found one object)",
+                                                       "Load of '%2' with '%3' failed because of bad size of result (found %1 objects)",
+                                                       size - 1, d->table, wc));
             else {
                 SKGStringListListIterator itrow = result.begin();
                 QStringList columns = *(itrow);
@@ -324,22 +334,22 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::save", err);
 
-    if (!d->document) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+    if (Q_UNLIKELY(!d->document)) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
     else {
-        //Save linking objects
+        // Save linking objects
         int nb = d->objects.count();
         for (int i = 0; !err && i < nb; ++i) {
             SKGObjectBase ref = d->objects.at(i);
             err = ref.save(iInsertOrUpdate, iReloadAfterSave);
         }
 
-        //Check if we are in a transaction
+        // Check if we are in a transaction
         IFOKDO(err, d->document->checkExistingTransaction())
         IFOK(err) {
-            //Table to use
+            // Table to use
             QString tablename = getRealTable();
 
-            //Build order
+            // Build order
             QString part1Insert;
             QString part2Insert;
             QString partUpdate;
@@ -348,7 +358,7 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
             for (it = d->attributes.begin() ; it != d->attributes.end(); ++it) {
                 QString att = SKGServices::stringToSqlString(it.key());
                 QString attlower = att.toLower();
-                if (att.length() > 2 && att == attlower) { //We must ignore attributes coming from views
+                if (att.length() > 2 && att == attlower) {  // We must ignore attributes coming from views
                     QString value = '\'' % SKGServices::stringToSqlString(it.value()) % '\'';
 
                     if (!part1Insert.isEmpty()) {
@@ -356,40 +366,40 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
                         part2Insert.append(',');
                         partUpdate.append(',');
                     }
-                    //Attribute
+                    // Attribute
                     part1Insert.append('\'' % att % '\'');
 
-                    //Value
+                    // Value
                     part2Insert.append(value);
 
-                    //Attribute=Value for update
+                    // Attribute=Value for update
                     partUpdate.append(att % '=' % value);
                 }
             }
 
-            //We try an Insert
+            // We try an Insert
             if (d->id == 0) {
-                //We have to try un insert
+                // We have to try un insert
                 err = getDocument()->executeSqliteOrder("INSERT INTO " % tablename % " (" % part1Insert % ") VALUES (" % part2Insert % ')', &(d->id));
             } else {
-                //We must try an update
-                err = SKGError(ERR_ABORT, ""); //Just to go in UPDATE code
+                // We must try an update
+                err = SKGError(ERR_ABORT, "");  // Just to go in UPDATE code
             }
 
             if (err && iInsertOrUpdate) {
-                //INSERT failed, could we try an update ?
+                // INSERT failed, could we try an update ?
                 QString wc = this->getWhereclauseId();
                 if (!wc.isEmpty()) {
-                    //Yes ==> Update
+                    // Yes ==> Update
                     err = getDocument()->executeSqliteOrder("UPDATE " % tablename % " SET " % partUpdate % " WHERE " % wc);
                 }
             }
         }
     }
 
-    //Reload object is updated
+    // Reload object is updated
     if (!err && iReloadAfterSave) {
-        //The object has been updated ==>load
+        // The object has been updated ==>load
         err = load();
     }
 
@@ -400,19 +410,19 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
 {
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::remove", err);
-    if (!d->document) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+    if (Q_UNLIKELY(!d->document)) err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
     else {
-        //Check if we are in a transaction
+        // Check if we are in a transaction
         err = d->document->checkExistingTransaction();
 
-        //delete order
+        // delete order
         QString viewForDelete = QString("v_") % getRealTable() % "_delete";
 
-        //Check if the delete view exist
+        // Check if the delete view exist
         SKGStringListList temporaryResult;
         d->document->executeSelectSqliteOrder("PRAGMA table_info( " % viewForDelete % " );", temporaryResult);
-        if (!iForce && temporaryResult.count() > 1) { //At least one attribute
-            //Delete view exists, check if the delete is authorized
+        if (!iForce && temporaryResult.count() > 1) {  // At least one attribute
+            // Delete view exists, check if the delete is authorized
             err = d->document->executeSelectSqliteOrder("SELECT t_delete_message FROM " % viewForDelete % " WHERE id=" % SKGServices::intToString(d->id), temporaryResult);
             IFOK(err) {
                 QString msg;
@@ -422,7 +432,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
             }
         }
 
-        QString displayname = getDisplayName(); //Must be done before the delete order
+        QString displayname = getDisplayName();  // Must be done before the delete order
         IFOKDO(err, d->document->executeSqliteOrder("DELETE FROM " % getRealTable() % " WHERE id=" % SKGServices::intToString(d->id)))
         if (iSendMessage && !err && !displayname.isEmpty())
             err = d->document->sendMessage(i18nc("An information to the user that something was deleted", "'%1' has been deleted", displayname), SKGDocument::Hidden);
@@ -433,7 +443,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
 
 SKGError SKGObjectBase::dump()
 {
-    //dump
+    // dump
     SKGTRACE << "=== START DUMP [" << getUniqueID() << "]===" << endl;
     SKGQStringQStringMapIterator it;
     for (it = d->attributes.begin() ; it != d->attributes.end(); ++it)
@@ -444,28 +454,27 @@ SKGError SKGObjectBase::dump()
 
 QStringList SKGObjectBase::getProperties() const
 {
-    return !getDocument() ? QStringList() : getDocument()->getParameters(getUniqueID());
+    return Q_UNLIKELY(!getDocument()) ? QStringList() : getDocument()->getParameters(getUniqueID());
 }
 
 QString SKGObjectBase::getProperty(const QString& iName) const
 {
-    return !getDocument() ? QString() : getDocument()->getParameter(iName, getUniqueID());
+    return Q_UNLIKELY(!getDocument()) ? QString() : getDocument()->getParameter(iName, getUniqueID());
 }
 
 QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
 {
-    return !getDocument() ? QVariant() : getDocument()->getParameterBlob(iName, getUniqueID());
+    return Q_UNLIKELY(!getDocument()) ? QVariant() : getDocument()->getParameterBlob(iName, getUniqueID());
 }
 
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated) const
 {
-    return !getDocument() ? SKGError() : getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
+    return Q_UNLIKELY(!getDocument()) ? SKGError() : getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
 }
 
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGPropertyObject* oObjectCreated) const
 {
-    return!getDocument() ? SKGError() :  getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
-
+    return Q_UNLIKELY(!getDocument()) ? SKGError() :  getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
 }
 
 #include "skgobjectbase.moc"
