@@ -19,20 +19,16 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include "skgreportbank.h"
-#include "skgtraces.h"
-#include "skgdocumentbank.h"
-#include "skgaccountobject.h"
-#include "skgunitobject.h"
+#include "skgreport.h"
 
-#include <kstandarddirs.h>
+#include <KStandardDirs>
 #include <grantlee/engine.h>
 #include <grantlee/templateloader.h>
 #include <grantlee/qtlocalizer.h>
 #include <grantlee/metatype.h>
-#include <kaboutdata.h>
-#include <kcomponentdata.h>
-#include <kcolorscheme.h>
+#include <KAboutData>
+#include <KComponentData>
+#include <KColorScheme>
 #include <KUrl>
 #include <KGlobalSettings>
 
@@ -41,6 +37,10 @@
 #include <QDir>
 #include <QFont>
 
+#include "skgtraces.h"
+#include "skgdocumentbank.h"
+#include "skgaccountobject.h"
+#include "skgunitobject.h"
 
 GRANTLEE_BEGIN_LOOKUP(SKGObjectBase)
 Q_UNUSED(object);
@@ -52,7 +52,7 @@ SKGReport::SKGReport(SKGDocument* iDocument)
 {
     SKGTRACEIN(1, "SKGReport::SKGReport");
 
-    //Grantlee initialization
+    // Grantlee initialization
     Grantlee::MetaType::init();
     Grantlee::registerMetaType<SKGObjectBase>();
 }
@@ -118,7 +118,7 @@ SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFi
     SKGTRACEINRC(10, "SKGReport::getReportFromTemplate", err);
     SKGDocument* doc = (iReport ? static_cast<SKGDocument*>(iReport->m_document) : NULL);
 
-    //Prepare grantlee engine
+    // Prepare grantlee engine
     Grantlee::Engine gEngine;
     const QStringList pluginDirs = KGlobal::dirs()->resourceDirs("qtplugins");
     foreach(const QString & pluginDir, pluginDirs) {
@@ -157,7 +157,7 @@ SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFi
     }
     Grantlee::Context gContext(mapping);
 
-    //Generation
+    // Generation
     {
         SKGTRACEINRC(10, "SKGReport::getReportFromTemplate-grantlee render", err);
         oHtml = gTemplate->render(&gContext);
