@@ -768,7 +768,9 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                     }
 
                     // Close the file
-                    fileOutput.finalize();
+                    if (!fileOutput.finalize()) {
+                        err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
+                    }
                     fileOutput.close();
                 }
             }
