@@ -21,18 +21,17 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-
-#include "skgerror.h"
-#include "skgdefine.h"
-#include "skgbasemodeler_export.h"
-
-#include <kurl.h>
+#include <KUrl>
 
 #include <QStringList>
 #include <QHash>
 #include <QDateTime>
 #include <QIcon>
 
+#include "skgerror.h"
+#include "skgdefine.h"
+#include "skgbasemodeler_export.h"
+
 /**
  * @var SQLLITEERROR
  * Must be used to generate a SKGError on an error coming from sqlite's API
@@ -146,7 +145,7 @@ public:
         AttributeType type;         /**< The type of the attribute */
         bool notnull;           /**< To know if the attribute can be null or not */
         QString defaultvalue;       /**< The default value of the attribute */
-    } ;
+    };
 
     /**
      * Search criteria
@@ -154,7 +153,7 @@ public:
     struct SKGSearchCriteria {
         QChar mode;              /**< The mode '+' or '-' */
         QStringList words;       /**< The list of words */
-    } ;
+    };
 
     /**
      * A list of SKGAttributeInfo ==> SKGAttributesList
@@ -186,7 +185,7 @@ public:
      * @param iAttribute name of the variable
      * @return value of the variable
      */
-    static QString getenv(const QString& iAttribute);
+    static QString getEnvVariable(const QString& iAttribute);
 
     /**
      * Convert a integer into a QString
