@@ -21,26 +21,23 @@
  */
 #include "skroogeakonadiresource.h"
 
-#include "settings.h"
-#include "settingsadaptor.h"
-
 #include <QtDBus/QDBusConnection>
 
-#include <kfiledialog.h>
-#include <klocalizedstring.h>
-#include <kdirwatch.h>
+#include <KFileDialog>
+#include <KLocalizedString>
+#include <KDirWatch>
 
 #include <Akonadi/EntityDisplayAttribute>
-#include <kcalcore/todo.h>
-#include <kpassworddialog.h>
+#include <KCalCore/Todo>
+#include <KPasswordDialog>
 
+#include "settings.h"
+#include "settingsadaptor.h"
 #include "skgdocumentbank.h"
 #include "skgrecurrentoperationobject.h"
 #include "skgoperationobject.h"
 #include "skgcategoryobject.h"
 
-using namespace Akonadi;
-
 skroogeakonadiResource::skroogeakonadiResource(const QString& id) : ResourceBase(id)
 {
     setObjectName(QLatin1String("SkroogeResource"));
@@ -60,27 +57,27 @@ skroogeakonadiResource::~skroogeakonadiResource() {}
 
 void skroogeakonadiResource::retrieveCollections()
 {
-    Collection c;
+    Akonadi::Collection c;
     c.setRemoteId(Settings::self()->path());
     c.setName(i18nc("Name of a collection akonadi", "Skrooge scheduled operations"));
-    c.setRights(Collection::ReadOnly);
+    c.setRights(Akonadi::Collection::ReadOnly);
     c.setParentCollection(Akonadi::Collection::root());
     c.setContentMimeTypes(QStringList() <<  QLatin1String("application/x-vnd.akonadi.calendar.todo"));
 
-    EntityDisplayAttribute* const attribute = new EntityDisplayAttribute();
+    Akonadi::EntityDisplayAttribute* const attribute = new Akonadi::EntityDisplayAttribute();
     attribute->setIconName("skrooge");
     c.addAttribute(attribute);
 
-    collectionsRetrieved(Collection::List() << c);
+    collectionsRetrieved(Akonadi::Collection::List() << c);
 
     if (!KDirWatch::self()->contains(Settings::self()->path())) KDirWatch::self()->addFile(Settings::self()->path());
 }
 
 void skroogeakonadiResource::retrieveItems(const Akonadi::Collection& collection)
 {
-    Item::List items;
+    Akonadi::Item::List items;
 
-    //Open the document
+    // Open the document
     SKGDocumentBank doc;
     SKGError err = doc.load(collection.remoteId(), Settings::self()->password(), false, true);
     IFOK(err) {
@@ -90,7 +87,7 @@ void skroogeakonadiResource::retrieveItems(const Akonadi::Collection& collection
             int nb = objs.count();
             if (nb) {
                 for (int i = 0; i < nb; ++i) {
-                    Item item(QLatin1String("application/x-vnd.akonadi.calendar.todo"));
+                    Akonadi::Item item(QLatin1String("application/x-vnd.akonadi.calendar.todo"));
                     item.setRemoteId(collection.remoteId() % ";" % SKGServices::intToString(objs.at(i).getID()));
 
                     items << item;
@@ -126,7 +123,7 @@ bool skroogeakonadiResource::retrieveItem(const Akonadi::Item& item, const QSet<
         obj.getParentOperation(ope);
         akonadiItem->setCategories(QStringList() << ope.getAttribute("t_CATEGORY"));
 
-        Item newItem(item);
+        Akonadi::Item newItem(item);
         newItem.setMimeType(QLatin1String("application/x-vnd.akonadi.calendar.todo"));
         newItem.setPayload<KCalCore::Incidence::Ptr>(akonadiItemPtr);
 
@@ -142,17 +139,19 @@ void skroogeakonadiResource::configure(WId windowId)
 {
     Q_UNUSED(windowId);
 
-    //Get the old path
+    // Get the old path
     const QString oldPath = Settings::self()->path();
     KUrl url;
     if (!oldPath.isEmpty()) url = KUrl::fromPath(oldPath);
-    else url = KUrl::fromPath(QDir::homePath());
+    else {
+        url = KUrl::fromPath(QDir::homePath());
+    }
 
     const QString newPath = KFileDialog::getOpenFileName(url, "*.skg|" % i18nc("A file format", "Skrooge document"), 0, i18nc("@title:window", "Select Skrooge document"));
 
     if (newPath.isEmpty() || oldPath == newPath) return;
 
-    //Password dialog
+    // Password dialog
     QString password;
     QPointer<KPasswordDialog> dlg = new KPasswordDialog();
     dlg->setPrompt(i18nc("Question", "If the file is protected.\nPlease enter the password."));
@@ -161,7 +160,7 @@ void skroogeakonadiResource::configure(WId windowId)
     }
     delete dlg;
 
-    //Save settings
+    // Save settings
     Settings::self()->setPath(newPath);
     Settings::self()->setPassword(password);
     Settings::self()->writeConfig();
