@@ -24,10 +24,10 @@
 #include "skgimportexportmanager.h"
 #include "skgtraces.h"
 
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
+#include <KAboutData>
+#include <KCmdLineArgs>
 #include <KDE/KLocale>
-#include <kurl.h>
+#include <KUrl>
 
 #include <QCoreApplication>
 #include <QFileInfo>
@@ -88,18 +88,20 @@ int main(int argc, char** argv)
 
     QCoreApplication app(argc, argv);
 
-    //Build list of arguments
+    // Build list of arguments
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
     SKGError err;
     if (!args->isSet("in")) err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -in option"));
-    else if (!args->isSet("out")) err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -out option"));
+    else if (!args->isSet("out")) {
+        err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -out option"));
+    }
 
-    //Initialisation of a bank document
+    // Initialisation of a bank document
     SKGDocumentBank document;
     document.setComputeBalances(false);
     IFOKDO(err, document.initialize())
     IFOK(err) {
-        //Import
+        // Import
         QString file = args->getOption("in");
         QFileInfo fi(file);
         if (fi.exists()) file = fi.absoluteFilePath();
@@ -131,7 +133,7 @@ int main(int argc, char** argv)
         }
     }
     IFOK(err) {
-        //Export
+        // Export
         QString file = args->getOption("out");
         QFileInfo fi(file);
         if (fi.exists()) file = fi.absoluteFilePath();
@@ -144,7 +146,7 @@ int main(int argc, char** argv)
             err = exp.exportFile();
         }
     }
-    args->clear(); // Free up some memory.
+    args->clear();  // Free up some memory.
 
     IFKO(err) {
         SKGTRACESUITE << err.getFullMessageWithHistorical() << endl;
