@@ -5,7 +5,7 @@ if (file_exists($file)) {
 } else {
   $fn="cache_".$_GET["code"].".csv";
   
-  if(!file_exists($fn) || (filemtime($fn) - 60*60*24) > time())
+  if(!file_exists($fn) || filemtime($fn) < time() - 60*60*24)
   {
     $page = file_get_contents("http://bitcoincharts.com/charts/chart.json?m=".$_GET["code"]."&i=Daily");
     $page = str_replace("[[", "", $page);
